Module: Google::Apis::CesV1
- Defined in:
- lib/google/apis/ces_v1.rb,
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/service.rb,
lib/google/apis/ces_v1/gem_version.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Gemini Enterprise for Customer Experience API
Defined Under Namespace
Classes: Action, ActionEntityOperation, Agent, AgentAgentToolset, AgentLlmAgent, AgentRemoteDialogflowAgent, AgentTool, AgentTransfer, AmbientSoundConfig, ApiAuthentication, ApiKeyConfig, App, AppSnapshot, AppVariableDeclaration, AppVersion, AudioProcessingConfig, AudioRecordingConfig, BargeInConfig, BatchDeleteConversationsRequest, BearerTokenConfig, BigQueryExportSettings, Blob, Callback, CancelOperationRequest, Changelog, ChannelProfile, ChannelProfilePersonaProperty, ChannelProfileWebWidgetConfig, ChannelProfileWebWidgetConfigSecuritySettings, Chunk, Citations, CitationsCitedChunk, ClientCertificateSettings, ClientFunction, CloudLoggingSettings, CodeBlock, ConnectorTool, ConnectorToolset, Conversation, ConversationLoggingSettings, ConversationTurn, CustomerEngagementSuiteService, DataStore, DataStoreConnectorConfig, DataStoreSettings, DataStoreSettingsEngine, DataStoreTool, DataStoreToolBoostSpec, DataStoreToolBoostSpecConditionBoostSpec, DataStoreToolBoostSpecConditionBoostSpecBoostControlSpec, DataStoreToolBoostSpecConditionBoostSpecBoostControlSpecControlPoint, DataStoreToolBoostSpecs, DataStoreToolDataStoreSource, DataStoreToolEngineSource, DataStoreToolGroundingConfig, DataStoreToolModalityConfig, DataStoreToolRewriterConfig, DataStoreToolSummarizationConfig, Deployment, Empty, EndSession, EndUserAuthConfig, EndUserAuthConfigOauth2AuthCodeConfig, EndUserAuthConfigOauth2JwtBearerConfig, EndpointControlPolicy, ErrorHandlingSettings, ErrorHandlingSettingsEndSessionConfig, ErrorHandlingSettingsFallbackResponseConfig, EvaluationMetricsThresholds, EvaluationMetricsThresholdsGoldenEvaluationMetricsThresholds, EvaluationMetricsThresholdsGoldenEvaluationMetricsThresholdsExpectationLevelMetricsThresholds, EvaluationMetricsThresholdsGoldenEvaluationMetricsThresholdsTurnLevelMetricsThresholds, EvaluationMetricsThresholdsToolMatchingSettings, Event, Example, ExecuteToolRequest, ExecuteToolResponse, ExperimentConfig, ExperimentConfigVersionRelease, ExperimentConfigVersionReleaseTrafficAllocation, ExportAppRequest, ExportAppResponse, ExpressionCondition, FileSearchTool, GenerateChatTokenRequest, GenerateChatTokenResponse, GoogleSearchSuggestions, GoogleSearchTool, GoogleSearchToolPromptConfig, Guardrail, GuardrailCodeCallback, GuardrailContentFilter, GuardrailLlmPolicy, GuardrailLlmPromptSecurity, GuardrailLlmPromptSecurityDefaultSecuritySettings, GuardrailModelSafety, GuardrailModelSafetySafetySetting, Image, ImportAppRequest, ImportAppRequestImportOptions, ImportAppResponse, InputAudioConfig, LanguageSettings, ListAgentsResponse, ListAppVersionsResponse, ListAppsResponse, ListChangelogsResponse, ListConversationsResponse, ListDeploymentsResponse, ListExamplesResponse, ListGuardrailsResponse, ListLocationsResponse, ListOperationsResponse, ListToolsResponse, ListToolsetsResponse, Location, LoggingSettings, McpTool, McpToolset, Message, MetricAnalysisSettings, MockConfig, MockedToolCall, ModelSettings, OAuthConfig, Omnichannel, OmnichannelIntegrationConfig, OmnichannelIntegrationConfigCesAppConfig, OmnichannelIntegrationConfigChannelConfig, OmnichannelIntegrationConfigRoutingConfig, OmnichannelIntegrationConfigSubscriberConfig, OmnichannelIntegrationConfigWhatsappConfig, OmnichannelOperationMetadata, OpenApiTool, OpenApiToolset, Operation, OperationMetadata, OutputAudioConfig, PythonCodeCondition, PythonFunction, RedactionConfig, RestoreAppVersionRequest, RetrieveToolSchemaRequest, RetrieveToolSchemaResponse, RetrieveToolsRequest, RetrieveToolsResponse, RunSessionRequest, RunSessionResponse, Schema, SecuritySettings, ServiceAccountAuthConfig, ServiceAgentIdTokenAuthConfig, ServiceDirectoryConfig, SessionConfig, SessionConfigRemoteDialogflowQueryParameters, SessionInput, SessionOutput, SessionOutputDiagnosticInfo, Span, Status, SynthesizeSpeechConfig, SystemTool, TimeZoneSettings, TlsConfig, TlsConfigCaCert, Tool, ToolCall, ToolCalls, ToolFakeConfig, ToolResponse, ToolResponses, Toolset, ToolsetTool, TransferRule, TransferRuleDeterministicTransfer, TransferRuleDisablePlannerTransfer, TriggerAction, TriggerActionGenerativeAnswer, TriggerActionRespondImmediately, TriggerActionResponse, TriggerActionTransferAgent, WebSearchQuery, WidgetTool, WidgetToolDataMapping, WidgetToolTextResponseConfig
Constant Summary collapse
- GEM_VERSION =
Version of the google-apis-ces_v1 gem
"0.6.0"- GENERATOR_VERSION =
Version of the code generator used to generate this client
"0.18.0"- REVISION =
Revision of the discovery document this client was generated from
"20260422"- VERSION =
Version of the Gemini Enterprise for Customer Experience API this client connects to. This is NOT the gem version.
'V1'- AUTH_CES =
Create, update, delete, and manage your Next Gen Agents
'https://www.googleapis.com/auth/ces'- AUTH_CLOUD_PLATFORM =
See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account.
'https://www.googleapis.com/auth/cloud-platform'