Class: Google::Apis::CesV1::AgentCard

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

AgentCard conveys key information about a remote agent. It is a trimmed version of the AgentCard defined in the A2A protocol https://a2a-protocol.org/ dev/specification/#441-agentcard

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AgentCard

Returns a new instance of AgentCard.



337
338
339
# File 'lib/google/apis/ces_v1/classes.rb', line 337

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Required. A description of the agent's domain of action/solution space. Corresponds to the JSON property description

Returns:

  • (String)


313
314
315
# File 'lib/google/apis/ces_v1/classes.rb', line 313

def description
  @description
end

#nameString

Required. A human-readable name for the agent. Corresponds to the JSON property name

Returns:

  • (String)


318
319
320
# File 'lib/google/apis/ces_v1/classes.rb', line 318

def name
  @name
end

#skillsArray<Google::Apis::CesV1::AgentSkill>

Required. Skills represent a unit of ability an agent can perform. This may somewhat abstract but represents a more focused set of actions that the agent is highly likely to succeed at. Corresponds to the JSON property skills



325
326
327
# File 'lib/google/apis/ces_v1/classes.rb', line 325

def skills
  @skills
end

#supported_interfacesArray<Google::Apis::CesV1::AgentInterface>

Required. Ordered list of supported interfaces. The first entry is preferred. Corresponds to the JSON property supportedInterfaces



330
331
332
# File 'lib/google/apis/ces_v1/classes.rb', line 330

def supported_interfaces
  @supported_interfaces
end

#versionString

Required. The version of the agent. Corresponds to the JSON property version

Returns:

  • (String)


335
336
337
# File 'lib/google/apis/ces_v1/classes.rb', line 335

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



342
343
344
345
346
347
348
# File 'lib/google/apis/ces_v1/classes.rb', line 342

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @name = args[:name] if args.key?(:name)
  @skills = args[:skills] if args.key?(:skills)
  @supported_interfaces = args[:supported_interfaces] if args.key?(:supported_interfaces)
  @version = args[:version] if args.key?(:version)
end