Class: Google::Apis::CesV1::AgentInterface

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Declares a combination of a target URL, transport and protocol version for interacting with the agent. This allows agents to expose the same functionality over multiple protocol binding mechanisms.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AgentInterface

Returns a new instance of AgentInterface.



382
383
384
# File 'lib/google/apis/ces_v1/classes.rb', line 382

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#protocol_bindingString

Required. The protocol binding supported at this URL. This is an open form string, to be easily extended for other protocol bindings. The core ones officially supported are JSONRPC, GRPC and HTTP+JSON. Corresponds to the JSON property protocolBinding

Returns:

  • (String)


362
363
364
# File 'lib/google/apis/ces_v1/classes.rb', line 362

def protocol_binding
  @protocol_binding
end

#protocol_versionString

Required. The version of the A2A protocol this interface exposes. Use the latest supported minor version per major version. Examples: "0.3", "1.0" Corresponds to the JSON property protocolVersion

Returns:

  • (String)


368
369
370
# File 'lib/google/apis/ces_v1/classes.rb', line 368

def protocol_version
  @protocol_version
end

#tenantString

Tenant ID to be used in the request when calling the agent. Corresponds to the JSON property tenant

Returns:

  • (String)


373
374
375
# File 'lib/google/apis/ces_v1/classes.rb', line 373

def tenant
  @tenant
end

#urlString

Required. The URL where this interface is available. Must be a valid absolute HTTPS URL in production. Example: "https://api.example.com/a2a/v1", "https:// grpc.example.com/a2a" Corresponds to the JSON property url

Returns:

  • (String)


380
381
382
# File 'lib/google/apis/ces_v1/classes.rb', line 380

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



387
388
389
390
391
392
# File 'lib/google/apis/ces_v1/classes.rb', line 387

def update!(**args)
  @protocol_binding = args[:protocol_binding] if args.key?(:protocol_binding)
  @protocol_version = args[:protocol_version] if args.key?(:protocol_version)
  @tenant = args[:tenant] if args.key?(:tenant)
  @url = args[:url] if args.key?(:url)
end