Class: Google::Apis::CesV1::AgentLlmAgent

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Default agent type. The agent uses instructions and callbacks specified in the agent to perform the task using a large language model.

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AgentLlmAgent

Returns a new instance of AgentLlmAgent.



302
303
304
# File 'lib/google/apis/ces_v1/classes.rb', line 302

def initialize(**args)
   update!(**args)
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



307
308
# File 'lib/google/apis/ces_v1/classes.rb', line 307

def update!(**args)
end