Class: Google::Apis::CesV1::AgentSkill
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::AgentSkill
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Represents a distinct capability or function that an agent can perform.
Instance Attribute Summary collapse
-
#description ⇒ String
Required.
-
#examples ⇒ Array<String>
Example prompts or scenarios that this skill can handle.
-
#id ⇒ String
Required.
-
#input_modes ⇒ Array<String>
The set of supported input media types for this skill, overriding the agent's defaults.
-
#name ⇒ String
Required.
-
#output_modes ⇒ Array<String>
The set of supported output media types for this skill, overriding the agent's defaults.
-
#tags ⇒ Array<String>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AgentSkill
constructor
A new instance of AgentSkill.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AgentSkill
Returns a new instance of AgentSkill.
523 524 525 |
# File 'lib/google/apis/ces_v1/classes.rb', line 523 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Required. A detailed description of the skill.
Corresponds to the JSON property description
489 490 491 |
# File 'lib/google/apis/ces_v1/classes.rb', line 489 def description @description end |
#examples ⇒ Array<String>
Example prompts or scenarios that this skill can handle.
Corresponds to the JSON property examples
494 495 496 |
# File 'lib/google/apis/ces_v1/classes.rb', line 494 def examples @examples end |
#id ⇒ String
Required. A unique identifier for the agent's skill.
Corresponds to the JSON property id
499 500 501 |
# File 'lib/google/apis/ces_v1/classes.rb', line 499 def id @id end |
#input_modes ⇒ Array<String>
The set of supported input media types for this skill, overriding the agent's
defaults.
Corresponds to the JSON property inputModes
505 506 507 |
# File 'lib/google/apis/ces_v1/classes.rb', line 505 def input_modes @input_modes end |
#name ⇒ String
Required. A human-readable name for the skill.
Corresponds to the JSON property name
510 511 512 |
# File 'lib/google/apis/ces_v1/classes.rb', line 510 def name @name end |
#output_modes ⇒ Array<String>
The set of supported output media types for this skill, overriding the agent's
defaults.
Corresponds to the JSON property outputModes
516 517 518 |
# File 'lib/google/apis/ces_v1/classes.rb', line 516 def output_modes @output_modes end |
#tags ⇒ Array<String>
Required. A set of keywords describing the skill's capabilities.
Corresponds to the JSON property tags
521 522 523 |
# File 'lib/google/apis/ces_v1/classes.rb', line 521 def @tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
528 529 530 531 532 533 534 535 536 |
# File 'lib/google/apis/ces_v1/classes.rb', line 528 def update!(**args) @description = args[:description] if args.key?(:description) @examples = args[:examples] if args.key?(:examples) @id = args[:id] if args.key?(:id) @input_modes = args[:input_modes] if args.key?(:input_modes) @name = args[:name] if args.key?(:name) @output_modes = args[:output_modes] if args.key?(:output_modes) @tags = args[:tags] if args.key?(:tags) end |