Class: Google::Apis::CesV1::AgentTransfer

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Represents an event indicating the transfer of a conversation to a different agent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AgentTransfer

Returns a new instance of AgentTransfer.



433
434
435
# File 'lib/google/apis/ces_v1/classes.rb', line 433

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Output only. Display name of the agent. Corresponds to the JSON property displayName

Returns:

  • (String)


424
425
426
# File 'lib/google/apis/ces_v1/classes.rb', line 424

def display_name
  @display_name
end

#target_agentString

Required. The agent to which the conversation is being transferred. The agent will handle the conversation from this point forward. Format: projects/ project/locations/location/apps/app/agents/agent` Corresponds to the JSON propertytargetAgent`

Returns:

  • (String)


431
432
433
# File 'lib/google/apis/ces_v1/classes.rb', line 431

def target_agent
  @target_agent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



438
439
440
441
# File 'lib/google/apis/ces_v1/classes.rb', line 438

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @target_agent = args[:target_agent] if args.key?(:target_agent)
end