Class: Google::Apis::CesV1::App

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

An app serves as a top-level container for a group of agents, including the root agent and its sub-agents, along with their associated configurations. These agents work together to achieve specific goals within the app's context.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ App

Returns a new instance of App.



897
898
899
# File 'lib/google/apis/ces_v1/classes.rb', line 897

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audio_processing_configGoogle::Apis::CesV1::AudioProcessingConfig

Configuration for how the input and output audio should be processed and delivered. Corresponds to the JSON property audioProcessingConfig



748
749
750
# File 'lib/google/apis/ces_v1/classes.rb', line 748

def audio_processing_config
  @audio_processing_config
end

#client_certificate_settingsGoogle::Apis::CesV1::ClientCertificateSettings

Settings for custom client certificates. Corresponds to the JSON property clientCertificateSettings



753
754
755
# File 'lib/google/apis/ces_v1/classes.rb', line 753

def client_certificate_settings
  @client_certificate_settings
end

#create_timeString

Output only. Timestamp when the app was created. Corresponds to the JSON property createTime

Returns:

  • (String)


758
759
760
# File 'lib/google/apis/ces_v1/classes.rb', line 758

def create_time
  @create_time
end

#data_store_settingsGoogle::Apis::CesV1::DataStoreSettings

Data store related settings for the app. Corresponds to the JSON property dataStoreSettings



763
764
765
# File 'lib/google/apis/ces_v1/classes.rb', line 763

def data_store_settings
  @data_store_settings
end

#default_channel_profileGoogle::Apis::CesV1::ChannelProfile

A ChannelProfile configures the agent's behavior for a specific communication channel, such as web UI or telephony. Corresponds to the JSON property defaultChannelProfile



769
770
771
# File 'lib/google/apis/ces_v1/classes.rb', line 769

def default_channel_profile
  @default_channel_profile
end

#deployment_countFixnum

Output only. Number of deployments in the app. Corresponds to the JSON property deploymentCount

Returns:

  • (Fixnum)


774
775
776
# File 'lib/google/apis/ces_v1/classes.rb', line 774

def deployment_count
  @deployment_count
end

#descriptionString

Optional. Human-readable description of the app. Corresponds to the JSON property description

Returns:

  • (String)


779
780
781
# File 'lib/google/apis/ces_v1/classes.rb', line 779

def description
  @description
end

#display_nameString

Required. Display name of the app. Corresponds to the JSON property displayName

Returns:

  • (String)


784
785
786
# File 'lib/google/apis/ces_v1/classes.rb', line 784

def display_name
  @display_name
end

#error_handling_settingsGoogle::Apis::CesV1::ErrorHandlingSettings

Settings to describe how errors should be handled in the app. Corresponds to the JSON property errorHandlingSettings



789
790
791
# File 'lib/google/apis/ces_v1/classes.rb', line 789

def error_handling_settings
  @error_handling_settings
end

#etagString

Output only. Etag used to ensure the object hasn't changed during a read- modify-write operation. If the etag is empty, the update will overwrite any concurrent changes. Corresponds to the JSON property etag

Returns:

  • (String)


796
797
798
# File 'lib/google/apis/ces_v1/classes.rb', line 796

def etag
  @etag
end

#evaluation_metrics_thresholdsGoogle::Apis::CesV1::EvaluationMetricsThresholds

Threshold settings for metrics in an Evaluation. Corresponds to the JSON property evaluationMetricsThresholds



801
802
803
# File 'lib/google/apis/ces_v1/classes.rb', line 801

def evaluation_metrics_thresholds
  @evaluation_metrics_thresholds
end

#global_instructionString

Optional. Instructions for all the agents in the app. You can use this instruction to set up a stable identity or personality across all the agents. Corresponds to the JSON property globalInstruction

Returns:

  • (String)


807
808
809
# File 'lib/google/apis/ces_v1/classes.rb', line 807

def global_instruction
  @global_instruction
end

#guardrailsArray<String>

Optional. List of guardrails for the app. Format: projects/project/ locations/location/apps/app/guardrails/guardrail` Corresponds to the JSON propertyguardrails`

Returns:

  • (Array<String>)


813
814
815
# File 'lib/google/apis/ces_v1/classes.rb', line 813

def guardrails
  @guardrails
end

#language_settingsGoogle::Apis::CesV1::LanguageSettings

Language settings of the app. Corresponds to the JSON property languageSettings



818
819
820
# File 'lib/google/apis/ces_v1/classes.rb', line 818

def language_settings
  @language_settings
end

#lockedBoolean Also known as: locked?

Optional. Indicates whether the app is locked for changes. If the app is locked, modifications to the app resources will be rejected. Corresponds to the JSON property locked

Returns:

  • (Boolean)


824
825
826
# File 'lib/google/apis/ces_v1/classes.rb', line 824

def locked
  @locked
end

#logging_settingsGoogle::Apis::CesV1::LoggingSettings

Settings to describe the logging behaviors for the app. Corresponds to the JSON property loggingSettings



830
831
832
# File 'lib/google/apis/ces_v1/classes.rb', line 830

def logging_settings
  @logging_settings
end

#metadataHash<String,String>

Optional. Metadata about the app. This field can be used to store additional information relevant to the app's details or intended usages. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,String>)


836
837
838
# File 'lib/google/apis/ces_v1/classes.rb', line 836

def 
  @metadata
end

#model_settingsGoogle::Apis::CesV1::ModelSettings

Model settings contains various configurations for the LLM model. Corresponds to the JSON property modelSettings



841
842
843
# File 'lib/google/apis/ces_v1/classes.rb', line 841

def model_settings
  @model_settings
end

#nameString

Identifier. The unique identifier of the app. Format: projects/project/ locations/location/apps/app` Corresponds to the JSON propertyname`

Returns:

  • (String)


847
848
849
# File 'lib/google/apis/ces_v1/classes.rb', line 847

def name
  @name
end

#pinnedBoolean Also known as: pinned?

Optional. Whether the app is pinned in the app list. Corresponds to the JSON property pinned

Returns:

  • (Boolean)


852
853
854
# File 'lib/google/apis/ces_v1/classes.rb', line 852

def pinned
  @pinned
end

#predefined_variable_declarationsArray<Google::Apis::CesV1::AppVariableDeclaration>

Output only. The declarations of predefined variables for the app. Corresponds to the JSON property predefinedVariableDeclarations



858
859
860
# File 'lib/google/apis/ces_v1/classes.rb', line 858

def predefined_variable_declarations
  @predefined_variable_declarations
end

#root_agentString

Optional. The root agent is the entry point of the app. Format: projects/ project/locations/location/apps/app/agents/agent` Corresponds to the JSON propertyrootAgent`

Returns:

  • (String)


864
865
866
# File 'lib/google/apis/ces_v1/classes.rb', line 864

def root_agent
  @root_agent
end

#time_zone_settingsGoogle::Apis::CesV1::TimeZoneSettings

TimeZone settings of the app. Corresponds to the JSON property timeZoneSettings



869
870
871
# File 'lib/google/apis/ces_v1/classes.rb', line 869

def time_zone_settings
  @time_zone_settings
end

#tool_execution_modeString

Optional. The tool execution mode for the app. If not provided, will default to PARALLEL. Corresponds to the JSON property toolExecutionMode

Returns:

  • (String)


875
876
877
# File 'lib/google/apis/ces_v1/classes.rb', line 875

def tool_execution_mode
  @tool_execution_mode
end

#update_timeString

Output only. Timestamp when the app was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


880
881
882
# File 'lib/google/apis/ces_v1/classes.rb', line 880

def update_time
  @update_time
end

#validation_errorsArray<String>

Output only. Misconfigurations or warnings in the app. Corresponds to the JSON property validationErrors

Returns:

  • (Array<String>)


885
886
887
# File 'lib/google/apis/ces_v1/classes.rb', line 885

def validation_errors
  @validation_errors
end

#variable_declarationsArray<Google::Apis::CesV1::AppVariableDeclaration>

Optional. The declarations of the variables. Corresponds to the JSON property variableDeclarations



890
891
892
# File 'lib/google/apis/ces_v1/classes.rb', line 890

def variable_declarations
  @variable_declarations
end

#vpc_sc_settingsGoogle::Apis::CesV1::VpcScSettings

VPC-SC settings for the app. Corresponds to the JSON property vpcScSettings



895
896
897
# File 'lib/google/apis/ces_v1/classes.rb', line 895

def vpc_sc_settings
  @vpc_sc_settings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



902
903
904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
# File 'lib/google/apis/ces_v1/classes.rb', line 902

def update!(**args)
  @audio_processing_config = args[:audio_processing_config] if args.key?(:audio_processing_config)
  @client_certificate_settings = args[:client_certificate_settings] if args.key?(:client_certificate_settings)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_store_settings = args[:data_store_settings] if args.key?(:data_store_settings)
  @default_channel_profile = args[:default_channel_profile] if args.key?(:default_channel_profile)
  @deployment_count = args[:deployment_count] if args.key?(:deployment_count)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @error_handling_settings = args[:error_handling_settings] if args.key?(:error_handling_settings)
  @etag = args[:etag] if args.key?(:etag)
  @evaluation_metrics_thresholds = args[:evaluation_metrics_thresholds] if args.key?(:evaluation_metrics_thresholds)
  @global_instruction = args[:global_instruction] if args.key?(:global_instruction)
  @guardrails = args[:guardrails] if args.key?(:guardrails)
  @language_settings = args[:language_settings] if args.key?(:language_settings)
  @locked = args[:locked] if args.key?(:locked)
  @logging_settings = args[:logging_settings] if args.key?(:logging_settings)
  @metadata = args[:metadata] if args.key?(:metadata)
  @model_settings = args[:model_settings] if args.key?(:model_settings)
  @name = args[:name] if args.key?(:name)
  @pinned = args[:pinned] if args.key?(:pinned)
  @predefined_variable_declarations = args[:predefined_variable_declarations] if args.key?(:predefined_variable_declarations)
  @root_agent = args[:root_agent] if args.key?(:root_agent)
  @time_zone_settings = args[:time_zone_settings] if args.key?(:time_zone_settings)
  @tool_execution_mode = args[:tool_execution_mode] if args.key?(:tool_execution_mode)
  @update_time = args[:update_time] if args.key?(:update_time)
  @validation_errors = args[:validation_errors] if args.key?(:validation_errors)
  @variable_declarations = args[:variable_declarations] if args.key?(:variable_declarations)
  @vpc_sc_settings = args[:vpc_sc_settings] if args.key?(:vpc_sc_settings)
end