Class: Google::Apis::CesV1::AppSnapshot
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::AppSnapshot
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
A snapshot of the app.
Instance Attribute Summary collapse
-
#agents ⇒ Array<Google::Apis::CesV1::Agent>
Optional.
-
#app ⇒ Google::Apis::CesV1::App
An app serves as a top-level container for a group of agents, including the root agent and its sub-agents, along with their associated configurations.
-
#examples ⇒ Array<Google::Apis::CesV1::Example>
Optional.
-
#guardrails ⇒ Array<Google::Apis::CesV1::Guardrail>
Optional.
-
#tools ⇒ Array<Google::Apis::CesV1::Tool>
Optional.
-
#toolsets ⇒ Array<Google::Apis::CesV1::Toolset>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AppSnapshot
constructor
A new instance of AppSnapshot.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AppSnapshot
Returns a new instance of AppSnapshot.
970 971 972 |
# File 'lib/google/apis/ces_v1/classes.rb', line 970 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agents ⇒ Array<Google::Apis::CesV1::Agent>
Optional. List of agents in the app.
Corresponds to the JSON property agents
941 942 943 |
# File 'lib/google/apis/ces_v1/classes.rb', line 941 def agents @agents end |
#app ⇒ Google::Apis::CesV1::App
An app serves as a top-level container for a group of agents, including the
root agent and its sub-agents, along with their associated configurations.
These agents work together to achieve specific goals within the app's context.
Corresponds to the JSON property app
948 949 950 |
# File 'lib/google/apis/ces_v1/classes.rb', line 948 def app @app end |
#examples ⇒ Array<Google::Apis::CesV1::Example>
Optional. List of examples in the app.
Corresponds to the JSON property examples
953 954 955 |
# File 'lib/google/apis/ces_v1/classes.rb', line 953 def examples @examples end |
#guardrails ⇒ Array<Google::Apis::CesV1::Guardrail>
Optional. List of guardrails in the app.
Corresponds to the JSON property guardrails
958 959 960 |
# File 'lib/google/apis/ces_v1/classes.rb', line 958 def guardrails @guardrails end |
#tools ⇒ Array<Google::Apis::CesV1::Tool>
Optional. List of tools in the app.
Corresponds to the JSON property tools
963 964 965 |
# File 'lib/google/apis/ces_v1/classes.rb', line 963 def tools @tools end |
#toolsets ⇒ Array<Google::Apis::CesV1::Toolset>
Optional. List of toolsets in the app.
Corresponds to the JSON property toolsets
968 969 970 |
# File 'lib/google/apis/ces_v1/classes.rb', line 968 def toolsets @toolsets end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
975 976 977 978 979 980 981 982 |
# File 'lib/google/apis/ces_v1/classes.rb', line 975 def update!(**args) @agents = args[:agents] if args.key?(:agents) @app = args[:app] if args.key?(:app) @examples = args[:examples] if args.key?(:examples) @guardrails = args[:guardrails] if args.key?(:guardrails) @tools = args[:tools] if args.key?(:tools) @toolsets = args[:toolsets] if args.key?(:toolsets) end |