Class: Google::Apis::CesV1::AppVersion
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::AppVersion
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
In Customer Engagement Suite (CES), an app version is a snapshot of the app at a specific point in time. It is immutable and cannot be modified once created.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#creator ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Optional.
-
#etag ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#snapshot ⇒ Google::Apis::CesV1::AppSnapshot
A snapshot of the app.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AppVersion
constructor
A new instance of AppVersion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AppVersion
Returns a new instance of AppVersion.
1060 1061 1062 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1060 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when the app version was created.
Corresponds to the JSON property createTime
1025 1026 1027 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1025 def create_time @create_time end |
#creator ⇒ String
Output only. Email of the user who created the app version.
Corresponds to the JSON property creator
1030 1031 1032 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1030 def creator @creator end |
#description ⇒ String
Optional. The description of the app version.
Corresponds to the JSON property description
1035 1036 1037 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1035 def description @description end |
#display_name ⇒ String
Optional. The display name of the app version.
Corresponds to the JSON property displayName
1040 1041 1042 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1040 def display_name @display_name end |
#etag ⇒ String
Output only. Etag used to ensure the object hasn't changed during a read-
modify-write operation. If the etag is empty, the update will overwrite any
concurrent changes.
Corresponds to the JSON property etag
1047 1048 1049 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1047 def etag @etag end |
#name ⇒ String
Identifier. The unique identifier of the app version. Format: projects/
project/locations/location/apps/app/versions/version`
Corresponds to the JSON propertyname`
1053 1054 1055 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1053 def name @name end |
#snapshot ⇒ Google::Apis::CesV1::AppSnapshot
A snapshot of the app.
Corresponds to the JSON property snapshot
1058 1059 1060 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1058 def snapshot @snapshot end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1065 1066 1067 1068 1069 1070 1071 1072 1073 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1065 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @creator = args[:creator] if args.key?(:creator) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @name = args[:name] if args.key?(:name) @snapshot = args[:snapshot] if args.key?(:snapshot) end |