Class: Google::Apis::CesV1::Callback

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

A callback defines the custom logic to be executed at various stages of agent interaction.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Callback

Returns a new instance of Callback.



1321
1322
1323
# File 'lib/google/apis/ces_v1/classes.rb', line 1321

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Optional. Human-readable description of the callback. Corresponds to the JSON property description

Returns:

  • (String)


1296
1297
1298
# File 'lib/google/apis/ces_v1/classes.rb', line 1296

def description
  @description
end

#disabledBoolean Also known as: disabled?

Optional. Whether the callback is disabled. Disabled callbacks are ignored by the agent. Corresponds to the JSON property disabled

Returns:

  • (Boolean)


1302
1303
1304
# File 'lib/google/apis/ces_v1/classes.rb', line 1302

def disabled
  @disabled
end

#proactive_execution_enabledBoolean Also known as: proactive_execution_enabled?

Optional. If enabled, the callback will also be executed on intermediate model outputs. This setting only affects after model callback. *ENABLE WITH CAUTION *. Typically after model callback only needs to be executed after receiving all model responses. Enabling proactive execution may have negative implication on the execution cost and latency, and should only be enabled in rare situations. Corresponds to the JSON property proactiveExecutionEnabled

Returns:

  • (Boolean)


1313
1314
1315
# File 'lib/google/apis/ces_v1/classes.rb', line 1313

def proactive_execution_enabled
  @proactive_execution_enabled
end

#python_codeString

Required. The python code to execute for the callback. Corresponds to the JSON property pythonCode

Returns:

  • (String)


1319
1320
1321
# File 'lib/google/apis/ces_v1/classes.rb', line 1319

def python_code
  @python_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1326
1327
1328
1329
1330
1331
# File 'lib/google/apis/ces_v1/classes.rb', line 1326

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @disabled = args[:disabled] if args.key?(:disabled)
  @proactive_execution_enabled = args[:proactive_execution_enabled] if args.key?(:proactive_execution_enabled)
  @python_code = args[:python_code] if args.key?(:python_code)
end