Class: Google::Apis::CesV1::Changelog

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Changelogs represent a change made to the app or to an resource within the app.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Changelog

Returns a new instance of Changelog.



1414
1415
1416
# File 'lib/google/apis/ces_v1/classes.rb', line 1414

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionString

Output only. The action that was performed on the resource. Corresponds to the JSON property action

Returns:

  • (String)


1354
1355
1356
# File 'lib/google/apis/ces_v1/classes.rb', line 1354

def action
  @action
end

#authorString

Output only. Email address of the change author. Corresponds to the JSON property author

Returns:

  • (String)


1359
1360
1361
# File 'lib/google/apis/ces_v1/classes.rb', line 1359

def author
  @author
end

#create_timeString

Output only. The time when the change was made. Corresponds to the JSON property createTime

Returns:

  • (String)


1364
1365
1366
# File 'lib/google/apis/ces_v1/classes.rb', line 1364

def create_time
  @create_time
end

#dependent_resourcesArray<Hash<String,Object>>

Output only. The dependent resources that were changed. Corresponds to the JSON property dependentResources

Returns:

  • (Array<Hash<String,Object>>)


1369
1370
1371
# File 'lib/google/apis/ces_v1/classes.rb', line 1369

def dependent_resources
  @dependent_resources
end

#descriptionString

Output only. Description of the change. which typically captures the changed fields in the resource. Corresponds to the JSON property description

Returns:

  • (String)


1375
1376
1377
# File 'lib/google/apis/ces_v1/classes.rb', line 1375

def description
  @description
end

#display_nameString

Output only. Display name of the change. It typically should be the display name of the resource that was changed. Corresponds to the JSON property displayName

Returns:

  • (String)


1381
1382
1383
# File 'lib/google/apis/ces_v1/classes.rb', line 1381

def display_name
  @display_name
end

#nameString

Identifier. The unique identifier of the changelog. Format: projects/project /locations/location/apps/app/changelogs/changelog` Corresponds to the JSON propertyname`

Returns:

  • (String)


1387
1388
1389
# File 'lib/google/apis/ces_v1/classes.rb', line 1387

def name
  @name
end

#new_resourceHash<String,Object>

Output only. The new resource after the change. Corresponds to the JSON property newResource

Returns:

  • (Hash<String,Object>)


1392
1393
1394
# File 'lib/google/apis/ces_v1/classes.rb', line 1392

def new_resource
  @new_resource
end

#original_resourceHash<String,Object>

Output only. The original resource before the change. Corresponds to the JSON property originalResource

Returns:

  • (Hash<String,Object>)


1397
1398
1399
# File 'lib/google/apis/ces_v1/classes.rb', line 1397

def original_resource
  @original_resource
end

#resourceString

Output only. The resource that was changed. Corresponds to the JSON property resource

Returns:

  • (String)


1402
1403
1404
# File 'lib/google/apis/ces_v1/classes.rb', line 1402

def resource
  @resource
end

#resource_typeString

Output only. The type of the resource that was changed. Corresponds to the JSON property resourceType

Returns:

  • (String)


1407
1408
1409
# File 'lib/google/apis/ces_v1/classes.rb', line 1407

def resource_type
  @resource_type
end

#sequence_numberFixnum

Output only. The monotonically increasing sequence number of the changelog. Corresponds to the JSON property sequenceNumber

Returns:

  • (Fixnum)


1412
1413
1414
# File 'lib/google/apis/ces_v1/classes.rb', line 1412

def sequence_number
  @sequence_number
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
# File 'lib/google/apis/ces_v1/classes.rb', line 1419

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @author = args[:author] if args.key?(:author)
  @create_time = args[:create_time] if args.key?(:create_time)
  @dependent_resources = args[:dependent_resources] if args.key?(:dependent_resources)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @new_resource = args[:new_resource] if args.key?(:new_resource)
  @original_resource = args[:original_resource] if args.key?(:original_resource)
  @resource = args[:resource] if args.key?(:resource)
  @resource_type = args[:resource_type] if args.key?(:resource_type)
  @sequence_number = args[:sequence_number] if args.key?(:sequence_number)
end