Class: Google::Apis::CesV1::ChannelProfileWebWidgetConfigSecuritySettings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Security settings for the web widget.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ChannelProfileWebWidgetConfigSecuritySettings

Returns a new instance of ChannelProfileWebWidgetConfigSecuritySettings.



1629
1630
1631
# File 'lib/google/apis/ces_v1/classes.rb', line 1629

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowed_originsArray<String>

Optional. The origins that are allowed to host the web widget. An origin is defined by RFC 6454. If empty, all origins are allowed. A maximum of 100 origins is allowed. Example: "https://example.com" Corresponds to the JSON property allowedOrigins

Returns:

  • (Array<String>)


1602
1603
1604
# File 'lib/google/apis/ces_v1/classes.rb', line 1602

def allowed_origins
  @allowed_origins
end

#enable_origin_checkBoolean Also known as: enable_origin_check?

Optional. Indicates whether origin check for the web widget is enabled. If true, the web widget will check the origin of the website that loads the web widget and only allow it to be loaded in the same origin or any of the allowed origins. Corresponds to the JSON property enableOriginCheck

Returns:

  • (Boolean)


1610
1611
1612
# File 'lib/google/apis/ces_v1/classes.rb', line 1610

def enable_origin_check
  @enable_origin_check
end

#enable_public_accessBoolean Also known as: enable_public_access?

Optional. Indicates whether public access to the web widget is enabled. If true, the web widget will be publicly accessible. If false, the web widget must be integrated with your own authentication and authorization system to return valid credentials for accessing the CES agent. Corresponds to the JSON property enablePublicAccess

Returns:

  • (Boolean)


1619
1620
1621
# File 'lib/google/apis/ces_v1/classes.rb', line 1619

def enable_public_access
  @enable_public_access
end

#enable_recaptchaBoolean Also known as: enable_recaptcha?

Optional. Indicates whether reCAPTCHA verification for the web widget is enabled. Corresponds to the JSON property enableRecaptcha

Returns:

  • (Boolean)


1626
1627
1628
# File 'lib/google/apis/ces_v1/classes.rb', line 1626

def enable_recaptcha
  @enable_recaptcha
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1634
1635
1636
1637
1638
1639
# File 'lib/google/apis/ces_v1/classes.rb', line 1634

def update!(**args)
  @allowed_origins = args[:allowed_origins] if args.key?(:allowed_origins)
  @enable_origin_check = args[:enable_origin_check] if args.key?(:enable_origin_check)
  @enable_public_access = args[:enable_public_access] if args.key?(:enable_public_access)
  @enable_recaptcha = args[:enable_recaptcha] if args.key?(:enable_recaptcha)
end