Class: Google::Apis::CesV1::CitationsCitedChunk
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::CitationsCitedChunk
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Piece of cited information.
Instance Attribute Summary collapse
-
#requires_attribution ⇒ Boolean
(also: #requires_attribution?)
Whether this citation requires attribution to be shown to the end users.
-
#text ⇒ String
Text used for citation.
-
#title ⇒ String
Title of the cited document.
-
#uri ⇒ String
URI used for citation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CitationsCitedChunk
constructor
A new instance of CitationsCitedChunk.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CitationsCitedChunk
Returns a new instance of CitationsCitedChunk.
1811 1812 1813 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1811 def initialize(**args) update!(**args) end |
Instance Attribute Details
#requires_attribution ⇒ Boolean Also known as: requires_attribution?
Whether this citation requires attribution to be shown to the end users.
Corresponds to the JSON property requiresAttribution
1793 1794 1795 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1793 def requires_attribution @requires_attribution end |
#text ⇒ String
Text used for citation.
Corresponds to the JSON property text
1799 1800 1801 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1799 def text @text end |
#title ⇒ String
Title of the cited document.
Corresponds to the JSON property title
1804 1805 1806 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1804 def title @title end |
#uri ⇒ String
URI used for citation.
Corresponds to the JSON property uri
1809 1810 1811 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1809 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1816 1817 1818 1819 1820 1821 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1816 def update!(**args) @requires_attribution = args[:requires_attribution] if args.key?(:requires_attribution) @text = args[:text] if args.key?(:text) @title = args[:title] if args.key?(:title) @uri = args[:uri] if args.key?(:uri) end |