Class: Google::Apis::CesV1::ClientCertificateSettings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Settings for custom client certificates.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ClientCertificateSettings

Returns a new instance of ClientCertificateSettings.



1577
1578
1579
# File 'lib/google/apis/ces_v1/classes.rb', line 1577

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#passphraseString

Optional. The name of the SecretManager secret version resource storing the passphrase to decrypt the private key. Should be left unset if the private key is not encrypted. Format: projects/project/secrets/secret/versions/ version` Corresponds to the JSON propertypassphrase`

Returns:

  • (String)


1562
1563
1564
# File 'lib/google/apis/ces_v1/classes.rb', line 1562

def passphrase
  @passphrase
end

#private_keyString

Required. The name of the SecretManager secret version resource storing the private key encoded in PEM format. Format: projects/project/secrets/secret /versions/version` Corresponds to the JSON propertyprivateKey`

Returns:

  • (String)


1569
1570
1571
# File 'lib/google/apis/ces_v1/classes.rb', line 1569

def private_key
  @private_key
end

#tls_certificateString

Required. The TLS certificate encoded in PEM format. This string must include the begin header and end footer lines. Corresponds to the JSON property tlsCertificate

Returns:

  • (String)


1575
1576
1577
# File 'lib/google/apis/ces_v1/classes.rb', line 1575

def tls_certificate
  @tls_certificate
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1582
1583
1584
1585
1586
# File 'lib/google/apis/ces_v1/classes.rb', line 1582

def update!(**args)
  @passphrase = args[:passphrase] if args.key?(:passphrase)
  @private_key = args[:private_key] if args.key?(:private_key)
  @tls_certificate = args[:tls_certificate] if args.key?(:tls_certificate)
end