Class: Google::Apis::CesV1::ConversationLoggingSettings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Settings to describe the conversation logging behaviors for the app.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConversationLoggingSettings

Returns a new instance of ConversationLoggingSettings.



2146
2147
2148
# File 'lib/google/apis/ces_v1/classes.rb', line 2146

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disable_conversation_loggingBoolean Also known as: disable_conversation_logging?

Optional. Whether to disable conversation logging for the sessions. Corresponds to the JSON property disableConversationLogging

Returns:

  • (Boolean)


2137
2138
2139
# File 'lib/google/apis/ces_v1/classes.rb', line 2137

def disable_conversation_logging
  @disable_conversation_logging
end

#retention_windowString

Optional. Controls the retention window for the conversation. If not set, the conversation will be retained for 365 days. Corresponds to the JSON property retentionWindow

Returns:

  • (String)


2144
2145
2146
# File 'lib/google/apis/ces_v1/classes.rb', line 2144

def retention_window
  @retention_window
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2151
2152
2153
2154
# File 'lib/google/apis/ces_v1/classes.rb', line 2151

def update!(**args)
  @disable_conversation_logging = args[:disable_conversation_logging] if args.key?(:disable_conversation_logging)
  @retention_window = args[:retention_window] if args.key?(:retention_window)
end