Class: Google::Apis::CesV1::DataStore

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

A DataStore resource in Vertex AI Search.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DataStore

Returns a new instance of DataStore.



2243
2244
2245
# File 'lib/google/apis/ces_v1/classes.rb', line 2243

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connector_configGoogle::Apis::CesV1::DataStoreConnectorConfig

The connector config for the data store connection. Corresponds to the JSON property connectorConfig



2213
2214
2215
# File 'lib/google/apis/ces_v1/classes.rb', line 2213

def connector_config
  @connector_config
end

#create_timeString

Output only. Timestamp when the data store was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2218
2219
2220
# File 'lib/google/apis/ces_v1/classes.rb', line 2218

def create_time
  @create_time
end

#display_nameString

Output only. The display name of the data store. Corresponds to the JSON property displayName

Returns:

  • (String)


2223
2224
2225
# File 'lib/google/apis/ces_v1/classes.rb', line 2223

def display_name
  @display_name
end

#document_processing_modeString

Output only. The document processing mode for the data store connection. Only set for PUBLIC_WEB and UNSTRUCTURED data stores. Corresponds to the JSON property documentProcessingMode

Returns:

  • (String)


2229
2230
2231
# File 'lib/google/apis/ces_v1/classes.rb', line 2229

def document_processing_mode
  @document_processing_mode
end

#nameString

Required. Full resource name of the DataStore. Format: projects/project/ locations/location/collections/collection/dataStores/dataStore` Corresponds to the JSON propertyname`

Returns:

  • (String)


2235
2236
2237
# File 'lib/google/apis/ces_v1/classes.rb', line 2235

def name
  @name
end

#typeString

Output only. The type of the data store. This field is readonly and populated by the server. Corresponds to the JSON property type

Returns:

  • (String)


2241
2242
2243
# File 'lib/google/apis/ces_v1/classes.rb', line 2241

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2248
2249
2250
2251
2252
2253
2254
2255
# File 'lib/google/apis/ces_v1/classes.rb', line 2248

def update!(**args)
  @connector_config = args[:connector_config] if args.key?(:connector_config)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @document_processing_mode = args[:document_processing_mode] if args.key?(:document_processing_mode)
  @name = args[:name] if args.key?(:name)
  @type = args[:type] if args.key?(:type)
end