Class: Google::Apis::CesV1::DataStoreConnectorConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

The connector config for the data store connection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DataStoreConnectorConfig

Returns a new instance of DataStoreConnectorConfig.



2255
2256
2257
# File 'lib/google/apis/ces_v1/classes.rb', line 2255

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#collectionString

Resource name of the collection the data store belongs to. Corresponds to the JSON property collection

Returns:

  • (String)


2242
2243
2244
# File 'lib/google/apis/ces_v1/classes.rb', line 2242

def collection
  @collection
end

#collection_display_nameString

Display name of the collection the data store belongs to. Corresponds to the JSON property collectionDisplayName

Returns:

  • (String)


2247
2248
2249
# File 'lib/google/apis/ces_v1/classes.rb', line 2247

def collection_display_name
  @collection_display_name
end

#data_sourceString

The name of the data source. Example: salesforce, jira, confluence, bigquery. Corresponds to the JSON property dataSource

Returns:

  • (String)


2253
2254
2255
# File 'lib/google/apis/ces_v1/classes.rb', line 2253

def data_source
  @data_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2260
2261
2262
2263
2264
# File 'lib/google/apis/ces_v1/classes.rb', line 2260

def update!(**args)
  @collection = args[:collection] if args.key?(:collection)
  @collection_display_name = args[:collection_display_name] if args.key?(:collection_display_name)
  @data_source = args[:data_source] if args.key?(:data_source)
end