Class: Google::Apis::CesV1::EndSession

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Indicates the session has terminated, due to either successful completion (e.g. user says "Good bye!" ) or an agent escalation. The agent will not process any further inputs after session is terminated and the client should half- close and disconnect after receiving all remaining responses from the agent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EndSession

Returns a new instance of EndSession.



2725
2726
2727
# File 'lib/google/apis/ces_v1/classes.rb', line 2725

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#metadataHash<String,Object>

Optional. Provides additional information about the end session signal, such as the reason for ending the session. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,Object>)


2723
2724
2725
# File 'lib/google/apis/ces_v1/classes.rb', line 2723

def 
  @metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2730
2731
2732
# File 'lib/google/apis/ces_v1/classes.rb', line 2730

def update!(**args)
  @metadata = args[:metadata] if args.key?(:metadata)
end