Class: Google::Apis::CesV1::EndpointControlPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Defines project/location level endpoint control policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EndpointControlPolicy

Returns a new instance of EndpointControlPolicy.



2999
3000
3001
# File 'lib/google/apis/ces_v1/classes.rb', line 2999

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowed_originsArray<String>

Optional. The allowed HTTP(s) origins that tools in the App are able to directly call. The enforcement depends on the value of enforcement_scope and the VPC-SC status of the project. If a port number is not provided, all ports will be allowed. Otherwise, the port number must match exactly. For example, " https://example.com" will match "https://example.com:443" and any other port. " https://example.com:443" will only match "https://example.com:443". Corresponds to the JSON property allowedOrigins

Returns:

  • (Array<String>)


2992
2993
2994
# File 'lib/google/apis/ces_v1/classes.rb', line 2992

def allowed_origins
  @allowed_origins
end

#enforcement_scopeString

Optional. The scope in which this policy's allowed_origins list is enforced. Corresponds to the JSON property enforcementScope

Returns:

  • (String)


2997
2998
2999
# File 'lib/google/apis/ces_v1/classes.rb', line 2997

def enforcement_scope
  @enforcement_scope
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3004
3005
3006
3007
# File 'lib/google/apis/ces_v1/classes.rb', line 3004

def update!(**args)
  @allowed_origins = args[:allowed_origins] if args.key?(:allowed_origins)
  @enforcement_scope = args[:enforcement_scope] if args.key?(:enforcement_scope)
end