Class: Google::Apis::CesV1::ExecuteToolResponse
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::ExecuteToolResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Response message for ToolService.ExecuteTool.
Instance Attribute Summary collapse
-
#citations ⇒ Google::Apis::CesV1::Citations
Citations associated with the agent response.
-
#google_search_suggestions ⇒ Google::Apis::CesV1::GoogleSearchSuggestions
Search suggestions from Google Search Tool.
-
#response ⇒ Hash<String,Object>
The tool execution result in JSON object format.
-
#tool ⇒ String
The name of the tool that got executed.
-
#toolset_tool ⇒ Google::Apis::CesV1::ToolsetTool
A tool that is created from a toolset.
-
#variables ⇒ Hash<String,Object>
The variable values at the end of the tool execution.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExecuteToolResponse
constructor
A new instance of ExecuteToolResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExecuteToolResponse
Returns a new instance of ExecuteToolResponse.
3434 3435 3436 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3434 def initialize(**args) update!(**args) end |
Instance Attribute Details
#citations ⇒ Google::Apis::CesV1::Citations
Citations associated with the agent response.
Corresponds to the JSON property citations
3403 3404 3405 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3403 def citations @citations end |
#google_search_suggestions ⇒ Google::Apis::CesV1::GoogleSearchSuggestions
Search suggestions from Google Search Tool.
Corresponds to the JSON property googleSearchSuggestions
3408 3409 3410 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3408 def google_search_suggestions @google_search_suggestions end |
#response ⇒ Hash<String,Object>
The tool execution result in JSON object format. Use "output" key to specify
tool response and "error" key to specify error details (if any). If "output"
and "error" keys are not specified, then whole "response" is treated as tool
execution result.
Corresponds to the JSON property response
3416 3417 3418 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3416 def response @response end |
#tool ⇒ String
The name of the tool that got executed. Format: projects/project/locations/
location/apps/app/tools/tool`
Corresponds to the JSON propertytool`
3422 3423 3424 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3422 def tool @tool end |
#toolset_tool ⇒ Google::Apis::CesV1::ToolsetTool
A tool that is created from a toolset.
Corresponds to the JSON property toolsetTool
3427 3428 3429 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3427 def toolset_tool @toolset_tool end |
#variables ⇒ Hash<String,Object>
The variable values at the end of the tool execution.
Corresponds to the JSON property variables
3432 3433 3434 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3432 def variables @variables end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3439 3440 3441 3442 3443 3444 3445 3446 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3439 def update!(**args) @citations = args[:citations] if args.key?(:citations) @google_search_suggestions = args[:google_search_suggestions] if args.key?(:google_search_suggestions) @response = args[:response] if args.key?(:response) @tool = args[:tool] if args.key?(:tool) @toolset_tool = args[:toolset_tool] if args.key?(:toolset_tool) @variables = args[:variables] if args.key?(:variables) end |