Class: Google::Apis::CesV1::GenerateChatTokenResponse
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::GenerateChatTokenResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Response message for WidgetService.GenerateChatToken.
Instance Attribute Summary collapse
-
#chat_token ⇒ String
The session scoped token for chat widget to authenticate with Session APIs.
-
#expire_time ⇒ String
The time at which the chat token expires.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenerateChatTokenResponse
constructor
A new instance of GenerateChatTokenResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenerateChatTokenResponse
Returns a new instance of GenerateChatTokenResponse.
3694 3695 3696 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3694 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chat_token ⇒ String
The session scoped token for chat widget to authenticate with Session APIs.
Corresponds to the JSON property chatToken
3687 3688 3689 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3687 def chat_token @chat_token end |
#expire_time ⇒ String
The time at which the chat token expires.
Corresponds to the JSON property expireTime
3692 3693 3694 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3692 def expire_time @expire_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3699 3700 3701 3702 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3699 def update!(**args) @chat_token = args[:chat_token] if args.key?(:chat_token) @expire_time = args[:expire_time] if args.key?(:expire_time) end |