Class: Google::Apis::CesV1::GoogleSearchSuggestions

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Search suggestions from Google Search Tool.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleSearchSuggestions

Returns a new instance of GoogleSearchSuggestions.



3363
3364
3365
# File 'lib/google/apis/ces_v1/classes.rb', line 3363

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#htmlsArray<String>

Compliant HTML and CSS styling for search suggestions. The provided HTML and CSS automatically adapts to your device settings, displaying in either light or dark mode indicated by @media(prefers-color-scheme). Corresponds to the JSON property htmls

Returns:

  • (Array<String>)


3355
3356
3357
# File 'lib/google/apis/ces_v1/classes.rb', line 3355

def htmls
  @htmls
end

#web_search_queriesArray<Google::Apis::CesV1::WebSearchQuery>

List of queries used to perform the google search along with the search result URIs forming the search suggestions. Corresponds to the JSON property webSearchQueries



3361
3362
3363
# File 'lib/google/apis/ces_v1/classes.rb', line 3361

def web_search_queries
  @web_search_queries
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3368
3369
3370
3371
# File 'lib/google/apis/ces_v1/classes.rb', line 3368

def update!(**args)
  @htmls = args[:htmls] if args.key?(:htmls)
  @web_search_queries = args[:web_search_queries] if args.key?(:web_search_queries)
end