Class: Google::Apis::CesV1::LanguageSettings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Language settings of the app.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LanguageSettings

Returns a new instance of LanguageSettings.



4345
4346
4347
# File 'lib/google/apis/ces_v1/classes.rb', line 4345

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#default_language_codeString

Optional. The default language code of the app. Corresponds to the JSON property defaultLanguageCode

Returns:

  • (String)


4319
4320
4321
# File 'lib/google/apis/ces_v1/classes.rb', line 4319

def default_language_code
  @default_language_code
end

#enable_multilingual_supportBoolean Also known as: enable_multilingual_support?

Optional. Enables multilingual support. If true, agents in the app will use pre-built instructions to improve handling of multilingual input. Corresponds to the JSON property enableMultilingualSupport

Returns:

  • (Boolean)


4325
4326
4327
# File 'lib/google/apis/ces_v1/classes.rb', line 4325

def enable_multilingual_support
  @enable_multilingual_support
end

#fallback_actionString

Optional. Deprecated: This feature is no longer supported. Use enable_multilingual_support instead to improve handling of multilingual input. The action to perform when an agent receives input in an unsupported language. This can be a predefined action or a custom tool call. Valid values are: - A tool's full resource name, which triggers a specific tool execution. - A predefined system action, such as "escalate" or "exit", which triggers an EndSession signal with corresponding metadata to terminate the conversation. Corresponds to the JSON property fallbackAction

Returns:

  • (String)


4337
4338
4339
# File 'lib/google/apis/ces_v1/classes.rb', line 4337

def fallback_action
  @fallback_action
end

#supported_language_codesArray<String>

Optional. List of languages codes supported by the app, in addition to the default_language_code. Corresponds to the JSON property supportedLanguageCodes

Returns:

  • (Array<String>)


4343
4344
4345
# File 'lib/google/apis/ces_v1/classes.rb', line 4343

def supported_language_codes
  @supported_language_codes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4350
4351
4352
4353
4354
4355
# File 'lib/google/apis/ces_v1/classes.rb', line 4350

def update!(**args)
  @default_language_code = args[:default_language_code] if args.key?(:default_language_code)
  @enable_multilingual_support = args[:enable_multilingual_support] if args.key?(:enable_multilingual_support)
  @fallback_action = args[:fallback_action] if args.key?(:fallback_action)
  @supported_language_codes = args[:supported_language_codes] if args.key?(:supported_language_codes)
end