Class: Google::Apis::CesV1::LfA2aV1AgentCapabilities

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Defines optional capabilities supported by an agent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LfA2aV1AgentCapabilities

Returns a new instance of LfA2aV1AgentCapabilities.



4477
4478
4479
# File 'lib/google/apis/ces_v1/classes.rb', line 4477

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#extended_agent_cardBoolean Also known as: extended_agent_card?

Indicates if the agent supports providing an extended agent card when authenticated. Corresponds to the JSON property extendedAgentCard

Returns:

  • (Boolean)


4456
4457
4458
# File 'lib/google/apis/ces_v1/classes.rb', line 4456

def extended_agent_card
  @extended_agent_card
end

#extensionsArray<Google::Apis::CesV1::LfA2aV1AgentExtension>

A list of protocol extensions supported by the agent. Corresponds to the JSON property extensions



4462
4463
4464
# File 'lib/google/apis/ces_v1/classes.rb', line 4462

def extensions
  @extensions
end

#push_notificationsBoolean Also known as: push_notifications?

Indicates if the agent supports sending push notifications for asynchronous task updates. Corresponds to the JSON property pushNotifications

Returns:

  • (Boolean)


4468
4469
4470
# File 'lib/google/apis/ces_v1/classes.rb', line 4468

def push_notifications
  @push_notifications
end

#streamingBoolean Also known as: streaming?

Indicates if the agent supports streaming responses. Corresponds to the JSON property streaming

Returns:

  • (Boolean)


4474
4475
4476
# File 'lib/google/apis/ces_v1/classes.rb', line 4474

def streaming
  @streaming
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4482
4483
4484
4485
4486
4487
# File 'lib/google/apis/ces_v1/classes.rb', line 4482

def update!(**args)
  @extended_agent_card = args[:extended_agent_card] if args.key?(:extended_agent_card)
  @extensions = args[:extensions] if args.key?(:extensions)
  @push_notifications = args[:push_notifications] if args.key?(:push_notifications)
  @streaming = args[:streaming] if args.key?(:streaming)
end