Class: Google::Apis::CesV1::LfA2aV1AgentCard

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

A self-describing manifest for an agent. It provides essential metadata including the agent's identity, capabilities, skills, supported communication methods, and security requirements. Next ID: 20

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LfA2aV1AgentCard

Returns a new instance of LfA2aV1AgentCard.



4572
4573
4574
# File 'lib/google/apis/ces_v1/classes.rb', line 4572

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#capabilitiesGoogle::Apis::CesV1::LfA2aV1AgentCapabilities

Defines optional capabilities supported by an agent. Corresponds to the JSON property capabilities



4499
4500
4501
# File 'lib/google/apis/ces_v1/classes.rb', line 4499

def capabilities
  @capabilities
end

#default_input_modesArray<String>

Required. protolint:enable REPEATED_FIELD_NAMES_PLURALIZED The set of interaction modes that the agent supports across all skills. This can be overridden per skill. Defined as media types. Corresponds to the JSON property defaultInputModes

Returns:

  • (Array<String>)


4506
4507
4508
# File 'lib/google/apis/ces_v1/classes.rb', line 4506

def default_input_modes
  @default_input_modes
end

#default_output_modesArray<String>

Required. The media types supported as outputs from this agent. Corresponds to the JSON property defaultOutputModes

Returns:

  • (Array<String>)


4511
4512
4513
# File 'lib/google/apis/ces_v1/classes.rb', line 4511

def default_output_modes
  @default_output_modes
end

#descriptionString

Required. A human-readable description of the agent, assisting users and other agents in understanding its purpose. Example: "Agent that helps users with recipes and cooking." Corresponds to the JSON property description

Returns:

  • (String)


4518
4519
4520
# File 'lib/google/apis/ces_v1/classes.rb', line 4518

def description
  @description
end

#documentation_urlString

A URL providing additional documentation about the agent. Corresponds to the JSON property documentationUrl

Returns:

  • (String)


4523
4524
4525
# File 'lib/google/apis/ces_v1/classes.rb', line 4523

def documentation_url
  @documentation_url
end

#icon_urlString

Optional. A URL to an icon for the agent. Corresponds to the JSON property iconUrl

Returns:

  • (String)


4528
4529
4530
# File 'lib/google/apis/ces_v1/classes.rb', line 4528

def icon_url
  @icon_url
end

#nameString

Required. A human readable name for the agent. Example: "Recipe Agent" Corresponds to the JSON property name

Returns:

  • (String)


4533
4534
4535
# File 'lib/google/apis/ces_v1/classes.rb', line 4533

def name
  @name
end

#providerGoogle::Apis::CesV1::LfA2aV1AgentProvider

Represents the service provider of an agent. Corresponds to the JSON property provider



4538
4539
4540
# File 'lib/google/apis/ces_v1/classes.rb', line 4538

def provider
  @provider
end

#security_requirementsArray<Google::Apis::CesV1::LfA2aV1SecurityRequirement>

Security requirements for contacting the agent. Corresponds to the JSON property securityRequirements



4543
4544
4545
# File 'lib/google/apis/ces_v1/classes.rb', line 4543

def security_requirements
  @security_requirements
end

#security_schemesHash<String,Google::Apis::CesV1::LfA2aV1SecurityScheme>

The security scheme details used for authenticating with this agent. Corresponds to the JSON property securitySchemes



4548
4549
4550
# File 'lib/google/apis/ces_v1/classes.rb', line 4548

def security_schemes
  @security_schemes
end

#signaturesArray<Google::Apis::CesV1::LfA2aV1AgentCardSignature>

JSON Web Signatures computed for this AgentCard. Corresponds to the JSON property signatures



4553
4554
4555
# File 'lib/google/apis/ces_v1/classes.rb', line 4553

def signatures
  @signatures
end

#skillsArray<Google::Apis::CesV1::LfA2aV1AgentSkill>

Required. Skills represent the abilities of an agent. It is largely a descriptive concept but represents a more focused set of behaviors that the agent is likely to succeed at. Corresponds to the JSON property skills



4560
4561
4562
# File 'lib/google/apis/ces_v1/classes.rb', line 4560

def skills
  @skills
end

#supported_interfacesArray<Google::Apis::CesV1::LfA2aV1AgentInterface>

Required. Ordered list of supported interfaces. The first entry is preferred. Corresponds to the JSON property supportedInterfaces



4565
4566
4567
# File 'lib/google/apis/ces_v1/classes.rb', line 4565

def supported_interfaces
  @supported_interfaces
end

#versionString

Required. The version of the agent. Example: "1.0.0" Corresponds to the JSON property version

Returns:

  • (String)


4570
4571
4572
# File 'lib/google/apis/ces_v1/classes.rb', line 4570

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4577
4578
4579
4580
4581
4582
4583
4584
4585
4586
4587
4588
4589
4590
4591
4592
# File 'lib/google/apis/ces_v1/classes.rb', line 4577

def update!(**args)
  @capabilities = args[:capabilities] if args.key?(:capabilities)
  @default_input_modes = args[:default_input_modes] if args.key?(:default_input_modes)
  @default_output_modes = args[:default_output_modes] if args.key?(:default_output_modes)
  @description = args[:description] if args.key?(:description)
  @documentation_url = args[:documentation_url] if args.key?(:documentation_url)
  @icon_url = args[:icon_url] if args.key?(:icon_url)
  @name = args[:name] if args.key?(:name)
  @provider = args[:provider] if args.key?(:provider)
  @security_requirements = args[:security_requirements] if args.key?(:security_requirements)
  @security_schemes = args[:security_schemes] if args.key?(:security_schemes)
  @signatures = args[:signatures] if args.key?(:signatures)
  @skills = args[:skills] if args.key?(:skills)
  @supported_interfaces = args[:supported_interfaces] if args.key?(:supported_interfaces)
  @version = args[:version] if args.key?(:version)
end