Class: Google::Apis::CesV1::LfA2aV1AgentExtension

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

A declaration of a protocol extension supported by an Agent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LfA2aV1AgentExtension

Returns a new instance of LfA2aV1AgentExtension.



4654
4655
4656
# File 'lib/google/apis/ces_v1/classes.rb', line 4654

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

A human-readable description of how this agent uses the extension. Corresponds to the JSON property description

Returns:

  • (String)


4635
4636
4637
# File 'lib/google/apis/ces_v1/classes.rb', line 4635

def description
  @description
end

#paramsHash<String,Object>

Optional. Extension-specific configuration parameters. Corresponds to the JSON property params

Returns:

  • (Hash<String,Object>)


4640
4641
4642
# File 'lib/google/apis/ces_v1/classes.rb', line 4640

def params
  @params
end

#requiredBoolean Also known as: required?

If true, the client must understand and comply with the extension's requirements. Corresponds to the JSON property required

Returns:

  • (Boolean)


4646
4647
4648
# File 'lib/google/apis/ces_v1/classes.rb', line 4646

def required
  @required
end

#uriString

The unique URI identifying the extension. Corresponds to the JSON property uri

Returns:

  • (String)


4652
4653
4654
# File 'lib/google/apis/ces_v1/classes.rb', line 4652

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4659
4660
4661
4662
4663
4664
# File 'lib/google/apis/ces_v1/classes.rb', line 4659

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @params = args[:params] if args.key?(:params)
  @required = args[:required] if args.key?(:required)
  @uri = args[:uri] if args.key?(:uri)
end