Class: Google::Apis::CesV1::LfA2aV1AgentSkill

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Represents a distinct capability or function that an agent can perform.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LfA2aV1AgentSkill

Returns a new instance of LfA2aV1AgentSkill.



4788
4789
4790
# File 'lib/google/apis/ces_v1/classes.rb', line 4788

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Required. A detailed description of the skill. Corresponds to the JSON property description

Returns:

  • (String)


4749
4750
4751
# File 'lib/google/apis/ces_v1/classes.rb', line 4749

def description
  @description
end

#examplesArray<String>

Example prompts or scenarios that this skill can handle. Corresponds to the JSON property examples

Returns:

  • (Array<String>)


4754
4755
4756
# File 'lib/google/apis/ces_v1/classes.rb', line 4754

def examples
  @examples
end

#idString

Required. A unique identifier for the agent's skill. Corresponds to the JSON property id

Returns:

  • (String)


4759
4760
4761
# File 'lib/google/apis/ces_v1/classes.rb', line 4759

def id
  @id
end

#input_modesArray<String>

The set of supported input media types for this skill, overriding the agent's defaults. Corresponds to the JSON property inputModes

Returns:

  • (Array<String>)


4765
4766
4767
# File 'lib/google/apis/ces_v1/classes.rb', line 4765

def input_modes
  @input_modes
end

#nameString

Required. A human-readable name for the skill. Corresponds to the JSON property name

Returns:

  • (String)


4770
4771
4772
# File 'lib/google/apis/ces_v1/classes.rb', line 4770

def name
  @name
end

#output_modesArray<String>

The set of supported output media types for this skill, overriding the agent's defaults. Corresponds to the JSON property outputModes

Returns:

  • (Array<String>)


4776
4777
4778
# File 'lib/google/apis/ces_v1/classes.rb', line 4776

def output_modes
  @output_modes
end

#security_requirementsArray<Google::Apis::CesV1::LfA2aV1SecurityRequirement>

Security schemes necessary for this skill. Corresponds to the JSON property securityRequirements



4781
4782
4783
# File 'lib/google/apis/ces_v1/classes.rb', line 4781

def security_requirements
  @security_requirements
end

#tagsArray<String>

Required. A set of keywords describing the skill's capabilities. Corresponds to the JSON property tags

Returns:

  • (Array<String>)


4786
4787
4788
# File 'lib/google/apis/ces_v1/classes.rb', line 4786

def tags
  @tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4793
4794
4795
4796
4797
4798
4799
4800
4801
4802
# File 'lib/google/apis/ces_v1/classes.rb', line 4793

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @examples = args[:examples] if args.key?(:examples)
  @id = args[:id] if args.key?(:id)
  @input_modes = args[:input_modes] if args.key?(:input_modes)
  @name = args[:name] if args.key?(:name)
  @output_modes = args[:output_modes] if args.key?(:output_modes)
  @security_requirements = args[:security_requirements] if args.key?(:security_requirements)
  @tags = args[:tags] if args.key?(:tags)
end