Class: Google::Apis::CesV1::LfA2aV1Artifact
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::LfA2aV1Artifact
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Artifacts represent task outputs.
Instance Attribute Summary collapse
-
#artifact_id ⇒ String
Required.
-
#description ⇒ String
Optional.
-
#extensions ⇒ Array<String>
The URIs of extensions that are present or contributed to this Artifact.
-
#metadata ⇒ Hash<String,Object>
Optional.
-
#name ⇒ String
A human readable name for the artifact.
-
#parts ⇒ Array<Google::Apis::CesV1::LfA2aV1Part>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LfA2aV1Artifact
constructor
A new instance of LfA2aV1Artifact.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LfA2aV1Artifact
Returns a new instance of LfA2aV1Artifact.
4824 4825 4826 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4824 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_id ⇒ String
Required. Unique identifier (e.g. UUID) for the artifact. It must be unique
within a task.
Corresponds to the JSON property artifactId
4797 4798 4799 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4797 def artifact_id @artifact_id end |
#description ⇒ String
Optional. A human readable description of the artifact.
Corresponds to the JSON property description
4802 4803 4804 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4802 def description @description end |
#extensions ⇒ Array<String>
The URIs of extensions that are present or contributed to this Artifact.
Corresponds to the JSON property extensions
4807 4808 4809 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4807 def extensions @extensions end |
#metadata ⇒ Hash<String,Object>
Optional. Metadata included with the artifact.
Corresponds to the JSON property metadata
4812 4813 4814 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4812 def @metadata end |
#name ⇒ String
A human readable name for the artifact.
Corresponds to the JSON property name
4817 4818 4819 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4817 def name @name end |
#parts ⇒ Array<Google::Apis::CesV1::LfA2aV1Part>
Required. The content of the artifact. Must contain at least one part.
Corresponds to the JSON property parts
4822 4823 4824 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4822 def parts @parts end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4829 4830 4831 4832 4833 4834 4835 4836 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4829 def update!(**args) @artifact_id = args[:artifact_id] if args.key?(:artifact_id) @description = args[:description] if args.key?(:description) @extensions = args[:extensions] if args.key?(:extensions) @metadata = args[:metadata] if args.key?(:metadata) @name = args[:name] if args.key?(:name) @parts = args[:parts] if args.key?(:parts) end |