Class: Google::Apis::CesV1::LfA2aV1HttpAuthSecurityScheme

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Defines a security scheme using HTTP authentication.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LfA2aV1HttpAuthSecurityScheme

Returns a new instance of LfA2aV1HttpAuthSecurityScheme.



5021
5022
5023
# File 'lib/google/apis/ces_v1/classes.rb', line 5021

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bearer_formatString

A hint to the client to identify how the bearer token is formatted (e.g., "JWT" ). Primarily for documentation purposes. Corresponds to the JSON property bearerFormat

Returns:

  • (String)


5007
5008
5009
# File 'lib/google/apis/ces_v1/classes.rb', line 5007

def bearer_format
  @bearer_format
end

#descriptionString

An optional description for the security scheme. Corresponds to the JSON property description

Returns:

  • (String)


5012
5013
5014
# File 'lib/google/apis/ces_v1/classes.rb', line 5012

def description
  @description
end

#schemeString

Required. The name of the HTTP Authentication scheme to be used in the Authorization header, as defined in RFC7235 (e.g., "Bearer"). This value should be registered in the IANA Authentication Scheme registry. Corresponds to the JSON property scheme

Returns:

  • (String)


5019
5020
5021
# File 'lib/google/apis/ces_v1/classes.rb', line 5019

def scheme
  @scheme
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5026
5027
5028
5029
5030
# File 'lib/google/apis/ces_v1/classes.rb', line 5026

def update!(**args)
  @bearer_format = args[:bearer_format] if args.key?(:bearer_format)
  @description = args[:description] if args.key?(:description)
  @scheme = args[:scheme] if args.key?(:scheme)
end