Class: Google::Apis::CesV1::LfA2aV1SecurityScheme
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::LfA2aV1SecurityScheme
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Defines a security scheme that can be used to secure an agent's endpoints. This is a discriminated union type based on the OpenAPI 3.2 Security Scheme Object. See: https://spec.openapis.org/oas/v3.2.0.html#security-scheme-object
Instance Attribute Summary collapse
-
#api_key_security_scheme ⇒ Google::Apis::CesV1::LfA2aV1ApiKeySecurityScheme
Defines a security scheme using an API key.
-
#http_auth_security_scheme ⇒ Google::Apis::CesV1::LfA2aV1HttpAuthSecurityScheme
Defines a security scheme using HTTP authentication.
-
#mtls_security_scheme ⇒ Google::Apis::CesV1::LfA2aV1MutualTlsSecurityScheme
Defines a security scheme using mTLS authentication.
-
#oauth2_security_scheme ⇒ Google::Apis::CesV1::LfA2aV1OAuth2SecurityScheme
Defines a security scheme using OAuth 2.0.
-
#open_id_connect_security_scheme ⇒ Google::Apis::CesV1::LfA2aV1OpenIdConnectSecurityScheme
Defines a security scheme using OpenID Connect.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LfA2aV1SecurityScheme
constructor
A new instance of LfA2aV1SecurityScheme.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LfA2aV1SecurityScheme
Returns a new instance of LfA2aV1SecurityScheme.
5403 5404 5405 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5403 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_key_security_scheme ⇒ Google::Apis::CesV1::LfA2aV1ApiKeySecurityScheme
Defines a security scheme using an API key.
Corresponds to the JSON property apiKeySecurityScheme
5381 5382 5383 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5381 def api_key_security_scheme @api_key_security_scheme end |
#http_auth_security_scheme ⇒ Google::Apis::CesV1::LfA2aV1HttpAuthSecurityScheme
Defines a security scheme using HTTP authentication.
Corresponds to the JSON property httpAuthSecurityScheme
5386 5387 5388 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5386 def http_auth_security_scheme @http_auth_security_scheme end |
#mtls_security_scheme ⇒ Google::Apis::CesV1::LfA2aV1MutualTlsSecurityScheme
Defines a security scheme using mTLS authentication.
Corresponds to the JSON property mtlsSecurityScheme
5391 5392 5393 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5391 def mtls_security_scheme @mtls_security_scheme end |
#oauth2_security_scheme ⇒ Google::Apis::CesV1::LfA2aV1OAuth2SecurityScheme
Defines a security scheme using OAuth 2.0.
Corresponds to the JSON property oauth2SecurityScheme
5396 5397 5398 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5396 def oauth2_security_scheme @oauth2_security_scheme end |
#open_id_connect_security_scheme ⇒ Google::Apis::CesV1::LfA2aV1OpenIdConnectSecurityScheme
Defines a security scheme using OpenID Connect.
Corresponds to the JSON property openIdConnectSecurityScheme
5401 5402 5403 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5401 def open_id_connect_security_scheme @open_id_connect_security_scheme end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5408 5409 5410 5411 5412 5413 5414 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5408 def update!(**args) @api_key_security_scheme = args[:api_key_security_scheme] if args.key?(:api_key_security_scheme) @http_auth_security_scheme = args[:http_auth_security_scheme] if args.key?(:http_auth_security_scheme) @mtls_security_scheme = args[:mtls_security_scheme] if args.key?(:mtls_security_scheme) @oauth2_security_scheme = args[:oauth2_security_scheme] if args.key?(:oauth2_security_scheme) @open_id_connect_security_scheme = args[:open_id_connect_security_scheme] if args.key?(:open_id_connect_security_scheme) end |