Class: Google::Apis::CesV1::LfA2aV1SendMessageRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Represents a request for the SendMessage method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LfA2aV1SendMessageRequest

Returns a new instance of LfA2aV1SendMessageRequest.



5410
5411
5412
# File 'lib/google/apis/ces_v1/classes.rb', line 5410

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#configurationGoogle::Apis::CesV1::LfA2aV1SendMessageConfiguration

Configuration of a send message request. Corresponds to the JSON property configuration



5393
5394
5395
# File 'lib/google/apis/ces_v1/classes.rb', line 5393

def configuration
  @configuration
end

#messageGoogle::Apis::CesV1::LfA2aV1Message

Message is one unit of communication between client and server. It can be associated with a context and/or a task. For server messages, context_id must be provided, and task_id only if a task was created. For client messages, both fields are optional, with the caveat that if both are provided, they have to match (the context_id has to be the one that is set on the task) . If only task_id is provided, the server will infer context_id from it. Corresponds to the JSON property message



5403
5404
5405
# File 'lib/google/apis/ces_v1/classes.rb', line 5403

def message
  @message
end

#metadataHash<String,Object>

A flexible key-value map for passing additional context or parameters. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,Object>)


5408
5409
5410
# File 'lib/google/apis/ces_v1/classes.rb', line 5408

def 
  @metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5415
5416
5417
5418
5419
# File 'lib/google/apis/ces_v1/classes.rb', line 5415

def update!(**args)
  @configuration = args[:configuration] if args.key?(:configuration)
  @message = args[:message] if args.key?(:message)
  @metadata = args[:metadata] if args.key?(:metadata)
end