Class: Google::Apis::CesV1::LfA2aV1TaskPushNotificationConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

A container associating a push notification configuration with a specific task.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LfA2aV1TaskPushNotificationConfig

Returns a new instance of LfA2aV1TaskPushNotificationConfig.



5641
5642
5643
# File 'lib/google/apis/ces_v1/classes.rb', line 5641

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authenticationGoogle::Apis::CesV1::LfA2aV1AuthenticationInfo

Defines authentication details, used for push notifications. Corresponds to the JSON property authentication



5612
5613
5614
# File 'lib/google/apis/ces_v1/classes.rb', line 5612

def authentication
  @authentication
end

#idString

The push notification configuration details. A unique identifier (e.g. UUID) for this push notification configuration. Corresponds to the JSON property id

Returns:

  • (String)


5618
5619
5620
# File 'lib/google/apis/ces_v1/classes.rb', line 5618

def id
  @id
end

#task_idString

The ID of the task this configuration is associated with. Corresponds to the JSON property taskId

Returns:

  • (String)


5623
5624
5625
# File 'lib/google/apis/ces_v1/classes.rb', line 5623

def task_id
  @task_id
end

#tenantString

Optional. Opaque routing identifier. Must match the tenant value from the selected AgentInterface in the Agent Card when that field is set. Corresponds to the JSON property tenant

Returns:

  • (String)


5629
5630
5631
# File 'lib/google/apis/ces_v1/classes.rb', line 5629

def tenant
  @tenant
end

#tokenString

A token unique for this task or session. Corresponds to the JSON property token

Returns:

  • (String)


5634
5635
5636
# File 'lib/google/apis/ces_v1/classes.rb', line 5634

def token
  @token
end

#urlString

Required. The URL where the notification should be sent. Corresponds to the JSON property url

Returns:

  • (String)


5639
5640
5641
# File 'lib/google/apis/ces_v1/classes.rb', line 5639

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5646
5647
5648
5649
5650
5651
5652
5653
# File 'lib/google/apis/ces_v1/classes.rb', line 5646

def update!(**args)
  @authentication = args[:authentication] if args.key?(:authentication)
  @id = args[:id] if args.key?(:id)
  @task_id = args[:task_id] if args.key?(:task_id)
  @tenant = args[:tenant] if args.key?(:tenant)
  @token = args[:token] if args.key?(:token)
  @url = args[:url] if args.key?(:url)
end