Class: Google::Apis::CesV1::LfA2aV1TaskStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

A container for the status of a task

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LfA2aV1TaskStatus

Returns a new instance of LfA2aV1TaskStatus.



5603
5604
5605
# File 'lib/google/apis/ces_v1/classes.rb', line 5603

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#messageGoogle::Apis::CesV1::LfA2aV1Message

Message is one unit of communication between client and server. It can be associated with a context and/or a task. For server messages, context_id must be provided, and task_id only if a task was created. For client messages, both fields are optional, with the caveat that if both are provided, they have to match (the context_id has to be the one that is set on the task) . If only task_id is provided, the server will infer context_id from it. Corresponds to the JSON property message



5590
5591
5592
# File 'lib/google/apis/ces_v1/classes.rb', line 5590

def message
  @message
end

#stateString

Required. The current state of this task. Corresponds to the JSON property state

Returns:

  • (String)


5595
5596
5597
# File 'lib/google/apis/ces_v1/classes.rb', line 5595

def state
  @state
end

#timestampString

ISO 8601 Timestamp when the status was recorded. Example: "2023-10-27T10:00: 00Z" Corresponds to the JSON property timestamp

Returns:

  • (String)


5601
5602
5603
# File 'lib/google/apis/ces_v1/classes.rb', line 5601

def timestamp
  @timestamp
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5608
5609
5610
5611
5612
# File 'lib/google/apis/ces_v1/classes.rb', line 5608

def update!(**args)
  @message = args[:message] if args.key?(:message)
  @state = args[:state] if args.key?(:state)
  @timestamp = args[:timestamp] if args.key?(:timestamp)
end