Class: Google::Apis::CesV1::ListLocationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::ListLocationsResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
The response message for Locations.ListLocations.
Instance Attribute Summary collapse
-
#locations ⇒ Array<Google::Apis::CesV1::Location>
A list of locations that matches the specified filter in the request.
-
#next_page_token ⇒ String
The standard List next-page token.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListLocationsResponse
constructor
A new instance of ListLocationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListLocationsResponse
Returns a new instance of ListLocationsResponse.
5863 5864 5865 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5863 def initialize(**args) update!(**args) end |
Instance Attribute Details
#locations ⇒ Array<Google::Apis::CesV1::Location>
A list of locations that matches the specified filter in the request.
Corresponds to the JSON property locations
5856 5857 5858 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5856 def locations @locations end |
#next_page_token ⇒ String
The standard List next-page token.
Corresponds to the JSON property nextPageToken
5861 5862 5863 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5861 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5868 5869 5870 5871 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5868 def update!(**args) @locations = args[:locations] if args.key?(:locations) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |