Class: Google::Apis::CesV1::ListOperationsResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

The response message for Operations.ListOperations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListOperationsResponse

Returns a new instance of ListOperationsResponse.



5896
5897
5898
# File 'lib/google/apis/ces_v1/classes.rb', line 5896

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

The standard List next-page token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


5881
5882
5883
# File 'lib/google/apis/ces_v1/classes.rb', line 5881

def next_page_token
  @next_page_token
end

#operationsArray<Google::Apis::CesV1::Operation>

A list of operations that matches the specified filter in the request. Corresponds to the JSON property operations

Returns:



5886
5887
5888
# File 'lib/google/apis/ces_v1/classes.rb', line 5886

def operations
  @operations
end

#unreachableArray<String>

Unordered list. Unreachable resources. Populated when the request sets ListOperationsRequest.return_partial_success and reads across collections. For example, when attempting to list all resources across all supported locations. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


5894
5895
5896
# File 'lib/google/apis/ces_v1/classes.rb', line 5894

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5901
5902
5903
5904
5905
# File 'lib/google/apis/ces_v1/classes.rb', line 5901

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @operations = args[:operations] if args.key?(:operations)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end