Class: Google::Apis::CesV1::OmnichannelIntegrationConfigWhatsappConfig
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::OmnichannelIntegrationConfigWhatsappConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
How Omnichannel should receive/reply events from WhatsApp.
Instance Attribute Summary collapse
-
#meta_business_portfolio_id ⇒ String
The Meta Business Portfolio (MBP) ID.
-
#phone_number ⇒ String
The phone number used for sending/receiving messages.
-
#phone_number_id ⇒ String
The Phone Number ID associated with the WhatsApp Business Account.
-
#webhook_verify_token ⇒ String
The verify token configured in the Meta App Dashboard for webhook verification.
-
#whatsapp_business_account_id ⇒ String
The customer's WhatsApp Business Account (WABA) ID.
-
#whatsapp_business_token ⇒ String
The access token for authenticating API calls to the WhatsApp Cloud API.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OmnichannelIntegrationConfigWhatsappConfig
constructor
A new instance of OmnichannelIntegrationConfigWhatsappConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OmnichannelIntegrationConfigWhatsappConfig
Returns a new instance of OmnichannelIntegrationConfigWhatsappConfig.
4991 4992 4993 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4991 def initialize(**args) update!(**args) end |
Instance Attribute Details
#meta_business_portfolio_id ⇒ String
The Meta Business Portfolio (MBP) ID. https://www.facebook.com/business/help/
1710077379203657
Corresponds to the JSON property metaBusinessPortfolioId
4962 4963 4964 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4962 def @meta_business_portfolio_id end |
#phone_number ⇒ String
The phone number used for sending/receiving messages.
Corresponds to the JSON property phoneNumber
4967 4968 4969 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4967 def phone_number @phone_number end |
#phone_number_id ⇒ String
The Phone Number ID associated with the WhatsApp Business Account.
Corresponds to the JSON property phoneNumberId
4972 4973 4974 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4972 def phone_number_id @phone_number_id end |
#webhook_verify_token ⇒ String
The verify token configured in the Meta App Dashboard for webhook verification.
Corresponds to the JSON property webhookVerifyToken
4977 4978 4979 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4977 def webhook_verify_token @webhook_verify_token end |
#whatsapp_business_account_id ⇒ String
The customer's WhatsApp Business Account (WABA) ID.
Corresponds to the JSON property whatsappBusinessAccountId
4982 4983 4984 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4982 def whatsapp_business_account_id @whatsapp_business_account_id end |
#whatsapp_business_token ⇒ String
The access token for authenticating API calls to the WhatsApp Cloud API. https:
//developers.facebook.com/docs/whatsapp/business-management-api/get-started/#
business-integration-system-user-access-tokens
Corresponds to the JSON property whatsappBusinessToken
4989 4990 4991 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4989 def whatsapp_business_token @whatsapp_business_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4996 4997 4998 4999 5000 5001 5002 5003 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4996 def update!(**args) @meta_business_portfolio_id = args[:meta_business_portfolio_id] if args.key?(:meta_business_portfolio_id) @phone_number = args[:phone_number] if args.key?(:phone_number) @phone_number_id = args[:phone_number_id] if args.key?(:phone_number_id) @webhook_verify_token = args[:webhook_verify_token] if args.key?(:webhook_verify_token) @whatsapp_business_account_id = args[:whatsapp_business_account_id] if args.key?(:whatsapp_business_account_id) @whatsapp_business_token = args[:whatsapp_business_token] if args.key?(:whatsapp_business_token) end |