Class: Google::Apis::CesV1::OpenApiTool

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

A remote API tool defined by an OpenAPI schema.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OpenApiTool

Returns a new instance of OpenApiTool.



6612
6613
6614
# File 'lib/google/apis/ces_v1/classes.rb', line 6612

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_authenticationGoogle::Apis::CesV1::ApiAuthentication

Authentication information required for API calls. Corresponds to the JSON property apiAuthentication



6567
6568
6569
# File 'lib/google/apis/ces_v1/classes.rb', line 6567

def api_authentication
  @api_authentication
end

#descriptionString

Optional. The description of the tool. If not provided, the description of the tool will be derived from the OpenAPI schema, from operation.description or operation.summary. Corresponds to the JSON property description

Returns:

  • (String)


6574
6575
6576
# File 'lib/google/apis/ces_v1/classes.rb', line 6574

def description
  @description
end

#ignore_unknown_fieldsBoolean Also known as: ignore_unknown_fields?

Optional. If true, the agent will ignore unknown fields in the API response. Corresponds to the JSON property ignoreUnknownFields

Returns:

  • (Boolean)


6579
6580
6581
# File 'lib/google/apis/ces_v1/classes.rb', line 6579

def ignore_unknown_fields
  @ignore_unknown_fields
end

#nameString

Optional. The name of the tool. If not provided, the name of the tool will be derived from the OpenAPI schema, from operation.operationId. Corresponds to the JSON property name

Returns:

  • (String)


6586
6587
6588
# File 'lib/google/apis/ces_v1/classes.rb', line 6586

def name
  @name
end

#open_api_schemaString

Required. The OpenAPI schema in JSON or YAML format. Corresponds to the JSON property openApiSchema

Returns:

  • (String)


6591
6592
6593
# File 'lib/google/apis/ces_v1/classes.rb', line 6591

def open_api_schema
  @open_api_schema
end

#service_directory_configGoogle::Apis::CesV1::ServiceDirectoryConfig

Configuration for tools using Service Directory. Corresponds to the JSON property serviceDirectoryConfig



6596
6597
6598
# File 'lib/google/apis/ces_v1/classes.rb', line 6596

def service_directory_config
  @service_directory_config
end

#tls_configGoogle::Apis::CesV1::TlsConfig

The TLS configuration. Corresponds to the JSON property tlsConfig



6601
6602
6603
# File 'lib/google/apis/ces_v1/classes.rb', line 6601

def tls_config
  @tls_config
end

#urlString

Optional. The server URL of the Open API schema. This field is only set in tools in the environment dependencies during the export process if the schema contains a server url. During the import process, if this url is present in the environment dependencies and the schema has the $env_var placeholder, it will replace the placeholder in the schema. Corresponds to the JSON property url

Returns:

  • (String)


6610
6611
6612
# File 'lib/google/apis/ces_v1/classes.rb', line 6610

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6617
6618
6619
6620
6621
6622
6623
6624
6625
6626
# File 'lib/google/apis/ces_v1/classes.rb', line 6617

def update!(**args)
  @api_authentication = args[:api_authentication] if args.key?(:api_authentication)
  @description = args[:description] if args.key?(:description)
  @ignore_unknown_fields = args[:ignore_unknown_fields] if args.key?(:ignore_unknown_fields)
  @name = args[:name] if args.key?(:name)
  @open_api_schema = args[:open_api_schema] if args.key?(:open_api_schema)
  @service_directory_config = args[:service_directory_config] if args.key?(:service_directory_config)
  @tls_config = args[:tls_config] if args.key?(:tls_config)
  @url = args[:url] if args.key?(:url)
end