Class: Google::Apis::CesV1::RetrieveToolsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Request message for ToolService.RetrieveTools.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RetrieveToolsRequest

Returns a new instance of RetrieveToolsRequest.



6959
6960
6961
# File 'lib/google/apis/ces_v1/classes.rb', line 6959

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bypass_persistence_configBoolean Also known as: bypass_persistence_config?

Optional. If true, the returned tools will contain raw descriptions and schemas directly from the server, bypassing any stored persistence configurations (overrides/snapshots). Corresponds to the JSON property bypassPersistenceConfig

Returns:

  • (Boolean)


6950
6951
6952
# File 'lib/google/apis/ces_v1/classes.rb', line 6950

def bypass_persistence_config
  @bypass_persistence_config
end

#tool_idsArray<String>

Optional. The identifiers of the tools to retrieve from the toolset. If empty, all tools in the toolset will be returned. Corresponds to the JSON property toolIds

Returns:

  • (Array<String>)


6957
6958
6959
# File 'lib/google/apis/ces_v1/classes.rb', line 6957

def tool_ids
  @tool_ids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6964
6965
6966
6967
# File 'lib/google/apis/ces_v1/classes.rb', line 6964

def update!(**args)
  @bypass_persistence_config = args[:bypass_persistence_config] if args.key?(:bypass_persistence_config)
  @tool_ids = args[:tool_ids] if args.key?(:tool_ids)
end