Class: Google::Apis::CesV1::RetrieveToolsResponse
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::RetrieveToolsResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Response message for ToolService.RetrieveTools.
Instance Attribute Summary collapse
-
#tools ⇒ Array<Google::Apis::CesV1::Tool>
The list of tools that are included in the specified toolset.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RetrieveToolsResponse
constructor
A new instance of RetrieveToolsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RetrieveToolsResponse
Returns a new instance of RetrieveToolsResponse.
6999 7000 7001 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6999 def initialize(**args) update!(**args) end |
Instance Attribute Details
#tools ⇒ Array<Google::Apis::CesV1::Tool>
The list of tools that are included in the specified toolset.
Corresponds to the JSON property tools
6997 6998 6999 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6997 def tools @tools end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7004 7005 7006 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7004 def update!(**args) @tools = args[:tools] if args.key?(:tools) end |