Class: Google::Apis::CesV1::SessionConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

The configuration for the session.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SessionConfig

Returns a new instance of SessionConfig.



7439
7440
7441
# File 'lib/google/apis/ces_v1/classes.rb', line 7439

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deploymentString

Optional. The deployment of the app to use for the session. Format: projects/ project/locations/location/apps/app/deployments/deployment` Corresponds to the JSON propertydeployment`

Returns:

  • (String)


7370
7371
7372
# File 'lib/google/apis/ces_v1/classes.rb', line 7370

def deployment
  @deployment
end

#enable_text_streamingBoolean Also known as: enable_text_streaming?

Optional. Whether to enable streaming text outputs from the model. By default, text outputs from the model are collected before sending to the client. NOTE: This is only supported for text (non-voice) sessions via StreamRunSession or BidiRunSession. Corresponds to the JSON property enableTextStreaming

Returns:

  • (Boolean)


7378
7379
7380
# File 'lib/google/apis/ces_v1/classes.rb', line 7378

def enable_text_streaming
  @enable_text_streaming
end

#entry_agentString

Optional. The entry agent to handle the session. If not specified, the session will be handled by the root agent of the app. Format: projects/project/ locations/location/apps/app/agents/agent` Corresponds to the JSON propertyentryAgent`

Returns:

  • (String)


7386
7387
7388
# File 'lib/google/apis/ces_v1/classes.rb', line 7386

def entry_agent
  @entry_agent
end

#exclude_diagnostic_infoBoolean Also known as: exclude_diagnostic_info?

Optional. Whether to exclude diagnostic info from the session output. Corresponds to the JSON property excludeDiagnosticInfo

Returns:

  • (Boolean)


7391
7392
7393
# File 'lib/google/apis/ces_v1/classes.rb', line 7391

def exclude_diagnostic_info
  @exclude_diagnostic_info
end

#historical_contextsArray<Google::Apis::CesV1::Message>

Optional. The historical context of the session, including user inputs, agent responses, and other messages. Typically, CES agent would manage session automatically so client doesn't need to explicitly populate this field. However, client can optionally override the historical contexts to force the session start from certain state. Corresponds to the JSON property historicalContexts

Returns:



7401
7402
7403
# File 'lib/google/apis/ces_v1/classes.rb', line 7401

def historical_contexts
  @historical_contexts
end

#input_audio_configGoogle::Apis::CesV1::InputAudioConfig

InputAudioConfig configures how the CES agent should interpret the incoming audio data. Corresponds to the JSON property inputAudioConfig



7407
7408
7409
# File 'lib/google/apis/ces_v1/classes.rb', line 7407

def input_audio_config
  @input_audio_config
end

#output_audio_configGoogle::Apis::CesV1::OutputAudioConfig

OutputAudioConfig configures how the CES agent should synthesize outgoing audio responses. Corresponds to the JSON property outputAudioConfig



7413
7414
7415
# File 'lib/google/apis/ces_v1/classes.rb', line 7413

def output_audio_config
  @output_audio_config
end

#remote_dialogflow_query_parametersGoogle::Apis::CesV1::SessionConfigRemoteDialogflowQueryParameters

QueryParameters to send to the remote Dialogflow agent when the session control is transferred to the remote agent. Corresponds to the JSON property remoteDialogflowQueryParameters



7422
7423
7424
# File 'lib/google/apis/ces_v1/classes.rb', line 7422

def remote_dialogflow_query_parameters
  @remote_dialogflow_query_parameters
end

#time_zoneString

Optional. The time zone of the user. If provided, the agent will use the time zone for date and time related variables. Otherwise, the agent will use the time zone specified in the App.time_zone_settings. The format is the IANA Time Zone Database time zone, e.g. "America/Los_Angeles". Corresponds to the JSON property timeZone

Returns:

  • (String)


7430
7431
7432
# File 'lib/google/apis/ces_v1/classes.rb', line 7430

def time_zone
  @time_zone
end

#use_tool_fakesBoolean Also known as: use_tool_fakes?

Optional. Whether to use tool fakes for the session. If this field is set, the agent will attempt use tool fakes instead of calling the real tools. Corresponds to the JSON property useToolFakes

Returns:

  • (Boolean)


7436
7437
7438
# File 'lib/google/apis/ces_v1/classes.rb', line 7436

def use_tool_fakes
  @use_tool_fakes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7444
7445
7446
7447
7448
7449
7450
7451
7452
7453
7454
7455
# File 'lib/google/apis/ces_v1/classes.rb', line 7444

def update!(**args)
  @deployment = args[:deployment] if args.key?(:deployment)
  @enable_text_streaming = args[:enable_text_streaming] if args.key?(:enable_text_streaming)
  @entry_agent = args[:entry_agent] if args.key?(:entry_agent)
  @exclude_diagnostic_info = args[:exclude_diagnostic_info] if args.key?(:exclude_diagnostic_info)
  @historical_contexts = args[:historical_contexts] if args.key?(:historical_contexts)
  @input_audio_config = args[:input_audio_config] if args.key?(:input_audio_config)
  @output_audio_config = args[:output_audio_config] if args.key?(:output_audio_config)
  @remote_dialogflow_query_parameters = args[:remote_dialogflow_query_parameters] if args.key?(:remote_dialogflow_query_parameters)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
  @use_tool_fakes = args[:use_tool_fakes] if args.key?(:use_tool_fakes)
end