Class: Google::Apis::CesV1::Span
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::Span
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
A span is a unit of work or a single operation during the request processing.
Instance Attribute Summary collapse
-
#attributes ⇒ Hash<String,Object>
Output only.
-
#child_spans ⇒ Array<Google::Apis::CesV1::Span>
Output only.
-
#duration ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#start_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Span
constructor
A new instance of Span.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Span
Returns a new instance of Span.
7705 7706 7707 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7705 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attributes ⇒ Hash<String,Object>
Output only. Key-value attributes associated with the span.
Corresponds to the JSON property attributes
7678 7679 7680 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7678 def attributes @attributes end |
#child_spans ⇒ Array<Google::Apis::CesV1::Span>
Output only. The child spans that are nested under this span.
Corresponds to the JSON property childSpans
7683 7684 7685 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7683 def child_spans @child_spans end |
#duration ⇒ String
Output only. The duration of the span.
Corresponds to the JSON property duration
7688 7689 7690 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7688 def duration @duration end |
#end_time ⇒ String
Output only. The end time of the span.
Corresponds to the JSON property endTime
7693 7694 7695 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7693 def end_time @end_time end |
#name ⇒ String
Output only. The name of the span.
Corresponds to the JSON property name
7698 7699 7700 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7698 def name @name end |
#start_time ⇒ String
Output only. The start time of the span.
Corresponds to the JSON property startTime
7703 7704 7705 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7703 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7710 7711 7712 7713 7714 7715 7716 7717 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7710 def update!(**args) @attributes = args[:attributes] if args.key?(:attributes) @child_spans = args[:child_spans] if args.key?(:child_spans) @duration = args[:duration] if args.key?(:duration) @end_time = args[:end_time] if args.key?(:end_time) @name = args[:name] if args.key?(:name) @start_time = args[:start_time] if args.key?(:start_time) end |