Class: Google::Apis::CesV1::ToolFakeConfig
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::ToolFakeConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Configuration for tool behavior in fake mode.
Instance Attribute Summary collapse
-
#code_block ⇒ Google::Apis::CesV1::CodeBlock
A code block to be executed instead of a real tool call.
-
#enable_fake_mode ⇒ Boolean
(also: #enable_fake_mode?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ToolFakeConfig
constructor
A new instance of ToolFakeConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ToolFakeConfig
Returns a new instance of ToolFakeConfig.
8087 8088 8089 |
# File 'lib/google/apis/ces_v1/classes.rb', line 8087 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code_block ⇒ Google::Apis::CesV1::CodeBlock
A code block to be executed instead of a real tool call.
Corresponds to the JSON property codeBlock
8079 8080 8081 |
# File 'lib/google/apis/ces_v1/classes.rb', line 8079 def code_block @code_block end |
#enable_fake_mode ⇒ Boolean Also known as: enable_fake_mode?
Optional. Whether the tool is using fake mode.
Corresponds to the JSON property enableFakeMode
8084 8085 8086 |
# File 'lib/google/apis/ces_v1/classes.rb', line 8084 def enable_fake_mode @enable_fake_mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8092 8093 8094 8095 |
# File 'lib/google/apis/ces_v1/classes.rb', line 8092 def update!(**args) @code_block = args[:code_block] if args.key?(:code_block) @enable_fake_mode = args[:enable_fake_mode] if args.key?(:enable_fake_mode) end |