Class: Google::Apis::CesV1::Toolset

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

A toolset represents a group of dynamically managed tools that can be used by the agent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Toolset

Returns a new instance of Toolset.



8327
8328
8329
# File 'lib/google/apis/ces_v1/classes.rb', line 8327

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connector_toolsetGoogle::Apis::CesV1::ConnectorToolset

A toolset that generates tools from an Integration Connectors Connection. Corresponds to the JSON property connectorToolset



8265
8266
8267
# File 'lib/google/apis/ces_v1/classes.rb', line 8265

def connector_toolset
  @connector_toolset
end

#create_timeString

Output only. Timestamp when the toolset was created. Corresponds to the JSON property createTime

Returns:

  • (String)


8270
8271
8272
# File 'lib/google/apis/ces_v1/classes.rb', line 8270

def create_time
  @create_time
end

#descriptionString

Optional. The description of the toolset. Corresponds to the JSON property description

Returns:

  • (String)


8275
8276
8277
# File 'lib/google/apis/ces_v1/classes.rb', line 8275

def description
  @description
end

#display_nameString

Optional. The display name of the toolset. Must be unique within the same app. Corresponds to the JSON property displayName

Returns:

  • (String)


8280
8281
8282
# File 'lib/google/apis/ces_v1/classes.rb', line 8280

def display_name
  @display_name
end

#etagString

ETag used to ensure the object hasn't changed during a read-modify-write operation. If the etag is empty, the update will overwrite any concurrent changes. Corresponds to the JSON property etag

Returns:

  • (String)


8287
8288
8289
# File 'lib/google/apis/ces_v1/classes.rb', line 8287

def etag
  @etag
end

#execution_typeString

Optional. The execution type of the tools in the toolset. Corresponds to the JSON property executionType

Returns:

  • (String)


8292
8293
8294
# File 'lib/google/apis/ces_v1/classes.rb', line 8292

def execution_type
  @execution_type
end

#mcp_toolsetGoogle::Apis::CesV1::McpToolset

A toolset that contains a list of tools that are offered by the MCP server. Corresponds to the JSON property mcpToolset



8297
8298
8299
# File 'lib/google/apis/ces_v1/classes.rb', line 8297

def mcp_toolset
  @mcp_toolset
end

#nameString

Identifier. The unique identifier of the toolset. Format: projects/project/ locations/location/apps/app/toolsets/toolset` Corresponds to the JSON propertyname`

Returns:

  • (String)


8303
8304
8305
# File 'lib/google/apis/ces_v1/classes.rb', line 8303

def name
  @name
end

#open_api_toolsetGoogle::Apis::CesV1::OpenApiToolset

A toolset that contains a list of tools that are defined by an OpenAPI schema. Corresponds to the JSON property openApiToolset



8308
8309
8310
# File 'lib/google/apis/ces_v1/classes.rb', line 8308

def open_api_toolset
  @open_api_toolset
end

#timeoutString

Optional. The timeout for the toolset execution. If not set, the default timeout is 30 seconds for SYNCHRONOUS toolsets and 60 seconds for ASYNCHRONOUS toolsets. Corresponds to the JSON property timeout

Returns:

  • (String)


8315
8316
8317
# File 'lib/google/apis/ces_v1/classes.rb', line 8315

def timeout
  @timeout
end

#tool_fake_configGoogle::Apis::CesV1::ToolFakeConfig

Configuration for tool behavior in fake mode. Corresponds to the JSON property toolFakeConfig



8320
8321
8322
# File 'lib/google/apis/ces_v1/classes.rb', line 8320

def tool_fake_config
  @tool_fake_config
end

#update_timeString

Output only. Timestamp when the toolset was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


8325
8326
8327
# File 'lib/google/apis/ces_v1/classes.rb', line 8325

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8332
8333
8334
8335
8336
8337
8338
8339
8340
8341
8342
8343
8344
8345
# File 'lib/google/apis/ces_v1/classes.rb', line 8332

def update!(**args)
  @connector_toolset = args[:connector_toolset] if args.key?(:connector_toolset)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @execution_type = args[:execution_type] if args.key?(:execution_type)
  @mcp_toolset = args[:mcp_toolset] if args.key?(:mcp_toolset)
  @name = args[:name] if args.key?(:name)
  @open_api_toolset = args[:open_api_toolset] if args.key?(:open_api_toolset)
  @timeout = args[:timeout] if args.key?(:timeout)
  @tool_fake_config = args[:tool_fake_config] if args.key?(:tool_fake_config)
  @update_time = args[:update_time] if args.key?(:update_time)
end