Class: Google::Apis::CesV1::TransferRule

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Rule for transferring to a specific agent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TransferRule

Returns a new instance of TransferRule.



8307
8308
8309
# File 'lib/google/apis/ces_v1/classes.rb', line 8307

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#child_agentString

Required. The resource name of the child agent the rule applies to. Format: projects/project/locations/location/apps/app/agents/agent` Corresponds to the JSON propertychildAgent`

Returns:

  • (String)


8289
8290
8291
# File 'lib/google/apis/ces_v1/classes.rb', line 8289

def child_agent
  @child_agent
end

#deterministic_transferGoogle::Apis::CesV1::TransferRuleDeterministicTransfer

Deterministic transfer rule. When the condition evaluates to true, the transfer occurs. Corresponds to the JSON property deterministicTransfer



8295
8296
8297
# File 'lib/google/apis/ces_v1/classes.rb', line 8295

def deterministic_transfer
  @deterministic_transfer
end

#directionString

Required. The direction of the transfer. Corresponds to the JSON property direction

Returns:

  • (String)


8300
8301
8302
# File 'lib/google/apis/ces_v1/classes.rb', line 8300

def direction
  @direction
end

#disable_planner_transferGoogle::Apis::CesV1::TransferRuleDisablePlannerTransfer

A rule that prevents the planner from transferring to the target agent. Corresponds to the JSON property disablePlannerTransfer



8305
8306
8307
# File 'lib/google/apis/ces_v1/classes.rb', line 8305

def disable_planner_transfer
  @disable_planner_transfer
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8312
8313
8314
8315
8316
8317
# File 'lib/google/apis/ces_v1/classes.rb', line 8312

def update!(**args)
  @child_agent = args[:child_agent] if args.key?(:child_agent)
  @deterministic_transfer = args[:deterministic_transfer] if args.key?(:deterministic_transfer)
  @direction = args[:direction] if args.key?(:direction)
  @disable_planner_transfer = args[:disable_planner_transfer] if args.key?(:disable_planner_transfer)
end