Class: Google::Apis::CesV1::TriggerActionRespondImmediately

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

The agent will immediately respond with a preconfigured response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TriggerActionRespondImmediately

Returns a new instance of TriggerActionRespondImmediately.



8451
8452
8453
# File 'lib/google/apis/ces_v1/classes.rb', line 8451

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#responsesArray<Google::Apis::CesV1::TriggerActionResponse>

Required. The canned responses for the agent to choose from. The response is chosen randomly. Corresponds to the JSON property responses



8449
8450
8451
# File 'lib/google/apis/ces_v1/classes.rb', line 8449

def responses
  @responses
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8456
8457
8458
# File 'lib/google/apis/ces_v1/classes.rb', line 8456

def update!(**args)
  @responses = args[:responses] if args.key?(:responses)
end