Class: Google::Apis::CesV1::TriggerActionTransferAgent

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

The agent will transfer the conversation to a different agent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TriggerActionTransferAgent

Returns a new instance of TriggerActionTransferAgent.



6938
6939
6940
# File 'lib/google/apis/ces_v1/classes.rb', line 6938

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agentString

Required. The name of the agent to transfer the conversation to. The agent must be in the same app as the current agent. Format: projects/project/ locations/location/apps/app/agents/agent` Corresponds to the JSON propertyagent`

Returns:

  • (String)


6936
6937
6938
# File 'lib/google/apis/ces_v1/classes.rb', line 6936

def agent
  @agent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6943
6944
6945
# File 'lib/google/apis/ces_v1/classes.rb', line 6943

def update!(**args)
  @agent = args[:agent] if args.key?(:agent)
end