Class: Google::Apis::CesV1::WebSearchQuery

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Represents a single web search query and its associated search uri.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WebSearchQuery

Returns a new instance of WebSearchQuery.



8546
8547
8548
# File 'lib/google/apis/ces_v1/classes.rb', line 8546

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#queryString

The search query text. Corresponds to the JSON property query

Returns:

  • (String)


8539
8540
8541
# File 'lib/google/apis/ces_v1/classes.rb', line 8539

def query
  @query
end

#uriString

The URI to the Google Search results page for the query. Corresponds to the JSON property uri

Returns:

  • (String)


8544
8545
8546
# File 'lib/google/apis/ces_v1/classes.rb', line 8544

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8551
8552
8553
8554
# File 'lib/google/apis/ces_v1/classes.rb', line 8551

def update!(**args)
  @query = args[:query] if args.key?(:query)
  @uri = args[:uri] if args.key?(:uri)
end