Class: Google::Apis::CesV1::WidgetToolDataMapping

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Configuration for mapping data from a source tool to the widget's input parameters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WidgetToolDataMapping

Returns a new instance of WidgetToolDataMapping.



8699
8700
8701
# File 'lib/google/apis/ces_v1/classes.rb', line 8699

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#field_mappingsHash<String,String>

Optional. A map of widget input parameter fields to the corresponding output fields of the source tool. Corresponds to the JSON property fieldMappings

Returns:

  • (Hash<String,String>)


8675
8676
8677
# File 'lib/google/apis/ces_v1/classes.rb', line 8675

def field_mappings
  @field_mappings
end

#modeString

Optional. The mode of the data mapping. Corresponds to the JSON property mode

Returns:

  • (String)


8680
8681
8682
# File 'lib/google/apis/ces_v1/classes.rb', line 8680

def mode
  @mode
end

#python_functionGoogle::Apis::CesV1::PythonFunction

A Python function tool. Corresponds to the JSON property pythonFunction



8685
8686
8687
# File 'lib/google/apis/ces_v1/classes.rb', line 8685

def python_function
  @python_function
end

#python_scriptString

Deprecated: Use python_function instead. Corresponds to the JSON property pythonScript

Returns:

  • (String)


8690
8691
8692
# File 'lib/google/apis/ces_v1/classes.rb', line 8690

def python_script
  @python_script
end

#source_tool_nameString

Optional. The resource name of the tool that provides the data for the widget ( e.g., a search tool or a custom function). Format: projects/project/ locations/location/agents/agent/tools/tool` Corresponds to the JSON propertysourceToolName`

Returns:

  • (String)


8697
8698
8699
# File 'lib/google/apis/ces_v1/classes.rb', line 8697

def source_tool_name
  @source_tool_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8704
8705
8706
8707
8708
8709
8710
# File 'lib/google/apis/ces_v1/classes.rb', line 8704

def update!(**args)
  @field_mappings = args[:field_mappings] if args.key?(:field_mappings)
  @mode = args[:mode] if args.key?(:mode)
  @python_function = args[:python_function] if args.key?(:python_function)
  @python_script = args[:python_script] if args.key?(:python_script)
  @source_tool_name = args[:source_tool_name] if args.key?(:source_tool_name)
end