Class: Google::Apis::CesV1::Action
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::Action
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Configuration of an Action for the tool to use. Note: This can be either an Action or an Operation. See https://cloud.google.com/integration-connectors/ docs/entities-operation-action for details.
Instance Attribute Summary collapse
-
#connection_action_id ⇒ String
ID of a Connection action for the tool to use.
-
#entity_operation ⇒ Google::Apis::CesV1::ActionEntityOperation
Entity CRUD operation specification.
-
#input_fields ⇒ Array<String>
Optional.
-
#output_fields ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Action
constructor
A new instance of Action.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Action
Returns a new instance of Action.
53 54 55 |
# File 'lib/google/apis/ces_v1/classes.rb', line 53 def initialize(**args) update!(**args) end |
Instance Attribute Details
#connection_action_id ⇒ String
ID of a Connection action for the tool to use.
Corresponds to the JSON property connectionActionId
34 35 36 |
# File 'lib/google/apis/ces_v1/classes.rb', line 34 def connection_action_id @connection_action_id end |
#entity_operation ⇒ Google::Apis::CesV1::ActionEntityOperation
Entity CRUD operation specification.
Corresponds to the JSON property entityOperation
39 40 41 |
# File 'lib/google/apis/ces_v1/classes.rb', line 39 def entity_operation @entity_operation end |
#input_fields ⇒ Array<String>
Optional. Entity fields to use as inputs for the operation. If no fields are
specified, all fields of the Entity will be used.
Corresponds to the JSON property inputFields
45 46 47 |
# File 'lib/google/apis/ces_v1/classes.rb', line 45 def input_fields @input_fields end |
#output_fields ⇒ Array<String>
Optional. Entity fields to return from the operation. If no fields are
specified, all fields of the Entity will be returned.
Corresponds to the JSON property outputFields
51 52 53 |
# File 'lib/google/apis/ces_v1/classes.rb', line 51 def output_fields @output_fields end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
58 59 60 61 62 63 |
# File 'lib/google/apis/ces_v1/classes.rb', line 58 def update!(**args) @connection_action_id = args[:connection_action_id] if args.key?(:connection_action_id) @entity_operation = args[:entity_operation] if args.key?(:entity_operation) @input_fields = args[:input_fields] if args.key?(:input_fields) @output_fields = args[:output_fields] if args.key?(:output_fields) end |