Class: Google::Apis::CesV1::AgentRemoteDialogflowAgent
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::AgentRemoteDialogflowAgent
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
The agent which will transfer execution to a remote Dialogflow CX agent. The Dialogflow agent will process subsequent user queries until the session ends or flow ends, and the control is transferred back to the parent CES agent.
Instance Attribute Summary collapse
-
#agent ⇒ String
Required.
-
#environment_id ⇒ String
Optional.
-
#flow_id ⇒ String
Optional.
-
#input_variable_mapping ⇒ Hash<String,String>
Optional.
-
#output_variable_mapping ⇒ Hash<String,String>
Optional.
-
#respect_response_interruption_settings ⇒ Boolean
(also: #respect_response_interruption_settings?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AgentRemoteDialogflowAgent
constructor
A new instance of AgentRemoteDialogflowAgent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AgentRemoteDialogflowAgent
Returns a new instance of AgentRemoteDialogflowAgent.
361 362 363 |
# File 'lib/google/apis/ces_v1/classes.rb', line 361 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent ⇒ String
Required. The Dialogflow agent resource name. Format: projects/project/locations/
location/agents/agent`
Corresponds to the JSON propertyagent`
323 324 325 |
# File 'lib/google/apis/ces_v1/classes.rb', line 323 def agent @agent end |
#environment_id ⇒ String
Optional. The environment ID of the Dialogflow agent to be used for the agent
execution. If not specified, the draft environment will be used.
Corresponds to the JSON property environmentId
329 330 331 |
# File 'lib/google/apis/ces_v1/classes.rb', line 329 def environment_id @environment_id end |
#flow_id ⇒ String
Optional. The flow ID of the flow in the Dialogflow agent.
Corresponds to the JSON property flowId
334 335 336 |
# File 'lib/google/apis/ces_v1/classes.rb', line 334 def flow_id @flow_id end |
#input_variable_mapping ⇒ Hash<String,String>
Optional. The mapping of the app variables names to the Dialogflow session
parameters names to be sent to the Dialogflow agent as input.
Corresponds to the JSON property inputVariableMapping
340 341 342 |
# File 'lib/google/apis/ces_v1/classes.rb', line 340 def input_variable_mapping @input_variable_mapping end |
#output_variable_mapping ⇒ Hash<String,String>
Optional. The mapping of the Dialogflow session parameters names to the app
variables names to be sent back to the CES agent after the Dialogflow agent
execution ends.
Corresponds to the JSON property outputVariableMapping
347 348 349 |
# File 'lib/google/apis/ces_v1/classes.rb', line 347 def output_variable_mapping @output_variable_mapping end |
#respect_response_interruption_settings ⇒ Boolean Also known as: respect_response_interruption_settings?
Optional. Indicates whether to respect the message-level interruption settings
configured in the Dialogflow agent. * If false: all response messages from the
Dialogflow agent follow the app-level barge-in settings. * If true: only
response messages with allow_playback_interruption
set to true will be interruptable, all other messages follow the app-level
barge-in settings.
Corresponds to the JSON property respectResponseInterruptionSettings
358 359 360 |
# File 'lib/google/apis/ces_v1/classes.rb', line 358 def respect_response_interruption_settings @respect_response_interruption_settings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
366 367 368 369 370 371 372 373 |
# File 'lib/google/apis/ces_v1/classes.rb', line 366 def update!(**args) @agent = args[:agent] if args.key?(:agent) @environment_id = args[:environment_id] if args.key?(:environment_id) @flow_id = args[:flow_id] if args.key?(:flow_id) @input_variable_mapping = args[:input_variable_mapping] if args.key?(:input_variable_mapping) @output_variable_mapping = args[:output_variable_mapping] if args.key?(:output_variable_mapping) @respect_response_interruption_settings = args[:respect_response_interruption_settings] if args.key?(:respect_response_interruption_settings) end |