Class: Google::Apis::CesV1::AgentSkill

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Represents a distinct capability or function that an agent can perform.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AgentSkill

Returns a new instance of AgentSkill.



515
516
517
# File 'lib/google/apis/ces_v1/classes.rb', line 515

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Required. A detailed description of the skill. Corresponds to the JSON property description

Returns:

  • (String)


481
482
483
# File 'lib/google/apis/ces_v1/classes.rb', line 481

def description
  @description
end

#examplesArray<String>

Example prompts or scenarios that this skill can handle. Corresponds to the JSON property examples

Returns:

  • (Array<String>)


486
487
488
# File 'lib/google/apis/ces_v1/classes.rb', line 486

def examples
  @examples
end

#idString

Required. A unique identifier for the agent's skill. Corresponds to the JSON property id

Returns:

  • (String)


491
492
493
# File 'lib/google/apis/ces_v1/classes.rb', line 491

def id
  @id
end

#input_modesArray<String>

The set of supported input media types for this skill, overriding the agent's defaults. Corresponds to the JSON property inputModes

Returns:

  • (Array<String>)


497
498
499
# File 'lib/google/apis/ces_v1/classes.rb', line 497

def input_modes
  @input_modes
end

#nameString

Required. A human-readable name for the skill. Corresponds to the JSON property name

Returns:

  • (String)


502
503
504
# File 'lib/google/apis/ces_v1/classes.rb', line 502

def name
  @name
end

#output_modesArray<String>

The set of supported output media types for this skill, overriding the agent's defaults. Corresponds to the JSON property outputModes

Returns:

  • (Array<String>)


508
509
510
# File 'lib/google/apis/ces_v1/classes.rb', line 508

def output_modes
  @output_modes
end

#tagsArray<String>

Required. A set of keywords describing the skill's capabilities. Corresponds to the JSON property tags

Returns:

  • (Array<String>)


513
514
515
# File 'lib/google/apis/ces_v1/classes.rb', line 513

def tags
  @tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



520
521
522
523
524
525
526
527
528
# File 'lib/google/apis/ces_v1/classes.rb', line 520

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @examples = args[:examples] if args.key?(:examples)
  @id = args[:id] if args.key?(:id)
  @input_modes = args[:input_modes] if args.key?(:input_modes)
  @name = args[:name] if args.key?(:name)
  @output_modes = args[:output_modes] if args.key?(:output_modes)
  @tags = args[:tags] if args.key?(:tags)
end