Class: Google::Apis::CesV1::AgentTool

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Represents a tool that allows the agent to call another agent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AgentTool

Returns a new instance of AgentTool.



566
567
568
# File 'lib/google/apis/ces_v1/classes.rb', line 566

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agentString

Optional. The resource name of the agent that is the entry point of the tool. Format: projects/project/locations/location/agents/agent` Corresponds to the JSON propertyagent`

Returns:

  • (String)


547
548
549
# File 'lib/google/apis/ces_v1/classes.rb', line 547

def agent
  @agent
end

#descriptionString

Optional. Description of the tool's purpose. Corresponds to the JSON property description

Returns:

  • (String)


552
553
554
# File 'lib/google/apis/ces_v1/classes.rb', line 552

def description
  @description
end

#nameString

Required. The name of the agent tool. Corresponds to the JSON property name

Returns:

  • (String)


557
558
559
# File 'lib/google/apis/ces_v1/classes.rb', line 557

def name
  @name
end

#root_agentString

Optional. Deprecated: Use agent instead. The resource name of the root agent that is the entry point of the tool. Format: projects/project/locations/ location/agents/agent` Corresponds to the JSON propertyrootAgent`

Returns:

  • (String)


564
565
566
# File 'lib/google/apis/ces_v1/classes.rb', line 564

def root_agent
  @root_agent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



571
572
573
574
575
576
# File 'lib/google/apis/ces_v1/classes.rb', line 571

def update!(**args)
  @agent = args[:agent] if args.key?(:agent)
  @description = args[:description] if args.key?(:description)
  @name = args[:name] if args.key?(:name)
  @root_agent = args[:root_agent] if args.key?(:root_agent)
end