Class: Google::Apis::CesV1::AgentTool
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::AgentTool
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Represents a tool that allows the agent to call another agent.
Instance Attribute Summary collapse
-
#agent ⇒ String
Optional.
-
#description ⇒ String
Optional.
-
#name ⇒ String
Required.
-
#root_agent ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AgentTool
constructor
A new instance of AgentTool.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AgentTool
Returns a new instance of AgentTool.
558 559 560 |
# File 'lib/google/apis/ces_v1/classes.rb', line 558 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent ⇒ String
Optional. The resource name of the agent that is the entry point of the tool.
Format: projects/project/locations/location/agents/agent`
Corresponds to the JSON propertyagent`
539 540 541 |
# File 'lib/google/apis/ces_v1/classes.rb', line 539 def agent @agent end |
#description ⇒ String
Optional. Description of the tool's purpose.
Corresponds to the JSON property description
544 545 546 |
# File 'lib/google/apis/ces_v1/classes.rb', line 544 def description @description end |
#name ⇒ String
Required. The name of the agent tool.
Corresponds to the JSON property name
549 550 551 |
# File 'lib/google/apis/ces_v1/classes.rb', line 549 def name @name end |
#root_agent ⇒ String
Optional. Deprecated: Use agent instead. The resource name of the root agent
that is the entry point of the tool. Format: projects/project/locations/
location/agents/agent`
Corresponds to the JSON propertyrootAgent`
556 557 558 |
# File 'lib/google/apis/ces_v1/classes.rb', line 556 def root_agent @root_agent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
563 564 565 566 567 568 |
# File 'lib/google/apis/ces_v1/classes.rb', line 563 def update!(**args) @agent = args[:agent] if args.key?(:agent) @description = args[:description] if args.key?(:description) @name = args[:name] if args.key?(:name) @root_agent = args[:root_agent] if args.key?(:root_agent) end |