Class: Google::Apis::CesV1::AgentTool
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::AgentTool
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Represents a tool that allows the agent to call another agent.
Instance Attribute Summary collapse
-
#agent ⇒ String
Optional.
-
#description ⇒ String
Optional.
-
#name ⇒ String
Required.
-
#root_agent ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AgentTool
constructor
A new instance of AgentTool.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AgentTool
Returns a new instance of AgentTool.
403 404 405 |
# File 'lib/google/apis/ces_v1/classes.rb', line 403 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent ⇒ String
Optional. The resource name of the agent that is the entry point of the tool.
Format: projects/project/locations/location/agents/agent`
Corresponds to the JSON propertyagent`
384 385 386 |
# File 'lib/google/apis/ces_v1/classes.rb', line 384 def agent @agent end |
#description ⇒ String
Optional. Description of the tool's purpose.
Corresponds to the JSON property description
389 390 391 |
# File 'lib/google/apis/ces_v1/classes.rb', line 389 def description @description end |
#name ⇒ String
Required. The name of the agent tool.
Corresponds to the JSON property name
394 395 396 |
# File 'lib/google/apis/ces_v1/classes.rb', line 394 def name @name end |
#root_agent ⇒ String
Optional. Deprecated: Use agent instead. The resource name of the root agent
that is the entry point of the tool. Format: projects/project/locations/
location/agents/agent`
Corresponds to the JSON propertyrootAgent`
401 402 403 |
# File 'lib/google/apis/ces_v1/classes.rb', line 401 def root_agent @root_agent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
408 409 410 411 412 413 |
# File 'lib/google/apis/ces_v1/classes.rb', line 408 def update!(**args) @agent = args[:agent] if args.key?(:agent) @description = args[:description] if args.key?(:description) @name = args[:name] if args.key?(:name) @root_agent = args[:root_agent] if args.key?(:root_agent) end |