Class: Google::Apis::CesV1::AgentTransfer
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::AgentTransfer
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Represents an event indicating the transfer of a conversation to a different agent.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Output only.
-
#target_agent ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AgentTransfer
constructor
A new instance of AgentTransfer.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AgentTransfer
Returns a new instance of AgentTransfer.
433 434 435 |
# File 'lib/google/apis/ces_v1/classes.rb', line 433 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Output only. Display name of the agent.
Corresponds to the JSON property displayName
424 425 426 |
# File 'lib/google/apis/ces_v1/classes.rb', line 424 def display_name @display_name end |
#target_agent ⇒ String
Required. The agent to which the conversation is being transferred. The agent
will handle the conversation from this point forward. Format: projects/
project/locations/location/apps/app/agents/agent`
Corresponds to the JSON propertytargetAgent`
431 432 433 |
# File 'lib/google/apis/ces_v1/classes.rb', line 431 def target_agent @target_agent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
438 439 440 441 |
# File 'lib/google/apis/ces_v1/classes.rb', line 438 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @target_agent = args[:target_agent] if args.key?(:target_agent) end |