Class: Google::Apis::CesV1::AmbientSoundConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Configuration for the ambient sound to be played with the synthesized agent response, to enhance the naturalness of the conversation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AmbientSoundConfig

Returns a new instance of AmbientSoundConfig.



637
638
639
# File 'lib/google/apis/ces_v1/classes.rb', line 637

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gcs_uriString

Optional. Ambient noise as a mono-channel, 16kHz WAV file stored in Cloud Storage. Note: Please make sure the CES service agent service-@gcp-sa-ces.iam.gserviceaccount.com has storage. objects.get permission to the Cloud Storage object. Corresponds to the JSON property gcsUri

Returns:

  • (String)


610
611
612
# File 'lib/google/apis/ces_v1/classes.rb', line 610

def gcs_uri
  @gcs_uri
end

#prebuilt_ambient_noiseString

Optional. Deprecated: prebuilt_ambient_noise is deprecated in favor of prebuilt_ambient_sound. Corresponds to the JSON property prebuiltAmbientNoise

Returns:

  • (String)


616
617
618
# File 'lib/google/apis/ces_v1/classes.rb', line 616

def prebuilt_ambient_noise
  @prebuilt_ambient_noise
end

#prebuilt_ambient_soundString

Optional. Name of the prebuilt ambient sound. Valid values are: - "coffee_shop"

  • "keyboard" - "keypad" - "hum" - "office_1" - "office_2" - "office_3" - " room_1" - "room_2" - "room_3" - "room_4" - "room_5" - "air_conditioner" Corresponds to the JSON property prebuiltAmbientSound

Returns:

  • (String)


623
624
625
# File 'lib/google/apis/ces_v1/classes.rb', line 623

def prebuilt_ambient_sound
  @prebuilt_ambient_sound
end

#volume_gain_dbFloat

Optional. Volume gain (in dB) of the normal native volume supported by ambient noise, in the range [-96.0, 16.0]. If unset, or set to a value of 0.0 (dB), will play at normal native signal amplitude. A value of -6.0 (dB) will play at approximately half the amplitude of the normal native signal amplitude. A value of +6.0 (dB) will play at approximately twice the amplitude of the normal native signal amplitude. We strongly recommend not to exceed +10 (dB) as there's usually no effective increase in loudness for any value greater than that. Corresponds to the JSON property volumeGainDb

Returns:

  • (Float)


635
636
637
# File 'lib/google/apis/ces_v1/classes.rb', line 635

def volume_gain_db
  @volume_gain_db
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



642
643
644
645
646
647
# File 'lib/google/apis/ces_v1/classes.rb', line 642

def update!(**args)
  @gcs_uri = args[:gcs_uri] if args.key?(:gcs_uri)
  @prebuilt_ambient_noise = args[:prebuilt_ambient_noise] if args.key?(:prebuilt_ambient_noise)
  @prebuilt_ambient_sound = args[:prebuilt_ambient_sound] if args.key?(:prebuilt_ambient_sound)
  @volume_gain_db = args[:volume_gain_db] if args.key?(:volume_gain_db)
end