Class: Google::Apis::CesV1::AmbientSoundConfig
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::AmbientSoundConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Configuration for the ambient sound to be played with the synthesized agent response, to enhance the naturalness of the conversation.
Instance Attribute Summary collapse
-
#gcs_uri ⇒ String
Optional.
-
#prebuilt_ambient_noise ⇒ String
Optional.
-
#prebuilt_ambient_sound ⇒ String
Optional.
-
#volume_gain_db ⇒ Float
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AmbientSoundConfig
constructor
A new instance of AmbientSoundConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AmbientSoundConfig
Returns a new instance of AmbientSoundConfig.
482 483 484 |
# File 'lib/google/apis/ces_v1/classes.rb', line 482 def initialize(**args) update!(**args) end |
Instance Attribute Details
#gcs_uri ⇒ String
Optional. Ambient noise as a mono-channel, 16kHz WAV file stored in Cloud
Storage. Note: Please make sure the CES
service agent service-@gcp-sa-ces.iam.gserviceaccount.com has storage.
objects.get permission to the Cloud Storage object.
Corresponds to the JSON property gcsUri
455 456 457 |
# File 'lib/google/apis/ces_v1/classes.rb', line 455 def gcs_uri @gcs_uri end |
#prebuilt_ambient_noise ⇒ String
Optional. Deprecated: prebuilt_ambient_noise is deprecated in favor of
prebuilt_ambient_sound.
Corresponds to the JSON property prebuiltAmbientNoise
461 462 463 |
# File 'lib/google/apis/ces_v1/classes.rb', line 461 def prebuilt_ambient_noise @prebuilt_ambient_noise end |
#prebuilt_ambient_sound ⇒ String
Optional. Name of the prebuilt ambient sound. Valid values are: - "coffee_shop"
- "keyboard" - "keypad" - "hum" - "office_1" - "office_2" - "office_3" - "
room_1" - "room_2" - "room_3" - "room_4" - "room_5" - "air_conditioner"
Corresponds to the JSON property
prebuiltAmbientSound
468 469 470 |
# File 'lib/google/apis/ces_v1/classes.rb', line 468 def prebuilt_ambient_sound @prebuilt_ambient_sound end |
#volume_gain_db ⇒ Float
Optional. Volume gain (in dB) of the normal native volume supported by ambient
noise, in the range [-96.0, 16.0]. If unset, or set to a value of 0.0 (dB),
will play at normal native signal amplitude. A value of -6.0 (dB) will play at
approximately half the amplitude of the normal native signal amplitude. A
value of +6.0 (dB) will play at approximately twice the amplitude of the
normal native signal amplitude. We strongly recommend not to exceed +10 (dB)
as there's usually no effective increase in loudness for any value greater
than that.
Corresponds to the JSON property volumeGainDb
480 481 482 |
# File 'lib/google/apis/ces_v1/classes.rb', line 480 def volume_gain_db @volume_gain_db end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
487 488 489 490 491 492 |
# File 'lib/google/apis/ces_v1/classes.rb', line 487 def update!(**args) @gcs_uri = args[:gcs_uri] if args.key?(:gcs_uri) @prebuilt_ambient_noise = args[:prebuilt_ambient_noise] if args.key?(:prebuilt_ambient_noise) @prebuilt_ambient_sound = args[:prebuilt_ambient_sound] if args.key?(:prebuilt_ambient_sound) @volume_gain_db = args[:volume_gain_db] if args.key?(:volume_gain_db) end |