Class: Google::Apis::CesV1::App
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::App
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
An app serves as a top-level container for a group of agents, including the root agent and its sub-agents, along with their associated configurations. These agents work together to achieve specific goals within the app's context.
Instance Attribute Summary collapse
-
#audio_processing_config ⇒ Google::Apis::CesV1::AudioProcessingConfig
Configuration for how the input and output audio should be processed and delivered.
-
#client_certificate_settings ⇒ Google::Apis::CesV1::ClientCertificateSettings
Settings for custom client certificates.
-
#create_time ⇒ String
Output only.
-
#data_store_settings ⇒ Google::Apis::CesV1::DataStoreSettings
Data store related settings for the app.
-
#default_channel_profile ⇒ Google::Apis::CesV1::ChannelProfile
A ChannelProfile configures the agent's behavior for a specific communication channel, such as web UI or telephony.
-
#deployment_count ⇒ Fixnum
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Required.
-
#error_handling_settings ⇒ Google::Apis::CesV1::ErrorHandlingSettings
Settings to describe how errors should be handled in the app.
-
#etag ⇒ String
Output only.
-
#evaluation_metrics_thresholds ⇒ Google::Apis::CesV1::EvaluationMetricsThresholds
Threshold settings for metrics in an Evaluation.
-
#global_instruction ⇒ String
Optional.
-
#guardrails ⇒ Array<String>
Optional.
-
#language_settings ⇒ Google::Apis::CesV1::LanguageSettings
Language settings of the app.
-
#locked ⇒ Boolean
(also: #locked?)
Optional.
-
#logging_settings ⇒ Google::Apis::CesV1::LoggingSettings
Settings to describe the logging behaviors for the app.
-
#metadata ⇒ Hash<String,String>
Optional.
-
#model_settings ⇒ Google::Apis::CesV1::ModelSettings
Model settings contains various configurations for the LLM model.
-
#name ⇒ String
Identifier.
-
#pinned ⇒ Boolean
(also: #pinned?)
Optional.
-
#predefined_variable_declarations ⇒ Array<Google::Apis::CesV1::AppVariableDeclaration>
Output only.
-
#root_agent ⇒ String
Optional.
-
#time_zone_settings ⇒ Google::Apis::CesV1::TimeZoneSettings
TimeZone settings of the app.
-
#tool_execution_mode ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
-
#validation_errors ⇒ Array<String>
Output only.
-
#variable_declarations ⇒ Array<Google::Apis::CesV1::AppVariableDeclaration>
Optional.
-
#vpc_sc_settings ⇒ Google::Apis::CesV1::VpcScSettings
VPC-SC settings for the app.
Instance Method Summary collapse
-
#initialize(**args) ⇒ App
constructor
A new instance of App.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ App
Returns a new instance of App.
889 890 891 |
# File 'lib/google/apis/ces_v1/classes.rb', line 889 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audio_processing_config ⇒ Google::Apis::CesV1::AudioProcessingConfig
Configuration for how the input and output audio should be processed and
delivered.
Corresponds to the JSON property audioProcessingConfig
740 741 742 |
# File 'lib/google/apis/ces_v1/classes.rb', line 740 def audio_processing_config @audio_processing_config end |
#client_certificate_settings ⇒ Google::Apis::CesV1::ClientCertificateSettings
Settings for custom client certificates.
Corresponds to the JSON property clientCertificateSettings
745 746 747 |
# File 'lib/google/apis/ces_v1/classes.rb', line 745 def client_certificate_settings @client_certificate_settings end |
#create_time ⇒ String
Output only. Timestamp when the app was created.
Corresponds to the JSON property createTime
750 751 752 |
# File 'lib/google/apis/ces_v1/classes.rb', line 750 def create_time @create_time end |
#data_store_settings ⇒ Google::Apis::CesV1::DataStoreSettings
Data store related settings for the app.
Corresponds to the JSON property dataStoreSettings
755 756 757 |
# File 'lib/google/apis/ces_v1/classes.rb', line 755 def data_store_settings @data_store_settings end |
#default_channel_profile ⇒ Google::Apis::CesV1::ChannelProfile
A ChannelProfile configures the agent's behavior for a specific communication
channel, such as web UI or telephony.
Corresponds to the JSON property defaultChannelProfile
761 762 763 |
# File 'lib/google/apis/ces_v1/classes.rb', line 761 def default_channel_profile @default_channel_profile end |
#deployment_count ⇒ Fixnum
Output only. Number of deployments in the app.
Corresponds to the JSON property deploymentCount
766 767 768 |
# File 'lib/google/apis/ces_v1/classes.rb', line 766 def deployment_count @deployment_count end |
#description ⇒ String
Optional. Human-readable description of the app.
Corresponds to the JSON property description
771 772 773 |
# File 'lib/google/apis/ces_v1/classes.rb', line 771 def description @description end |
#display_name ⇒ String
Required. Display name of the app.
Corresponds to the JSON property displayName
776 777 778 |
# File 'lib/google/apis/ces_v1/classes.rb', line 776 def display_name @display_name end |
#error_handling_settings ⇒ Google::Apis::CesV1::ErrorHandlingSettings
Settings to describe how errors should be handled in the app.
Corresponds to the JSON property errorHandlingSettings
781 782 783 |
# File 'lib/google/apis/ces_v1/classes.rb', line 781 def error_handling_settings @error_handling_settings end |
#etag ⇒ String
Output only. Etag used to ensure the object hasn't changed during a read-
modify-write operation. If the etag is empty, the update will overwrite any
concurrent changes.
Corresponds to the JSON property etag
788 789 790 |
# File 'lib/google/apis/ces_v1/classes.rb', line 788 def etag @etag end |
#evaluation_metrics_thresholds ⇒ Google::Apis::CesV1::EvaluationMetricsThresholds
Threshold settings for metrics in an Evaluation.
Corresponds to the JSON property evaluationMetricsThresholds
793 794 795 |
# File 'lib/google/apis/ces_v1/classes.rb', line 793 def evaluation_metrics_thresholds @evaluation_metrics_thresholds end |
#global_instruction ⇒ String
Optional. Instructions for all the agents in the app. You can use this
instruction to set up a stable identity or personality across all the agents.
Corresponds to the JSON property globalInstruction
799 800 801 |
# File 'lib/google/apis/ces_v1/classes.rb', line 799 def global_instruction @global_instruction end |
#guardrails ⇒ Array<String>
Optional. List of guardrails for the app. Format: projects/project/
locations/location/apps/app/guardrails/guardrail`
Corresponds to the JSON propertyguardrails`
805 806 807 |
# File 'lib/google/apis/ces_v1/classes.rb', line 805 def guardrails @guardrails end |
#language_settings ⇒ Google::Apis::CesV1::LanguageSettings
Language settings of the app.
Corresponds to the JSON property languageSettings
810 811 812 |
# File 'lib/google/apis/ces_v1/classes.rb', line 810 def language_settings @language_settings end |
#locked ⇒ Boolean Also known as: locked?
Optional. Indicates whether the app is locked for changes. If the app is
locked, modifications to the app resources will be rejected.
Corresponds to the JSON property locked
816 817 818 |
# File 'lib/google/apis/ces_v1/classes.rb', line 816 def locked @locked end |
#logging_settings ⇒ Google::Apis::CesV1::LoggingSettings
Settings to describe the logging behaviors for the app.
Corresponds to the JSON property loggingSettings
822 823 824 |
# File 'lib/google/apis/ces_v1/classes.rb', line 822 def logging_settings @logging_settings end |
#metadata ⇒ Hash<String,String>
Optional. Metadata about the app. This field can be used to store additional
information relevant to the app's details or intended usages.
Corresponds to the JSON property metadata
828 829 830 |
# File 'lib/google/apis/ces_v1/classes.rb', line 828 def @metadata end |
#model_settings ⇒ Google::Apis::CesV1::ModelSettings
Model settings contains various configurations for the LLM model.
Corresponds to the JSON property modelSettings
833 834 835 |
# File 'lib/google/apis/ces_v1/classes.rb', line 833 def model_settings @model_settings end |
#name ⇒ String
Identifier. The unique identifier of the app. Format: projects/project/
locations/location/apps/app`
Corresponds to the JSON propertyname`
839 840 841 |
# File 'lib/google/apis/ces_v1/classes.rb', line 839 def name @name end |
#pinned ⇒ Boolean Also known as: pinned?
Optional. Whether the app is pinned in the app list.
Corresponds to the JSON property pinned
844 845 846 |
# File 'lib/google/apis/ces_v1/classes.rb', line 844 def pinned @pinned end |
#predefined_variable_declarations ⇒ Array<Google::Apis::CesV1::AppVariableDeclaration>
Output only. The declarations of predefined variables for the app.
Corresponds to the JSON property predefinedVariableDeclarations
850 851 852 |
# File 'lib/google/apis/ces_v1/classes.rb', line 850 def predefined_variable_declarations @predefined_variable_declarations end |
#root_agent ⇒ String
Optional. The root agent is the entry point of the app. Format: projects/
project/locations/location/apps/app/agents/agent`
Corresponds to the JSON propertyrootAgent`
856 857 858 |
# File 'lib/google/apis/ces_v1/classes.rb', line 856 def root_agent @root_agent end |
#time_zone_settings ⇒ Google::Apis::CesV1::TimeZoneSettings
TimeZone settings of the app.
Corresponds to the JSON property timeZoneSettings
861 862 863 |
# File 'lib/google/apis/ces_v1/classes.rb', line 861 def time_zone_settings @time_zone_settings end |
#tool_execution_mode ⇒ String
Optional. The tool execution mode for the app. If not provided, will default
to PARALLEL.
Corresponds to the JSON property toolExecutionMode
867 868 869 |
# File 'lib/google/apis/ces_v1/classes.rb', line 867 def tool_execution_mode @tool_execution_mode end |
#update_time ⇒ String
Output only. Timestamp when the app was last updated.
Corresponds to the JSON property updateTime
872 873 874 |
# File 'lib/google/apis/ces_v1/classes.rb', line 872 def update_time @update_time end |
#validation_errors ⇒ Array<String>
Output only. Misconfigurations or warnings in the app.
Corresponds to the JSON property validationErrors
877 878 879 |
# File 'lib/google/apis/ces_v1/classes.rb', line 877 def validation_errors @validation_errors end |
#variable_declarations ⇒ Array<Google::Apis::CesV1::AppVariableDeclaration>
Optional. The declarations of the variables.
Corresponds to the JSON property variableDeclarations
882 883 884 |
# File 'lib/google/apis/ces_v1/classes.rb', line 882 def variable_declarations @variable_declarations end |
#vpc_sc_settings ⇒ Google::Apis::CesV1::VpcScSettings
VPC-SC settings for the app.
Corresponds to the JSON property vpcScSettings
887 888 889 |
# File 'lib/google/apis/ces_v1/classes.rb', line 887 def vpc_sc_settings @vpc_sc_settings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 |
# File 'lib/google/apis/ces_v1/classes.rb', line 894 def update!(**args) @audio_processing_config = args[:audio_processing_config] if args.key?(:audio_processing_config) @client_certificate_settings = args[:client_certificate_settings] if args.key?(:client_certificate_settings) @create_time = args[:create_time] if args.key?(:create_time) @data_store_settings = args[:data_store_settings] if args.key?(:data_store_settings) @default_channel_profile = args[:default_channel_profile] if args.key?(:default_channel_profile) @deployment_count = args[:deployment_count] if args.key?(:deployment_count) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @error_handling_settings = args[:error_handling_settings] if args.key?(:error_handling_settings) @etag = args[:etag] if args.key?(:etag) @evaluation_metrics_thresholds = args[:evaluation_metrics_thresholds] if args.key?(:evaluation_metrics_thresholds) @global_instruction = args[:global_instruction] if args.key?(:global_instruction) @guardrails = args[:guardrails] if args.key?(:guardrails) @language_settings = args[:language_settings] if args.key?(:language_settings) @locked = args[:locked] if args.key?(:locked) @logging_settings = args[:logging_settings] if args.key?(:logging_settings) @metadata = args[:metadata] if args.key?(:metadata) @model_settings = args[:model_settings] if args.key?(:model_settings) @name = args[:name] if args.key?(:name) @pinned = args[:pinned] if args.key?(:pinned) @predefined_variable_declarations = args[:predefined_variable_declarations] if args.key?(:predefined_variable_declarations) @root_agent = args[:root_agent] if args.key?(:root_agent) @time_zone_settings = args[:time_zone_settings] if args.key?(:time_zone_settings) @tool_execution_mode = args[:tool_execution_mode] if args.key?(:tool_execution_mode) @update_time = args[:update_time] if args.key?(:update_time) @validation_errors = args[:validation_errors] if args.key?(:validation_errors) @variable_declarations = args[:variable_declarations] if args.key?(:variable_declarations) @vpc_sc_settings = args[:vpc_sc_settings] if args.key?(:vpc_sc_settings) end |