Class: Google::Apis::CesV1::App
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::App
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
An app serves as a top-level container for a group of agents, including the root agent and its sub-agents, along with their associated configurations. These agents work together to achieve specific goals within the app's context.
Instance Attribute Summary collapse
-
#audio_processing_config ⇒ Google::Apis::CesV1::AudioProcessingConfig
Configuration for how the input and output audio should be processed and delivered.
-
#client_certificate_settings ⇒ Google::Apis::CesV1::ClientCertificateSettings
Settings for custom client certificates.
-
#create_time ⇒ String
Output only.
-
#data_store_settings ⇒ Google::Apis::CesV1::DataStoreSettings
Data store related settings for the app.
-
#default_channel_profile ⇒ Google::Apis::CesV1::ChannelProfile
A ChannelProfile configures the agent's behavior for a specific communication channel, such as web UI or telephony.
-
#deployment_count ⇒ Fixnum
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Required.
-
#error_handling_settings ⇒ Google::Apis::CesV1::ErrorHandlingSettings
Settings to describe how errors should be handled in the app.
-
#etag ⇒ String
Output only.
-
#evaluation_metrics_thresholds ⇒ Google::Apis::CesV1::EvaluationMetricsThresholds
Threshold settings for metrics in an Evaluation.
-
#global_instruction ⇒ String
Optional.
-
#guardrails ⇒ Array<String>
Optional.
-
#language_settings ⇒ Google::Apis::CesV1::LanguageSettings
Language settings of the app.
-
#locked ⇒ Boolean
(also: #locked?)
Optional.
-
#logging_settings ⇒ Google::Apis::CesV1::LoggingSettings
Settings to describe the logging behaviors for the app.
-
#metadata ⇒ Hash<String,String>
Optional.
-
#model_settings ⇒ Google::Apis::CesV1::ModelSettings
Model settings contains various configurations for the LLM model.
-
#name ⇒ String
Identifier.
-
#pinned ⇒ Boolean
(also: #pinned?)
Optional.
-
#predefined_variable_declarations ⇒ Array<Google::Apis::CesV1::AppVariableDeclaration>
Output only.
-
#root_agent ⇒ String
Optional.
-
#time_zone_settings ⇒ Google::Apis::CesV1::TimeZoneSettings
TimeZone settings of the app.
-
#tool_execution_mode ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
-
#variable_declarations ⇒ Array<Google::Apis::CesV1::AppVariableDeclaration>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ App
constructor
A new instance of App.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ App
Returns a new instance of App.
724 725 726 |
# File 'lib/google/apis/ces_v1/classes.rb', line 724 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audio_processing_config ⇒ Google::Apis::CesV1::AudioProcessingConfig
Configuration for how the input and output audio should be processed and
delivered.
Corresponds to the JSON property audioProcessingConfig
585 586 587 |
# File 'lib/google/apis/ces_v1/classes.rb', line 585 def audio_processing_config @audio_processing_config end |
#client_certificate_settings ⇒ Google::Apis::CesV1::ClientCertificateSettings
Settings for custom client certificates.
Corresponds to the JSON property clientCertificateSettings
590 591 592 |
# File 'lib/google/apis/ces_v1/classes.rb', line 590 def client_certificate_settings @client_certificate_settings end |
#create_time ⇒ String
Output only. Timestamp when the app was created.
Corresponds to the JSON property createTime
595 596 597 |
# File 'lib/google/apis/ces_v1/classes.rb', line 595 def create_time @create_time end |
#data_store_settings ⇒ Google::Apis::CesV1::DataStoreSettings
Data store related settings for the app.
Corresponds to the JSON property dataStoreSettings
600 601 602 |
# File 'lib/google/apis/ces_v1/classes.rb', line 600 def data_store_settings @data_store_settings end |
#default_channel_profile ⇒ Google::Apis::CesV1::ChannelProfile
A ChannelProfile configures the agent's behavior for a specific communication
channel, such as web UI or telephony.
Corresponds to the JSON property defaultChannelProfile
606 607 608 |
# File 'lib/google/apis/ces_v1/classes.rb', line 606 def default_channel_profile @default_channel_profile end |
#deployment_count ⇒ Fixnum
Output only. Number of deployments in the app.
Corresponds to the JSON property deploymentCount
611 612 613 |
# File 'lib/google/apis/ces_v1/classes.rb', line 611 def deployment_count @deployment_count end |
#description ⇒ String
Optional. Human-readable description of the app.
Corresponds to the JSON property description
616 617 618 |
# File 'lib/google/apis/ces_v1/classes.rb', line 616 def description @description end |
#display_name ⇒ String
Required. Display name of the app.
Corresponds to the JSON property displayName
621 622 623 |
# File 'lib/google/apis/ces_v1/classes.rb', line 621 def display_name @display_name end |
#error_handling_settings ⇒ Google::Apis::CesV1::ErrorHandlingSettings
Settings to describe how errors should be handled in the app.
Corresponds to the JSON property errorHandlingSettings
626 627 628 |
# File 'lib/google/apis/ces_v1/classes.rb', line 626 def error_handling_settings @error_handling_settings end |
#etag ⇒ String
Output only. Etag used to ensure the object hasn't changed during a read-
modify-write operation. If the etag is empty, the update will overwrite any
concurrent changes.
Corresponds to the JSON property etag
633 634 635 |
# File 'lib/google/apis/ces_v1/classes.rb', line 633 def etag @etag end |
#evaluation_metrics_thresholds ⇒ Google::Apis::CesV1::EvaluationMetricsThresholds
Threshold settings for metrics in an Evaluation.
Corresponds to the JSON property evaluationMetricsThresholds
638 639 640 |
# File 'lib/google/apis/ces_v1/classes.rb', line 638 def evaluation_metrics_thresholds @evaluation_metrics_thresholds end |
#global_instruction ⇒ String
Optional. Instructions for all the agents in the app. You can use this
instruction to set up a stable identity or personality across all the agents.
Corresponds to the JSON property globalInstruction
644 645 646 |
# File 'lib/google/apis/ces_v1/classes.rb', line 644 def global_instruction @global_instruction end |
#guardrails ⇒ Array<String>
Optional. List of guardrails for the app. Format: projects/project/
locations/location/apps/app/guardrails/guardrail`
Corresponds to the JSON propertyguardrails`
650 651 652 |
# File 'lib/google/apis/ces_v1/classes.rb', line 650 def guardrails @guardrails end |
#language_settings ⇒ Google::Apis::CesV1::LanguageSettings
Language settings of the app.
Corresponds to the JSON property languageSettings
655 656 657 |
# File 'lib/google/apis/ces_v1/classes.rb', line 655 def language_settings @language_settings end |
#locked ⇒ Boolean Also known as: locked?
Optional. Indicates whether the app is locked for changes. If the app is
locked, modifications to the app resources will be rejected.
Corresponds to the JSON property locked
661 662 663 |
# File 'lib/google/apis/ces_v1/classes.rb', line 661 def locked @locked end |
#logging_settings ⇒ Google::Apis::CesV1::LoggingSettings
Settings to describe the logging behaviors for the app.
Corresponds to the JSON property loggingSettings
667 668 669 |
# File 'lib/google/apis/ces_v1/classes.rb', line 667 def logging_settings @logging_settings end |
#metadata ⇒ Hash<String,String>
Optional. Metadata about the app. This field can be used to store additional
information relevant to the app's details or intended usages.
Corresponds to the JSON property metadata
673 674 675 |
# File 'lib/google/apis/ces_v1/classes.rb', line 673 def @metadata end |
#model_settings ⇒ Google::Apis::CesV1::ModelSettings
Model settings contains various configurations for the LLM model.
Corresponds to the JSON property modelSettings
678 679 680 |
# File 'lib/google/apis/ces_v1/classes.rb', line 678 def model_settings @model_settings end |
#name ⇒ String
Identifier. The unique identifier of the app. Format: projects/project/
locations/location/apps/app`
Corresponds to the JSON propertyname`
684 685 686 |
# File 'lib/google/apis/ces_v1/classes.rb', line 684 def name @name end |
#pinned ⇒ Boolean Also known as: pinned?
Optional. Whether the app is pinned in the app list.
Corresponds to the JSON property pinned
689 690 691 |
# File 'lib/google/apis/ces_v1/classes.rb', line 689 def pinned @pinned end |
#predefined_variable_declarations ⇒ Array<Google::Apis::CesV1::AppVariableDeclaration>
Output only. The declarations of predefined variables for the app.
Corresponds to the JSON property predefinedVariableDeclarations
695 696 697 |
# File 'lib/google/apis/ces_v1/classes.rb', line 695 def predefined_variable_declarations @predefined_variable_declarations end |
#root_agent ⇒ String
Optional. The root agent is the entry point of the app. Format: projects/
project/locations/location/apps/app/agents/agent`
Corresponds to the JSON propertyrootAgent`
701 702 703 |
# File 'lib/google/apis/ces_v1/classes.rb', line 701 def root_agent @root_agent end |
#time_zone_settings ⇒ Google::Apis::CesV1::TimeZoneSettings
TimeZone settings of the app.
Corresponds to the JSON property timeZoneSettings
706 707 708 |
# File 'lib/google/apis/ces_v1/classes.rb', line 706 def time_zone_settings @time_zone_settings end |
#tool_execution_mode ⇒ String
Optional. The tool execution mode for the app. If not provided, will default
to PARALLEL.
Corresponds to the JSON property toolExecutionMode
712 713 714 |
# File 'lib/google/apis/ces_v1/classes.rb', line 712 def tool_execution_mode @tool_execution_mode end |
#update_time ⇒ String
Output only. Timestamp when the app was last updated.
Corresponds to the JSON property updateTime
717 718 719 |
# File 'lib/google/apis/ces_v1/classes.rb', line 717 def update_time @update_time end |
#variable_declarations ⇒ Array<Google::Apis::CesV1::AppVariableDeclaration>
Optional. The declarations of the variables.
Corresponds to the JSON property variableDeclarations
722 723 724 |
# File 'lib/google/apis/ces_v1/classes.rb', line 722 def variable_declarations @variable_declarations end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 |
# File 'lib/google/apis/ces_v1/classes.rb', line 729 def update!(**args) @audio_processing_config = args[:audio_processing_config] if args.key?(:audio_processing_config) @client_certificate_settings = args[:client_certificate_settings] if args.key?(:client_certificate_settings) @create_time = args[:create_time] if args.key?(:create_time) @data_store_settings = args[:data_store_settings] if args.key?(:data_store_settings) @default_channel_profile = args[:default_channel_profile] if args.key?(:default_channel_profile) @deployment_count = args[:deployment_count] if args.key?(:deployment_count) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @error_handling_settings = args[:error_handling_settings] if args.key?(:error_handling_settings) @etag = args[:etag] if args.key?(:etag) @evaluation_metrics_thresholds = args[:evaluation_metrics_thresholds] if args.key?(:evaluation_metrics_thresholds) @global_instruction = args[:global_instruction] if args.key?(:global_instruction) @guardrails = args[:guardrails] if args.key?(:guardrails) @language_settings = args[:language_settings] if args.key?(:language_settings) @locked = args[:locked] if args.key?(:locked) @logging_settings = args[:logging_settings] if args.key?(:logging_settings) @metadata = args[:metadata] if args.key?(:metadata) @model_settings = args[:model_settings] if args.key?(:model_settings) @name = args[:name] if args.key?(:name) @pinned = args[:pinned] if args.key?(:pinned) @predefined_variable_declarations = args[:predefined_variable_declarations] if args.key?(:predefined_variable_declarations) @root_agent = args[:root_agent] if args.key?(:root_agent) @time_zone_settings = args[:time_zone_settings] if args.key?(:time_zone_settings) @tool_execution_mode = args[:tool_execution_mode] if args.key?(:tool_execution_mode) @update_time = args[:update_time] if args.key?(:update_time) @variable_declarations = args[:variable_declarations] if args.key?(:variable_declarations) end |