Class: Google::Apis::CesV1::AppSnapshot

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

A snapshot of the app.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AppSnapshot

Returns a new instance of AppSnapshot.



962
963
964
# File 'lib/google/apis/ces_v1/classes.rb', line 962

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agentsArray<Google::Apis::CesV1::Agent>

Optional. List of agents in the app. Corresponds to the JSON property agents

Returns:



933
934
935
# File 'lib/google/apis/ces_v1/classes.rb', line 933

def agents
  @agents
end

#appGoogle::Apis::CesV1::App

An app serves as a top-level container for a group of agents, including the root agent and its sub-agents, along with their associated configurations. These agents work together to achieve specific goals within the app's context. Corresponds to the JSON property app



940
941
942
# File 'lib/google/apis/ces_v1/classes.rb', line 940

def app
  @app
end

#examplesArray<Google::Apis::CesV1::Example>

Optional. List of examples in the app. Corresponds to the JSON property examples

Returns:



945
946
947
# File 'lib/google/apis/ces_v1/classes.rb', line 945

def examples
  @examples
end

#guardrailsArray<Google::Apis::CesV1::Guardrail>

Optional. List of guardrails in the app. Corresponds to the JSON property guardrails

Returns:



950
951
952
# File 'lib/google/apis/ces_v1/classes.rb', line 950

def guardrails
  @guardrails
end

#toolsArray<Google::Apis::CesV1::Tool>

Optional. List of tools in the app. Corresponds to the JSON property tools

Returns:



955
956
957
# File 'lib/google/apis/ces_v1/classes.rb', line 955

def tools
  @tools
end

#toolsetsArray<Google::Apis::CesV1::Toolset>

Optional. List of toolsets in the app. Corresponds to the JSON property toolsets

Returns:



960
961
962
# File 'lib/google/apis/ces_v1/classes.rb', line 960

def toolsets
  @toolsets
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



967
968
969
970
971
972
973
974
# File 'lib/google/apis/ces_v1/classes.rb', line 967

def update!(**args)
  @agents = args[:agents] if args.key?(:agents)
  @app = args[:app] if args.key?(:app)
  @examples = args[:examples] if args.key?(:examples)
  @guardrails = args[:guardrails] if args.key?(:guardrails)
  @tools = args[:tools] if args.key?(:tools)
  @toolsets = args[:toolsets] if args.key?(:toolsets)
end