Class: Google::Apis::CesV1::AppSnapshot

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

A snapshot of the app.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AppSnapshot

Returns a new instance of AppSnapshot.



795
796
797
# File 'lib/google/apis/ces_v1/classes.rb', line 795

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agentsArray<Google::Apis::CesV1::Agent>

Optional. List of agents in the app. Corresponds to the JSON property agents

Returns:



766
767
768
# File 'lib/google/apis/ces_v1/classes.rb', line 766

def agents
  @agents
end

#appGoogle::Apis::CesV1::App

An app serves as a top-level container for a group of agents, including the root agent and its sub-agents, along with their associated configurations. These agents work together to achieve specific goals within the app's context. Corresponds to the JSON property app



773
774
775
# File 'lib/google/apis/ces_v1/classes.rb', line 773

def app
  @app
end

#examplesArray<Google::Apis::CesV1::Example>

Optional. List of examples in the app. Corresponds to the JSON property examples

Returns:



778
779
780
# File 'lib/google/apis/ces_v1/classes.rb', line 778

def examples
  @examples
end

#guardrailsArray<Google::Apis::CesV1::Guardrail>

Optional. List of guardrails in the app. Corresponds to the JSON property guardrails

Returns:



783
784
785
# File 'lib/google/apis/ces_v1/classes.rb', line 783

def guardrails
  @guardrails
end

#toolsArray<Google::Apis::CesV1::Tool>

Optional. List of tools in the app. Corresponds to the JSON property tools

Returns:



788
789
790
# File 'lib/google/apis/ces_v1/classes.rb', line 788

def tools
  @tools
end

#toolsetsArray<Google::Apis::CesV1::Toolset>

Optional. List of toolsets in the app. Corresponds to the JSON property toolsets

Returns:



793
794
795
# File 'lib/google/apis/ces_v1/classes.rb', line 793

def toolsets
  @toolsets
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



800
801
802
803
804
805
806
807
# File 'lib/google/apis/ces_v1/classes.rb', line 800

def update!(**args)
  @agents = args[:agents] if args.key?(:agents)
  @app = args[:app] if args.key?(:app)
  @examples = args[:examples] if args.key?(:examples)
  @guardrails = args[:guardrails] if args.key?(:guardrails)
  @tools = args[:tools] if args.key?(:tools)
  @toolsets = args[:toolsets] if args.key?(:toolsets)
end