Class: Google::Apis::CesV1::AppVersion
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::AppVersion
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
In Customer Engagement Suite (CES), an app version is a snapshot of the app at a specific point in time. It is immutable and cannot be modified once created.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#creator ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Optional.
-
#etag ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#snapshot ⇒ Google::Apis::CesV1::AppSnapshot
A snapshot of the app.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AppVersion
constructor
A new instance of AppVersion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AppVersion
Returns a new instance of AppVersion.
1052 1053 1054 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1052 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when the app version was created.
Corresponds to the JSON property createTime
1017 1018 1019 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1017 def create_time @create_time end |
#creator ⇒ String
Output only. Email of the user who created the app version.
Corresponds to the JSON property creator
1022 1023 1024 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1022 def creator @creator end |
#description ⇒ String
Optional. The description of the app version.
Corresponds to the JSON property description
1027 1028 1029 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1027 def description @description end |
#display_name ⇒ String
Optional. The display name of the app version.
Corresponds to the JSON property displayName
1032 1033 1034 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1032 def display_name @display_name end |
#etag ⇒ String
Output only. Etag used to ensure the object hasn't changed during a read-
modify-write operation. If the etag is empty, the update will overwrite any
concurrent changes.
Corresponds to the JSON property etag
1039 1040 1041 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1039 def etag @etag end |
#name ⇒ String
Identifier. The unique identifier of the app version. Format: projects/
project/locations/location/apps/app/versions/version`
Corresponds to the JSON propertyname`
1045 1046 1047 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1045 def name @name end |
#snapshot ⇒ Google::Apis::CesV1::AppSnapshot
A snapshot of the app.
Corresponds to the JSON property snapshot
1050 1051 1052 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1050 def snapshot @snapshot end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1057 1058 1059 1060 1061 1062 1063 1064 1065 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1057 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @creator = args[:creator] if args.key?(:creator) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @name = args[:name] if args.key?(:name) @snapshot = args[:snapshot] if args.key?(:snapshot) end |