Class: Google::Apis::CesV1::AppVersion

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

In Customer Engagement Suite (CES), an app version is a snapshot of the app at a specific point in time. It is immutable and cannot be modified once created.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AppVersion

Returns a new instance of AppVersion.



885
886
887
# File 'lib/google/apis/ces_v1/classes.rb', line 885

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when the app version was created. Corresponds to the JSON property createTime

Returns:

  • (String)


850
851
852
# File 'lib/google/apis/ces_v1/classes.rb', line 850

def create_time
  @create_time
end

#creatorString

Output only. Email of the user who created the app version. Corresponds to the JSON property creator

Returns:

  • (String)


855
856
857
# File 'lib/google/apis/ces_v1/classes.rb', line 855

def creator
  @creator
end

#descriptionString

Optional. The description of the app version. Corresponds to the JSON property description

Returns:

  • (String)


860
861
862
# File 'lib/google/apis/ces_v1/classes.rb', line 860

def description
  @description
end

#display_nameString

Optional. The display name of the app version. Corresponds to the JSON property displayName

Returns:

  • (String)


865
866
867
# File 'lib/google/apis/ces_v1/classes.rb', line 865

def display_name
  @display_name
end

#etagString

Output only. Etag used to ensure the object hasn't changed during a read- modify-write operation. If the etag is empty, the update will overwrite any concurrent changes. Corresponds to the JSON property etag

Returns:

  • (String)


872
873
874
# File 'lib/google/apis/ces_v1/classes.rb', line 872

def etag
  @etag
end

#nameString

Identifier. The unique identifier of the app version. Format: projects/ project/locations/location/apps/app/versions/version` Corresponds to the JSON propertyname`

Returns:

  • (String)


878
879
880
# File 'lib/google/apis/ces_v1/classes.rb', line 878

def name
  @name
end

#snapshotGoogle::Apis::CesV1::AppSnapshot

A snapshot of the app. Corresponds to the JSON property snapshot



883
884
885
# File 'lib/google/apis/ces_v1/classes.rb', line 883

def snapshot
  @snapshot
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



890
891
892
893
894
895
896
897
898
# File 'lib/google/apis/ces_v1/classes.rb', line 890

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @creator = args[:creator] if args.key?(:creator)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @name = args[:name] if args.key?(:name)
  @snapshot = args[:snapshot] if args.key?(:snapshot)
end