Class: Google::Apis::CesV1::AudioProcessingConfig
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::AudioProcessingConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Configuration for how the input and output audio should be processed and delivered.
Instance Attribute Summary collapse
-
#ambient_sound_config ⇒ Google::Apis::CesV1::AmbientSoundConfig
Configuration for the ambient sound to be played with the synthesized agent response, to enhance the naturalness of the conversation.
-
#barge_in_config ⇒ Google::Apis::CesV1::BargeInConfig
Configuration for how the user barge-in activities should be handled.
-
#inactivity_timeout ⇒ String
Optional.
-
#synthesize_speech_configs ⇒ Hash<String,Google::Apis::CesV1::SynthesizeSpeechConfig>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AudioProcessingConfig
constructor
A new instance of AudioProcessingConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AudioProcessingConfig
Returns a new instance of AudioProcessingConfig.
934 935 936 |
# File 'lib/google/apis/ces_v1/classes.rb', line 934 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ambient_sound_config ⇒ Google::Apis::CesV1::AmbientSoundConfig
Configuration for the ambient sound to be played with the synthesized agent
response, to enhance the naturalness of the conversation.
Corresponds to the JSON property ambientSoundConfig
910 911 912 |
# File 'lib/google/apis/ces_v1/classes.rb', line 910 def ambient_sound_config @ambient_sound_config end |
#barge_in_config ⇒ Google::Apis::CesV1::BargeInConfig
Configuration for how the user barge-in activities should be handled.
Corresponds to the JSON property bargeInConfig
915 916 917 |
# File 'lib/google/apis/ces_v1/classes.rb', line 915 def @barge_in_config end |
#inactivity_timeout ⇒ String
Optional. The duration of user inactivity (no speech or interaction) before
the agent prompts the user for reengagement. If not set, the agent will not
prompt the user for reengagement.
Corresponds to the JSON property inactivityTimeout
922 923 924 |
# File 'lib/google/apis/ces_v1/classes.rb', line 922 def inactivity_timeout @inactivity_timeout end |
#synthesize_speech_configs ⇒ Hash<String,Google::Apis::CesV1::SynthesizeSpeechConfig>
Optional. Configuration of how the agent response should be synthesized,
mapping from the language code to SynthesizeSpeechConfig. If the configuration
for the specified language code is not found, the configuration for the root
language code will be used. For example, if the map contains "en-us" and "en",
and the specified language code is "en-gb", then "en" configuration will be
used. Note: Language code is case-insensitive.
Corresponds to the JSON property synthesizeSpeechConfigs
932 933 934 |
# File 'lib/google/apis/ces_v1/classes.rb', line 932 def synthesize_speech_configs @synthesize_speech_configs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
939 940 941 942 943 944 |
# File 'lib/google/apis/ces_v1/classes.rb', line 939 def update!(**args) @ambient_sound_config = args[:ambient_sound_config] if args.key?(:ambient_sound_config) @barge_in_config = args[:barge_in_config] if args.key?(:barge_in_config) @inactivity_timeout = args[:inactivity_timeout] if args.key?(:inactivity_timeout) @synthesize_speech_configs = args[:synthesize_speech_configs] if args.key?(:synthesize_speech_configs) end |