Class: Google::Apis::CesV1::AudioRecordingConfig
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::AudioRecordingConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Configuration for how the audio interactions should be recorded.
Instance Attribute Summary collapse
-
#gcs_bucket ⇒ String
Optional.
-
#gcs_path_prefix ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AudioRecordingConfig
constructor
A new instance of AudioRecordingConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AudioRecordingConfig
Returns a new instance of AudioRecordingConfig.
971 972 973 |
# File 'lib/google/apis/ces_v1/classes.rb', line 971 def initialize(**args) update!(**args) end |
Instance Attribute Details
#gcs_bucket ⇒ String
Optional. The Cloud Storage bucket to
store the session audio recordings. The URI must start with "gs://". Please
choose a bucket location that meets your data residency requirements. Note: If
the Cloud Storage bucket is in a different project from the app, you should
grant storage.objects.create permission to the CES service agent service-@
gcp-sa-ces.iam.gserviceaccount.com.
Corresponds to the JSON property gcsBucket
959 960 961 |
# File 'lib/google/apis/ces_v1/classes.rb', line 959 def gcs_bucket @gcs_bucket end |
#gcs_path_prefix ⇒ String
Optional. The Cloud Storage path prefix for audio recordings. This prefix can
include the following placeholders, which will be dynamically substituted at
serving time: - $project: project ID - $location: app location - $app: app ID -
$date: session date in YYYY-MM-DD format - $session: session ID If the path
prefix is not specified, the default prefix $project/$location/$app/$date/$
session/ will be used.
Corresponds to the JSON property gcsPathPrefix
969 970 971 |
# File 'lib/google/apis/ces_v1/classes.rb', line 969 def gcs_path_prefix @gcs_path_prefix end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
976 977 978 979 |
# File 'lib/google/apis/ces_v1/classes.rb', line 976 def update!(**args) @gcs_bucket = args[:gcs_bucket] if args.key?(:gcs_bucket) @gcs_path_prefix = args[:gcs_path_prefix] if args.key?(:gcs_path_prefix) end |