Class: Google::Apis::CesV1::BargeInConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Configuration for how the user barge-in activities should be handled.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BargeInConfig

Returns a new instance of BargeInConfig.



1178
1179
1180
# File 'lib/google/apis/ces_v1/classes.rb', line 1178

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#barge_in_awarenessBoolean Also known as: barge_in_awareness?

Optional. If enabled, the agent will adapt its next response based on the assumption that the user hasn't heard the full preceding agent message. This should not be used in scenarios where agent responses are displayed visually. Corresponds to the JSON property bargeInAwareness

Returns:

  • (Boolean)


1166
1167
1168
# File 'lib/google/apis/ces_v1/classes.rb', line 1166

def barge_in_awareness
  @barge_in_awareness
end

#disable_barge_inBoolean Also known as: disable_barge_in?

Optional. Disables user barge-in while the agent is speaking. If true, user input during agent response playback will be ignored. Deprecated: disable_barge_in is deprecated in favor of disable_barge_in_control in ChannelProfile. Corresponds to the JSON property disableBargeIn

Returns:

  • (Boolean)


1175
1176
1177
# File 'lib/google/apis/ces_v1/classes.rb', line 1175

def disable_barge_in
  @disable_barge_in
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1183
1184
1185
1186
# File 'lib/google/apis/ces_v1/classes.rb', line 1183

def update!(**args)
  @barge_in_awareness = args[:barge_in_awareness] if args.key?(:barge_in_awareness)
  @disable_barge_in = args[:disable_barge_in] if args.key?(:disable_barge_in)
end