Class: Google::Apis::CesV1::BargeInConfig
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::BargeInConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Configuration for how the user barge-in activities should be handled.
Instance Attribute Summary collapse
-
#barge_in_awareness ⇒ Boolean
(also: #barge_in_awareness?)
Optional.
-
#disable_barge_in ⇒ Boolean
(also: #disable_barge_in?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BargeInConfig
constructor
A new instance of BargeInConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BargeInConfig
Returns a new instance of BargeInConfig.
1170 1171 1172 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1170 def initialize(**args) update!(**args) end |
Instance Attribute Details
#barge_in_awareness ⇒ Boolean Also known as: barge_in_awareness?
Optional. If enabled, the agent will adapt its next response based on the
assumption that the user hasn't heard the full preceding agent message. This
should not be used in scenarios where agent responses are displayed visually.
Corresponds to the JSON property bargeInAwareness
1158 1159 1160 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1158 def @barge_in_awareness end |
#disable_barge_in ⇒ Boolean Also known as: disable_barge_in?
Optional. Disables user barge-in while the agent is speaking. If true, user
input during agent response playback will be ignored. Deprecated:
disable_barge_in is deprecated in favor of disable_barge_in_control in
ChannelProfile.
Corresponds to the JSON property disableBargeIn
1167 1168 1169 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1167 def @disable_barge_in end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1175 1176 1177 1178 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1175 def update!(**args) @barge_in_awareness = args[:barge_in_awareness] if args.key?(:barge_in_awareness) @disable_barge_in = args[:disable_barge_in] if args.key?(:disable_barge_in) end |