Class: Google::Apis::CesV1::Changelog

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Changelogs represent a change made to the app or to an resource within the app.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Changelog

Returns a new instance of Changelog.



1406
1407
1408
# File 'lib/google/apis/ces_v1/classes.rb', line 1406

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionString

Output only. The action that was performed on the resource. Corresponds to the JSON property action

Returns:

  • (String)


1346
1347
1348
# File 'lib/google/apis/ces_v1/classes.rb', line 1346

def action
  @action
end

#authorString

Output only. Email address of the change author. Corresponds to the JSON property author

Returns:

  • (String)


1351
1352
1353
# File 'lib/google/apis/ces_v1/classes.rb', line 1351

def author
  @author
end

#create_timeString

Output only. The time when the change was made. Corresponds to the JSON property createTime

Returns:

  • (String)


1356
1357
1358
# File 'lib/google/apis/ces_v1/classes.rb', line 1356

def create_time
  @create_time
end

#dependent_resourcesArray<Hash<String,Object>>

Output only. The dependent resources that were changed. Corresponds to the JSON property dependentResources

Returns:

  • (Array<Hash<String,Object>>)


1361
1362
1363
# File 'lib/google/apis/ces_v1/classes.rb', line 1361

def dependent_resources
  @dependent_resources
end

#descriptionString

Output only. Description of the change. which typically captures the changed fields in the resource. Corresponds to the JSON property description

Returns:

  • (String)


1367
1368
1369
# File 'lib/google/apis/ces_v1/classes.rb', line 1367

def description
  @description
end

#display_nameString

Output only. Display name of the change. It typically should be the display name of the resource that was changed. Corresponds to the JSON property displayName

Returns:

  • (String)


1373
1374
1375
# File 'lib/google/apis/ces_v1/classes.rb', line 1373

def display_name
  @display_name
end

#nameString

Identifier. The unique identifier of the changelog. Format: projects/project /locations/location/apps/app/changelogs/changelog` Corresponds to the JSON propertyname`

Returns:

  • (String)


1379
1380
1381
# File 'lib/google/apis/ces_v1/classes.rb', line 1379

def name
  @name
end

#new_resourceHash<String,Object>

Output only. The new resource after the change. Corresponds to the JSON property newResource

Returns:

  • (Hash<String,Object>)


1384
1385
1386
# File 'lib/google/apis/ces_v1/classes.rb', line 1384

def new_resource
  @new_resource
end

#original_resourceHash<String,Object>

Output only. The original resource before the change. Corresponds to the JSON property originalResource

Returns:

  • (Hash<String,Object>)


1389
1390
1391
# File 'lib/google/apis/ces_v1/classes.rb', line 1389

def original_resource
  @original_resource
end

#resourceString

Output only. The resource that was changed. Corresponds to the JSON property resource

Returns:

  • (String)


1394
1395
1396
# File 'lib/google/apis/ces_v1/classes.rb', line 1394

def resource
  @resource
end

#resource_typeString

Output only. The type of the resource that was changed. Corresponds to the JSON property resourceType

Returns:

  • (String)


1399
1400
1401
# File 'lib/google/apis/ces_v1/classes.rb', line 1399

def resource_type
  @resource_type
end

#sequence_numberFixnum

Output only. The monotonically increasing sequence number of the changelog. Corresponds to the JSON property sequenceNumber

Returns:

  • (Fixnum)


1404
1405
1406
# File 'lib/google/apis/ces_v1/classes.rb', line 1404

def sequence_number
  @sequence_number
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1411
1412
1413
1414
1415
1416
1417
1418
1419
1420
1421
1422
1423
1424
# File 'lib/google/apis/ces_v1/classes.rb', line 1411

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @author = args[:author] if args.key?(:author)
  @create_time = args[:create_time] if args.key?(:create_time)
  @dependent_resources = args[:dependent_resources] if args.key?(:dependent_resources)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @new_resource = args[:new_resource] if args.key?(:new_resource)
  @original_resource = args[:original_resource] if args.key?(:original_resource)
  @resource = args[:resource] if args.key?(:resource)
  @resource_type = args[:resource_type] if args.key?(:resource_type)
  @sequence_number = args[:sequence_number] if args.key?(:sequence_number)
end