Class: Google::Apis::CesV1::Changelog

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Changelogs represent a change made to the app or to an resource within the app.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Changelog

Returns a new instance of Changelog.



1239
1240
1241
# File 'lib/google/apis/ces_v1/classes.rb', line 1239

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionString

Output only. The action that was performed on the resource. Corresponds to the JSON property action

Returns:

  • (String)


1179
1180
1181
# File 'lib/google/apis/ces_v1/classes.rb', line 1179

def action
  @action
end

#authorString

Output only. Email address of the change author. Corresponds to the JSON property author

Returns:

  • (String)


1184
1185
1186
# File 'lib/google/apis/ces_v1/classes.rb', line 1184

def author
  @author
end

#create_timeString

Output only. The time when the change was made. Corresponds to the JSON property createTime

Returns:

  • (String)


1189
1190
1191
# File 'lib/google/apis/ces_v1/classes.rb', line 1189

def create_time
  @create_time
end

#dependent_resourcesArray<Hash<String,Object>>

Output only. The dependent resources that were changed. Corresponds to the JSON property dependentResources

Returns:

  • (Array<Hash<String,Object>>)


1194
1195
1196
# File 'lib/google/apis/ces_v1/classes.rb', line 1194

def dependent_resources
  @dependent_resources
end

#descriptionString

Output only. Description of the change. which typically captures the changed fields in the resource. Corresponds to the JSON property description

Returns:

  • (String)


1200
1201
1202
# File 'lib/google/apis/ces_v1/classes.rb', line 1200

def description
  @description
end

#display_nameString

Output only. Display name of the change. It typically should be the display name of the resource that was changed. Corresponds to the JSON property displayName

Returns:

  • (String)


1206
1207
1208
# File 'lib/google/apis/ces_v1/classes.rb', line 1206

def display_name
  @display_name
end

#nameString

Identifier. The unique identifier of the changelog. Format: projects/project /locations/location/apps/app/changelogs/changelog` Corresponds to the JSON propertyname`

Returns:

  • (String)


1212
1213
1214
# File 'lib/google/apis/ces_v1/classes.rb', line 1212

def name
  @name
end

#new_resourceHash<String,Object>

Output only. The new resource after the change. Corresponds to the JSON property newResource

Returns:

  • (Hash<String,Object>)


1217
1218
1219
# File 'lib/google/apis/ces_v1/classes.rb', line 1217

def new_resource
  @new_resource
end

#original_resourceHash<String,Object>

Output only. The original resource before the change. Corresponds to the JSON property originalResource

Returns:

  • (Hash<String,Object>)


1222
1223
1224
# File 'lib/google/apis/ces_v1/classes.rb', line 1222

def original_resource
  @original_resource
end

#resourceString

Output only. The resource that was changed. Corresponds to the JSON property resource

Returns:

  • (String)


1227
1228
1229
# File 'lib/google/apis/ces_v1/classes.rb', line 1227

def resource
  @resource
end

#resource_typeString

Output only. The type of the resource that was changed. Corresponds to the JSON property resourceType

Returns:

  • (String)


1232
1233
1234
# File 'lib/google/apis/ces_v1/classes.rb', line 1232

def resource_type
  @resource_type
end

#sequence_numberFixnum

Output only. The monotonically increasing sequence number of the changelog. Corresponds to the JSON property sequenceNumber

Returns:

  • (Fixnum)


1237
1238
1239
# File 'lib/google/apis/ces_v1/classes.rb', line 1237

def sequence_number
  @sequence_number
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1244
1245
1246
1247
1248
1249
1250
1251
1252
1253
1254
1255
1256
1257
# File 'lib/google/apis/ces_v1/classes.rb', line 1244

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @author = args[:author] if args.key?(:author)
  @create_time = args[:create_time] if args.key?(:create_time)
  @dependent_resources = args[:dependent_resources] if args.key?(:dependent_resources)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @new_resource = args[:new_resource] if args.key?(:new_resource)
  @original_resource = args[:original_resource] if args.key?(:original_resource)
  @resource = args[:resource] if args.key?(:resource)
  @resource_type = args[:resource_type] if args.key?(:resource_type)
  @sequence_number = args[:sequence_number] if args.key?(:sequence_number)
end