Class: Google::Apis::CesV1::ChannelProfile
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::ChannelProfile
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
A ChannelProfile configures the agent's behavior for a specific communication channel, such as web UI or telephony.
Instance Attribute Summary collapse
-
#channel_type ⇒ String
Optional.
-
#disable_barge_in_control ⇒ Boolean
(also: #disable_barge_in_control?)
Optional.
-
#disable_dtmf ⇒ Boolean
(also: #disable_dtmf?)
Optional.
-
#noise_suppression_level ⇒ String
Optional.
-
#persona_property ⇒ Google::Apis::CesV1::ChannelProfilePersonaProperty
Represents the persona property of a channel.
-
#profile_id ⇒ String
Optional.
-
#web_widget_config ⇒ Google::Apis::CesV1::ChannelProfileWebWidgetConfig
Message for configuration for the web widget.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ChannelProfile
constructor
A new instance of ChannelProfile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ChannelProfile
Returns a new instance of ChannelProfile.
1472 1473 1474 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1472 def initialize(**args) update!(**args) end |
Instance Attribute Details
#channel_type ⇒ String
Optional. The type of the channel profile.
Corresponds to the JSON property channelType
1435 1436 1437 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1435 def channel_type @channel_type end |
#disable_barge_in_control ⇒ Boolean Also known as: disable_barge_in_control?
Optional. Whether to disable user barge-in control in the conversation. - **
true*: User interruptions are disabled while the agent is speaking. - **false
*: The agent retains automatic control over when the user can interrupt.
Corresponds to the JSON property disableBargeInControl
1442 1443 1444 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1442 def @disable_barge_in_control end |
#disable_dtmf ⇒ Boolean Also known as: disable_dtmf?
Optional. Whether to disable DTMF (dual-tone multi-frequency).
Corresponds to the JSON property disableDtmf
1448 1449 1450 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1448 def disable_dtmf @disable_dtmf end |
#noise_suppression_level ⇒ String
Optional. The noise suppression level of the channel profile. Available values
are "low", "moderate", "high", "very_high".
Corresponds to the JSON property noiseSuppressionLevel
1455 1456 1457 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1455 def noise_suppression_level @noise_suppression_level end |
#persona_property ⇒ Google::Apis::CesV1::ChannelProfilePersonaProperty
Represents the persona property of a channel.
Corresponds to the JSON property personaProperty
1460 1461 1462 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1460 def persona_property @persona_property end |
#profile_id ⇒ String
Optional. The unique identifier of the channel profile.
Corresponds to the JSON property profileId
1465 1466 1467 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1465 def profile_id @profile_id end |
#web_widget_config ⇒ Google::Apis::CesV1::ChannelProfileWebWidgetConfig
Message for configuration for the web widget.
Corresponds to the JSON property webWidgetConfig
1470 1471 1472 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1470 def @web_widget_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1477 1478 1479 1480 1481 1482 1483 1484 1485 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1477 def update!(**args) @channel_type = args[:channel_type] if args.key?(:channel_type) @disable_barge_in_control = args[:disable_barge_in_control] if args.key?(:disable_barge_in_control) @disable_dtmf = args[:disable_dtmf] if args.key?(:disable_dtmf) @noise_suppression_level = args[:noise_suppression_level] if args.key?(:noise_suppression_level) @persona_property = args[:persona_property] if args.key?(:persona_property) @profile_id = args[:profile_id] if args.key?(:profile_id) @web_widget_config = args[:web_widget_config] if args.key?(:web_widget_config) end |