Class: Google::Apis::CesV1::ChannelProfile

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

A ChannelProfile configures the agent's behavior for a specific communication channel, such as web UI or telephony.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ChannelProfile

Returns a new instance of ChannelProfile.



1305
1306
1307
# File 'lib/google/apis/ces_v1/classes.rb', line 1305

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#channel_typeString

Optional. The type of the channel profile. Corresponds to the JSON property channelType

Returns:

  • (String)


1268
1269
1270
# File 'lib/google/apis/ces_v1/classes.rb', line 1268

def channel_type
  @channel_type
end

#disable_barge_in_controlBoolean Also known as: disable_barge_in_control?

Optional. Whether to disable user barge-in control in the conversation. - ** true*: User interruptions are disabled while the agent is speaking. - **false *: The agent retains automatic control over when the user can interrupt. Corresponds to the JSON property disableBargeInControl

Returns:

  • (Boolean)


1275
1276
1277
# File 'lib/google/apis/ces_v1/classes.rb', line 1275

def disable_barge_in_control
  @disable_barge_in_control
end

#disable_dtmfBoolean Also known as: disable_dtmf?

Optional. Whether to disable DTMF (dual-tone multi-frequency). Corresponds to the JSON property disableDtmf

Returns:

  • (Boolean)


1281
1282
1283
# File 'lib/google/apis/ces_v1/classes.rb', line 1281

def disable_dtmf
  @disable_dtmf
end

#noise_suppression_levelString

Optional. The noise suppression level of the channel profile. Available values are "low", "moderate", "high", "very_high". Corresponds to the JSON property noiseSuppressionLevel

Returns:

  • (String)


1288
1289
1290
# File 'lib/google/apis/ces_v1/classes.rb', line 1288

def noise_suppression_level
  @noise_suppression_level
end

#persona_propertyGoogle::Apis::CesV1::ChannelProfilePersonaProperty

Represents the persona property of a channel. Corresponds to the JSON property personaProperty



1293
1294
1295
# File 'lib/google/apis/ces_v1/classes.rb', line 1293

def persona_property
  @persona_property
end

#profile_idString

Optional. The unique identifier of the channel profile. Corresponds to the JSON property profileId

Returns:

  • (String)


1298
1299
1300
# File 'lib/google/apis/ces_v1/classes.rb', line 1298

def profile_id
  @profile_id
end

#web_widget_configGoogle::Apis::CesV1::ChannelProfileWebWidgetConfig

Message for configuration for the web widget. Corresponds to the JSON property webWidgetConfig



1303
1304
1305
# File 'lib/google/apis/ces_v1/classes.rb', line 1303

def web_widget_config
  @web_widget_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1310
1311
1312
1313
1314
1315
1316
1317
1318
# File 'lib/google/apis/ces_v1/classes.rb', line 1310

def update!(**args)
  @channel_type = args[:channel_type] if args.key?(:channel_type)
  @disable_barge_in_control = args[:disable_barge_in_control] if args.key?(:disable_barge_in_control)
  @disable_dtmf = args[:disable_dtmf] if args.key?(:disable_dtmf)
  @noise_suppression_level = args[:noise_suppression_level] if args.key?(:noise_suppression_level)
  @persona_property = args[:persona_property] if args.key?(:persona_property)
  @profile_id = args[:profile_id] if args.key?(:profile_id)
  @web_widget_config = args[:web_widget_config] if args.key?(:web_widget_config)
end