Class: Google::Apis::CesV1::ChannelProfileWebWidgetConfigSecuritySettings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Security settings for the web widget.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ChannelProfileWebWidgetConfigSecuritySettings

Returns a new instance of ChannelProfileWebWidgetConfigSecuritySettings.



1580
1581
1582
# File 'lib/google/apis/ces_v1/classes.rb', line 1580

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowed_originsArray<String>

Optional. The origins that are allowed to host the web widget. An origin is defined by RFC 6454. If empty, all origins are allowed. A maximum of 100 origins is allowed. Example: "https://example.com" Corresponds to the JSON property allowedOrigins

Returns:

  • (Array<String>)


1553
1554
1555
# File 'lib/google/apis/ces_v1/classes.rb', line 1553

def allowed_origins
  @allowed_origins
end

#enable_origin_checkBoolean Also known as: enable_origin_check?

Optional. Indicates whether origin check for the web widget is enabled. If true, the web widget will check the origin of the website that loads the web widget and only allow it to be loaded in the same origin or any of the allowed origins. Corresponds to the JSON property enableOriginCheck

Returns:

  • (Boolean)


1561
1562
1563
# File 'lib/google/apis/ces_v1/classes.rb', line 1561

def enable_origin_check
  @enable_origin_check
end

#enable_public_accessBoolean Also known as: enable_public_access?

Optional. Indicates whether public access to the web widget is enabled. If true, the web widget will be publicly accessible. If false, the web widget must be integrated with your own authentication and authorization system to return valid credentials for accessing the CES agent. Corresponds to the JSON property enablePublicAccess

Returns:

  • (Boolean)


1570
1571
1572
# File 'lib/google/apis/ces_v1/classes.rb', line 1570

def enable_public_access
  @enable_public_access
end

#enable_recaptchaBoolean Also known as: enable_recaptcha?

Optional. Indicates whether reCAPTCHA verification for the web widget is enabled. Corresponds to the JSON property enableRecaptcha

Returns:

  • (Boolean)


1577
1578
1579
# File 'lib/google/apis/ces_v1/classes.rb', line 1577

def enable_recaptcha
  @enable_recaptcha
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1585
1586
1587
1588
1589
1590
# File 'lib/google/apis/ces_v1/classes.rb', line 1585

def update!(**args)
  @allowed_origins = args[:allowed_origins] if args.key?(:allowed_origins)
  @enable_origin_check = args[:enable_origin_check] if args.key?(:enable_origin_check)
  @enable_public_access = args[:enable_public_access] if args.key?(:enable_public_access)
  @enable_recaptcha = args[:enable_recaptcha] if args.key?(:enable_recaptcha)
end