Class: Google::Apis::CesV1::ChannelProfileWebWidgetConfigSecuritySettings
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::ChannelProfileWebWidgetConfigSecuritySettings
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Security settings for the web widget.
Instance Attribute Summary collapse
-
#allowed_origins ⇒ Array<String>
Optional.
-
#enable_origin_check ⇒ Boolean
(also: #enable_origin_check?)
Optional.
-
#enable_public_access ⇒ Boolean
(also: #enable_public_access?)
Optional.
-
#enable_recaptcha ⇒ Boolean
(also: #enable_recaptcha?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ChannelProfileWebWidgetConfigSecuritySettings
constructor
A new instance of ChannelProfileWebWidgetConfigSecuritySettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ChannelProfileWebWidgetConfigSecuritySettings
Returns a new instance of ChannelProfileWebWidgetConfigSecuritySettings.
1413 1414 1415 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1413 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed_origins ⇒ Array<String>
Optional. The origins that are allowed to host the web widget. An origin is
defined by RFC 6454. If empty, all origins are allowed. A maximum of 100
origins is allowed. Example: "https://example.com"
Corresponds to the JSON property allowedOrigins
1386 1387 1388 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1386 def allowed_origins @allowed_origins end |
#enable_origin_check ⇒ Boolean Also known as: enable_origin_check?
Optional. Indicates whether origin check for the web widget is enabled. If
true, the web widget will check the origin of the website that loads the web
widget and only allow it to be loaded in the same origin or any of the allowed
origins.
Corresponds to the JSON property enableOriginCheck
1394 1395 1396 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1394 def enable_origin_check @enable_origin_check end |
#enable_public_access ⇒ Boolean Also known as: enable_public_access?
Optional. Indicates whether public access to the web widget is enabled. If
true, the web widget will be publicly accessible. If false, the web widget
must be integrated with your own authentication and authorization system to
return valid credentials for accessing the CES agent.
Corresponds to the JSON property enablePublicAccess
1403 1404 1405 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1403 def enable_public_access @enable_public_access end |
#enable_recaptcha ⇒ Boolean Also known as: enable_recaptcha?
Optional. Indicates whether reCAPTCHA verification for the web widget is
enabled.
Corresponds to the JSON property enableRecaptcha
1410 1411 1412 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1410 def enable_recaptcha @enable_recaptcha end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1418 1419 1420 1421 1422 1423 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1418 def update!(**args) @allowed_origins = args[:allowed_origins] if args.key?(:allowed_origins) @enable_origin_check = args[:enable_origin_check] if args.key?(:enable_origin_check) @enable_public_access = args[:enable_public_access] if args.key?(:enable_public_access) @enable_recaptcha = args[:enable_recaptcha] if args.key?(:enable_recaptcha) end |