Class: Google::Apis::CesV1::Chunk
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::Chunk
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
A chunk of content within a message.
Instance Attribute Summary collapse
-
#agent_transfer ⇒ Google::Apis::CesV1::AgentTransfer
Represents an event indicating the transfer of a conversation to a different agent.
-
#blob ⇒ Google::Apis::CesV1::Blob
Represents a blob input or output in the conversation.
-
#default_variables ⇒ Hash<String,Object>
A struct represents default variables at the start of the conversation, keyed by variable names.
-
#image ⇒ Google::Apis::CesV1::Image
Represents an image input or output in the conversation.
-
#payload ⇒ Hash<String,Object>
Optional.
-
#text ⇒ String
Optional.
-
#tool_call ⇒ Google::Apis::CesV1::ToolCall
Request for the client or the agent to execute the specified tool.
-
#tool_response ⇒ Google::Apis::CesV1::ToolResponse
The execution result of a specific tool from the client or the agent.
-
#transcript ⇒ String
Optional.
-
#updated_variables ⇒ Hash<String,Object>
A struct represents variables that were updated in the conversation, keyed by variable names.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Chunk
constructor
A new instance of Chunk.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Chunk
Returns a new instance of Chunk.
1748 1749 1750 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1748 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_transfer ⇒ Google::Apis::CesV1::AgentTransfer
Represents an event indicating the transfer of a conversation to a different
agent.
Corresponds to the JSON property agentTransfer
1699 1700 1701 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1699 def agent_transfer @agent_transfer end |
#blob ⇒ Google::Apis::CesV1::Blob
Represents a blob input or output in the conversation.
Corresponds to the JSON property blob
1704 1705 1706 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1704 def blob @blob end |
#default_variables ⇒ Hash<String,Object>
A struct represents default variables at the start of the conversation, keyed
by variable names.
Corresponds to the JSON property defaultVariables
1710 1711 1712 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1710 def default_variables @default_variables end |
#image ⇒ Google::Apis::CesV1::Image
Represents an image input or output in the conversation.
Corresponds to the JSON property image
1715 1716 1717 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1715 def image @image end |
#payload ⇒ Hash<String,Object>
Optional. Custom payload data.
Corresponds to the JSON property payload
1720 1721 1722 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1720 def payload @payload end |
#text ⇒ String
Optional. Text data.
Corresponds to the JSON property text
1725 1726 1727 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1725 def text @text end |
#tool_call ⇒ Google::Apis::CesV1::ToolCall
Request for the client or the agent to execute the specified tool.
Corresponds to the JSON property toolCall
1730 1731 1732 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1730 def tool_call @tool_call end |
#tool_response ⇒ Google::Apis::CesV1::ToolResponse
The execution result of a specific tool from the client or the agent.
Corresponds to the JSON property toolResponse
1735 1736 1737 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1735 def tool_response @tool_response end |
#transcript ⇒ String
Optional. Transcript associated with the audio.
Corresponds to the JSON property transcript
1740 1741 1742 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1740 def transcript @transcript end |
#updated_variables ⇒ Hash<String,Object>
A struct represents variables that were updated in the conversation, keyed by
variable names.
Corresponds to the JSON property updatedVariables
1746 1747 1748 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1746 def updated_variables @updated_variables end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1753 def update!(**args) @agent_transfer = args[:agent_transfer] if args.key?(:agent_transfer) @blob = args[:blob] if args.key?(:blob) @default_variables = args[:default_variables] if args.key?(:default_variables) @image = args[:image] if args.key?(:image) @payload = args[:payload] if args.key?(:payload) @text = args[:text] if args.key?(:text) @tool_call = args[:tool_call] if args.key?(:tool_call) @tool_response = args[:tool_response] if args.key?(:tool_response) @transcript = args[:transcript] if args.key?(:transcript) @updated_variables = args[:updated_variables] if args.key?(:updated_variables) end |