Class: Google::Apis::CesV1::Chunk

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

A chunk of content within a message.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Chunk

Returns a new instance of Chunk.



1658
1659
1660
# File 'lib/google/apis/ces_v1/classes.rb', line 1658

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_transferGoogle::Apis::CesV1::AgentTransfer

Represents an event indicating the transfer of a conversation to a different agent. Corresponds to the JSON property agentTransfer



1609
1610
1611
# File 'lib/google/apis/ces_v1/classes.rb', line 1609

def agent_transfer
  @agent_transfer
end

#blobGoogle::Apis::CesV1::Blob

Represents a blob input or output in the conversation. Corresponds to the JSON property blob



1614
1615
1616
# File 'lib/google/apis/ces_v1/classes.rb', line 1614

def blob
  @blob
end

#default_variablesHash<String,Object>

A struct represents default variables at the start of the conversation, keyed by variable names. Corresponds to the JSON property defaultVariables

Returns:

  • (Hash<String,Object>)


1620
1621
1622
# File 'lib/google/apis/ces_v1/classes.rb', line 1620

def default_variables
  @default_variables
end

#imageGoogle::Apis::CesV1::Image

Represents an image input or output in the conversation. Corresponds to the JSON property image



1625
1626
1627
# File 'lib/google/apis/ces_v1/classes.rb', line 1625

def image
  @image
end

#payloadHash<String,Object>

Optional. Custom payload data. Corresponds to the JSON property payload

Returns:

  • (Hash<String,Object>)


1630
1631
1632
# File 'lib/google/apis/ces_v1/classes.rb', line 1630

def payload
  @payload
end

#textString

Optional. Text data. Corresponds to the JSON property text

Returns:

  • (String)


1635
1636
1637
# File 'lib/google/apis/ces_v1/classes.rb', line 1635

def text
  @text
end

#tool_callGoogle::Apis::CesV1::ToolCall

Request for the client or the agent to execute the specified tool. Corresponds to the JSON property toolCall



1640
1641
1642
# File 'lib/google/apis/ces_v1/classes.rb', line 1640

def tool_call
  @tool_call
end

#tool_responseGoogle::Apis::CesV1::ToolResponse

The execution result of a specific tool from the client or the agent. Corresponds to the JSON property toolResponse



1645
1646
1647
# File 'lib/google/apis/ces_v1/classes.rb', line 1645

def tool_response
  @tool_response
end

#transcriptString

Optional. Transcript associated with the audio. Corresponds to the JSON property transcript

Returns:

  • (String)


1650
1651
1652
# File 'lib/google/apis/ces_v1/classes.rb', line 1650

def transcript
  @transcript
end

#updated_variablesHash<String,Object>

A struct represents variables that were updated in the conversation, keyed by variable names. Corresponds to the JSON property updatedVariables

Returns:

  • (Hash<String,Object>)


1656
1657
1658
# File 'lib/google/apis/ces_v1/classes.rb', line 1656

def updated_variables
  @updated_variables
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
# File 'lib/google/apis/ces_v1/classes.rb', line 1663

def update!(**args)
  @agent_transfer = args[:agent_transfer] if args.key?(:agent_transfer)
  @blob = args[:blob] if args.key?(:blob)
  @default_variables = args[:default_variables] if args.key?(:default_variables)
  @image = args[:image] if args.key?(:image)
  @payload = args[:payload] if args.key?(:payload)
  @text = args[:text] if args.key?(:text)
  @tool_call = args[:tool_call] if args.key?(:tool_call)
  @tool_response = args[:tool_response] if args.key?(:tool_response)
  @transcript = args[:transcript] if args.key?(:transcript)
  @updated_variables = args[:updated_variables] if args.key?(:updated_variables)
end