Class: Google::Apis::CesV1::Chunk
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::Chunk
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
A chunk of content within a message.
Instance Attribute Summary collapse
-
#agent_transfer ⇒ Google::Apis::CesV1::AgentTransfer
Represents an event indicating the transfer of a conversation to a different agent.
-
#blob ⇒ Google::Apis::CesV1::Blob
Represents a blob input or output in the conversation.
-
#default_variables ⇒ Hash<String,Object>
A struct represents default variables at the start of the conversation, keyed by variable names.
-
#image ⇒ Google::Apis::CesV1::Image
Represents an image input or output in the conversation.
-
#payload ⇒ Hash<String,Object>
Optional.
-
#text ⇒ String
Optional.
-
#tool_call ⇒ Google::Apis::CesV1::ToolCall
Request for the client or the agent to execute the specified tool.
-
#tool_response ⇒ Google::Apis::CesV1::ToolResponse
The execution result of a specific tool from the client or the agent.
-
#transcript ⇒ String
Optional.
-
#updated_variables ⇒ Hash<String,Object>
A struct represents variables that were updated in the conversation, keyed by variable names.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Chunk
constructor
A new instance of Chunk.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Chunk
Returns a new instance of Chunk.
1650 1651 1652 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1650 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_transfer ⇒ Google::Apis::CesV1::AgentTransfer
Represents an event indicating the transfer of a conversation to a different
agent.
Corresponds to the JSON property agentTransfer
1601 1602 1603 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1601 def agent_transfer @agent_transfer end |
#blob ⇒ Google::Apis::CesV1::Blob
Represents a blob input or output in the conversation.
Corresponds to the JSON property blob
1606 1607 1608 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1606 def blob @blob end |
#default_variables ⇒ Hash<String,Object>
A struct represents default variables at the start of the conversation, keyed
by variable names.
Corresponds to the JSON property defaultVariables
1612 1613 1614 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1612 def default_variables @default_variables end |
#image ⇒ Google::Apis::CesV1::Image
Represents an image input or output in the conversation.
Corresponds to the JSON property image
1617 1618 1619 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1617 def image @image end |
#payload ⇒ Hash<String,Object>
Optional. Custom payload data.
Corresponds to the JSON property payload
1622 1623 1624 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1622 def payload @payload end |
#text ⇒ String
Optional. Text data.
Corresponds to the JSON property text
1627 1628 1629 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1627 def text @text end |
#tool_call ⇒ Google::Apis::CesV1::ToolCall
Request for the client or the agent to execute the specified tool.
Corresponds to the JSON property toolCall
1632 1633 1634 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1632 def tool_call @tool_call end |
#tool_response ⇒ Google::Apis::CesV1::ToolResponse
The execution result of a specific tool from the client or the agent.
Corresponds to the JSON property toolResponse
1637 1638 1639 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1637 def tool_response @tool_response end |
#transcript ⇒ String
Optional. Transcript associated with the audio.
Corresponds to the JSON property transcript
1642 1643 1644 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1642 def transcript @transcript end |
#updated_variables ⇒ Hash<String,Object>
A struct represents variables that were updated in the conversation, keyed by
variable names.
Corresponds to the JSON property updatedVariables
1648 1649 1650 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1648 def updated_variables @updated_variables end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 1666 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1655 def update!(**args) @agent_transfer = args[:agent_transfer] if args.key?(:agent_transfer) @blob = args[:blob] if args.key?(:blob) @default_variables = args[:default_variables] if args.key?(:default_variables) @image = args[:image] if args.key?(:image) @payload = args[:payload] if args.key?(:payload) @text = args[:text] if args.key?(:text) @tool_call = args[:tool_call] if args.key?(:tool_call) @tool_response = args[:tool_response] if args.key?(:tool_response) @transcript = args[:transcript] if args.key?(:transcript) @updated_variables = args[:updated_variables] if args.key?(:updated_variables) end |