Class: Google::Apis::CesV1::Chunk
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::Chunk
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
A chunk of content within a message.
Instance Attribute Summary collapse
-
#agent_transfer ⇒ Google::Apis::CesV1::AgentTransfer
Represents an event indicating the transfer of a conversation to a different agent.
-
#blob ⇒ Google::Apis::CesV1::Blob
Represents a blob input or output in the conversation.
-
#default_variables ⇒ Hash<String,Object>
A struct represents default variables at the start of the conversation, keyed by variable names.
-
#image ⇒ Google::Apis::CesV1::Image
Represents an image input or output in the conversation.
-
#payload ⇒ Hash<String,Object>
Optional.
-
#text ⇒ String
Optional.
-
#tool_call ⇒ Google::Apis::CesV1::ToolCall
Request for the client or the agent to execute the specified tool.
-
#tool_response ⇒ Google::Apis::CesV1::ToolResponse
The execution result of a specific tool from the client or the agent.
-
#transcript ⇒ String
Optional.
-
#updated_variables ⇒ Hash<String,Object>
A struct represents variables that were updated in the conversation, keyed by variable names.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Chunk
constructor
A new instance of Chunk.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Chunk
Returns a new instance of Chunk.
1483 1484 1485 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1483 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_transfer ⇒ Google::Apis::CesV1::AgentTransfer
Represents an event indicating the transfer of a conversation to a different
agent.
Corresponds to the JSON property agentTransfer
1434 1435 1436 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1434 def agent_transfer @agent_transfer end |
#blob ⇒ Google::Apis::CesV1::Blob
Represents a blob input or output in the conversation.
Corresponds to the JSON property blob
1439 1440 1441 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1439 def blob @blob end |
#default_variables ⇒ Hash<String,Object>
A struct represents default variables at the start of the conversation, keyed
by variable names.
Corresponds to the JSON property defaultVariables
1445 1446 1447 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1445 def default_variables @default_variables end |
#image ⇒ Google::Apis::CesV1::Image
Represents an image input or output in the conversation.
Corresponds to the JSON property image
1450 1451 1452 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1450 def image @image end |
#payload ⇒ Hash<String,Object>
Optional. Custom payload data.
Corresponds to the JSON property payload
1455 1456 1457 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1455 def payload @payload end |
#text ⇒ String
Optional. Text data.
Corresponds to the JSON property text
1460 1461 1462 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1460 def text @text end |
#tool_call ⇒ Google::Apis::CesV1::ToolCall
Request for the client or the agent to execute the specified tool.
Corresponds to the JSON property toolCall
1465 1466 1467 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1465 def tool_call @tool_call end |
#tool_response ⇒ Google::Apis::CesV1::ToolResponse
The execution result of a specific tool from the client or the agent.
Corresponds to the JSON property toolResponse
1470 1471 1472 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1470 def tool_response @tool_response end |
#transcript ⇒ String
Optional. Transcript associated with the audio.
Corresponds to the JSON property transcript
1475 1476 1477 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1475 def transcript @transcript end |
#updated_variables ⇒ Hash<String,Object>
A struct represents variables that were updated in the conversation, keyed by
variable names.
Corresponds to the JSON property updatedVariables
1481 1482 1483 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1481 def updated_variables @updated_variables end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1488 def update!(**args) @agent_transfer = args[:agent_transfer] if args.key?(:agent_transfer) @blob = args[:blob] if args.key?(:blob) @default_variables = args[:default_variables] if args.key?(:default_variables) @image = args[:image] if args.key?(:image) @payload = args[:payload] if args.key?(:payload) @text = args[:text] if args.key?(:text) @tool_call = args[:tool_call] if args.key?(:tool_call) @tool_response = args[:tool_response] if args.key?(:tool_response) @transcript = args[:transcript] if args.key?(:transcript) @updated_variables = args[:updated_variables] if args.key?(:updated_variables) end |