Class: Google::Apis::CesV1::ClientFunction
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::ClientFunction
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Represents a client-side function that the agent can invoke. When the tool is chosen by the agent, control is handed off to the client. The client is responsible for executing the function and returning the result as a ToolResponse to continue the interaction with the agent.
Instance Attribute Summary collapse
-
#description ⇒ String
Optional.
-
#name ⇒ String
Required.
-
#parameters ⇒ Google::Apis::CesV1::Schema
Represents a select subset of an OpenAPI 3.0 schema object.
-
#response ⇒ Google::Apis::CesV1::Schema
Represents a select subset of an OpenAPI 3.0 schema object.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ClientFunction
constructor
A new instance of ClientFunction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ClientFunction
Returns a new instance of ClientFunction.
1791 1792 1793 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1791 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Optional. The function description.
Corresponds to the JSON property description
1774 1775 1776 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1774 def description @description end |
#name ⇒ String
Required. The function name.
Corresponds to the JSON property name
1779 1780 1781 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1779 def name @name end |
#parameters ⇒ Google::Apis::CesV1::Schema
Represents a select subset of an OpenAPI 3.0 schema object.
Corresponds to the JSON property parameters
1784 1785 1786 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1784 def parameters @parameters end |
#response ⇒ Google::Apis::CesV1::Schema
Represents a select subset of an OpenAPI 3.0 schema object.
Corresponds to the JSON property response
1789 1790 1791 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1789 def response @response end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1796 1797 1798 1799 1800 1801 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1796 def update!(**args) @description = args[:description] if args.key?(:description) @name = args[:name] if args.key?(:name) @parameters = args[:parameters] if args.key?(:parameters) @response = args[:response] if args.key?(:response) end |