Class: Google::Apis::CesV1::ClientFunction
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::ClientFunction
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Represents a client-side function that the agent can invoke. When the tool is chosen by the agent, control is handed off to the client. The client is responsible for executing the function and returning the result as a ToolResponse to continue the interaction with the agent.
Instance Attribute Summary collapse
-
#description ⇒ String
Optional.
-
#name ⇒ String
Required.
-
#parameters ⇒ Google::Apis::CesV1::Schema
Represents a select subset of an OpenAPI 3.0 schema object.
-
#response ⇒ Google::Apis::CesV1::Schema
Represents a select subset of an OpenAPI 3.0 schema object.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ClientFunction
constructor
A new instance of ClientFunction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ClientFunction
Returns a new instance of ClientFunction.
1783 1784 1785 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1783 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Optional. The function description.
Corresponds to the JSON property description
1766 1767 1768 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1766 def description @description end |
#name ⇒ String
Required. The function name.
Corresponds to the JSON property name
1771 1772 1773 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1771 def name @name end |
#parameters ⇒ Google::Apis::CesV1::Schema
Represents a select subset of an OpenAPI 3.0 schema object.
Corresponds to the JSON property parameters
1776 1777 1778 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1776 def parameters @parameters end |
#response ⇒ Google::Apis::CesV1::Schema
Represents a select subset of an OpenAPI 3.0 schema object.
Corresponds to the JSON property response
1781 1782 1783 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1781 def response @response end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1788 1789 1790 1791 1792 1793 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1788 def update!(**args) @description = args[:description] if args.key?(:description) @name = args[:name] if args.key?(:name) @parameters = args[:parameters] if args.key?(:parameters) @response = args[:response] if args.key?(:response) end |