Class: Google::Apis::CesV1::ClientFunction
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::ClientFunction
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Represents a client-side function that the agent can invoke. When the tool is chosen by the agent, control is handed off to the client. The client is responsible for executing the function and returning the result as a ToolResponse to continue the interaction with the agent.
Instance Attribute Summary collapse
-
#description ⇒ String
Optional.
-
#name ⇒ String
Required.
-
#parameters ⇒ Google::Apis::CesV1::Schema
Represents a select subset of an OpenAPI 3.0 schema object.
-
#response ⇒ Google::Apis::CesV1::Schema
Represents a select subset of an OpenAPI 3.0 schema object.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ClientFunction
constructor
A new instance of ClientFunction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ClientFunction
Returns a new instance of ClientFunction.
1616 1617 1618 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1616 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Optional. The function description.
Corresponds to the JSON property description
1599 1600 1601 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1599 def description @description end |
#name ⇒ String
Required. The function name.
Corresponds to the JSON property name
1604 1605 1606 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1604 def name @name end |
#parameters ⇒ Google::Apis::CesV1::Schema
Represents a select subset of an OpenAPI 3.0 schema object.
Corresponds to the JSON property parameters
1609 1610 1611 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1609 def parameters @parameters end |
#response ⇒ Google::Apis::CesV1::Schema
Represents a select subset of an OpenAPI 3.0 schema object.
Corresponds to the JSON property response
1614 1615 1616 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1614 def response @response end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1621 1622 1623 1624 1625 1626 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1621 def update!(**args) @description = args[:description] if args.key?(:description) @name = args[:name] if args.key?(:name) @parameters = args[:parameters] if args.key?(:parameters) @response = args[:response] if args.key?(:response) end |