Class: Google::Apis::CesV1::ConnectorTool

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

A ConnectorTool allows connections to different integrations. See: https:// cloud.google.com/integration-connectors/docs/overview.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConnectorTool

Returns a new instance of ConnectorTool.



1878
1879
1880
# File 'lib/google/apis/ces_v1/classes.rb', line 1878

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionGoogle::Apis::CesV1::Action

Configuration of an Action for the tool to use. Note: This can be either an Action or an Operation. See https://cloud.google.com/integration-connectors/ docs/entities-operation-action for details. Corresponds to the JSON property action



1850
1851
1852
# File 'lib/google/apis/ces_v1/classes.rb', line 1850

def action
  @action
end

#auth_configGoogle::Apis::CesV1::EndUserAuthConfig

End-user authentication configuration used for Connection calls. The field values must be the names of context variables in the format $context. variables.. Corresponds to the JSON property authConfig



1857
1858
1859
# File 'lib/google/apis/ces_v1/classes.rb', line 1857

def auth_config
  @auth_config
end

#connectionString

Required. The full resource name of the referenced Integration Connectors Connection. Format: projects/project/locations/location/connections/ connection` Corresponds to the JSON propertyconnection`

Returns:

  • (String)


1864
1865
1866
# File 'lib/google/apis/ces_v1/classes.rb', line 1864

def connection
  @connection
end

#descriptionString

Optional. The description of the tool that can be used by the Agent to decide whether to call this ConnectorTool. Corresponds to the JSON property description

Returns:

  • (String)


1870
1871
1872
# File 'lib/google/apis/ces_v1/classes.rb', line 1870

def description
  @description
end

#nameString

Optional. The name of the tool that can be used by the Agent to decide whether to call this ConnectorTool. Corresponds to the JSON property name

Returns:

  • (String)


1876
1877
1878
# File 'lib/google/apis/ces_v1/classes.rb', line 1876

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1883
1884
1885
1886
1887
1888
1889
# File 'lib/google/apis/ces_v1/classes.rb', line 1883

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @auth_config = args[:auth_config] if args.key?(:auth_config)
  @connection = args[:connection] if args.key?(:connection)
  @description = args[:description] if args.key?(:description)
  @name = args[:name] if args.key?(:name)
end