Class: Google::Apis::CesV1::ConnectorTool
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::ConnectorTool
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
A ConnectorTool allows connections to different integrations. See: https:// cloud.google.com/integration-connectors/docs/overview.
Instance Attribute Summary collapse
-
#action ⇒ Google::Apis::CesV1::Action
Configuration of an Action for the tool to use.
-
#auth_config ⇒ Google::Apis::CesV1::EndUserAuthConfig
End-user authentication configuration used for Connection calls.
-
#connection ⇒ String
Required.
-
#description ⇒ String
Optional.
-
#name ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConnectorTool
constructor
A new instance of ConnectorTool.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConnectorTool
Returns a new instance of ConnectorTool.
1711 1712 1713 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1711 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ Google::Apis::CesV1::Action
Configuration of an Action for the tool to use. Note: This can be either an
Action or an Operation. See https://cloud.google.com/integration-connectors/
docs/entities-operation-action for details.
Corresponds to the JSON property action
1683 1684 1685 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1683 def action @action end |
#auth_config ⇒ Google::Apis::CesV1::EndUserAuthConfig
End-user authentication configuration used for Connection calls. The field
values must be the names of context variables in the format $context.
variables..
Corresponds to the JSON property authConfig
1690 1691 1692 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1690 def auth_config @auth_config end |
#connection ⇒ String
Required. The full resource name of the referenced Integration Connectors
Connection. Format: projects/project/locations/location/connections/
connection`
Corresponds to the JSON propertyconnection`
1697 1698 1699 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1697 def connection @connection end |
#description ⇒ String
Optional. The description of the tool that can be used by the Agent to decide
whether to call this ConnectorTool.
Corresponds to the JSON property description
1703 1704 1705 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1703 def description @description end |
#name ⇒ String
Optional. The name of the tool that can be used by the Agent to decide whether
to call this ConnectorTool.
Corresponds to the JSON property name
1709 1710 1711 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1709 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1716 1717 1718 1719 1720 1721 1722 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1716 def update!(**args) @action = args[:action] if args.key?(:action) @auth_config = args[:auth_config] if args.key?(:auth_config) @connection = args[:connection] if args.key?(:connection) @description = args[:description] if args.key?(:description) @name = args[:name] if args.key?(:name) end |