Class: Google::Apis::CesV1::ConnectorToolset

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

A toolset that generates tools from an Integration Connectors Connection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConnectorToolset

Returns a new instance of ConnectorToolset.



1916
1917
1918
# File 'lib/google/apis/ces_v1/classes.rb', line 1916

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auth_configGoogle::Apis::CesV1::EndUserAuthConfig

End-user authentication configuration used for Connection calls. The field values must be the names of context variables in the format $context. variables.. Corresponds to the JSON property authConfig



1901
1902
1903
# File 'lib/google/apis/ces_v1/classes.rb', line 1901

def auth_config
  @auth_config
end

#connectionString

Required. The full resource name of the referenced Integration Connectors Connection. Format: projects/project/locations/location/connections/ connection` Corresponds to the JSON propertyconnection`

Returns:

  • (String)


1908
1909
1910
# File 'lib/google/apis/ces_v1/classes.rb', line 1908

def connection
  @connection
end

#connector_actionsArray<Google::Apis::CesV1::Action>

Required. The list of connector actions/entity operations to generate tools for. Corresponds to the JSON property connectorActions

Returns:



1914
1915
1916
# File 'lib/google/apis/ces_v1/classes.rb', line 1914

def connector_actions
  @connector_actions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1921
1922
1923
1924
1925
# File 'lib/google/apis/ces_v1/classes.rb', line 1921

def update!(**args)
  @auth_config = args[:auth_config] if args.key?(:auth_config)
  @connection = args[:connection] if args.key?(:connection)
  @connector_actions = args[:connector_actions] if args.key?(:connector_actions)
end