Class: Google::Apis::CesV1::Conversation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

A conversation represents an interaction between an end user and the CES app.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Conversation

Returns a new instance of Conversation.



2011
2012
2013
# File 'lib/google/apis/ces_v1/classes.rb', line 2011

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_versionString

Output only. The version of the app used for processing the conversation. Format: projects/project/locations/location/apps/app/versions/version` Corresponds to the JSON propertyappVersion`

Returns:

  • (String)


1944
1945
1946
# File 'lib/google/apis/ces_v1/classes.rb', line 1944

def app_version
  @app_version
end

#channel_typeString

DEPRECATED. Please use input_types instead. Corresponds to the JSON property channelType

Returns:

  • (String)


1949
1950
1951
# File 'lib/google/apis/ces_v1/classes.rb', line 1949

def channel_type
  @channel_type
end

#deploymentString

Output only. The deployment of the app used for processing the conversation. Format: projects/project/locations/location/apps/app/deployments/ deployment` Corresponds to the JSON propertydeployment`

Returns:

  • (String)


1956
1957
1958
# File 'lib/google/apis/ces_v1/classes.rb', line 1956

def deployment
  @deployment
end

#end_timeString

Output only. Timestamp when the conversation was completed. Corresponds to the JSON property endTime

Returns:

  • (String)


1961
1962
1963
# File 'lib/google/apis/ces_v1/classes.rb', line 1961

def end_time
  @end_time
end

#entry_agentString

Output only. The agent that initially handles the conversation. If not specified, the conversation is handled by the root agent. Format: projects/ project/locations/location/apps/app/agents/agent` Corresponds to the JSON propertyentryAgent`

Returns:

  • (String)


1968
1969
1970
# File 'lib/google/apis/ces_v1/classes.rb', line 1968

def entry_agent
  @entry_agent
end

#input_typesArray<String>

Output only. The input types of the conversation. Corresponds to the JSON property inputTypes

Returns:

  • (Array<String>)


1973
1974
1975
# File 'lib/google/apis/ces_v1/classes.rb', line 1973

def input_types
  @input_types
end

#language_codeString

Output only. The language code of the conversation. Corresponds to the JSON property languageCode

Returns:

  • (String)


1978
1979
1980
# File 'lib/google/apis/ces_v1/classes.rb', line 1978

def language_code
  @language_code
end

#messagesArray<Google::Apis::CesV1::Message>

Deprecated. Use turns instead. Corresponds to the JSON property messages

Returns:



1983
1984
1985
# File 'lib/google/apis/ces_v1/classes.rb', line 1983

def messages
  @messages
end

#nameString

Identifier. The unique identifier of the conversation. Format: projects/ project/locations/location/apps/app/conversations/conversation` Corresponds to the JSON propertyname`

Returns:

  • (String)


1989
1990
1991
# File 'lib/google/apis/ces_v1/classes.rb', line 1989

def name
  @name
end

#sourceString

Output only. Indicate the source of the conversation. Corresponds to the JSON property source

Returns:

  • (String)


1994
1995
1996
# File 'lib/google/apis/ces_v1/classes.rb', line 1994

def source
  @source
end

#start_timeString

Output only. Timestamp when the conversation was created. Corresponds to the JSON property startTime

Returns:

  • (String)


1999
2000
2001
# File 'lib/google/apis/ces_v1/classes.rb', line 1999

def start_time
  @start_time
end

#turn_countFixnum

Output only. The number of turns in the conversation. Corresponds to the JSON property turnCount

Returns:

  • (Fixnum)


2004
2005
2006
# File 'lib/google/apis/ces_v1/classes.rb', line 2004

def turn_count
  @turn_count
end

#turnsArray<Google::Apis::CesV1::ConversationTurn>

Required. The turns in the conversation. Corresponds to the JSON property turns



2009
2010
2011
# File 'lib/google/apis/ces_v1/classes.rb', line 2009

def turns
  @turns
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2016
2017
2018
2019
2020
2021
2022
2023
2024
2025
2026
2027
2028
2029
2030
# File 'lib/google/apis/ces_v1/classes.rb', line 2016

def update!(**args)
  @app_version = args[:app_version] if args.key?(:app_version)
  @channel_type = args[:channel_type] if args.key?(:channel_type)
  @deployment = args[:deployment] if args.key?(:deployment)
  @end_time = args[:end_time] if args.key?(:end_time)
  @entry_agent = args[:entry_agent] if args.key?(:entry_agent)
  @input_types = args[:input_types] if args.key?(:input_types)
  @language_code = args[:language_code] if args.key?(:language_code)
  @messages = args[:messages] if args.key?(:messages)
  @name = args[:name] if args.key?(:name)
  @source = args[:source] if args.key?(:source)
  @start_time = args[:start_time] if args.key?(:start_time)
  @turn_count = args[:turn_count] if args.key?(:turn_count)
  @turns = args[:turns] if args.key?(:turns)
end