Class: Google::Apis::CesV1::Conversation
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::Conversation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
A conversation represents an interaction between an end user and the CES app.
Instance Attribute Summary collapse
-
#app_version ⇒ String
Output only.
-
#channel_type ⇒ String
DEPRECATED.
-
#deployment ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#entry_agent ⇒ String
Output only.
-
#input_types ⇒ Array<String>
Output only.
-
#language_code ⇒ String
Output only.
-
#messages ⇒ Array<Google::Apis::CesV1::Message>
Deprecated.
-
#name ⇒ String
Identifier.
-
#source ⇒ String
Output only.
-
#start_time ⇒ String
Output only.
-
#turn_count ⇒ Fixnum
Output only.
-
#turns ⇒ Array<Google::Apis::CesV1::ConversationTurn>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Conversation
constructor
A new instance of Conversation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Conversation
Returns a new instance of Conversation.
2003 2004 2005 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2003 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_version ⇒ String
Output only. The version of the app used for processing the conversation.
Format: projects/project/locations/location/apps/app/versions/version`
Corresponds to the JSON propertyappVersion`
1936 1937 1938 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1936 def app_version @app_version end |
#channel_type ⇒ String
DEPRECATED. Please use input_types instead.
Corresponds to the JSON property channelType
1941 1942 1943 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1941 def channel_type @channel_type end |
#deployment ⇒ String
Output only. The deployment of the app used for processing the conversation.
Format: projects/project/locations/location/apps/app/deployments/
deployment`
Corresponds to the JSON propertydeployment`
1948 1949 1950 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1948 def deployment @deployment end |
#end_time ⇒ String
Output only. Timestamp when the conversation was completed.
Corresponds to the JSON property endTime
1953 1954 1955 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1953 def end_time @end_time end |
#entry_agent ⇒ String
Output only. The agent that initially handles the conversation. If not
specified, the conversation is handled by the root agent. Format: projects/
project/locations/location/apps/app/agents/agent`
Corresponds to the JSON propertyentryAgent`
1960 1961 1962 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1960 def entry_agent @entry_agent end |
#input_types ⇒ Array<String>
Output only. The input types of the conversation.
Corresponds to the JSON property inputTypes
1965 1966 1967 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1965 def input_types @input_types end |
#language_code ⇒ String
Output only. The language code of the conversation.
Corresponds to the JSON property languageCode
1970 1971 1972 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1970 def language_code @language_code end |
#messages ⇒ Array<Google::Apis::CesV1::Message>
Deprecated. Use turns instead.
Corresponds to the JSON property messages
1975 1976 1977 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1975 def @messages end |
#name ⇒ String
Identifier. The unique identifier of the conversation. Format: projects/
project/locations/location/apps/app/conversations/conversation`
Corresponds to the JSON propertyname`
1981 1982 1983 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1981 def name @name end |
#source ⇒ String
Output only. Indicate the source of the conversation.
Corresponds to the JSON property source
1986 1987 1988 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1986 def source @source end |
#start_time ⇒ String
Output only. Timestamp when the conversation was created.
Corresponds to the JSON property startTime
1991 1992 1993 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1991 def start_time @start_time end |
#turn_count ⇒ Fixnum
Output only. The number of turns in the conversation.
Corresponds to the JSON property turnCount
1996 1997 1998 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1996 def turn_count @turn_count end |
#turns ⇒ Array<Google::Apis::CesV1::ConversationTurn>
Required. The turns in the conversation.
Corresponds to the JSON property turns
2001 2002 2003 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2001 def turns @turns end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2008 2009 2010 2011 2012 2013 2014 2015 2016 2017 2018 2019 2020 2021 2022 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2008 def update!(**args) @app_version = args[:app_version] if args.key?(:app_version) @channel_type = args[:channel_type] if args.key?(:channel_type) @deployment = args[:deployment] if args.key?(:deployment) @end_time = args[:end_time] if args.key?(:end_time) @entry_agent = args[:entry_agent] if args.key?(:entry_agent) @input_types = args[:input_types] if args.key?(:input_types) @language_code = args[:language_code] if args.key?(:language_code) @messages = args[:messages] if args.key?(:messages) @name = args[:name] if args.key?(:name) @source = args[:source] if args.key?(:source) @start_time = args[:start_time] if args.key?(:start_time) @turn_count = args[:turn_count] if args.key?(:turn_count) @turns = args[:turns] if args.key?(:turns) end |