Class: Google::Apis::CesV1::Conversation
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::Conversation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
A conversation represents an interaction between an end user and the CES app.
Instance Attribute Summary collapse
-
#app_version ⇒ String
Output only.
-
#channel_type ⇒ String
DEPRECATED.
-
#deployment ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#entry_agent ⇒ String
Output only.
-
#input_types ⇒ Array<String>
Output only.
-
#language_code ⇒ String
Output only.
-
#messages ⇒ Array<Google::Apis::CesV1::Message>
Deprecated.
-
#name ⇒ String
Identifier.
-
#source ⇒ String
Output only.
-
#start_time ⇒ String
Output only.
-
#turn_count ⇒ Fixnum
Output only.
-
#turns ⇒ Array<Google::Apis::CesV1::ConversationTurn>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Conversation
constructor
A new instance of Conversation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Conversation
Returns a new instance of Conversation.
1836 1837 1838 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1836 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_version ⇒ String
Output only. The version of the app used for processing the conversation.
Format: projects/project/locations/location/apps/app/versions/version`
Corresponds to the JSON propertyappVersion`
1769 1770 1771 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1769 def app_version @app_version end |
#channel_type ⇒ String
DEPRECATED. Please use input_types instead.
Corresponds to the JSON property channelType
1774 1775 1776 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1774 def channel_type @channel_type end |
#deployment ⇒ String
Output only. The deployment of the app used for processing the conversation.
Format: projects/project/locations/location/apps/app/deployments/
deployment`
Corresponds to the JSON propertydeployment`
1781 1782 1783 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1781 def deployment @deployment end |
#end_time ⇒ String
Output only. Timestamp when the conversation was completed.
Corresponds to the JSON property endTime
1786 1787 1788 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1786 def end_time @end_time end |
#entry_agent ⇒ String
Output only. The agent that initially handles the conversation. If not
specified, the conversation is handled by the root agent. Format: projects/
project/locations/location/apps/app/agents/agent`
Corresponds to the JSON propertyentryAgent`
1793 1794 1795 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1793 def entry_agent @entry_agent end |
#input_types ⇒ Array<String>
Output only. The input types of the conversation.
Corresponds to the JSON property inputTypes
1798 1799 1800 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1798 def input_types @input_types end |
#language_code ⇒ String
Output only. The language code of the conversation.
Corresponds to the JSON property languageCode
1803 1804 1805 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1803 def language_code @language_code end |
#messages ⇒ Array<Google::Apis::CesV1::Message>
Deprecated. Use turns instead.
Corresponds to the JSON property messages
1808 1809 1810 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1808 def @messages end |
#name ⇒ String
Identifier. The unique identifier of the conversation. Format: projects/
project/locations/location/apps/app/conversations/conversation`
Corresponds to the JSON propertyname`
1814 1815 1816 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1814 def name @name end |
#source ⇒ String
Output only. Indicate the source of the conversation.
Corresponds to the JSON property source
1819 1820 1821 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1819 def source @source end |
#start_time ⇒ String
Output only. Timestamp when the conversation was created.
Corresponds to the JSON property startTime
1824 1825 1826 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1824 def start_time @start_time end |
#turn_count ⇒ Fixnum
Output only. The number of turns in the conversation.
Corresponds to the JSON property turnCount
1829 1830 1831 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1829 def turn_count @turn_count end |
#turns ⇒ Array<Google::Apis::CesV1::ConversationTurn>
Required. The turns in the conversation.
Corresponds to the JSON property turns
1834 1835 1836 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1834 def turns @turns end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1841 1842 1843 1844 1845 1846 1847 1848 1849 1850 1851 1852 1853 1854 1855 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1841 def update!(**args) @app_version = args[:app_version] if args.key?(:app_version) @channel_type = args[:channel_type] if args.key?(:channel_type) @deployment = args[:deployment] if args.key?(:deployment) @end_time = args[:end_time] if args.key?(:end_time) @entry_agent = args[:entry_agent] if args.key?(:entry_agent) @input_types = args[:input_types] if args.key?(:input_types) @language_code = args[:language_code] if args.key?(:language_code) @messages = args[:messages] if args.key?(:messages) @name = args[:name] if args.key?(:name) @source = args[:source] if args.key?(:source) @start_time = args[:start_time] if args.key?(:start_time) @turn_count = args[:turn_count] if args.key?(:turn_count) @turns = args[:turns] if args.key?(:turns) end |