Class: Google::Apis::CesV1::ConversationLoggingSettings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Settings to describe the conversation logging behaviors for the app.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConversationLoggingSettings

Returns a new instance of ConversationLoggingSettings.



1874
1875
1876
# File 'lib/google/apis/ces_v1/classes.rb', line 1874

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disable_conversation_loggingBoolean Also known as: disable_conversation_logging?

Optional. Whether to disable conversation logging for the sessions. Corresponds to the JSON property disableConversationLogging

Returns:

  • (Boolean)


1865
1866
1867
# File 'lib/google/apis/ces_v1/classes.rb', line 1865

def disable_conversation_logging
  @disable_conversation_logging
end

#retention_windowString

Optional. Controls the retention window for the conversation. If not set, the conversation will be retained for 365 days. Corresponds to the JSON property retentionWindow

Returns:

  • (String)


1872
1873
1874
# File 'lib/google/apis/ces_v1/classes.rb', line 1872

def retention_window
  @retention_window
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1879
1880
1881
1882
# File 'lib/google/apis/ces_v1/classes.rb', line 1879

def update!(**args)
  @disable_conversation_logging = args[:disable_conversation_logging] if args.key?(:disable_conversation_logging)
  @retention_window = args[:retention_window] if args.key?(:retention_window)
end