Class: Google::Apis::CesV1::ConversationTurn
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::ConversationTurn
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
All information about a single turn in the conversation.
Instance Attribute Summary collapse
-
#messages ⇒ Array<Google::Apis::CesV1::Message>
Optional.
-
#resolved_developer_instruction ⇒ String
Output only.
-
#root_span ⇒ Google::Apis::CesV1::Span
A span is a unit of work or a single operation during the request processing.
-
#template_attributes ⇒ Hash<String,Object>
Optional.
-
#user_intended_text ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConversationTurn
constructor
A new instance of ConversationTurn.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConversationTurn
Returns a new instance of ConversationTurn.
2192 2193 2194 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2192 def initialize(**args) update!(**args) end |
Instance Attribute Details
#messages ⇒ Array<Google::Apis::CesV1::Message>
Optional. List of messages in the conversation turn, including user input,
agent responses and intermediate events during the processing.
Corresponds to the JSON property messages
2165 2166 2167 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2165 def @messages end |
#resolved_developer_instruction ⇒ String
Output only. The full dynamically resolved developer instruction generated
from templates. This field is only populated on-demand when requested during
history retrieval. It is not persisted.
Corresponds to the JSON property resolvedDeveloperInstruction
2172 2173 2174 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2172 def resolved_developer_instruction @resolved_developer_instruction end |
#root_span ⇒ Google::Apis::CesV1::Span
A span is a unit of work or a single operation during the request processing.
Corresponds to the JSON property rootSpan
2177 2178 2179 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2177 def root_span @root_span end |
#template_attributes ⇒ Hash<String,Object>
Optional. Variables or configurations referenced by the template engine during
dynamic prompt generation. This allows reconstructing the exact prompt sent to
the model for this turn.
Corresponds to the JSON property templateAttributes
2184 2185 2186 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2184 def template_attributes @template_attributes end |
#user_intended_text ⇒ String
Optional. The intended ground-truth text from the Simulated Caller (Polysynth).
Only populated when word error rate metrics are enabled.
Corresponds to the JSON property userIntendedText
2190 2191 2192 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2190 def user_intended_text @user_intended_text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2197 2198 2199 2200 2201 2202 2203 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2197 def update!(**args) @messages = args[:messages] if args.key?(:messages) @resolved_developer_instruction = args[:resolved_developer_instruction] if args.key?(:resolved_developer_instruction) @root_span = args[:root_span] if args.key?(:root_span) @template_attributes = args[:template_attributes] if args.key?(:template_attributes) @user_intended_text = args[:user_intended_text] if args.key?(:user_intended_text) end |