Class: Google::Apis::CesV1::ConversationTurn
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::ConversationTurn
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
All information about a single turn in the conversation.
Instance Attribute Summary collapse
-
#messages ⇒ Array<Google::Apis::CesV1::Message>
Optional.
-
#root_span ⇒ Google::Apis::CesV1::Span
A span is a unit of work or a single operation during the request processing.
-
#user_intended_text ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConversationTurn
constructor
A new instance of ConversationTurn.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConversationTurn
Returns a new instance of ConversationTurn.
2178 2179 2180 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2178 def initialize(**args) update!(**args) end |
Instance Attribute Details
#messages ⇒ Array<Google::Apis::CesV1::Message>
Optional. List of messages in the conversation turn, including user input,
agent responses and intermediate events during the processing.
Corresponds to the JSON property messages
2165 2166 2167 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2165 def @messages end |
#root_span ⇒ Google::Apis::CesV1::Span
A span is a unit of work or a single operation during the request processing.
Corresponds to the JSON property rootSpan
2170 2171 2172 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2170 def root_span @root_span end |
#user_intended_text ⇒ String
Optional. The intended ground-truth text from the Simulated Caller (Polysynth).
Only populated when word error rate metrics are enabled.
Corresponds to the JSON property userIntendedText
2176 2177 2178 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2176 def user_intended_text @user_intended_text end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2183 2184 2185 2186 2187 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2183 def update!(**args) @messages = args[:messages] if args.key?(:messages) @root_span = args[:root_span] if args.key?(:root_span) @user_intended_text = args[:user_intended_text] if args.key?(:user_intended_text) end |