Class: Google::Apis::CesV1::ConversationTurn

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

All information about a single turn in the conversation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConversationTurn

Returns a new instance of ConversationTurn.



2075
2076
2077
# File 'lib/google/apis/ces_v1/classes.rb', line 2075

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#messagesArray<Google::Apis::CesV1::Message>

Optional. List of messages in the conversation turn, including user input, agent responses and intermediate events during the processing. Corresponds to the JSON property messages

Returns:



2068
2069
2070
# File 'lib/google/apis/ces_v1/classes.rb', line 2068

def messages
  @messages
end

#root_spanGoogle::Apis::CesV1::Span

A span is a unit of work or a single operation during the request processing. Corresponds to the JSON property rootSpan



2073
2074
2075
# File 'lib/google/apis/ces_v1/classes.rb', line 2073

def root_span
  @root_span
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2080
2081
2082
2083
# File 'lib/google/apis/ces_v1/classes.rb', line 2080

def update!(**args)
  @messages = args[:messages] if args.key?(:messages)
  @root_span = args[:root_span] if args.key?(:root_span)
end