Class: Google::Apis::CesV1::ConversationTurn
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::ConversationTurn
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
All information about a single turn in the conversation.
Instance Attribute Summary collapse
-
#messages ⇒ Array<Google::Apis::CesV1::Message>
Optional.
-
#root_span ⇒ Google::Apis::CesV1::Span
A span is a unit of work or a single operation during the request processing.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConversationTurn
constructor
A new instance of ConversationTurn.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConversationTurn
Returns a new instance of ConversationTurn.
1900 1901 1902 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1900 def initialize(**args) update!(**args) end |
Instance Attribute Details
#messages ⇒ Array<Google::Apis::CesV1::Message>
Optional. List of messages in the conversation turn, including user input,
agent responses and intermediate events during the processing.
Corresponds to the JSON property messages
1893 1894 1895 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1893 def @messages end |
#root_span ⇒ Google::Apis::CesV1::Span
A span is a unit of work or a single operation during the request processing.
Corresponds to the JSON property rootSpan
1898 1899 1900 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1898 def root_span @root_span end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1905 1906 1907 1908 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1905 def update!(**args) @messages = args[:messages] if args.key?(:messages) @root_span = args[:root_span] if args.key?(:root_span) end |