Class: Google::Apis::CesV1::DataStore

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

A DataStore resource in Vertex AI Search.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DataStore

Returns a new instance of DataStore.



2115
2116
2117
# File 'lib/google/apis/ces_v1/classes.rb', line 2115

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connector_configGoogle::Apis::CesV1::DataStoreConnectorConfig

The connector config for the data store connection. Corresponds to the JSON property connectorConfig



2085
2086
2087
# File 'lib/google/apis/ces_v1/classes.rb', line 2085

def connector_config
  @connector_config
end

#create_timeString

Output only. Timestamp when the data store was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2090
2091
2092
# File 'lib/google/apis/ces_v1/classes.rb', line 2090

def create_time
  @create_time
end

#display_nameString

Output only. The display name of the data store. Corresponds to the JSON property displayName

Returns:

  • (String)


2095
2096
2097
# File 'lib/google/apis/ces_v1/classes.rb', line 2095

def display_name
  @display_name
end

#document_processing_modeString

Output only. The document processing mode for the data store connection. Only set for PUBLIC_WEB and UNSTRUCTURED data stores. Corresponds to the JSON property documentProcessingMode

Returns:

  • (String)


2101
2102
2103
# File 'lib/google/apis/ces_v1/classes.rb', line 2101

def document_processing_mode
  @document_processing_mode
end

#nameString

Required. Full resource name of the DataStore. Format: projects/project/ locations/location/collections/collection/dataStores/dataStore` Corresponds to the JSON propertyname`

Returns:

  • (String)


2107
2108
2109
# File 'lib/google/apis/ces_v1/classes.rb', line 2107

def name
  @name
end

#typeString

Output only. The type of the data store. This field is readonly and populated by the server. Corresponds to the JSON property type

Returns:

  • (String)


2113
2114
2115
# File 'lib/google/apis/ces_v1/classes.rb', line 2113

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2120
2121
2122
2123
2124
2125
2126
2127
# File 'lib/google/apis/ces_v1/classes.rb', line 2120

def update!(**args)
  @connector_config = args[:connector_config] if args.key?(:connector_config)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @document_processing_mode = args[:document_processing_mode] if args.key?(:document_processing_mode)
  @name = args[:name] if args.key?(:name)
  @type = args[:type] if args.key?(:type)
end