Class: Google::Apis::CesV1::DataStore

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

A DataStore resource in Vertex AI Search.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DataStore

Returns a new instance of DataStore.



1948
1949
1950
# File 'lib/google/apis/ces_v1/classes.rb', line 1948

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connector_configGoogle::Apis::CesV1::DataStoreConnectorConfig

The connector config for the data store connection. Corresponds to the JSON property connectorConfig



1918
1919
1920
# File 'lib/google/apis/ces_v1/classes.rb', line 1918

def connector_config
  @connector_config
end

#create_timeString

Output only. Timestamp when the data store was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1923
1924
1925
# File 'lib/google/apis/ces_v1/classes.rb', line 1923

def create_time
  @create_time
end

#display_nameString

Output only. The display name of the data store. Corresponds to the JSON property displayName

Returns:

  • (String)


1928
1929
1930
# File 'lib/google/apis/ces_v1/classes.rb', line 1928

def display_name
  @display_name
end

#document_processing_modeString

Output only. The document processing mode for the data store connection. Only set for PUBLIC_WEB and UNSTRUCTURED data stores. Corresponds to the JSON property documentProcessingMode

Returns:

  • (String)


1934
1935
1936
# File 'lib/google/apis/ces_v1/classes.rb', line 1934

def document_processing_mode
  @document_processing_mode
end

#nameString

Required. Full resource name of the DataStore. Format: projects/project/ locations/location/collections/collection/dataStores/dataStore` Corresponds to the JSON propertyname`

Returns:

  • (String)


1940
1941
1942
# File 'lib/google/apis/ces_v1/classes.rb', line 1940

def name
  @name
end

#typeString

Output only. The type of the data store. This field is readonly and populated by the server. Corresponds to the JSON property type

Returns:

  • (String)


1946
1947
1948
# File 'lib/google/apis/ces_v1/classes.rb', line 1946

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1953
1954
1955
1956
1957
1958
1959
1960
# File 'lib/google/apis/ces_v1/classes.rb', line 1953

def update!(**args)
  @connector_config = args[:connector_config] if args.key?(:connector_config)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @document_processing_mode = args[:document_processing_mode] if args.key?(:document_processing_mode)
  @name = args[:name] if args.key?(:name)
  @type = args[:type] if args.key?(:type)
end