Class: Google::Apis::CesV1::DataStoreConnectorConfig
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::DataStoreConnectorConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
The connector config for the data store connection.
Instance Attribute Summary collapse
-
#collection ⇒ String
Resource name of the collection the data store belongs to.
-
#collection_display_name ⇒ String
Display name of the collection the data store belongs to.
-
#data_source ⇒ String
The name of the data source.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DataStoreConnectorConfig
constructor
A new instance of DataStoreConnectorConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DataStoreConnectorConfig
Returns a new instance of DataStoreConnectorConfig.
2150 2151 2152 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2150 def initialize(**args) update!(**args) end |
Instance Attribute Details
#collection ⇒ String
Resource name of the collection the data store belongs to.
Corresponds to the JSON property collection
2137 2138 2139 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2137 def collection @collection end |
#collection_display_name ⇒ String
Display name of the collection the data store belongs to.
Corresponds to the JSON property collectionDisplayName
2142 2143 2144 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2142 def collection_display_name @collection_display_name end |
#data_source ⇒ String
The name of the data source. Example: salesforce, jira, confluence,
bigquery.
Corresponds to the JSON property dataSource
2148 2149 2150 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2148 def data_source @data_source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2155 2156 2157 2158 2159 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2155 def update!(**args) @collection = args[:collection] if args.key?(:collection) @collection_display_name = args[:collection_display_name] if args.key?(:collection_display_name) @data_source = args[:data_source] if args.key?(:data_source) end |