Class: Google::Apis::CesV1::DataStoreConnectorConfig
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::DataStoreConnectorConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
The connector config for the data store connection.
Instance Attribute Summary collapse
-
#collection ⇒ String
Resource name of the collection the data store belongs to.
-
#collection_display_name ⇒ String
Display name of the collection the data store belongs to.
-
#data_source ⇒ String
The name of the data source.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DataStoreConnectorConfig
constructor
A new instance of DataStoreConnectorConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DataStoreConnectorConfig
Returns a new instance of DataStoreConnectorConfig.
1983 1984 1985 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1983 def initialize(**args) update!(**args) end |
Instance Attribute Details
#collection ⇒ String
Resource name of the collection the data store belongs to.
Corresponds to the JSON property collection
1970 1971 1972 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1970 def collection @collection end |
#collection_display_name ⇒ String
Display name of the collection the data store belongs to.
Corresponds to the JSON property collectionDisplayName
1975 1976 1977 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1975 def collection_display_name @collection_display_name end |
#data_source ⇒ String
The name of the data source. Example: salesforce, jira, confluence,
bigquery.
Corresponds to the JSON property dataSource
1981 1982 1983 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1981 def data_source @data_source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1988 1989 1990 1991 1992 |
# File 'lib/google/apis/ces_v1/classes.rb', line 1988 def update!(**args) @collection = args[:collection] if args.key?(:collection) @collection_display_name = args[:collection_display_name] if args.key?(:collection_display_name) @data_source = args[:data_source] if args.key?(:data_source) end |