Class: Google::Apis::CesV1::DataStoreTool

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Tool to retrieve from Vertex AI Search datastore or engine for grounding. Accepts either a datastore or an engine, but not both. See Vertex AI Search: https://cloud.google.com/generative-ai-app-builder/docs/enterprise-search- introduction.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DataStoreTool

Returns a new instance of DataStoreTool.



2357
2358
2359
# File 'lib/google/apis/ces_v1/classes.rb', line 2357

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#boost_specsArray<Google::Apis::CesV1::DataStoreToolBoostSpecs>

Optional. Boost specification to boost certain documents. Corresponds to the JSON property boostSpecs



2324
2325
2326
# File 'lib/google/apis/ces_v1/classes.rb', line 2324

def boost_specs
  @boost_specs
end

#data_store_sourceGoogle::Apis::CesV1::DataStoreToolDataStoreSource

Configuration for searching within a specific DataStore. Corresponds to the JSON property dataStoreSource



2329
2330
2331
# File 'lib/google/apis/ces_v1/classes.rb', line 2329

def data_store_source
  @data_store_source
end

#descriptionString

Optional. The tool description. Corresponds to the JSON property description

Returns:

  • (String)


2334
2335
2336
# File 'lib/google/apis/ces_v1/classes.rb', line 2334

def description
  @description
end

#engine_sourceGoogle::Apis::CesV1::DataStoreToolEngineSource

Configuration for searching within an Engine, potentially targeting specific DataStores. Corresponds to the JSON property engineSource



2340
2341
2342
# File 'lib/google/apis/ces_v1/classes.rb', line 2340

def engine_source
  @engine_source
end

#filter_parameter_behaviorString

Optional. The filter parameter behavior. Corresponds to the JSON property filterParameterBehavior

Returns:

  • (String)


2345
2346
2347
# File 'lib/google/apis/ces_v1/classes.rb', line 2345

def filter_parameter_behavior
  @filter_parameter_behavior
end

#modality_configsArray<Google::Apis::CesV1::DataStoreToolModalityConfig>

Optional. The modality configs for the data store. Corresponds to the JSON property modalityConfigs



2350
2351
2352
# File 'lib/google/apis/ces_v1/classes.rb', line 2350

def modality_configs
  @modality_configs
end

#nameString

Required. The data store tool name. Corresponds to the JSON property name

Returns:

  • (String)


2355
2356
2357
# File 'lib/google/apis/ces_v1/classes.rb', line 2355

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2362
2363
2364
2365
2366
2367
2368
2369
2370
# File 'lib/google/apis/ces_v1/classes.rb', line 2362

def update!(**args)
  @boost_specs = args[:boost_specs] if args.key?(:boost_specs)
  @data_store_source = args[:data_store_source] if args.key?(:data_store_source)
  @description = args[:description] if args.key?(:description)
  @engine_source = args[:engine_source] if args.key?(:engine_source)
  @filter_parameter_behavior = args[:filter_parameter_behavior] if args.key?(:filter_parameter_behavior)
  @modality_configs = args[:modality_configs] if args.key?(:modality_configs)
  @name = args[:name] if args.key?(:name)
end