Class: Google::Apis::CesV1::DataStoreTool

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Tool to retrieve from Vertex AI Search datastore or engine for grounding. Accepts either a datastore or an engine, but not both. See Vertex AI Search: https://cloud.google.com/generative-ai-app-builder/docs/enterprise-search- introduction.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DataStoreTool

Returns a new instance of DataStoreTool.



2260
2261
2262
# File 'lib/google/apis/ces_v1/classes.rb', line 2260

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#boost_specsArray<Google::Apis::CesV1::DataStoreToolBoostSpecs>

Optional. Boost specification to boost certain documents. Corresponds to the JSON property boostSpecs



2227
2228
2229
# File 'lib/google/apis/ces_v1/classes.rb', line 2227

def boost_specs
  @boost_specs
end

#data_store_sourceGoogle::Apis::CesV1::DataStoreToolDataStoreSource

Configuration for searching within a specific DataStore. Corresponds to the JSON property dataStoreSource



2232
2233
2234
# File 'lib/google/apis/ces_v1/classes.rb', line 2232

def data_store_source
  @data_store_source
end

#descriptionString

Optional. The tool description. Corresponds to the JSON property description

Returns:

  • (String)


2237
2238
2239
# File 'lib/google/apis/ces_v1/classes.rb', line 2237

def description
  @description
end

#engine_sourceGoogle::Apis::CesV1::DataStoreToolEngineSource

Configuration for searching within an Engine, potentially targeting specific DataStores. Corresponds to the JSON property engineSource



2243
2244
2245
# File 'lib/google/apis/ces_v1/classes.rb', line 2243

def engine_source
  @engine_source
end

#filter_parameter_behaviorString

Optional. The filter parameter behavior. Corresponds to the JSON property filterParameterBehavior

Returns:

  • (String)


2248
2249
2250
# File 'lib/google/apis/ces_v1/classes.rb', line 2248

def filter_parameter_behavior
  @filter_parameter_behavior
end

#modality_configsArray<Google::Apis::CesV1::DataStoreToolModalityConfig>

Optional. The modality configs for the data store. Corresponds to the JSON property modalityConfigs



2253
2254
2255
# File 'lib/google/apis/ces_v1/classes.rb', line 2253

def modality_configs
  @modality_configs
end

#nameString

Required. The data store tool name. Corresponds to the JSON property name

Returns:

  • (String)


2258
2259
2260
# File 'lib/google/apis/ces_v1/classes.rb', line 2258

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2265
2266
2267
2268
2269
2270
2271
2272
2273
# File 'lib/google/apis/ces_v1/classes.rb', line 2265

def update!(**args)
  @boost_specs = args[:boost_specs] if args.key?(:boost_specs)
  @data_store_source = args[:data_store_source] if args.key?(:data_store_source)
  @description = args[:description] if args.key?(:description)
  @engine_source = args[:engine_source] if args.key?(:engine_source)
  @filter_parameter_behavior = args[:filter_parameter_behavior] if args.key?(:filter_parameter_behavior)
  @modality_configs = args[:modality_configs] if args.key?(:modality_configs)
  @name = args[:name] if args.key?(:name)
end