Class: Google::Apis::CesV1::DataStoreTool

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Tool to retrieve from Vertex AI Search datastore or engine for grounding. Accepts either a datastore or an engine, but not both. See Vertex AI Search: https://cloud.google.com/generative-ai-app-builder/docs/enterprise-search- introduction.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DataStoreTool

Returns a new instance of DataStoreTool.



2252
2253
2254
# File 'lib/google/apis/ces_v1/classes.rb', line 2252

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#boost_specsArray<Google::Apis::CesV1::DataStoreToolBoostSpecs>

Optional. Boost specification to boost certain documents. Corresponds to the JSON property boostSpecs



2219
2220
2221
# File 'lib/google/apis/ces_v1/classes.rb', line 2219

def boost_specs
  @boost_specs
end

#data_store_sourceGoogle::Apis::CesV1::DataStoreToolDataStoreSource

Configuration for searching within a specific DataStore. Corresponds to the JSON property dataStoreSource



2224
2225
2226
# File 'lib/google/apis/ces_v1/classes.rb', line 2224

def data_store_source
  @data_store_source
end

#descriptionString

Optional. The tool description. Corresponds to the JSON property description

Returns:

  • (String)


2229
2230
2231
# File 'lib/google/apis/ces_v1/classes.rb', line 2229

def description
  @description
end

#engine_sourceGoogle::Apis::CesV1::DataStoreToolEngineSource

Configuration for searching within an Engine, potentially targeting specific DataStores. Corresponds to the JSON property engineSource



2235
2236
2237
# File 'lib/google/apis/ces_v1/classes.rb', line 2235

def engine_source
  @engine_source
end

#filter_parameter_behaviorString

Optional. The filter parameter behavior. Corresponds to the JSON property filterParameterBehavior

Returns:

  • (String)


2240
2241
2242
# File 'lib/google/apis/ces_v1/classes.rb', line 2240

def filter_parameter_behavior
  @filter_parameter_behavior
end

#modality_configsArray<Google::Apis::CesV1::DataStoreToolModalityConfig>

Optional. The modality configs for the data store. Corresponds to the JSON property modalityConfigs



2245
2246
2247
# File 'lib/google/apis/ces_v1/classes.rb', line 2245

def modality_configs
  @modality_configs
end

#nameString

Required. The data store tool name. Corresponds to the JSON property name

Returns:

  • (String)


2250
2251
2252
# File 'lib/google/apis/ces_v1/classes.rb', line 2250

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2257
2258
2259
2260
2261
2262
2263
2264
2265
# File 'lib/google/apis/ces_v1/classes.rb', line 2257

def update!(**args)
  @boost_specs = args[:boost_specs] if args.key?(:boost_specs)
  @data_store_source = args[:data_store_source] if args.key?(:data_store_source)
  @description = args[:description] if args.key?(:description)
  @engine_source = args[:engine_source] if args.key?(:engine_source)
  @filter_parameter_behavior = args[:filter_parameter_behavior] if args.key?(:filter_parameter_behavior)
  @modality_configs = args[:modality_configs] if args.key?(:modality_configs)
  @name = args[:name] if args.key?(:name)
end