Class: Google::Apis::CesV1::DataStoreTool
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::DataStoreTool
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Tool to retrieve from Vertex AI Search datastore or engine for grounding. Accepts either a datastore or an engine, but not both. See Vertex AI Search: https://cloud.google.com/generative-ai-app-builder/docs/enterprise-search- introduction.
Instance Attribute Summary collapse
-
#boost_specs ⇒ Array<Google::Apis::CesV1::DataStoreToolBoostSpecs>
Optional.
-
#data_store_source ⇒ Google::Apis::CesV1::DataStoreToolDataStoreSource
Configuration for searching within a specific DataStore.
-
#description ⇒ String
Optional.
-
#engine_source ⇒ Google::Apis::CesV1::DataStoreToolEngineSource
Configuration for searching within an Engine, potentially targeting specific DataStores.
-
#filter_parameter_behavior ⇒ String
Optional.
-
#modality_configs ⇒ Array<Google::Apis::CesV1::DataStoreToolModalityConfig>
Optional.
-
#name ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DataStoreTool
constructor
A new instance of DataStoreTool.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DataStoreTool
Returns a new instance of DataStoreTool.
2085 2086 2087 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2085 def initialize(**args) update!(**args) end |
Instance Attribute Details
#boost_specs ⇒ Array<Google::Apis::CesV1::DataStoreToolBoostSpecs>
Optional. Boost specification to boost certain documents.
Corresponds to the JSON property boostSpecs
2052 2053 2054 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2052 def boost_specs @boost_specs end |
#data_store_source ⇒ Google::Apis::CesV1::DataStoreToolDataStoreSource
Configuration for searching within a specific DataStore.
Corresponds to the JSON property dataStoreSource
2057 2058 2059 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2057 def data_store_source @data_store_source end |
#description ⇒ String
Optional. The tool description.
Corresponds to the JSON property description
2062 2063 2064 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2062 def description @description end |
#engine_source ⇒ Google::Apis::CesV1::DataStoreToolEngineSource
Configuration for searching within an Engine, potentially targeting specific
DataStores.
Corresponds to the JSON property engineSource
2068 2069 2070 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2068 def engine_source @engine_source end |
#filter_parameter_behavior ⇒ String
Optional. The filter parameter behavior.
Corresponds to the JSON property filterParameterBehavior
2073 2074 2075 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2073 def filter_parameter_behavior @filter_parameter_behavior end |
#modality_configs ⇒ Array<Google::Apis::CesV1::DataStoreToolModalityConfig>
Optional. The modality configs for the data store.
Corresponds to the JSON property modalityConfigs
2078 2079 2080 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2078 def modality_configs @modality_configs end |
#name ⇒ String
Required. The data store tool name.
Corresponds to the JSON property name
2083 2084 2085 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2083 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2090 2091 2092 2093 2094 2095 2096 2097 2098 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2090 def update!(**args) @boost_specs = args[:boost_specs] if args.key?(:boost_specs) @data_store_source = args[:data_store_source] if args.key?(:data_store_source) @description = args[:description] if args.key?(:description) @engine_source = args[:engine_source] if args.key?(:engine_source) @filter_parameter_behavior = args[:filter_parameter_behavior] if args.key?(:filter_parameter_behavior) @modality_configs = args[:modality_configs] if args.key?(:modality_configs) @name = args[:name] if args.key?(:name) end |