Class: Google::Apis::CesV1::DataStoreToolBoostSpecConditionBoostSpec

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Boost specification for a condition.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DataStoreToolBoostSpecConditionBoostSpec

Returns a new instance of DataStoreToolBoostSpecConditionBoostSpec.



2316
2317
2318
# File 'lib/google/apis/ces_v1/classes.rb', line 2316

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#boostFloat

Optional. Strength of the boost, which should be in [-1, 1]. Negative boost means demotion. Default is 0.0. Setting to 1.0 gives the suggestions a big promotion. However, it does not necessarily mean that the top result will be a boosted suggestion. Setting to -1.0 gives the suggestions a big demotion. However, other suggestions that are relevant might still be shown. Setting to 0.0 means no boost applied. The boosting condition is ignored. Corresponds to the JSON property boost

Returns:

  • (Float)


2299
2300
2301
# File 'lib/google/apis/ces_v1/classes.rb', line 2299

def boost
  @boost
end

#boost_control_specGoogle::Apis::CesV1::DataStoreToolBoostSpecConditionBoostSpecBoostControlSpec

Specification for custom ranking based on customer specified attribute value. It provides more controls for customized ranking than the simple (condition, boost) combination above. Corresponds to the JSON property boostControlSpec



2306
2307
2308
# File 'lib/google/apis/ces_v1/classes.rb', line 2306

def boost_control_spec
  @boost_control_spec
end

#conditionString

Required. An expression which specifies a boost condition. The syntax is the same as filter expression syntax. Currently, the only supported condition is a list of BCP-47 lang codes. Example: To boost suggestions in languages en or fr: (lang_code: ANY("en", "fr")) Corresponds to the JSON property condition

Returns:

  • (String)


2314
2315
2316
# File 'lib/google/apis/ces_v1/classes.rb', line 2314

def condition
  @condition
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2321
2322
2323
2324
2325
# File 'lib/google/apis/ces_v1/classes.rb', line 2321

def update!(**args)
  @boost = args[:boost] if args.key?(:boost)
  @boost_control_spec = args[:boost_control_spec] if args.key?(:boost_control_spec)
  @condition = args[:condition] if args.key?(:condition)
end