Class: Google::Apis::CesV1::DataStoreToolBoostSpecConditionBoostSpecBoostControlSpec

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Specification for custom ranking based on customer specified attribute value. It provides more controls for customized ranking than the simple (condition, boost) combination above.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DataStoreToolBoostSpecConditionBoostSpecBoostControlSpec

Returns a new instance of DataStoreToolBoostSpecConditionBoostSpecBoostControlSpec.



2474
2475
2476
# File 'lib/google/apis/ces_v1/classes.rb', line 2474

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attribute_typeString

Optional. The attribute type to be used to determine the boost amount. The attribute value can be derived from the field value of the specified field_name. In the case of numerical it is straightforward i.e. attribute_value = numerical_field_value. In the case of freshness however, attribute_value = (time.now() - datetime_field_value). Corresponds to the JSON property attributeType

Returns:

  • (String)


2453
2454
2455
# File 'lib/google/apis/ces_v1/classes.rb', line 2453

def attribute_type
  @attribute_type
end

#control_pointsArray<Google::Apis::CesV1::DataStoreToolBoostSpecConditionBoostSpecBoostControlSpecControlPoint>

Optional. The control points used to define the curve. The monotonic function ( defined through the interpolation_type above) passes through the control points listed here. Corresponds to the JSON property controlPoints



2460
2461
2462
# File 'lib/google/apis/ces_v1/classes.rb', line 2460

def control_points
  @control_points
end

#field_nameString

Optional. The name of the field whose value will be used to determine the boost amount. Corresponds to the JSON property fieldName

Returns:

  • (String)


2466
2467
2468
# File 'lib/google/apis/ces_v1/classes.rb', line 2466

def field_name
  @field_name
end

#interpolation_typeString

Optional. The interpolation type to be applied to connect the control points listed below. Corresponds to the JSON property interpolationType

Returns:

  • (String)


2472
2473
2474
# File 'lib/google/apis/ces_v1/classes.rb', line 2472

def interpolation_type
  @interpolation_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2479
2480
2481
2482
2483
2484
# File 'lib/google/apis/ces_v1/classes.rb', line 2479

def update!(**args)
  @attribute_type = args[:attribute_type] if args.key?(:attribute_type)
  @control_points = args[:control_points] if args.key?(:control_points)
  @field_name = args[:field_name] if args.key?(:field_name)
  @interpolation_type = args[:interpolation_type] if args.key?(:interpolation_type)
end