Class: Google::Apis::CesV1::DataStoreToolBoostSpecConditionBoostSpecBoostControlSpec
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::DataStoreToolBoostSpecConditionBoostSpecBoostControlSpec
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Specification for custom ranking based on customer specified attribute value. It provides more controls for customized ranking than the simple (condition, boost) combination above.
Instance Attribute Summary collapse
-
#attribute_type ⇒ String
Optional.
-
#control_points ⇒ Array<Google::Apis::CesV1::DataStoreToolBoostSpecConditionBoostSpecBoostControlSpecControlPoint>
Optional.
-
#field_name ⇒ String
Optional.
-
#interpolation_type ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DataStoreToolBoostSpecConditionBoostSpecBoostControlSpec
constructor
A new instance of DataStoreToolBoostSpecConditionBoostSpecBoostControlSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DataStoreToolBoostSpecConditionBoostSpecBoostControlSpec
Returns a new instance of DataStoreToolBoostSpecConditionBoostSpecBoostControlSpec.
2195 2196 2197 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2195 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attribute_type ⇒ String
Optional. The attribute type to be used to determine the boost amount. The
attribute value can be derived from the field value of the specified
field_name. In the case of numerical it is straightforward i.e.
attribute_value = numerical_field_value. In the case of freshness however,
attribute_value = (time.now() - datetime_field_value).
Corresponds to the JSON property attributeType
2174 2175 2176 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2174 def attribute_type @attribute_type end |
#control_points ⇒ Array<Google::Apis::CesV1::DataStoreToolBoostSpecConditionBoostSpecBoostControlSpecControlPoint>
Optional. The control points used to define the curve. The monotonic function (
defined through the interpolation_type above) passes through the control
points listed here.
Corresponds to the JSON property controlPoints
2181 2182 2183 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2181 def control_points @control_points end |
#field_name ⇒ String
Optional. The name of the field whose value will be used to determine the
boost amount.
Corresponds to the JSON property fieldName
2187 2188 2189 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2187 def field_name @field_name end |
#interpolation_type ⇒ String
Optional. The interpolation type to be applied to connect the control points
listed below.
Corresponds to the JSON property interpolationType
2193 2194 2195 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2193 def interpolation_type @interpolation_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2200 2201 2202 2203 2204 2205 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2200 def update!(**args) @attribute_type = args[:attribute_type] if args.key?(:attribute_type) @control_points = args[:control_points] if args.key?(:control_points) @field_name = args[:field_name] if args.key?(:field_name) @interpolation_type = args[:interpolation_type] if args.key?(:interpolation_type) end |