Class: Google::Apis::CesV1::DataStoreToolBoostSpecConditionBoostSpecBoostControlSpecControlPoint

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

The control points used to define the curve. The curve defined through these control points can only be monotonically increasing or decreasing(constant values are acceptable).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DataStoreToolBoostSpecConditionBoostSpecBoostControlSpecControlPoint

Returns a new instance of DataStoreToolBoostSpecConditionBoostSpecBoostControlSpecControlPoint.



2228
2229
2230
# File 'lib/google/apis/ces_v1/classes.rb', line 2228

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attribute_valueString

Optional. Can be one of: 1. The numerical field value. 2. The duration spec for freshness: The value must be formatted as an XSD dayTimeDuration value ( a restricted subset of an ISO 8601 duration value). The pattern for this is: nDnM]. Corresponds to the JSON property attributeValue

Returns:

  • (String)


2220
2221
2222
# File 'lib/google/apis/ces_v1/classes.rb', line 2220

def attribute_value
  @attribute_value
end

#boost_amountFloat

Optional. The value between -1 to 1 by which to boost the score if the attribute_value evaluates to the value specified above. Corresponds to the JSON property boostAmount

Returns:

  • (Float)


2226
2227
2228
# File 'lib/google/apis/ces_v1/classes.rb', line 2226

def boost_amount
  @boost_amount
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2233
2234
2235
2236
# File 'lib/google/apis/ces_v1/classes.rb', line 2233

def update!(**args)
  @attribute_value = args[:attribute_value] if args.key?(:attribute_value)
  @boost_amount = args[:boost_amount] if args.key?(:boost_amount)
end