Class: Google::Apis::CesV1::DataStoreToolEngineSource

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Configuration for searching within an Engine, potentially targeting specific DataStores.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DataStoreToolEngineSource

Returns a new instance of DataStoreToolEngineSource.



2317
2318
2319
# File 'lib/google/apis/ces_v1/classes.rb', line 2317

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_store_sourcesArray<Google::Apis::CesV1::DataStoreToolDataStoreSource>

Optional. Use to target specific DataStores within the Engine. If empty, the search applies to all DataStores associated with the Engine. Corresponds to the JSON property dataStoreSources



2302
2303
2304
# File 'lib/google/apis/ces_v1/classes.rb', line 2302

def data_store_sources
  @data_store_sources
end

#engineString

Required. Full resource name of the Engine. Format: projects/project/ locations/location/collections/collection/engines/engine` Corresponds to the JSON propertyengine`

Returns:

  • (String)


2308
2309
2310
# File 'lib/google/apis/ces_v1/classes.rb', line 2308

def engine
  @engine
end

#filterString

Optional. A filter applied to the search across the Engine. Not relevant and not used if 'data_store_sources' is provided. See: https://cloud.google.com/ generative-ai-app-builder/docs/filter-search-metadata Corresponds to the JSON property filter

Returns:

  • (String)


2315
2316
2317
# File 'lib/google/apis/ces_v1/classes.rb', line 2315

def filter
  @filter
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2322
2323
2324
2325
2326
# File 'lib/google/apis/ces_v1/classes.rb', line 2322

def update!(**args)
  @data_store_sources = args[:data_store_sources] if args.key?(:data_store_sources)
  @engine = args[:engine] if args.key?(:engine)
  @filter = args[:filter] if args.key?(:filter)
end