Class: Google::Apis::CesV1::DataStoreToolGroundingConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Grounding configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DataStoreToolGroundingConfig

Returns a new instance of DataStoreToolGroundingConfig.



2349
2350
2351
# File 'lib/google/apis/ces_v1/classes.rb', line 2349

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disabledBoolean Also known as: disabled?

Optional. Whether grounding is disabled. Corresponds to the JSON property disabled

Returns:

  • (Boolean)


2336
2337
2338
# File 'lib/google/apis/ces_v1/classes.rb', line 2336

def disabled
  @disabled
end

#grounding_levelFloat

Optional. The groundedness threshold of the answer based on the retrieved sources. The value has a configurable range of [1, 5]. The level is used to threshold the groundedness of the answer, meaning that all responses with a groundedness score below the threshold will fall back to returning relevant snippets only. For example, a level of 3 means that the groundedness score must be 3 or higher for the response to be returned. Corresponds to the JSON property groundingLevel

Returns:

  • (Float)


2347
2348
2349
# File 'lib/google/apis/ces_v1/classes.rb', line 2347

def grounding_level
  @grounding_level
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2354
2355
2356
2357
# File 'lib/google/apis/ces_v1/classes.rb', line 2354

def update!(**args)
  @disabled = args[:disabled] if args.key?(:disabled)
  @grounding_level = args[:grounding_level] if args.key?(:grounding_level)
end