Class: Google::Apis::CesV1::Deployment
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::Deployment
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
A deployment represents an immutable, queryable version of the app. It is used to deploy an app version with a specific channel profile.
Instance Attribute Summary collapse
-
#app_version ⇒ String
Optional.
-
#channel_profile ⇒ Google::Apis::CesV1::ChannelProfile
A ChannelProfile configures the agent's behavior for a specific communication channel, such as web UI or telephony.
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#etag ⇒ String
Output only.
-
#experiment_config ⇒ Google::Apis::CesV1::ExperimentConfig
Experiment for the deployment.
-
#instagram_credentials ⇒ Google::Apis::CesV1::InstagramCredentials
Ephemeral Meta credentials for Instagram native integration.
-
#modality ⇒ String
Optional.
-
#model_settings ⇒ Google::Apis::CesV1::ModelSettings
Model settings contains various configurations for the LLM model.
-
#name ⇒ String
Identifier.
-
#update_time ⇒ String
Output only.
-
#whatsapp_credentials ⇒ Google::Apis::CesV1::WhatsAppCredentials
Ephemeral Meta credentials for WhatsApp native integration.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Deployment
constructor
A new instance of Deployment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Deployment
Returns a new instance of Deployment.
2839 2840 2841 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2839 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_version ⇒ String
Optional. The resource name of the app version to deploy. Format: projects/
project/locations/location/apps/app/versions/version`Useprojects/
project/locations/location/apps/app/versions/-to use the draft app.
Corresponds to the JSON propertyappVersion`
2776 2777 2778 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2776 def app_version @app_version end |
#channel_profile ⇒ Google::Apis::CesV1::ChannelProfile
A ChannelProfile configures the agent's behavior for a specific communication
channel, such as web UI or telephony.
Corresponds to the JSON property channelProfile
2782 2783 2784 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2782 def channel_profile @channel_profile end |
#create_time ⇒ String
Output only. Timestamp when this deployment was created.
Corresponds to the JSON property createTime
2787 2788 2789 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2787 def create_time @create_time end |
#display_name ⇒ String
Required. Display name of the deployment.
Corresponds to the JSON property displayName
2792 2793 2794 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2792 def display_name @display_name end |
#etag ⇒ String
Output only. Etag used to ensure the object hasn't changed during a read-
modify-write operation. If the etag is empty, the update will overwrite any
concurrent changes.
Corresponds to the JSON property etag
2799 2800 2801 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2799 def etag @etag end |
#experiment_config ⇒ Google::Apis::CesV1::ExperimentConfig
Experiment for the deployment.
Corresponds to the JSON property experimentConfig
2804 2805 2806 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2804 def experiment_config @experiment_config end |
#instagram_credentials ⇒ Google::Apis::CesV1::InstagramCredentials
Ephemeral Meta credentials for Instagram native integration.
Corresponds to the JSON property instagramCredentials
2809 2810 2811 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2809 def instagram_credentials @instagram_credentials end |
#modality ⇒ String
Optional. The modality of the deployment. Note: Deployment-level modality
override is gated behind an allowlist. Contact the CXAS team to enable this
field.
Corresponds to the JSON property modality
2816 2817 2818 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2816 def modality @modality end |
#model_settings ⇒ Google::Apis::CesV1::ModelSettings
Model settings contains various configurations for the LLM model.
Corresponds to the JSON property modelSettings
2821 2822 2823 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2821 def model_settings @model_settings end |
#name ⇒ String
Identifier. The resource name of the deployment. Format: projects/project/
locations/location/apps/app/deployments/deployment`
Corresponds to the JSON propertyname`
2827 2828 2829 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2827 def name @name end |
#update_time ⇒ String
Output only. Timestamp when this deployment was last updated.
Corresponds to the JSON property updateTime
2832 2833 2834 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2832 def update_time @update_time end |
#whatsapp_credentials ⇒ Google::Apis::CesV1::WhatsAppCredentials
Ephemeral Meta credentials for WhatsApp native integration.
Corresponds to the JSON property whatsappCredentials
2837 2838 2839 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2837 def whatsapp_credentials @whatsapp_credentials end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2844 2845 2846 2847 2848 2849 2850 2851 2852 2853 2854 2855 2856 2857 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2844 def update!(**args) @app_version = args[:app_version] if args.key?(:app_version) @channel_profile = args[:channel_profile] if args.key?(:channel_profile) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @experiment_config = args[:experiment_config] if args.key?(:experiment_config) @instagram_credentials = args[:instagram_credentials] if args.key?(:instagram_credentials) @modality = args[:modality] if args.key?(:modality) @model_settings = args[:model_settings] if args.key?(:model_settings) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) @whatsapp_credentials = args[:whatsapp_credentials] if args.key?(:whatsapp_credentials) end |