Class: Google::Apis::CesV1::Deployment
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::Deployment
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
A deployment represents an immutable, queryable version of the app. It is used to deploy an app version with a specific channel profile.
Instance Attribute Summary collapse
-
#app_version ⇒ String
Optional.
-
#channel_profile ⇒ Google::Apis::CesV1::ChannelProfile
A ChannelProfile configures the agent's behavior for a specific communication channel, such as web UI or telephony.
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#etag ⇒ String
Output only.
-
#experiment_config ⇒ Google::Apis::CesV1::ExperimentConfig
Experiment for the deployment.
-
#instagram_credentials ⇒ Google::Apis::CesV1::InstagramCredentials
Ephemeral Meta credentials for Instagram native integration.
-
#modality ⇒ String
Optional.
-
#model_settings ⇒ Google::Apis::CesV1::ModelSettings
Model settings contains various configurations for the LLM model.
-
#name ⇒ String
Identifier.
-
#update_time ⇒ String
Output only.
-
#whatsapp_credentials ⇒ Google::Apis::CesV1::WhatsAppCredentials
Ephemeral Meta credentials for WhatsApp native integration.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Deployment
constructor
A new instance of Deployment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Deployment
Returns a new instance of Deployment.
2806 2807 2808 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2806 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_version ⇒ String
Optional. The resource name of the app version to deploy. Format: projects/
project/locations/location/apps/app/versions/version`Useprojects/
project/locations/location/apps/app/versions/-to use the draft app.
Corresponds to the JSON propertyappVersion`
2743 2744 2745 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2743 def app_version @app_version end |
#channel_profile ⇒ Google::Apis::CesV1::ChannelProfile
A ChannelProfile configures the agent's behavior for a specific communication
channel, such as web UI or telephony.
Corresponds to the JSON property channelProfile
2749 2750 2751 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2749 def channel_profile @channel_profile end |
#create_time ⇒ String
Output only. Timestamp when this deployment was created.
Corresponds to the JSON property createTime
2754 2755 2756 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2754 def create_time @create_time end |
#display_name ⇒ String
Required. Display name of the deployment.
Corresponds to the JSON property displayName
2759 2760 2761 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2759 def display_name @display_name end |
#etag ⇒ String
Output only. Etag used to ensure the object hasn't changed during a read-
modify-write operation. If the etag is empty, the update will overwrite any
concurrent changes.
Corresponds to the JSON property etag
2766 2767 2768 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2766 def etag @etag end |
#experiment_config ⇒ Google::Apis::CesV1::ExperimentConfig
Experiment for the deployment.
Corresponds to the JSON property experimentConfig
2771 2772 2773 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2771 def experiment_config @experiment_config end |
#instagram_credentials ⇒ Google::Apis::CesV1::InstagramCredentials
Ephemeral Meta credentials for Instagram native integration.
Corresponds to the JSON property instagramCredentials
2776 2777 2778 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2776 def instagram_credentials @instagram_credentials end |
#modality ⇒ String
Optional. The modality of the deployment. Note: Deployment-level modality
override is gated behind an allowlist. Contact the CXAS team to enable this
field.
Corresponds to the JSON property modality
2783 2784 2785 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2783 def modality @modality end |
#model_settings ⇒ Google::Apis::CesV1::ModelSettings
Model settings contains various configurations for the LLM model.
Corresponds to the JSON property modelSettings
2788 2789 2790 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2788 def model_settings @model_settings end |
#name ⇒ String
Identifier. The resource name of the deployment. Format: projects/project/
locations/location/apps/app/deployments/deployment`
Corresponds to the JSON propertyname`
2794 2795 2796 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2794 def name @name end |
#update_time ⇒ String
Output only. Timestamp when this deployment was last updated.
Corresponds to the JSON property updateTime
2799 2800 2801 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2799 def update_time @update_time end |
#whatsapp_credentials ⇒ Google::Apis::CesV1::WhatsAppCredentials
Ephemeral Meta credentials for WhatsApp native integration.
Corresponds to the JSON property whatsappCredentials
2804 2805 2806 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2804 def whatsapp_credentials @whatsapp_credentials end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2811 2812 2813 2814 2815 2816 2817 2818 2819 2820 2821 2822 2823 2824 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2811 def update!(**args) @app_version = args[:app_version] if args.key?(:app_version) @channel_profile = args[:channel_profile] if args.key?(:channel_profile) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @experiment_config = args[:experiment_config] if args.key?(:experiment_config) @instagram_credentials = args[:instagram_credentials] if args.key?(:instagram_credentials) @modality = args[:modality] if args.key?(:modality) @model_settings = args[:model_settings] if args.key?(:model_settings) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) @whatsapp_credentials = args[:whatsapp_credentials] if args.key?(:whatsapp_credentials) end |