Class: Google::Apis::CesV1::Deployment

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

A deployment represents an immutable, queryable version of the app. It is used to deploy an app version with a specific channel profile.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Deployment

Returns a new instance of Deployment.



2794
2795
2796
# File 'lib/google/apis/ces_v1/classes.rb', line 2794

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_versionString

Optional. The resource name of the app version to deploy. Format: projects/ project/locations/location/apps/app/versions/version`Useprojects/ project/locations/location/apps/app/versions/-to use the draft app. Corresponds to the JSON propertyappVersion`

Returns:

  • (String)


2743
2744
2745
# File 'lib/google/apis/ces_v1/classes.rb', line 2743

def app_version
  @app_version
end

#channel_profileGoogle::Apis::CesV1::ChannelProfile

A ChannelProfile configures the agent's behavior for a specific communication channel, such as web UI or telephony. Corresponds to the JSON property channelProfile



2749
2750
2751
# File 'lib/google/apis/ces_v1/classes.rb', line 2749

def channel_profile
  @channel_profile
end

#create_timeString

Output only. Timestamp when this deployment was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2754
2755
2756
# File 'lib/google/apis/ces_v1/classes.rb', line 2754

def create_time
  @create_time
end

#display_nameString

Required. Display name of the deployment. Corresponds to the JSON property displayName

Returns:

  • (String)


2759
2760
2761
# File 'lib/google/apis/ces_v1/classes.rb', line 2759

def display_name
  @display_name
end

#etagString

Output only. Etag used to ensure the object hasn't changed during a read- modify-write operation. If the etag is empty, the update will overwrite any concurrent changes. Corresponds to the JSON property etag

Returns:

  • (String)


2766
2767
2768
# File 'lib/google/apis/ces_v1/classes.rb', line 2766

def etag
  @etag
end

#experiment_configGoogle::Apis::CesV1::ExperimentConfig

Experiment for the deployment. Corresponds to the JSON property experimentConfig



2771
2772
2773
# File 'lib/google/apis/ces_v1/classes.rb', line 2771

def experiment_config
  @experiment_config
end

#instagram_credentialsGoogle::Apis::CesV1::InstagramCredentials

Ephemeral Meta credentials for Instagram native integration. Corresponds to the JSON property instagramCredentials



2776
2777
2778
# File 'lib/google/apis/ces_v1/classes.rb', line 2776

def instagram_credentials
  @instagram_credentials
end

#nameString

Identifier. The resource name of the deployment. Format: projects/project/ locations/location/apps/app/deployments/deployment` Corresponds to the JSON propertyname`

Returns:

  • (String)


2782
2783
2784
# File 'lib/google/apis/ces_v1/classes.rb', line 2782

def name
  @name
end

#update_timeString

Output only. Timestamp when this deployment was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


2787
2788
2789
# File 'lib/google/apis/ces_v1/classes.rb', line 2787

def update_time
  @update_time
end

#whatsapp_credentialsGoogle::Apis::CesV1::WhatsAppCredentials

Ephemeral Meta credentials for WhatsApp native integration. Corresponds to the JSON property whatsappCredentials



2792
2793
2794
# File 'lib/google/apis/ces_v1/classes.rb', line 2792

def whatsapp_credentials
  @whatsapp_credentials
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2799
2800
2801
2802
2803
2804
2805
2806
2807
2808
2809
2810
# File 'lib/google/apis/ces_v1/classes.rb', line 2799

def update!(**args)
  @app_version = args[:app_version] if args.key?(:app_version)
  @channel_profile = args[:channel_profile] if args.key?(:channel_profile)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @experiment_config = args[:experiment_config] if args.key?(:experiment_config)
  @instagram_credentials = args[:instagram_credentials] if args.key?(:instagram_credentials)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
  @whatsapp_credentials = args[:whatsapp_credentials] if args.key?(:whatsapp_credentials)
end