Class: Google::Apis::CesV1::Deployment

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

A deployment represents an immutable, queryable version of the app. It is used to deploy an app version with a specific channel profile.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Deployment

Returns a new instance of Deployment.



2679
2680
2681
# File 'lib/google/apis/ces_v1/classes.rb', line 2679

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_versionString

Optional. The resource name of the app version to deploy. Format: projects/ project/locations/location/apps/app/versions/version`Useprojects/ project/locations/location/apps/app/versions/-to use the draft app. Corresponds to the JSON propertyappVersion`

Returns:

  • (String)


2638
2639
2640
# File 'lib/google/apis/ces_v1/classes.rb', line 2638

def app_version
  @app_version
end

#channel_profileGoogle::Apis::CesV1::ChannelProfile

A ChannelProfile configures the agent's behavior for a specific communication channel, such as web UI or telephony. Corresponds to the JSON property channelProfile



2644
2645
2646
# File 'lib/google/apis/ces_v1/classes.rb', line 2644

def channel_profile
  @channel_profile
end

#create_timeString

Output only. Timestamp when this deployment was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2649
2650
2651
# File 'lib/google/apis/ces_v1/classes.rb', line 2649

def create_time
  @create_time
end

#display_nameString

Required. Display name of the deployment. Corresponds to the JSON property displayName

Returns:

  • (String)


2654
2655
2656
# File 'lib/google/apis/ces_v1/classes.rb', line 2654

def display_name
  @display_name
end

#etagString

Output only. Etag used to ensure the object hasn't changed during a read- modify-write operation. If the etag is empty, the update will overwrite any concurrent changes. Corresponds to the JSON property etag

Returns:

  • (String)


2661
2662
2663
# File 'lib/google/apis/ces_v1/classes.rb', line 2661

def etag
  @etag
end

#experiment_configGoogle::Apis::CesV1::ExperimentConfig

Experiment for the deployment. Corresponds to the JSON property experimentConfig



2666
2667
2668
# File 'lib/google/apis/ces_v1/classes.rb', line 2666

def experiment_config
  @experiment_config
end

#nameString

Identifier. The resource name of the deployment. Format: projects/project/ locations/location/apps/app/deployments/deployment` Corresponds to the JSON propertyname`

Returns:

  • (String)


2672
2673
2674
# File 'lib/google/apis/ces_v1/classes.rb', line 2672

def name
  @name
end

#update_timeString

Output only. Timestamp when this deployment was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


2677
2678
2679
# File 'lib/google/apis/ces_v1/classes.rb', line 2677

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2684
2685
2686
2687
2688
2689
2690
2691
2692
2693
# File 'lib/google/apis/ces_v1/classes.rb', line 2684

def update!(**args)
  @app_version = args[:app_version] if args.key?(:app_version)
  @channel_profile = args[:channel_profile] if args.key?(:channel_profile)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @experiment_config = args[:experiment_config] if args.key?(:experiment_config)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end