Class: Google::Apis::CesV1::Deployment
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::Deployment
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
A deployment represents an immutable, queryable version of the app. It is used to deploy an app version with a specific channel profile.
Instance Attribute Summary collapse
-
#app_version ⇒ String
Optional.
-
#channel_profile ⇒ Google::Apis::CesV1::ChannelProfile
A ChannelProfile configures the agent's behavior for a specific communication channel, such as web UI or telephony.
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#etag ⇒ String
Output only.
-
#experiment_config ⇒ Google::Apis::CesV1::ExperimentConfig
Experiment for the deployment.
-
#name ⇒ String
Identifier.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Deployment
constructor
A new instance of Deployment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Deployment
Returns a new instance of Deployment.
2512 2513 2514 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2512 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_version ⇒ String
Optional. The resource name of the app version to deploy. Format: projects/
project/locations/location/apps/app/versions/version`Useprojects/
project/locations/location/apps/app/versions/-to use the draft app.
Corresponds to the JSON propertyappVersion`
2471 2472 2473 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2471 def app_version @app_version end |
#channel_profile ⇒ Google::Apis::CesV1::ChannelProfile
A ChannelProfile configures the agent's behavior for a specific communication
channel, such as web UI or telephony.
Corresponds to the JSON property channelProfile
2477 2478 2479 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2477 def channel_profile @channel_profile end |
#create_time ⇒ String
Output only. Timestamp when this deployment was created.
Corresponds to the JSON property createTime
2482 2483 2484 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2482 def create_time @create_time end |
#display_name ⇒ String
Required. Display name of the deployment.
Corresponds to the JSON property displayName
2487 2488 2489 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2487 def display_name @display_name end |
#etag ⇒ String
Output only. Etag used to ensure the object hasn't changed during a read-
modify-write operation. If the etag is empty, the update will overwrite any
concurrent changes.
Corresponds to the JSON property etag
2494 2495 2496 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2494 def etag @etag end |
#experiment_config ⇒ Google::Apis::CesV1::ExperimentConfig
Experiment for the deployment.
Corresponds to the JSON property experimentConfig
2499 2500 2501 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2499 def experiment_config @experiment_config end |
#name ⇒ String
Identifier. The resource name of the deployment. Format: projects/project/
locations/location/apps/app/deployments/deployment`
Corresponds to the JSON propertyname`
2505 2506 2507 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2505 def name @name end |
#update_time ⇒ String
Output only. Timestamp when this deployment was last updated.
Corresponds to the JSON property updateTime
2510 2511 2512 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2510 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2517 def update!(**args) @app_version = args[:app_version] if args.key?(:app_version) @channel_profile = args[:channel_profile] if args.key?(:channel_profile) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @experiment_config = args[:experiment_config] if args.key?(:experiment_config) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) end |