Class: Google::Apis::CesV1::EndSession

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Indicates the session has terminated, due to either successful completion (e.g. user says "Good bye!" ) or an agent escalation. The agent will not process any further inputs after session is terminated and the client should half- close and disconnect after receiving all remaining responses from the agent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EndSession

Returns a new instance of EndSession.



2558
2559
2560
# File 'lib/google/apis/ces_v1/classes.rb', line 2558

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#metadataHash<String,Object>

Optional. Provides additional information about the end session signal, such as the reason for ending the session. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,Object>)


2556
2557
2558
# File 'lib/google/apis/ces_v1/classes.rb', line 2556

def 
  @metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2563
2564
2565
# File 'lib/google/apis/ces_v1/classes.rb', line 2563

def update!(**args)
  @metadata = args[:metadata] if args.key?(:metadata)
end