Class: Google::Apis::CesV1::EndpointControlPolicy
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::EndpointControlPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Defines project/location level endpoint control policy.
Instance Attribute Summary collapse
-
#allowed_origins ⇒ Array<String>
Optional.
-
#enforcement_scope ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EndpointControlPolicy
constructor
A new instance of EndpointControlPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EndpointControlPolicy
Returns a new instance of EndpointControlPolicy.
2668 2669 2670 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2668 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed_origins ⇒ Array<String>
Optional. The allowed HTTP(s) origins that tools in the App are able to
directly call. The enforcement depends on the value of enforcement_scope and
the VPC-SC status of the project. If a port number is not provided, all ports
will be allowed. Otherwise, the port number must match exactly. For example, "
https://example.com" will match "https://example.com:443" and any other port. "
https://example.com:443" will only match "https://example.com:443".
Corresponds to the JSON property allowedOrigins
2661 2662 2663 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2661 def allowed_origins @allowed_origins end |
#enforcement_scope ⇒ String
Optional. The scope in which this policy's allowed_origins list is enforced.
Corresponds to the JSON property enforcementScope
2666 2667 2668 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2666 def enforcement_scope @enforcement_scope end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2673 2674 2675 2676 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2673 def update!(**args) @allowed_origins = args[:allowed_origins] if args.key?(:allowed_origins) @enforcement_scope = args[:enforcement_scope] if args.key?(:enforcement_scope) end |