Class: Google::Apis::CesV1::ErrorHandlingSettings
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::ErrorHandlingSettings
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Settings to describe how errors should be handled in the app.
Instance Attribute Summary collapse
-
#end_session_config ⇒ Google::Apis::CesV1::ErrorHandlingSettingsEndSessionConfig
Configuration for ending the session in case of system errors (e.g. LLM errors) .
-
#error_handling_strategy ⇒ String
Optional.
-
#fallback_response_config ⇒ Google::Apis::CesV1::ErrorHandlingSettingsFallbackResponseConfig
Configuration for handling fallback responses.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ErrorHandlingSettings
constructor
A new instance of ErrorHandlingSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ErrorHandlingSettings
Returns a new instance of ErrorHandlingSettings.
2699 2700 2701 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2699 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_session_config ⇒ Google::Apis::CesV1::ErrorHandlingSettingsEndSessionConfig
Configuration for ending the session in case of system errors (e.g. LLM errors)
.
Corresponds to the JSON property endSessionConfig
2687 2688 2689 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2687 def end_session_config @end_session_config end |
#error_handling_strategy ⇒ String
Optional. The strategy to use for error handling.
Corresponds to the JSON property errorHandlingStrategy
2692 2693 2694 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2692 def error_handling_strategy @error_handling_strategy end |
#fallback_response_config ⇒ Google::Apis::CesV1::ErrorHandlingSettingsFallbackResponseConfig
Configuration for handling fallback responses.
Corresponds to the JSON property fallbackResponseConfig
2697 2698 2699 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2697 def fallback_response_config @fallback_response_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2704 2705 2706 2707 2708 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2704 def update!(**args) @end_session_config = args[:end_session_config] if args.key?(:end_session_config) @error_handling_strategy = args[:error_handling_strategy] if args.key?(:error_handling_strategy) @fallback_response_config = args[:fallback_response_config] if args.key?(:fallback_response_config) end |