Class: Google::Apis::CesV1::ErrorHandlingSettingsFallbackResponseConfig
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::ErrorHandlingSettingsFallbackResponseConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Configuration for handling fallback responses.
Instance Attribute Summary collapse
-
#custom_fallback_messages ⇒ Hash<String,String>
Optional.
-
#max_fallback_attempts ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ErrorHandlingSettingsFallbackResponseConfig
constructor
A new instance of ErrorHandlingSettingsFallbackResponseConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ErrorHandlingSettingsFallbackResponseConfig
Returns a new instance of ErrorHandlingSettingsFallbackResponseConfig.
2752 2753 2754 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2752 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_fallback_messages ⇒ Hash<String,String>
Optional. The fallback messages in case of system errors (e.g. LLM errors),
mapped by supported language code.
Corresponds to the JSON property customFallbackMessages
2744 2745 2746 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2744 def @custom_fallback_messages end |
#max_fallback_attempts ⇒ Fixnum
Optional. The maximum number of fallback attempts to make before the agent
emitting EndSession Signal.
Corresponds to the JSON property maxFallbackAttempts
2750 2751 2752 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2750 def max_fallback_attempts @max_fallback_attempts end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2757 2758 2759 2760 |
# File 'lib/google/apis/ces_v1/classes.rb', line 2757 def update!(**args) @custom_fallback_messages = args[:custom_fallback_messages] if args.key?(:custom_fallback_messages) @max_fallback_attempts = args[:max_fallback_attempts] if args.key?(:max_fallback_attempts) end |