Class: Google::Apis::CesV1::Example
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::Example
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
An example represents a sample conversation between the user and the agent(s).
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Required.
-
#entry_agent ⇒ String
Optional.
-
#etag ⇒ String
Etag used to ensure the object hasn't changed during a read-modify-write operation.
-
#invalid ⇒ Boolean
(also: #invalid?)
Output only.
-
#messages ⇒ Array<Google::Apis::CesV1::Message>
Optional.
-
#name ⇒ String
Identifier.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Example
constructor
A new instance of Example.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Example
Returns a new instance of Example.
3326 3327 3328 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3326 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when the example was created.
Corresponds to the JSON property createTime
3277 3278 3279 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3277 def create_time @create_time end |
#description ⇒ String
Optional. Human-readable description of the example.
Corresponds to the JSON property description
3282 3283 3284 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3282 def description @description end |
#display_name ⇒ String
Required. Display name of the example.
Corresponds to the JSON property displayName
3287 3288 3289 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3287 def display_name @display_name end |
#entry_agent ⇒ String
Optional. The agent that initially handles the conversation. If not specified,
the example represents a conversation that is handled by the root agent.
Format: projects/project/locations/location/apps/app/agents/agent`
Corresponds to the JSON propertyentryAgent`
3294 3295 3296 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3294 def entry_agent @entry_agent end |
#etag ⇒ String
Etag used to ensure the object hasn't changed during a read-modify-write
operation. If the etag is empty, the update will overwrite any concurrent
changes.
Corresponds to the JSON property etag
3301 3302 3303 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3301 def etag @etag end |
#invalid ⇒ Boolean Also known as: invalid?
Output only. The example may become invalid if referencing resources are
deleted. Invalid examples will not be used as few-shot examples.
Corresponds to the JSON property invalid
3307 3308 3309 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3307 def invalid @invalid end |
#messages ⇒ Array<Google::Apis::CesV1::Message>
Optional. The collection of messages that make up the conversation.
Corresponds to the JSON property messages
3313 3314 3315 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3313 def @messages end |
#name ⇒ String
Identifier. The unique identifier of the example. Format: projects/project/
locations/location/apps/app/examples/example`
Corresponds to the JSON propertyname`
3319 3320 3321 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3319 def name @name end |
#update_time ⇒ String
Output only. Timestamp when the example was last updated.
Corresponds to the JSON property updateTime
3324 3325 3326 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3324 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3331 3332 3333 3334 3335 3336 3337 3338 3339 3340 3341 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3331 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @entry_agent = args[:entry_agent] if args.key?(:entry_agent) @etag = args[:etag] if args.key?(:etag) @invalid = args[:invalid] if args.key?(:invalid) @messages = args[:messages] if args.key?(:messages) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) end |