Class: Google::Apis::CesV1::Example

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

An example represents a sample conversation between the user and the agent(s).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Example

Returns a new instance of Example.



3263
3264
3265
# File 'lib/google/apis/ces_v1/classes.rb', line 3263

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when the example was created. Corresponds to the JSON property createTime

Returns:

  • (String)


3214
3215
3216
# File 'lib/google/apis/ces_v1/classes.rb', line 3214

def create_time
  @create_time
end

#descriptionString

Optional. Human-readable description of the example. Corresponds to the JSON property description

Returns:

  • (String)


3219
3220
3221
# File 'lib/google/apis/ces_v1/classes.rb', line 3219

def description
  @description
end

#display_nameString

Required. Display name of the example. Corresponds to the JSON property displayName

Returns:

  • (String)


3224
3225
3226
# File 'lib/google/apis/ces_v1/classes.rb', line 3224

def display_name
  @display_name
end

#entry_agentString

Optional. The agent that initially handles the conversation. If not specified, the example represents a conversation that is handled by the root agent. Format: projects/project/locations/location/apps/app/agents/agent` Corresponds to the JSON propertyentryAgent`

Returns:

  • (String)


3231
3232
3233
# File 'lib/google/apis/ces_v1/classes.rb', line 3231

def entry_agent
  @entry_agent
end

#etagString

Etag used to ensure the object hasn't changed during a read-modify-write operation. If the etag is empty, the update will overwrite any concurrent changes. Corresponds to the JSON property etag

Returns:

  • (String)


3238
3239
3240
# File 'lib/google/apis/ces_v1/classes.rb', line 3238

def etag
  @etag
end

#invalidBoolean Also known as: invalid?

Output only. The example may become invalid if referencing resources are deleted. Invalid examples will not be used as few-shot examples. Corresponds to the JSON property invalid

Returns:

  • (Boolean)


3244
3245
3246
# File 'lib/google/apis/ces_v1/classes.rb', line 3244

def invalid
  @invalid
end

#messagesArray<Google::Apis::CesV1::Message>

Optional. The collection of messages that make up the conversation. Corresponds to the JSON property messages

Returns:



3250
3251
3252
# File 'lib/google/apis/ces_v1/classes.rb', line 3250

def messages
  @messages
end

#nameString

Identifier. The unique identifier of the example. Format: projects/project/ locations/location/apps/app/examples/example` Corresponds to the JSON propertyname`

Returns:

  • (String)


3256
3257
3258
# File 'lib/google/apis/ces_v1/classes.rb', line 3256

def name
  @name
end

#update_timeString

Output only. Timestamp when the example was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


3261
3262
3263
# File 'lib/google/apis/ces_v1/classes.rb', line 3261

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3268
3269
3270
3271
3272
3273
3274
3275
3276
3277
3278
# File 'lib/google/apis/ces_v1/classes.rb', line 3268

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @entry_agent = args[:entry_agent] if args.key?(:entry_agent)
  @etag = args[:etag] if args.key?(:etag)
  @invalid = args[:invalid] if args.key?(:invalid)
  @messages = args[:messages] if args.key?(:messages)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end