Class: Google::Apis::CesV1::Example
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::Example
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
An example represents a sample conversation between the user and the agent(s).
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Required.
-
#entry_agent ⇒ String
Optional.
-
#etag ⇒ String
Etag used to ensure the object hasn't changed during a read-modify-write operation.
-
#invalid ⇒ Boolean
(also: #invalid?)
Output only.
-
#messages ⇒ Array<Google::Apis::CesV1::Message>
Optional.
-
#name ⇒ String
Identifier.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Example
constructor
A new instance of Example.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Example
Returns a new instance of Example.
3146 3147 3148 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3146 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Timestamp when the example was created.
Corresponds to the JSON property createTime
3097 3098 3099 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3097 def create_time @create_time end |
#description ⇒ String
Optional. Human-readable description of the example.
Corresponds to the JSON property description
3102 3103 3104 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3102 def description @description end |
#display_name ⇒ String
Required. Display name of the example.
Corresponds to the JSON property displayName
3107 3108 3109 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3107 def display_name @display_name end |
#entry_agent ⇒ String
Optional. The agent that initially handles the conversation. If not specified,
the example represents a conversation that is handled by the root agent.
Format: projects/project/locations/location/apps/app/agents/agent`
Corresponds to the JSON propertyentryAgent`
3114 3115 3116 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3114 def entry_agent @entry_agent end |
#etag ⇒ String
Etag used to ensure the object hasn't changed during a read-modify-write
operation. If the etag is empty, the update will overwrite any concurrent
changes.
Corresponds to the JSON property etag
3121 3122 3123 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3121 def etag @etag end |
#invalid ⇒ Boolean Also known as: invalid?
Output only. The example may become invalid if referencing resources are
deleted. Invalid examples will not be used as few-shot examples.
Corresponds to the JSON property invalid
3127 3128 3129 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3127 def invalid @invalid end |
#messages ⇒ Array<Google::Apis::CesV1::Message>
Optional. The collection of messages that make up the conversation.
Corresponds to the JSON property messages
3133 3134 3135 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3133 def @messages end |
#name ⇒ String
Identifier. The unique identifier of the example. Format: projects/project/
locations/location/apps/app/examples/example`
Corresponds to the JSON propertyname`
3139 3140 3141 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3139 def name @name end |
#update_time ⇒ String
Output only. Timestamp when the example was last updated.
Corresponds to the JSON property updateTime
3144 3145 3146 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3144 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3151 3152 3153 3154 3155 3156 3157 3158 3159 3160 3161 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3151 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @entry_agent = args[:entry_agent] if args.key?(:entry_agent) @etag = args[:etag] if args.key?(:etag) @invalid = args[:invalid] if args.key?(:invalid) @messages = args[:messages] if args.key?(:messages) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) end |