Class: Google::Apis::CesV1::Example

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

An example represents a sample conversation between the user and the agent(s).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Example

Returns a new instance of Example.



2979
2980
2981
# File 'lib/google/apis/ces_v1/classes.rb', line 2979

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Timestamp when the example was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2930
2931
2932
# File 'lib/google/apis/ces_v1/classes.rb', line 2930

def create_time
  @create_time
end

#descriptionString

Optional. Human-readable description of the example. Corresponds to the JSON property description

Returns:

  • (String)


2935
2936
2937
# File 'lib/google/apis/ces_v1/classes.rb', line 2935

def description
  @description
end

#display_nameString

Required. Display name of the example. Corresponds to the JSON property displayName

Returns:

  • (String)


2940
2941
2942
# File 'lib/google/apis/ces_v1/classes.rb', line 2940

def display_name
  @display_name
end

#entry_agentString

Optional. The agent that initially handles the conversation. If not specified, the example represents a conversation that is handled by the root agent. Format: projects/project/locations/location/apps/app/agents/agent` Corresponds to the JSON propertyentryAgent`

Returns:

  • (String)


2947
2948
2949
# File 'lib/google/apis/ces_v1/classes.rb', line 2947

def entry_agent
  @entry_agent
end

#etagString

Etag used to ensure the object hasn't changed during a read-modify-write operation. If the etag is empty, the update will overwrite any concurrent changes. Corresponds to the JSON property etag

Returns:

  • (String)


2954
2955
2956
# File 'lib/google/apis/ces_v1/classes.rb', line 2954

def etag
  @etag
end

#invalidBoolean Also known as: invalid?

Output only. The example may become invalid if referencing resources are deleted. Invalid examples will not be used as few-shot examples. Corresponds to the JSON property invalid

Returns:

  • (Boolean)


2960
2961
2962
# File 'lib/google/apis/ces_v1/classes.rb', line 2960

def invalid
  @invalid
end

#messagesArray<Google::Apis::CesV1::Message>

Optional. The collection of messages that make up the conversation. Corresponds to the JSON property messages

Returns:



2966
2967
2968
# File 'lib/google/apis/ces_v1/classes.rb', line 2966

def messages
  @messages
end

#nameString

Identifier. The unique identifier of the example. Format: projects/project/ locations/location/apps/app/examples/example` Corresponds to the JSON propertyname`

Returns:

  • (String)


2972
2973
2974
# File 'lib/google/apis/ces_v1/classes.rb', line 2972

def name
  @name
end

#update_timeString

Output only. Timestamp when the example was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


2977
2978
2979
# File 'lib/google/apis/ces_v1/classes.rb', line 2977

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2984
2985
2986
2987
2988
2989
2990
2991
2992
2993
2994
# File 'lib/google/apis/ces_v1/classes.rb', line 2984

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @entry_agent = args[:entry_agent] if args.key?(:entry_agent)
  @etag = args[:etag] if args.key?(:etag)
  @invalid = args[:invalid] if args.key?(:invalid)
  @messages = args[:messages] if args.key?(:messages)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end