Class: Google::Apis::CesV1::ExecuteToolRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Request message for ToolService.ExecuteTool.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExecuteToolRequest

Returns a new instance of ExecuteToolRequest.



3201
3202
3203
# File 'lib/google/apis/ces_v1/classes.rb', line 3201

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#argsHash<String,Object>

Optional. The input parameters and values for the tool in JSON object format. Corresponds to the JSON property args

Returns:

  • (Hash<String,Object>)


3171
3172
3173
# File 'lib/google/apis/ces_v1/classes.rb', line 3171

def args
  @args
end

#contextHash<String,Object>

Optional. The ToolCallContext to be passed to the Python tool. Corresponds to the JSON property context

Returns:

  • (Hash<String,Object>)


3178
3179
3180
# File 'lib/google/apis/ces_v1/classes.rb', line 3178

def context
  @context
end

#mock_configGoogle::Apis::CesV1::MockConfig

Mock tool calls configuration for the session. Corresponds to the JSON property mockConfig



3183
3184
3185
# File 'lib/google/apis/ces_v1/classes.rb', line 3183

def mock_config
  @mock_config
end

#toolString

Optional. The name of the tool to execute. Format: projects/project/ locations/location/apps/app/tools/tool Corresponds to the JSON property tool

Returns:

  • (String)


3189
3190
3191
# File 'lib/google/apis/ces_v1/classes.rb', line 3189

def tool
  @tool
end

#toolset_toolGoogle::Apis::CesV1::ToolsetTool

A tool that is created from a toolset. Corresponds to the JSON property toolsetTool



3194
3195
3196
# File 'lib/google/apis/ces_v1/classes.rb', line 3194

def toolset_tool
  @toolset_tool
end

#variablesHash<String,Object>

Optional. The variables that are available for the tool execution. Corresponds to the JSON property variables

Returns:

  • (Hash<String,Object>)


3199
3200
3201
# File 'lib/google/apis/ces_v1/classes.rb', line 3199

def variables
  @variables
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3206
3207
3208
3209
3210
3211
3212
3213
# File 'lib/google/apis/ces_v1/classes.rb', line 3206

def update!(**args)
  @args = args[:args] if args.key?(:args)
  @context = args[:context] if args.key?(:context)
  @mock_config = args[:mock_config] if args.key?(:mock_config)
  @tool = args[:tool] if args.key?(:tool)
  @toolset_tool = args[:toolset_tool] if args.key?(:toolset_tool)
  @variables = args[:variables] if args.key?(:variables)
end