Class: Google::Apis::CesV1::ExecuteToolRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Request message for ToolService.ExecuteTool.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExecuteToolRequest

Returns a new instance of ExecuteToolRequest.



3034
3035
3036
# File 'lib/google/apis/ces_v1/classes.rb', line 3034

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#argsHash<String,Object>

Optional. The input parameters and values for the tool in JSON object format. Corresponds to the JSON property args

Returns:

  • (Hash<String,Object>)


3004
3005
3006
# File 'lib/google/apis/ces_v1/classes.rb', line 3004

def args
  @args
end

#contextHash<String,Object>

Optional. The ToolCallContext to be passed to the Python tool. Corresponds to the JSON property context

Returns:

  • (Hash<String,Object>)


3011
3012
3013
# File 'lib/google/apis/ces_v1/classes.rb', line 3011

def context
  @context
end

#mock_configGoogle::Apis::CesV1::MockConfig

Mock tool calls configuration for the session. Corresponds to the JSON property mockConfig



3016
3017
3018
# File 'lib/google/apis/ces_v1/classes.rb', line 3016

def mock_config
  @mock_config
end

#toolString

Optional. The name of the tool to execute. Format: projects/project/ locations/location/apps/app/tools/tool Corresponds to the JSON property tool

Returns:

  • (String)


3022
3023
3024
# File 'lib/google/apis/ces_v1/classes.rb', line 3022

def tool
  @tool
end

#toolset_toolGoogle::Apis::CesV1::ToolsetTool

A tool that is created from a toolset. Corresponds to the JSON property toolsetTool



3027
3028
3029
# File 'lib/google/apis/ces_v1/classes.rb', line 3027

def toolset_tool
  @toolset_tool
end

#variablesHash<String,Object>

Optional. The variables that are available for the tool execution. Corresponds to the JSON property variables

Returns:

  • (Hash<String,Object>)


3032
3033
3034
# File 'lib/google/apis/ces_v1/classes.rb', line 3032

def variables
  @variables
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3039
3040
3041
3042
3043
3044
3045
3046
# File 'lib/google/apis/ces_v1/classes.rb', line 3039

def update!(**args)
  @args = args[:args] if args.key?(:args)
  @context = args[:context] if args.key?(:context)
  @mock_config = args[:mock_config] if args.key?(:mock_config)
  @tool = args[:tool] if args.key?(:tool)
  @toolset_tool = args[:toolset_tool] if args.key?(:toolset_tool)
  @variables = args[:variables] if args.key?(:variables)
end