Class: Google::Apis::CesV1::ExecuteToolResponse
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::ExecuteToolResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Response message for ToolService.ExecuteTool.
Instance Attribute Summary collapse
-
#response ⇒ Hash<String,Object>
The tool execution result in JSON object format.
-
#tool ⇒ String
The name of the tool that got executed.
-
#toolset_tool ⇒ Google::Apis::CesV1::ToolsetTool
A tool that is created from a toolset.
-
#variables ⇒ Hash<String,Object>
The variable values at the end of the tool execution.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExecuteToolResponse
constructor
A new instance of ExecuteToolResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExecuteToolResponse
Returns a new instance of ExecuteToolResponse.
3252 3253 3254 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3252 def initialize(**args) update!(**args) end |
Instance Attribute Details
#response ⇒ Hash<String,Object>
The tool execution result in JSON object format. Use "output" key to specify
tool response and "error" key to specify error details (if any). If "output"
and "error" keys are not specified, then whole "response" is treated as tool
execution result.
Corresponds to the JSON property response
3234 3235 3236 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3234 def response @response end |
#tool ⇒ String
The name of the tool that got executed. Format: projects/project/locations/
location/apps/app/tools/tool`
Corresponds to the JSON propertytool`
3240 3241 3242 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3240 def tool @tool end |
#toolset_tool ⇒ Google::Apis::CesV1::ToolsetTool
A tool that is created from a toolset.
Corresponds to the JSON property toolsetTool
3245 3246 3247 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3245 def toolset_tool @toolset_tool end |
#variables ⇒ Hash<String,Object>
The variable values at the end of the tool execution.
Corresponds to the JSON property variables
3250 3251 3252 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3250 def variables @variables end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3257 3258 3259 3260 3261 3262 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3257 def update!(**args) @response = args[:response] if args.key?(:response) @tool = args[:tool] if args.key?(:tool) @toolset_tool = args[:toolset_tool] if args.key?(:toolset_tool) @variables = args[:variables] if args.key?(:variables) end |