Class: Google::Apis::CesV1::ExecuteToolResponse
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::ExecuteToolResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Response message for ToolService.ExecuteTool.
Instance Attribute Summary collapse
-
#response ⇒ Hash<String,Object>
The tool execution result in JSON object format.
-
#tool ⇒ String
The name of the tool that got executed.
-
#toolset_tool ⇒ Google::Apis::CesV1::ToolsetTool
A tool that is created from a toolset.
-
#variables ⇒ Hash<String,Object>
The variable values at the end of the tool execution.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExecuteToolResponse
constructor
A new instance of ExecuteToolResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExecuteToolResponse
Returns a new instance of ExecuteToolResponse.
3077 3078 3079 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3077 def initialize(**args) update!(**args) end |
Instance Attribute Details
#response ⇒ Hash<String,Object>
The tool execution result in JSON object format. Use "output" key to specify
tool response and "error" key to specify error details (if any). If "output"
and "error" keys are not specified, then whole "response" is treated as tool
execution result.
Corresponds to the JSON property response
3059 3060 3061 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3059 def response @response end |
#tool ⇒ String
The name of the tool that got executed. Format: projects/project/locations/
location/apps/app/tools/tool`
Corresponds to the JSON propertytool`
3065 3066 3067 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3065 def tool @tool end |
#toolset_tool ⇒ Google::Apis::CesV1::ToolsetTool
A tool that is created from a toolset.
Corresponds to the JSON property toolsetTool
3070 3071 3072 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3070 def toolset_tool @toolset_tool end |
#variables ⇒ Hash<String,Object>
The variable values at the end of the tool execution.
Corresponds to the JSON property variables
3075 3076 3077 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3075 def variables @variables end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3082 3083 3084 3085 3086 3087 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3082 def update!(**args) @response = args[:response] if args.key?(:response) @tool = args[:tool] if args.key?(:tool) @toolset_tool = args[:toolset_tool] if args.key?(:toolset_tool) @variables = args[:variables] if args.key?(:variables) end |