Class: Google::Apis::CesV1::ExportAppRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Request message for AgentService.ExportApp.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExportAppRequest

Returns a new instance of ExportAppRequest.



3365
3366
3367
# File 'lib/google/apis/ces_v1/classes.rb', line 3365

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_versionString

Optional. The resource name of the app version to export. Format: projects/ project/locations/location/apps/app/versions/version`. Corresponds to the JSON propertyappVersion`

Returns:

  • (String)


3351
3352
3353
# File 'lib/google/apis/ces_v1/classes.rb', line 3351

def app_version
  @app_version
end

#export_formatString

Required. The format to export the app in. Corresponds to the JSON property exportFormat

Returns:

  • (String)


3356
3357
3358
# File 'lib/google/apis/ces_v1/classes.rb', line 3356

def export_format
  @export_format
end

#gcs_uriString

Optional. The Google Cloud Storage URI to which to export the app. The format of this URI must be gs:///. The exported app archive will be written directly to the specified GCS object. Corresponds to the JSON property gcsUri

Returns:

  • (String)


3363
3364
3365
# File 'lib/google/apis/ces_v1/classes.rb', line 3363

def gcs_uri
  @gcs_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3370
3371
3372
3373
3374
# File 'lib/google/apis/ces_v1/classes.rb', line 3370

def update!(**args)
  @app_version = args[:app_version] if args.key?(:app_version)
  @export_format = args[:export_format] if args.key?(:export_format)
  @gcs_uri = args[:gcs_uri] if args.key?(:gcs_uri)
end