Class: Google::Apis::CesV1::ExportAppRequest
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::ExportAppRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Request message for AgentService.ExportApp.
Instance Attribute Summary collapse
-
#app_version ⇒ String
Optional.
-
#export_format ⇒ String
Required.
-
#gcs_uri ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExportAppRequest
constructor
A new instance of ExportAppRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExportAppRequest
Returns a new instance of ExportAppRequest.
3357 3358 3359 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3357 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_version ⇒ String
Optional. The resource name of the app version to export. Format: projects/
project/locations/location/apps/app/versions/version`.
Corresponds to the JSON propertyappVersion`
3343 3344 3345 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3343 def app_version @app_version end |
#export_format ⇒ String
Required. The format to export the app in.
Corresponds to the JSON property exportFormat
3348 3349 3350 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3348 def export_format @export_format end |
#gcs_uri ⇒ String
Optional. The Google Cloud Storage
URI to which to export the app. The format of this URI must be gs:///. The
exported app archive will be written directly to the specified GCS object.
Corresponds to the JSON property gcsUri
3355 3356 3357 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3355 def gcs_uri @gcs_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3362 3363 3364 3365 3366 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3362 def update!(**args) @app_version = args[:app_version] if args.key?(:app_version) @export_format = args[:export_format] if args.key?(:export_format) @gcs_uri = args[:gcs_uri] if args.key?(:gcs_uri) end |