Class: Google::Apis::CesV1::FileSearchTool

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

The file search tool allows the agent to search across the files uploaded by the app/agent developer. It has presets to give relatively good quality search over the uploaded files and summarization of the retrieved results.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FileSearchTool

Returns a new instance of FileSearchTool.



3618
3619
3620
# File 'lib/google/apis/ces_v1/classes.rb', line 3618

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#corpus_typeString

Optional. The type of the corpus. Default is FULLY_MANAGED. Corresponds to the JSON property corpusType

Returns:

  • (String)


3600
3601
3602
# File 'lib/google/apis/ces_v1/classes.rb', line 3600

def corpus_type
  @corpus_type
end

#descriptionString

Optional. The tool description. Corresponds to the JSON property description

Returns:

  • (String)


3605
3606
3607
# File 'lib/google/apis/ces_v1/classes.rb', line 3605

def description
  @description
end

#file_corpusString

Optional. The corpus where files are stored. Format: projects/project/ locations/location/ragCorpora/rag_corpus Corresponds to the JSON property fileCorpus

Returns:

  • (String)


3611
3612
3613
# File 'lib/google/apis/ces_v1/classes.rb', line 3611

def file_corpus
  @file_corpus
end

#nameString

Required. The tool name. Corresponds to the JSON property name

Returns:

  • (String)


3616
3617
3618
# File 'lib/google/apis/ces_v1/classes.rb', line 3616

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3623
3624
3625
3626
3627
3628
# File 'lib/google/apis/ces_v1/classes.rb', line 3623

def update!(**args)
  @corpus_type = args[:corpus_type] if args.key?(:corpus_type)
  @description = args[:description] if args.key?(:description)
  @file_corpus = args[:file_corpus] if args.key?(:file_corpus)
  @name = args[:name] if args.key?(:name)
end