Class: Google::Apis::CesV1::FileSearchTool

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

The file search tool allows the agent to search across the files uploaded by the app/agent developer. It has presets to give relatively good quality search over the uploaded files and summarization of the retrieved results.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FileSearchTool

Returns a new instance of FileSearchTool.



3571
3572
3573
# File 'lib/google/apis/ces_v1/classes.rb', line 3571

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#corpus_typeString

Optional. The type of the corpus. Default is FULLY_MANAGED. Corresponds to the JSON property corpusType

Returns:

  • (String)


3553
3554
3555
# File 'lib/google/apis/ces_v1/classes.rb', line 3553

def corpus_type
  @corpus_type
end

#descriptionString

Optional. The tool description. Corresponds to the JSON property description

Returns:

  • (String)


3558
3559
3560
# File 'lib/google/apis/ces_v1/classes.rb', line 3558

def description
  @description
end

#file_corpusString

Optional. The corpus where files are stored. Format: projects/project/ locations/location/ragCorpora/rag_corpus Corresponds to the JSON property fileCorpus

Returns:

  • (String)


3564
3565
3566
# File 'lib/google/apis/ces_v1/classes.rb', line 3564

def file_corpus
  @file_corpus
end

#nameString

Required. The tool name. Corresponds to the JSON property name

Returns:

  • (String)


3569
3570
3571
# File 'lib/google/apis/ces_v1/classes.rb', line 3569

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3576
3577
3578
3579
3580
3581
# File 'lib/google/apis/ces_v1/classes.rb', line 3576

def update!(**args)
  @corpus_type = args[:corpus_type] if args.key?(:corpus_type)
  @description = args[:description] if args.key?(:description)
  @file_corpus = args[:file_corpus] if args.key?(:file_corpus)
  @name = args[:name] if args.key?(:name)
end