Class: Google::Apis::CesV1::FileSearchTool
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::FileSearchTool
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
The file search tool allows the agent to search across the files uploaded by the app/agent developer. It has presets to give relatively good quality search over the uploaded files and summarization of the retrieved results.
Instance Attribute Summary collapse
-
#corpus_type ⇒ String
Optional.
-
#description ⇒ String
Optional.
-
#file_corpus ⇒ String
Optional.
-
#name ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FileSearchTool
constructor
A new instance of FileSearchTool.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FileSearchTool
Returns a new instance of FileSearchTool.
3442 3443 3444 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3442 def initialize(**args) update!(**args) end |
Instance Attribute Details
#corpus_type ⇒ String
Optional. The type of the corpus. Default is FULLY_MANAGED.
Corresponds to the JSON property corpusType
3424 3425 3426 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3424 def corpus_type @corpus_type end |
#description ⇒ String
Optional. The tool description.
Corresponds to the JSON property description
3429 3430 3431 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3429 def description @description end |
#file_corpus ⇒ String
Optional. The corpus where files are stored. Format: projects/project/
locations/location/ragCorpora/rag_corpus
Corresponds to the JSON property fileCorpus
3435 3436 3437 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3435 def file_corpus @file_corpus end |
#name ⇒ String
Required. The tool name.
Corresponds to the JSON property name
3440 3441 3442 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3440 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3447 3448 3449 3450 3451 3452 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3447 def update!(**args) @corpus_type = args[:corpus_type] if args.key?(:corpus_type) @description = args[:description] if args.key?(:description) @file_corpus = args[:file_corpus] if args.key?(:file_corpus) @name = args[:name] if args.key?(:name) end |