Class: Google::Apis::CesV1::GenerateChatTokenRequest
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::GenerateChatTokenRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Request message for WidgetService.GenerateChatToken.
Instance Attribute Summary collapse
-
#deployment ⇒ String
Required.
-
#live_handoff_enabled ⇒ Boolean
(also: #live_handoff_enabled?)
Optional.
-
#recaptcha_token ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenerateChatTokenRequest
constructor
A new instance of GenerateChatTokenRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenerateChatTokenRequest
Returns a new instance of GenerateChatTokenRequest.
3309 3310 3311 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3309 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deployment ⇒ String
Required. The deployment of the app to use for the session. Format: projects/
project/locations/location/apps/app/deployments/deployment
Corresponds to the JSON property deployment
3296 3297 3298 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3296 def deployment @deployment end |
#live_handoff_enabled ⇒ Boolean Also known as: live_handoff_enabled?
Optional. Indicates if live handoff is enabled for the session.
Corresponds to the JSON property liveHandoffEnabled
3301 3302 3303 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3301 def live_handoff_enabled @live_handoff_enabled end |
#recaptcha_token ⇒ String
Optional. The reCAPTCHA token generated by the client-side chat widget.
Corresponds to the JSON property recaptchaToken
3307 3308 3309 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3307 def recaptcha_token @recaptcha_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3314 3315 3316 3317 3318 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3314 def update!(**args) @deployment = args[:deployment] if args.key?(:deployment) @live_handoff_enabled = args[:live_handoff_enabled] if args.key?(:live_handoff_enabled) @recaptcha_token = args[:recaptcha_token] if args.key?(:recaptcha_token) end |