Class: Google::Apis::CesV1::GenerateChatTokenResponse
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::GenerateChatTokenResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Response message for WidgetService.GenerateChatToken.
Instance Attribute Summary collapse
-
#chat_token ⇒ String
The session scoped token for chat widget to authenticate with Session APIs.
-
#expire_time ⇒ String
The time at which the chat token expires.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenerateChatTokenResponse
constructor
A new instance of GenerateChatTokenResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenerateChatTokenResponse
Returns a new instance of GenerateChatTokenResponse.
3510 3511 3512 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3510 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chat_token ⇒ String
The session scoped token for chat widget to authenticate with Session APIs.
Corresponds to the JSON property chatToken
3503 3504 3505 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3503 def chat_token @chat_token end |
#expire_time ⇒ String
The time at which the chat token expires.
Corresponds to the JSON property expireTime
3508 3509 3510 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3508 def expire_time @expire_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3515 3516 3517 3518 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3515 def update!(**args) @chat_token = args[:chat_token] if args.key?(:chat_token) @expire_time = args[:expire_time] if args.key?(:expire_time) end |