Class: Google::Apis::CesV1::GenerateChatTokenResponse
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::GenerateChatTokenResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Response message for WidgetService.GenerateChatToken.
Instance Attribute Summary collapse
-
#chat_token ⇒ String
The session scoped token for chat widget to authenticate with Session APIs.
-
#expire_time ⇒ String
The time at which the chat token expires.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenerateChatTokenResponse
constructor
A new instance of GenerateChatTokenResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenerateChatTokenResponse
Returns a new instance of GenerateChatTokenResponse.
3335 3336 3337 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3335 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chat_token ⇒ String
The session scoped token for chat widget to authenticate with Session APIs.
Corresponds to the JSON property chatToken
3328 3329 3330 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3328 def chat_token @chat_token end |
#expire_time ⇒ String
The time at which the chat token expires.
Corresponds to the JSON property expireTime
3333 3334 3335 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3333 def expire_time @expire_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3340 3341 3342 3343 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3340 def update!(**args) @chat_token = args[:chat_token] if args.key?(:chat_token) @expire_time = args[:expire_time] if args.key?(:expire_time) end |