Class: Google::Apis::CesV1::GoogleSearchTool
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::GoogleSearchTool
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Represents a tool to perform Google web searches for grounding. See https:// cloud.google.com/customer-engagement-ai/conversational-agents/ps/tool#google- search.
Instance Attribute Summary collapse
-
#context_urls ⇒ Array<String>
Optional.
-
#description ⇒ String
Optional.
-
#exclude_domains ⇒ Array<String>
Optional.
-
#name ⇒ String
Required.
-
#preferred_domains ⇒ Array<String>
Optional.
-
#prompt_config ⇒ Google::Apis::CesV1::GoogleSearchToolPromptConfig
Prompt settings used by the model when processing or summarizing the google search results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleSearchTool
constructor
A new instance of GoogleSearchTool.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleSearchTool
Returns a new instance of GoogleSearchTool.
3415 3416 3417 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3415 def initialize(**args) update!(**args) end |
Instance Attribute Details
#context_urls ⇒ Array<String>
Optional. Content will be fetched directly from these URLs for context and
grounding. Example: "https://example.com/path.html". A maximum of 20 URLs are
allowed.
Corresponds to the JSON property contextUrls
3385 3386 3387 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3385 def context_urls @context_urls end |
#description ⇒ String
Optional. Description of the tool's purpose.
Corresponds to the JSON property description
3390 3391 3392 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3390 def description @description end |
#exclude_domains ⇒ Array<String>
Optional. List of domains to be excluded from the search results. Example: "
example.com". A maximum of 2000 domains can be excluded.
Corresponds to the JSON property excludeDomains
3396 3397 3398 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3396 def exclude_domains @exclude_domains end |
#name ⇒ String
Required. The name of the tool.
Corresponds to the JSON property name
3401 3402 3403 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3401 def name @name end |
#preferred_domains ⇒ Array<String>
Optional. Specifies domains to restrict search results to. Example: "example.
com", "another.site". A maximum of 20 domains can be specified.
Corresponds to the JSON property preferredDomains
3407 3408 3409 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3407 def preferred_domains @preferred_domains end |
#prompt_config ⇒ Google::Apis::CesV1::GoogleSearchToolPromptConfig
Prompt settings used by the model when processing or summarizing the google
search results.
Corresponds to the JSON property promptConfig
3413 3414 3415 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3413 def prompt_config @prompt_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3420 3421 3422 3423 3424 3425 3426 3427 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3420 def update!(**args) @context_urls = args[:context_urls] if args.key?(:context_urls) @description = args[:description] if args.key?(:description) @exclude_domains = args[:exclude_domains] if args.key?(:exclude_domains) @name = args[:name] if args.key?(:name) @preferred_domains = args[:preferred_domains] if args.key?(:preferred_domains) @prompt_config = args[:prompt_config] if args.key?(:prompt_config) end |