Class: Google::Apis::CesV1::GoogleSearchToolPromptConfig
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::GoogleSearchToolPromptConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Prompt settings used by the model when processing or summarizing the google search results.
Instance Attribute Summary collapse
-
#text_prompt ⇒ String
Optional.
-
#voice_prompt ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleSearchToolPromptConfig
constructor
A new instance of GoogleSearchToolPromptConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleSearchToolPromptConfig
Returns a new instance of GoogleSearchToolPromptConfig.
3622 3623 3624 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3622 def initialize(**args) update!(**args) end |
Instance Attribute Details
#text_prompt ⇒ String
Optional. Defines the prompt used for the system instructions when interacting
with the agent in chat conversations. If not set, default prompt will be used.
Corresponds to the JSON property textPrompt
3614 3615 3616 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3614 def text_prompt @text_prompt end |
#voice_prompt ⇒ String
Optional. Defines the prompt used for the system instructions when interacting
with the agent in voice conversations. If not set, default prompt will be used.
Corresponds to the JSON property voicePrompt
3620 3621 3622 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3620 def voice_prompt @voice_prompt end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3627 3628 3629 3630 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3627 def update!(**args) @text_prompt = args[:text_prompt] if args.key?(:text_prompt) @voice_prompt = args[:voice_prompt] if args.key?(:voice_prompt) end |