Class: Google::Apis::CesV1::GoogleSearchToolPromptConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Prompt settings used by the model when processing or summarizing the google search results.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleSearchToolPromptConfig

Returns a new instance of GoogleSearchToolPromptConfig.



3447
3448
3449
# File 'lib/google/apis/ces_v1/classes.rb', line 3447

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#text_promptString

Optional. Defines the prompt used for the system instructions when interacting with the agent in chat conversations. If not set, default prompt will be used. Corresponds to the JSON property textPrompt

Returns:

  • (String)


3439
3440
3441
# File 'lib/google/apis/ces_v1/classes.rb', line 3439

def text_prompt
  @text_prompt
end

#voice_promptString

Optional. Defines the prompt used for the system instructions when interacting with the agent in voice conversations. If not set, default prompt will be used. Corresponds to the JSON property voicePrompt

Returns:

  • (String)


3445
3446
3447
# File 'lib/google/apis/ces_v1/classes.rb', line 3445

def voice_prompt
  @voice_prompt
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3452
3453
3454
3455
# File 'lib/google/apis/ces_v1/classes.rb', line 3452

def update!(**args)
  @text_prompt = args[:text_prompt] if args.key?(:text_prompt)
  @voice_prompt = args[:voice_prompt] if args.key?(:voice_prompt)
end