Class: Google::Apis::CesV1::GuardrailCodeCallback
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::GuardrailCodeCallback
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Guardrail that blocks the conversation based on the code callbacks provided.
Instance Attribute Summary collapse
-
#after_agent_callback ⇒ Google::Apis::CesV1::Callback
A callback defines the custom logic to be executed at various stages of agent interaction.
-
#after_model_callback ⇒ Google::Apis::CesV1::Callback
A callback defines the custom logic to be executed at various stages of agent interaction.
-
#before_agent_callback ⇒ Google::Apis::CesV1::Callback
A callback defines the custom logic to be executed at various stages of agent interaction.
-
#before_model_callback ⇒ Google::Apis::CesV1::Callback
A callback defines the custom logic to be executed at various stages of agent interaction.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GuardrailCodeCallback
constructor
A new instance of GuardrailCodeCallback.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GuardrailCodeCallback
Returns a new instance of GuardrailCodeCallback.
3896 3897 3898 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3896 def initialize(**args) update!(**args) end |
Instance Attribute Details
#after_agent_callback ⇒ Google::Apis::CesV1::Callback
A callback defines the custom logic to be executed at various stages of agent
interaction.
Corresponds to the JSON property afterAgentCallback
3876 3877 3878 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3876 def after_agent_callback @after_agent_callback end |
#after_model_callback ⇒ Google::Apis::CesV1::Callback
A callback defines the custom logic to be executed at various stages of agent
interaction.
Corresponds to the JSON property afterModelCallback
3882 3883 3884 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3882 def after_model_callback @after_model_callback end |
#before_agent_callback ⇒ Google::Apis::CesV1::Callback
A callback defines the custom logic to be executed at various stages of agent
interaction.
Corresponds to the JSON property beforeAgentCallback
3888 3889 3890 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3888 def before_agent_callback @before_agent_callback end |
#before_model_callback ⇒ Google::Apis::CesV1::Callback
A callback defines the custom logic to be executed at various stages of agent
interaction.
Corresponds to the JSON property beforeModelCallback
3894 3895 3896 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3894 def before_model_callback @before_model_callback end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3901 3902 3903 3904 3905 3906 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3901 def update!(**args) @after_agent_callback = args[:after_agent_callback] if args.key?(:after_agent_callback) @after_model_callback = args[:after_model_callback] if args.key?(:after_model_callback) @before_agent_callback = args[:before_agent_callback] if args.key?(:before_agent_callback) @before_model_callback = args[:before_model_callback] if args.key?(:before_model_callback) end |