Class: Google::Apis::CesV1::GuardrailCodeCallback

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Guardrail that blocks the conversation based on the code callbacks provided.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GuardrailCodeCallback

Returns a new instance of GuardrailCodeCallback.



3586
3587
3588
# File 'lib/google/apis/ces_v1/classes.rb', line 3586

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#after_agent_callbackGoogle::Apis::CesV1::Callback

A callback defines the custom logic to be executed at various stages of agent interaction. Corresponds to the JSON property afterAgentCallback



3566
3567
3568
# File 'lib/google/apis/ces_v1/classes.rb', line 3566

def after_agent_callback
  @after_agent_callback
end

#after_model_callbackGoogle::Apis::CesV1::Callback

A callback defines the custom logic to be executed at various stages of agent interaction. Corresponds to the JSON property afterModelCallback



3572
3573
3574
# File 'lib/google/apis/ces_v1/classes.rb', line 3572

def after_model_callback
  @after_model_callback
end

#before_agent_callbackGoogle::Apis::CesV1::Callback

A callback defines the custom logic to be executed at various stages of agent interaction. Corresponds to the JSON property beforeAgentCallback



3578
3579
3580
# File 'lib/google/apis/ces_v1/classes.rb', line 3578

def before_agent_callback
  @before_agent_callback
end

#before_model_callbackGoogle::Apis::CesV1::Callback

A callback defines the custom logic to be executed at various stages of agent interaction. Corresponds to the JSON property beforeModelCallback



3584
3585
3586
# File 'lib/google/apis/ces_v1/classes.rb', line 3584

def before_model_callback
  @before_model_callback
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3591
3592
3593
3594
3595
3596
# File 'lib/google/apis/ces_v1/classes.rb', line 3591

def update!(**args)
  @after_agent_callback = args[:after_agent_callback] if args.key?(:after_agent_callback)
  @after_model_callback = args[:after_model_callback] if args.key?(:after_model_callback)
  @before_agent_callback = args[:before_agent_callback] if args.key?(:before_agent_callback)
  @before_model_callback = args[:before_model_callback] if args.key?(:before_model_callback)
end