Class: Google::Apis::CesV1::GuardrailLlmPolicy
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::GuardrailLlmPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Guardrail that blocks the conversation if the LLM response is considered violating the policy based on the LLM classification.
Instance Attribute Summary collapse
-
#allow_short_utterance ⇒ Boolean
(also: #allow_short_utterance?)
Optional.
-
#fail_open ⇒ Boolean
(also: #fail_open?)
Optional.
-
#max_conversation_messages ⇒ Fixnum
Optional.
-
#model_settings ⇒ Google::Apis::CesV1::ModelSettings
Model settings contains various configurations for the LLM model.
-
#policy_scope ⇒ String
Required.
-
#prompt ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GuardrailLlmPolicy
constructor
A new instance of GuardrailLlmPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GuardrailLlmPolicy
Returns a new instance of GuardrailLlmPolicy.
4031 4032 4033 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4031 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allow_short_utterance ⇒ Boolean Also known as: allow_short_utterance?
Optional. By default, the LLM policy check is bypassed for short utterances.
Enabling this setting applies the policy check to all utterances, including
those that would normally be skipped.
Corresponds to the JSON property allowShortUtterance
3997 3998 3999 |
# File 'lib/google/apis/ces_v1/classes.rb', line 3997 def allow_short_utterance @allow_short_utterance end |
#fail_open ⇒ Boolean Also known as: fail_open?
Optional. If an error occurs during the policy check, fail open and do not
trigger the guardrail.
Corresponds to the JSON property failOpen
4004 4005 4006 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4004 def fail_open @fail_open end |
#max_conversation_messages ⇒ Fixnum
Optional. When checking this policy, consider the last 'n' messages in the
conversation. When not set a default value of 10 will be used.
Corresponds to the JSON property maxConversationMessages
4011 4012 4013 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4011 def @max_conversation_messages end |
#model_settings ⇒ Google::Apis::CesV1::ModelSettings
Model settings contains various configurations for the LLM model.
Corresponds to the JSON property modelSettings
4016 4017 4018 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4016 def model_settings @model_settings end |
#policy_scope ⇒ String
Required. Defines when to apply the policy check during the conversation. If
set to POLICY_SCOPE_UNSPECIFIED, the policy will be applied to the user
input. When applying the policy to the agent response, additional latency will
be introduced before the agent can respond.
Corresponds to the JSON property policyScope
4024 4025 4026 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4024 def policy_scope @policy_scope end |
#prompt ⇒ String
Required. Policy prompt.
Corresponds to the JSON property prompt
4029 4030 4031 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4029 def prompt @prompt end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4036 4037 4038 4039 4040 4041 4042 4043 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4036 def update!(**args) @allow_short_utterance = args[:allow_short_utterance] if args.key?(:allow_short_utterance) @fail_open = args[:fail_open] if args.key?(:fail_open) @max_conversation_messages = args[:max_conversation_messages] if args.key?(:max_conversation_messages) @model_settings = args[:model_settings] if args.key?(:model_settings) @policy_scope = args[:policy_scope] if args.key?(:policy_scope) @prompt = args[:prompt] if args.key?(:prompt) end |