Class: Google::Apis::CesV1::GuardrailLlmPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Guardrail that blocks the conversation if the LLM response is considered violating the policy based on the LLM classification.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GuardrailLlmPolicy

Returns a new instance of GuardrailLlmPolicy.



3855
3856
3857
# File 'lib/google/apis/ces_v1/classes.rb', line 3855

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_short_utteranceBoolean Also known as: allow_short_utterance?

Optional. By default, the LLM policy check is bypassed for short utterances. Enabling this setting applies the policy check to all utterances, including those that would normally be skipped. Corresponds to the JSON property allowShortUtterance

Returns:

  • (Boolean)


3821
3822
3823
# File 'lib/google/apis/ces_v1/classes.rb', line 3821

def allow_short_utterance
  @allow_short_utterance
end

#fail_openBoolean Also known as: fail_open?

Optional. If an error occurs during the policy check, fail open and do not trigger the guardrail. Corresponds to the JSON property failOpen

Returns:

  • (Boolean)


3828
3829
3830
# File 'lib/google/apis/ces_v1/classes.rb', line 3828

def fail_open
  @fail_open
end

#max_conversation_messagesFixnum

Optional. When checking this policy, consider the last 'n' messages in the conversation. When not set a default value of 10 will be used. Corresponds to the JSON property maxConversationMessages

Returns:

  • (Fixnum)


3835
3836
3837
# File 'lib/google/apis/ces_v1/classes.rb', line 3835

def max_conversation_messages
  @max_conversation_messages
end

#model_settingsGoogle::Apis::CesV1::ModelSettings

Model settings contains various configurations for the LLM model. Corresponds to the JSON property modelSettings



3840
3841
3842
# File 'lib/google/apis/ces_v1/classes.rb', line 3840

def model_settings
  @model_settings
end

#policy_scopeString

Required. Defines when to apply the policy check during the conversation. If set to POLICY_SCOPE_UNSPECIFIED, the policy will be applied to the user input. When applying the policy to the agent response, additional latency will be introduced before the agent can respond. Corresponds to the JSON property policyScope

Returns:

  • (String)


3848
3849
3850
# File 'lib/google/apis/ces_v1/classes.rb', line 3848

def policy_scope
  @policy_scope
end

#promptString

Required. Policy prompt. Corresponds to the JSON property prompt

Returns:

  • (String)


3853
3854
3855
# File 'lib/google/apis/ces_v1/classes.rb', line 3853

def prompt
  @prompt
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3860
3861
3862
3863
3864
3865
3866
3867
# File 'lib/google/apis/ces_v1/classes.rb', line 3860

def update!(**args)
  @allow_short_utterance = args[:allow_short_utterance] if args.key?(:allow_short_utterance)
  @fail_open = args[:fail_open] if args.key?(:fail_open)
  @max_conversation_messages = args[:max_conversation_messages] if args.key?(:max_conversation_messages)
  @model_settings = args[:model_settings] if args.key?(:model_settings)
  @policy_scope = args[:policy_scope] if args.key?(:policy_scope)
  @prompt = args[:prompt] if args.key?(:prompt)
end