Class: Google::Apis::CesV1::GuardrailLlmPromptSecurityDefaultSecuritySettings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Configuration for default system security settings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GuardrailLlmPromptSecurityDefaultSecuritySettings

Returns a new instance of GuardrailLlmPromptSecurityDefaultSecuritySettings.



4047
4048
4049
# File 'lib/google/apis/ces_v1/classes.rb', line 4047

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#default_prompt_templateString

Output only. The default prompt template used by the system. This field is for display purposes to show the user what prompt the system uses by default. It is OUTPUT_ONLY. Corresponds to the JSON property defaultPromptTemplate

Returns:

  • (String)


4045
4046
4047
# File 'lib/google/apis/ces_v1/classes.rb', line 4045

def default_prompt_template
  @default_prompt_template
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4052
4053
4054
# File 'lib/google/apis/ces_v1/classes.rb', line 4052

def update!(**args)
  @default_prompt_template = args[:default_prompt_template] if args.key?(:default_prompt_template)
end