Class: Google::Apis::CesV1::GuardrailModelSafety
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::GuardrailModelSafety
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Model safety settings overrides. When this is set, it will override the default settings and trigger the guardrail if the response is considered unsafe.
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(**args) ⇒ GuardrailModelSafety
constructor
A new instance of GuardrailModelSafety.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GuardrailModelSafety
Returns a new instance of GuardrailModelSafety.
4131 4132 4133 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4131 def initialize(**args) update!(**args) end |
Instance Attribute Details
#safety_settings ⇒ Array<Google::Apis::CesV1::GuardrailModelSafetySafetySetting>
Required. List of safety settings.
Corresponds to the JSON property safetySettings
4129 4130 4131 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4129 def safety_settings @safety_settings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4136 4137 4138 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4136 def update!(**args) @safety_settings = args[:safety_settings] if args.key?(:safety_settings) end |