Class: Google::Apis::CesV1::GuardrailModelSafety
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::GuardrailModelSafety
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Model safety settings overrides. When this is set, it will override the default settings and trigger the guardrail if the response is considered unsafe.
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(**args) ⇒ GuardrailModelSafety
constructor
A new instance of GuardrailModelSafety.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GuardrailModelSafety
Returns a new instance of GuardrailModelSafety.
4082 4083 4084 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4082 def initialize(**args) update!(**args) end |
Instance Attribute Details
#safety_settings ⇒ Array<Google::Apis::CesV1::GuardrailModelSafetySafetySetting>
Required. List of safety settings.
Corresponds to the JSON property safetySettings
4080 4081 4082 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4080 def safety_settings @safety_settings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4087 4088 4089 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4087 def update!(**args) @safety_settings = args[:safety_settings] if args.key?(:safety_settings) end |