Class: Google::Apis::CesV1::GuardrailModelSafety

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Model safety settings overrides. When this is set, it will override the default settings and trigger the guardrail if the response is considered unsafe.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GuardrailModelSafety

Returns a new instance of GuardrailModelSafety.



3939
3940
3941
# File 'lib/google/apis/ces_v1/classes.rb', line 3939

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#safety_settingsArray<Google::Apis::CesV1::GuardrailModelSafetySafetySetting>

Required. List of safety settings. Corresponds to the JSON property safetySettings



3937
3938
3939
# File 'lib/google/apis/ces_v1/classes.rb', line 3937

def safety_settings
  @safety_settings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3944
3945
3946
# File 'lib/google/apis/ces_v1/classes.rb', line 3944

def update!(**args)
  @safety_settings = args[:safety_settings] if args.key?(:safety_settings)
end