Class: Google::Apis::CesV1::GuardrailModelSafety

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Model safety settings overrides. When this is set, it will override the default settings and trigger the guardrail if the response is considered unsafe.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GuardrailModelSafety

Returns a new instance of GuardrailModelSafety.



3772
3773
3774
# File 'lib/google/apis/ces_v1/classes.rb', line 3772

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#safety_settingsArray<Google::Apis::CesV1::GuardrailModelSafetySafetySetting>

Required. List of safety settings. Corresponds to the JSON property safetySettings



3770
3771
3772
# File 'lib/google/apis/ces_v1/classes.rb', line 3770

def safety_settings
  @safety_settings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3777
3778
3779
# File 'lib/google/apis/ces_v1/classes.rb', line 3777

def update!(**args)
  @safety_settings = args[:safety_settings] if args.key?(:safety_settings)
end