Class: Google::Apis::CesV1::ImportAppRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Request message for AgentService.ImportApp.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ImportAppRequest

Returns a new instance of ImportAppRequest.



4057
4058
4059
# File 'lib/google/apis/ces_v1/classes.rb', line 4057

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_contentString

Raw bytes representing the compressed zip file with the app folder structure. Corresponds to the JSON property appContent NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


4017
4018
4019
# File 'lib/google/apis/ces_v1/classes.rb', line 4017

def app_content
  @app_content
end

#app_idString

Optional. The ID to use for the imported app. * If not specified, a unique ID will be automatically assigned for the app. * Otherwise, the imported app will use this ID as the final component of its resource name. If an app with the same ID already exists at the specified location in the project, the content of the existing app will be replaced. Corresponds to the JSON property appId

Returns:

  • (String)


4026
4027
4028
# File 'lib/google/apis/ces_v1/classes.rb', line 4026

def app_id
  @app_id
end

#display_nameString

Optional. The display name of the app to import. * If the app is created on import, and the display name is specified, the imported app will use this display name. If a conflict is detected with an existing app, a timestamp will be appended to the display name to make it unique. * If the app is a reimport, this field should not be set. Providing a display name during reimport will result in an INVALID_ARGUMENT error. Corresponds to the JSON property displayName

Returns:

  • (String)


4036
4037
4038
# File 'lib/google/apis/ces_v1/classes.rb', line 4036

def display_name
  @display_name
end

#gcs_uriString

The Google Cloud Storage URI from which to import app. The format of this URI must be gs:///. Corresponds to the JSON property gcsUri

Returns:

  • (String)


4042
4043
4044
# File 'lib/google/apis/ces_v1/classes.rb', line 4042

def gcs_uri
  @gcs_uri
end

#ignore_app_lockBoolean Also known as: ignore_app_lock?

Optional. Flag for overriding the app lock during import. If set to true, the import process will ignore the app lock. Corresponds to the JSON property ignoreAppLock

Returns:

  • (Boolean)


4048
4049
4050
# File 'lib/google/apis/ces_v1/classes.rb', line 4048

def ignore_app_lock
  @ignore_app_lock
end

#import_optionsGoogle::Apis::CesV1::ImportAppRequestImportOptions

Configuration options for the app import process. These options control how the import behaves, particularly when conflicts arise with existing app data. Corresponds to the JSON property importOptions



4055
4056
4057
# File 'lib/google/apis/ces_v1/classes.rb', line 4055

def import_options
  @import_options
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4062
4063
4064
4065
4066
4067
4068
4069
# File 'lib/google/apis/ces_v1/classes.rb', line 4062

def update!(**args)
  @app_content = args[:app_content] if args.key?(:app_content)
  @app_id = args[:app_id] if args.key?(:app_id)
  @display_name = args[:display_name] if args.key?(:display_name)
  @gcs_uri = args[:gcs_uri] if args.key?(:gcs_uri)
  @ignore_app_lock = args[:ignore_app_lock] if args.key?(:ignore_app_lock)
  @import_options = args[:import_options] if args.key?(:import_options)
end