Class: Google::Apis::CesV1::ImportAppRequestImportOptions

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Configuration options for the app import process. These options control how the import behaves, particularly when conflicts arise with existing app data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ImportAppRequestImportOptions

Returns a new instance of ImportAppRequestImportOptions.



4258
4259
4260
# File 'lib/google/apis/ces_v1/classes.rb', line 4258

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conflict_resolution_strategyString

Optional. The strategy to use when resolving conflicts during import. Corresponds to the JSON property conflictResolutionStrategy

Returns:

  • (String)


4248
4249
4250
# File 'lib/google/apis/ces_v1/classes.rb', line 4248

def conflict_resolution_strategy
  @conflict_resolution_strategy
end

#validate_onlyBoolean Also known as: validate_only?

Optional. Flag for dry-running the import process. If set to true, the import process will only perform validations and will not make any changes to the existing app or create a new one. Corresponds to the JSON property validateOnly

Returns:

  • (Boolean)


4255
4256
4257
# File 'lib/google/apis/ces_v1/classes.rb', line 4255

def validate_only
  @validate_only
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4263
4264
4265
4266
# File 'lib/google/apis/ces_v1/classes.rb', line 4263

def update!(**args)
  @conflict_resolution_strategy = args[:conflict_resolution_strategy] if args.key?(:conflict_resolution_strategy)
  @validate_only = args[:validate_only] if args.key?(:validate_only)
end