Class: Google::Apis::CesV1::ImportAppRequestImportOptions

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Configuration options for the app import process. These options control how the import behaves, particularly when conflicts arise with existing app data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ImportAppRequestImportOptions

Returns a new instance of ImportAppRequestImportOptions.



3907
3908
3909
# File 'lib/google/apis/ces_v1/classes.rb', line 3907

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conflict_resolution_strategyString

Optional. The strategy to use when resolving conflicts during import. Corresponds to the JSON property conflictResolutionStrategy

Returns:

  • (String)


3905
3906
3907
# File 'lib/google/apis/ces_v1/classes.rb', line 3905

def conflict_resolution_strategy
  @conflict_resolution_strategy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3912
3913
3914
# File 'lib/google/apis/ces_v1/classes.rb', line 3912

def update!(**args)
  @conflict_resolution_strategy = args[:conflict_resolution_strategy] if args.key?(:conflict_resolution_strategy)
end