Class: Google::Apis::CesV1::ImportAppResponse
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::ImportAppResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Response message for AgentService.ImportApp.
Instance Attribute Summary collapse
-
#name ⇒ String
The resource name of the app that was imported.
-
#warnings ⇒ Array<String>
Warning messages generated during the import process.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ImportAppResponse
constructor
A new instance of ImportAppResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ImportAppResponse
Returns a new instance of ImportAppResponse.
4285 4286 4287 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4285 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
The resource name of the app that was imported.
Corresponds to the JSON property name
4276 4277 4278 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4276 def name @name end |
#warnings ⇒ Array<String>
Warning messages generated during the import process. If errors occur for
specific resources, they will not be included in the imported app and the
error will be mentioned here.
Corresponds to the JSON property warnings
4283 4284 4285 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4283 def warnings @warnings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4290 4291 4292 4293 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4290 def update!(**args) @name = args[:name] if args.key?(:name) @warnings = args[:warnings] if args.key?(:warnings) end |