Class: Google::Apis::CesV1::ImportAppResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Response message for AgentService.ImportApp.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ImportAppResponse

Returns a new instance of ImportAppResponse.



4243
4244
4245
# File 'lib/google/apis/ces_v1/classes.rb', line 4243

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

The resource name of the app that was imported. Corresponds to the JSON property name

Returns:

  • (String)


4234
4235
4236
# File 'lib/google/apis/ces_v1/classes.rb', line 4234

def name
  @name
end

#warningsArray<String>

Warning messages generated during the import process. If errors occur for specific resources, they will not be included in the imported app and the error will be mentioned here. Corresponds to the JSON property warnings

Returns:

  • (Array<String>)


4241
4242
4243
# File 'lib/google/apis/ces_v1/classes.rb', line 4241

def warnings
  @warnings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4248
4249
4250
4251
# File 'lib/google/apis/ces_v1/classes.rb', line 4248

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @warnings = args[:warnings] if args.key?(:warnings)
end