Class: Google::Apis::CesV1::ImportAppResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Response message for AgentService.ImportApp.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ImportAppResponse

Returns a new instance of ImportAppResponse.



4100
4101
4102
# File 'lib/google/apis/ces_v1/classes.rb', line 4100

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

The resource name of the app that was imported. Corresponds to the JSON property name

Returns:

  • (String)


4091
4092
4093
# File 'lib/google/apis/ces_v1/classes.rb', line 4091

def name
  @name
end

#warningsArray<String>

Warning messages generated during the import process. If errors occur for specific resources, they will not be included in the imported app and the error will be mentioned here. Corresponds to the JSON property warnings

Returns:

  • (Array<String>)


4098
4099
4100
# File 'lib/google/apis/ces_v1/classes.rb', line 4098

def warnings
  @warnings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4105
4106
4107
4108
# File 'lib/google/apis/ces_v1/classes.rb', line 4105

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @warnings = args[:warnings] if args.key?(:warnings)
end