Class: Google::Apis::CesV1::LanguageSettings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Language settings of the app.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LanguageSettings

Returns a new instance of LanguageSettings.



4331
4332
4333
# File 'lib/google/apis/ces_v1/classes.rb', line 4331

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#default_language_codeString

Optional. The default language code of the app. Corresponds to the JSON property defaultLanguageCode

Returns:

  • (String)


4305
4306
4307
# File 'lib/google/apis/ces_v1/classes.rb', line 4305

def default_language_code
  @default_language_code
end

#enable_multilingual_supportBoolean Also known as: enable_multilingual_support?

Optional. Enables multilingual support. If true, agents in the app will use pre-built instructions to improve handling of multilingual input. Corresponds to the JSON property enableMultilingualSupport

Returns:

  • (Boolean)


4311
4312
4313
# File 'lib/google/apis/ces_v1/classes.rb', line 4311

def enable_multilingual_support
  @enable_multilingual_support
end

#fallback_actionString

Optional. Deprecated: This feature is no longer supported. Use enable_multilingual_support instead to improve handling of multilingual input. The action to perform when an agent receives input in an unsupported language. This can be a predefined action or a custom tool call. Valid values are: - A tool's full resource name, which triggers a specific tool execution. - A predefined system action, such as "escalate" or "exit", which triggers an EndSession signal with corresponding metadata to terminate the conversation. Corresponds to the JSON property fallbackAction

Returns:

  • (String)


4323
4324
4325
# File 'lib/google/apis/ces_v1/classes.rb', line 4323

def fallback_action
  @fallback_action
end

#supported_language_codesArray<String>

Optional. List of languages codes supported by the app, in addition to the default_language_code. Corresponds to the JSON property supportedLanguageCodes

Returns:

  • (Array<String>)


4329
4330
4331
# File 'lib/google/apis/ces_v1/classes.rb', line 4329

def supported_language_codes
  @supported_language_codes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4336
4337
4338
4339
4340
4341
# File 'lib/google/apis/ces_v1/classes.rb', line 4336

def update!(**args)
  @default_language_code = args[:default_language_code] if args.key?(:default_language_code)
  @enable_multilingual_support = args[:enable_multilingual_support] if args.key?(:enable_multilingual_support)
  @fallback_action = args[:fallback_action] if args.key?(:fallback_action)
  @supported_language_codes = args[:supported_language_codes] if args.key?(:supported_language_codes)
end