Class: Google::Apis::CesV1::LfA2aV1AgentCapabilities
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::LfA2aV1AgentCapabilities
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Defines optional capabilities supported by an agent.
Instance Attribute Summary collapse
-
#extended_agent_card ⇒ Boolean
(also: #extended_agent_card?)
Indicates if the agent supports providing an extended agent card when authenticated.
-
#extensions ⇒ Array<Google::Apis::CesV1::LfA2aV1AgentExtension>
A list of protocol extensions supported by the agent.
-
#push_notifications ⇒ Boolean
(also: #push_notifications?)
Indicates if the agent supports sending push notifications for asynchronous task updates.
-
#streaming ⇒ Boolean
(also: #streaming?)
Indicates if the agent supports streaming responses.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LfA2aV1AgentCapabilities
constructor
A new instance of LfA2aV1AgentCapabilities.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LfA2aV1AgentCapabilities
Returns a new instance of LfA2aV1AgentCapabilities.
4405 4406 4407 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4405 def initialize(**args) update!(**args) end |
Instance Attribute Details
#extended_agent_card ⇒ Boolean Also known as: extended_agent_card?
Indicates if the agent supports providing an extended agent card when
authenticated.
Corresponds to the JSON property extendedAgentCard
4384 4385 4386 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4384 def extended_agent_card @extended_agent_card end |
#extensions ⇒ Array<Google::Apis::CesV1::LfA2aV1AgentExtension>
A list of protocol extensions supported by the agent.
Corresponds to the JSON property extensions
4390 4391 4392 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4390 def extensions @extensions end |
#push_notifications ⇒ Boolean Also known as: push_notifications?
Indicates if the agent supports sending push notifications for asynchronous
task updates.
Corresponds to the JSON property pushNotifications
4396 4397 4398 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4396 def push_notifications @push_notifications end |
#streaming ⇒ Boolean Also known as: streaming?
Indicates if the agent supports streaming responses.
Corresponds to the JSON property streaming
4402 4403 4404 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4402 def streaming @streaming end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4410 4411 4412 4413 4414 4415 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4410 def update!(**args) @extended_agent_card = args[:extended_agent_card] if args.key?(:extended_agent_card) @extensions = args[:extensions] if args.key?(:extensions) @push_notifications = args[:push_notifications] if args.key?(:push_notifications) @streaming = args[:streaming] if args.key?(:streaming) end |