Class: Google::Apis::CesV1::LfA2aV1AgentCard
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::LfA2aV1AgentCard
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
A self-describing manifest for an agent. It provides essential metadata including the agent's identity, capabilities, skills, supported communication methods, and security requirements. Next ID: 20
Instance Attribute Summary collapse
-
#capabilities ⇒ Google::Apis::CesV1::LfA2aV1AgentCapabilities
Defines optional capabilities supported by an agent.
-
#default_input_modes ⇒ Array<String>
Required.
-
#default_output_modes ⇒ Array<String>
Required.
-
#description ⇒ String
Required.
-
#documentation_url ⇒ String
A URL providing additional documentation about the agent.
-
#icon_url ⇒ String
Optional.
-
#name ⇒ String
Required.
-
#provider ⇒ Google::Apis::CesV1::LfA2aV1AgentProvider
Represents the service provider of an agent.
-
#security_requirements ⇒ Array<Google::Apis::CesV1::LfA2aV1SecurityRequirement>
Security requirements for contacting the agent.
-
#security_schemes ⇒ Hash<String,Google::Apis::CesV1::LfA2aV1SecurityScheme>
The security scheme details used for authenticating with this agent.
-
#signatures ⇒ Array<Google::Apis::CesV1::LfA2aV1AgentCardSignature>
JSON Web Signatures computed for this
AgentCard. -
#skills ⇒ Array<Google::Apis::CesV1::LfA2aV1AgentSkill>
Required.
-
#supported_interfaces ⇒ Array<Google::Apis::CesV1::LfA2aV1AgentInterface>
Required.
-
#version ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LfA2aV1AgentCard
constructor
A new instance of LfA2aV1AgentCard.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LfA2aV1AgentCard
Returns a new instance of LfA2aV1AgentCard.
4514 4515 4516 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4514 def initialize(**args) update!(**args) end |
Instance Attribute Details
#capabilities ⇒ Google::Apis::CesV1::LfA2aV1AgentCapabilities
Defines optional capabilities supported by an agent.
Corresponds to the JSON property capabilities
4441 4442 4443 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4441 def capabilities @capabilities end |
#default_input_modes ⇒ Array<String>
Required. protolint:enable REPEATED_FIELD_NAMES_PLURALIZED The set of
interaction modes that the agent supports across all skills. This can be
overridden per skill. Defined as media types.
Corresponds to the JSON property defaultInputModes
4448 4449 4450 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4448 def default_input_modes @default_input_modes end |
#default_output_modes ⇒ Array<String>
Required. The media types supported as outputs from this agent.
Corresponds to the JSON property defaultOutputModes
4453 4454 4455 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4453 def default_output_modes @default_output_modes end |
#description ⇒ String
Required. A human-readable description of the agent, assisting users and other
agents in understanding its purpose. Example: "Agent that helps users with
recipes and cooking."
Corresponds to the JSON property description
4460 4461 4462 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4460 def description @description end |
#documentation_url ⇒ String
A URL providing additional documentation about the agent.
Corresponds to the JSON property documentationUrl
4465 4466 4467 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4465 def documentation_url @documentation_url end |
#icon_url ⇒ String
Optional. A URL to an icon for the agent.
Corresponds to the JSON property iconUrl
4470 4471 4472 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4470 def icon_url @icon_url end |
#name ⇒ String
Required. A human readable name for the agent. Example: "Recipe Agent"
Corresponds to the JSON property name
4475 4476 4477 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4475 def name @name end |
#provider ⇒ Google::Apis::CesV1::LfA2aV1AgentProvider
Represents the service provider of an agent.
Corresponds to the JSON property provider
4480 4481 4482 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4480 def provider @provider end |
#security_requirements ⇒ Array<Google::Apis::CesV1::LfA2aV1SecurityRequirement>
Security requirements for contacting the agent.
Corresponds to the JSON property securityRequirements
4485 4486 4487 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4485 def security_requirements @security_requirements end |
#security_schemes ⇒ Hash<String,Google::Apis::CesV1::LfA2aV1SecurityScheme>
The security scheme details used for authenticating with this agent.
Corresponds to the JSON property securitySchemes
4490 4491 4492 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4490 def security_schemes @security_schemes end |
#signatures ⇒ Array<Google::Apis::CesV1::LfA2aV1AgentCardSignature>
JSON Web Signatures computed for this AgentCard.
Corresponds to the JSON property signatures
4495 4496 4497 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4495 def signatures @signatures end |
#skills ⇒ Array<Google::Apis::CesV1::LfA2aV1AgentSkill>
Required. Skills represent the abilities of an agent. It is largely a
descriptive concept but represents a more focused set of behaviors that the
agent is likely to succeed at.
Corresponds to the JSON property skills
4502 4503 4504 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4502 def skills @skills end |
#supported_interfaces ⇒ Array<Google::Apis::CesV1::LfA2aV1AgentInterface>
Required. Ordered list of supported interfaces. The first entry is preferred.
Corresponds to the JSON property supportedInterfaces
4507 4508 4509 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4507 def supported_interfaces @supported_interfaces end |
#version ⇒ String
Required. The version of the agent. Example: "1.0.0"
Corresponds to the JSON property version
4512 4513 4514 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4512 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4519 4520 4521 4522 4523 4524 4525 4526 4527 4528 4529 4530 4531 4532 4533 4534 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4519 def update!(**args) @capabilities = args[:capabilities] if args.key?(:capabilities) @default_input_modes = args[:default_input_modes] if args.key?(:default_input_modes) @default_output_modes = args[:default_output_modes] if args.key?(:default_output_modes) @description = args[:description] if args.key?(:description) @documentation_url = args[:documentation_url] if args.key?(:documentation_url) @icon_url = args[:icon_url] if args.key?(:icon_url) @name = args[:name] if args.key?(:name) @provider = args[:provider] if args.key?(:provider) @security_requirements = args[:security_requirements] if args.key?(:security_requirements) @security_schemes = args[:security_schemes] if args.key?(:security_schemes) @signatures = args[:signatures] if args.key?(:signatures) @skills = args[:skills] if args.key?(:skills) @supported_interfaces = args[:supported_interfaces] if args.key?(:supported_interfaces) @version = args[:version] if args.key?(:version) end |