Class: Google::Apis::CesV1::LfA2aV1AgentExtension
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::LfA2aV1AgentExtension
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
A declaration of a protocol extension supported by an Agent.
Instance Attribute Summary collapse
-
#description ⇒ String
A human-readable description of how this agent uses the extension.
-
#params ⇒ Hash<String,Object>
Optional.
-
#required ⇒ Boolean
(also: #required?)
If true, the client must understand and comply with the extension's requirements.
-
#uri ⇒ String
The unique URI identifying the extension.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LfA2aV1AgentExtension
constructor
A new instance of LfA2aV1AgentExtension.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LfA2aV1AgentExtension
Returns a new instance of LfA2aV1AgentExtension.
4638 4639 4640 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4638 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
A human-readable description of how this agent uses the extension.
Corresponds to the JSON property description
4619 4620 4621 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4619 def description @description end |
#params ⇒ Hash<String,Object>
Optional. Extension-specific configuration parameters.
Corresponds to the JSON property params
4624 4625 4626 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4624 def params @params end |
#required ⇒ Boolean Also known as: required?
If true, the client must understand and comply with the extension's
requirements.
Corresponds to the JSON property required
4630 4631 4632 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4630 def required @required end |
#uri ⇒ String
The unique URI identifying the extension.
Corresponds to the JSON property uri
4636 4637 4638 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4636 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4643 4644 4645 4646 4647 4648 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4643 def update!(**args) @description = args[:description] if args.key?(:description) @params = args[:params] if args.key?(:params) @required = args[:required] if args.key?(:required) @uri = args[:uri] if args.key?(:uri) end |