Class: Google::Apis::CesV1::LfA2aV1AgentExtension
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::LfA2aV1AgentExtension
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
A declaration of a protocol extension supported by an Agent.
Instance Attribute Summary collapse
-
#description ⇒ String
A human-readable description of how this agent uses the extension.
-
#params ⇒ Hash<String,Object>
Optional.
-
#required ⇒ Boolean
(also: #required?)
If true, the client must understand and comply with the extension's requirements.
-
#uri ⇒ String
The unique URI identifying the extension.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LfA2aV1AgentExtension
constructor
A new instance of LfA2aV1AgentExtension.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LfA2aV1AgentExtension
Returns a new instance of LfA2aV1AgentExtension.
4582 4583 4584 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4582 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
A human-readable description of how this agent uses the extension.
Corresponds to the JSON property description
4563 4564 4565 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4563 def description @description end |
#params ⇒ Hash<String,Object>
Optional. Extension-specific configuration parameters.
Corresponds to the JSON property params
4568 4569 4570 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4568 def params @params end |
#required ⇒ Boolean Also known as: required?
If true, the client must understand and comply with the extension's
requirements.
Corresponds to the JSON property required
4574 4575 4576 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4574 def required @required end |
#uri ⇒ String
The unique URI identifying the extension.
Corresponds to the JSON property uri
4580 4581 4582 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4580 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4587 4588 4589 4590 4591 4592 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4587 def update!(**args) @description = args[:description] if args.key?(:description) @params = args[:params] if args.key?(:params) @required = args[:required] if args.key?(:required) @uri = args[:uri] if args.key?(:uri) end |