Class: Google::Apis::CesV1::LfA2aV1AgentInterface
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::LfA2aV1AgentInterface
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Declares a combination of a target URL, transport and protocol version for interacting with the agent. This allows agents to expose the same functionality over multiple protocol binding mechanisms.
Instance Attribute Summary collapse
-
#protocol_binding ⇒ String
Required.
-
#protocol_version ⇒ String
Required.
-
#tenant ⇒ String
Tenant ID to be used in the request when calling the agent.
-
#url ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LfA2aV1AgentInterface
constructor
A new instance of LfA2aV1AgentInterface.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LfA2aV1AgentInterface
Returns a new instance of LfA2aV1AgentInterface.
4626 4627 4628 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4626 def initialize(**args) update!(**args) end |
Instance Attribute Details
#protocol_binding ⇒ String
Required. The protocol binding supported at this URL. This is an open form
string, to be easily extended for other protocol bindings. The core ones
officially supported are JSONRPC, GRPC and HTTP+JSON.
Corresponds to the JSON property protocolBinding
4606 4607 4608 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4606 def protocol_binding @protocol_binding end |
#protocol_version ⇒ String
Required. The version of the A2A protocol this interface exposes. Use the
latest supported minor version per major version. Examples: "0.3", "1.0"
Corresponds to the JSON property protocolVersion
4612 4613 4614 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4612 def protocol_version @protocol_version end |
#tenant ⇒ String
Tenant ID to be used in the request when calling the agent.
Corresponds to the JSON property tenant
4617 4618 4619 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4617 def tenant @tenant end |
#url ⇒ String
Required. The URL where this interface is available. Must be a valid absolute
HTTPS URL in production. Example: "https://api.example.com/a2a/v1", "https://
grpc.example.com/a2a"
Corresponds to the JSON property url
4624 4625 4626 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4624 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4631 4632 4633 4634 4635 4636 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4631 def update!(**args) @protocol_binding = args[:protocol_binding] if args.key?(:protocol_binding) @protocol_version = args[:protocol_version] if args.key?(:protocol_version) @tenant = args[:tenant] if args.key?(:tenant) @url = args[:url] if args.key?(:url) end |