Class: Google::Apis::CesV1::LfA2aV1AgentSkill

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Represents a distinct capability or function that an agent can perform.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LfA2aV1AgentSkill

Returns a new instance of LfA2aV1AgentSkill.



4772
4773
4774
# File 'lib/google/apis/ces_v1/classes.rb', line 4772

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Required. A detailed description of the skill. Corresponds to the JSON property description

Returns:

  • (String)


4733
4734
4735
# File 'lib/google/apis/ces_v1/classes.rb', line 4733

def description
  @description
end

#examplesArray<String>

Example prompts or scenarios that this skill can handle. Corresponds to the JSON property examples

Returns:

  • (Array<String>)


4738
4739
4740
# File 'lib/google/apis/ces_v1/classes.rb', line 4738

def examples
  @examples
end

#idString

Required. A unique identifier for the agent's skill. Corresponds to the JSON property id

Returns:

  • (String)


4743
4744
4745
# File 'lib/google/apis/ces_v1/classes.rb', line 4743

def id
  @id
end

#input_modesArray<String>

The set of supported input media types for this skill, overriding the agent's defaults. Corresponds to the JSON property inputModes

Returns:

  • (Array<String>)


4749
4750
4751
# File 'lib/google/apis/ces_v1/classes.rb', line 4749

def input_modes
  @input_modes
end

#nameString

Required. A human-readable name for the skill. Corresponds to the JSON property name

Returns:

  • (String)


4754
4755
4756
# File 'lib/google/apis/ces_v1/classes.rb', line 4754

def name
  @name
end

#output_modesArray<String>

The set of supported output media types for this skill, overriding the agent's defaults. Corresponds to the JSON property outputModes

Returns:

  • (Array<String>)


4760
4761
4762
# File 'lib/google/apis/ces_v1/classes.rb', line 4760

def output_modes
  @output_modes
end

#security_requirementsArray<Google::Apis::CesV1::LfA2aV1SecurityRequirement>

Security schemes necessary for this skill. Corresponds to the JSON property securityRequirements



4765
4766
4767
# File 'lib/google/apis/ces_v1/classes.rb', line 4765

def security_requirements
  @security_requirements
end

#tagsArray<String>

Required. A set of keywords describing the skill's capabilities. Corresponds to the JSON property tags

Returns:

  • (Array<String>)


4770
4771
4772
# File 'lib/google/apis/ces_v1/classes.rb', line 4770

def tags
  @tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4777
4778
4779
4780
4781
4782
4783
4784
4785
4786
# File 'lib/google/apis/ces_v1/classes.rb', line 4777

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @examples = args[:examples] if args.key?(:examples)
  @id = args[:id] if args.key?(:id)
  @input_modes = args[:input_modes] if args.key?(:input_modes)
  @name = args[:name] if args.key?(:name)
  @output_modes = args[:output_modes] if args.key?(:output_modes)
  @security_requirements = args[:security_requirements] if args.key?(:security_requirements)
  @tags = args[:tags] if args.key?(:tags)
end