Class: Google::Apis::CesV1::LfA2aV1AgentSkill
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::LfA2aV1AgentSkill
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Represents a distinct capability or function that an agent can perform.
Instance Attribute Summary collapse
-
#description ⇒ String
Required.
-
#examples ⇒ Array<String>
Example prompts or scenarios that this skill can handle.
-
#id ⇒ String
Required.
-
#input_modes ⇒ Array<String>
The set of supported input media types for this skill, overriding the agent's defaults.
-
#name ⇒ String
Required.
-
#output_modes ⇒ Array<String>
The set of supported output media types for this skill, overriding the agent's defaults.
-
#security_requirements ⇒ Array<Google::Apis::CesV1::LfA2aV1SecurityRequirement>
Security schemes necessary for this skill.
-
#tags ⇒ Array<String>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LfA2aV1AgentSkill
constructor
A new instance of LfA2aV1AgentSkill.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LfA2aV1AgentSkill
Returns a new instance of LfA2aV1AgentSkill.
4730 4731 4732 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4730 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Required. A detailed description of the skill.
Corresponds to the JSON property description
4691 4692 4693 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4691 def description @description end |
#examples ⇒ Array<String>
Example prompts or scenarios that this skill can handle.
Corresponds to the JSON property examples
4696 4697 4698 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4696 def examples @examples end |
#id ⇒ String
Required. A unique identifier for the agent's skill.
Corresponds to the JSON property id
4701 4702 4703 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4701 def id @id end |
#input_modes ⇒ Array<String>
The set of supported input media types for this skill, overriding the agent's
defaults.
Corresponds to the JSON property inputModes
4707 4708 4709 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4707 def input_modes @input_modes end |
#name ⇒ String
Required. A human-readable name for the skill.
Corresponds to the JSON property name
4712 4713 4714 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4712 def name @name end |
#output_modes ⇒ Array<String>
The set of supported output media types for this skill, overriding the agent's
defaults.
Corresponds to the JSON property outputModes
4718 4719 4720 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4718 def output_modes @output_modes end |
#security_requirements ⇒ Array<Google::Apis::CesV1::LfA2aV1SecurityRequirement>
Security schemes necessary for this skill.
Corresponds to the JSON property securityRequirements
4723 4724 4725 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4723 def security_requirements @security_requirements end |
#tags ⇒ Array<String>
Required. A set of keywords describing the skill's capabilities.
Corresponds to the JSON property tags
4728 4729 4730 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4728 def @tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4735 4736 4737 4738 4739 4740 4741 4742 4743 4744 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4735 def update!(**args) @description = args[:description] if args.key?(:description) @examples = args[:examples] if args.key?(:examples) @id = args[:id] if args.key?(:id) @input_modes = args[:input_modes] if args.key?(:input_modes) @name = args[:name] if args.key?(:name) @output_modes = args[:output_modes] if args.key?(:output_modes) @security_requirements = args[:security_requirements] if args.key?(:security_requirements) @tags = args[:tags] if args.key?(:tags) end |