Class: Google::Apis::CesV1::LfA2aV1AgentSkill
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::LfA2aV1AgentSkill
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Represents a distinct capability or function that an agent can perform.
Instance Attribute Summary collapse
-
#description ⇒ String
Required.
-
#examples ⇒ Array<String>
Example prompts or scenarios that this skill can handle.
-
#id ⇒ String
Required.
-
#input_modes ⇒ Array<String>
The set of supported input media types for this skill, overriding the agent's defaults.
-
#name ⇒ String
Required.
-
#output_modes ⇒ Array<String>
The set of supported output media types for this skill, overriding the agent's defaults.
-
#security_requirements ⇒ Array<Google::Apis::CesV1::LfA2aV1SecurityRequirement>
Security schemes necessary for this skill.
-
#tags ⇒ Array<String>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LfA2aV1AgentSkill
constructor
A new instance of LfA2aV1AgentSkill.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LfA2aV1AgentSkill
Returns a new instance of LfA2aV1AgentSkill.
4711 4712 4713 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4711 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Required. A detailed description of the skill.
Corresponds to the JSON property description
4672 4673 4674 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4672 def description @description end |
#examples ⇒ Array<String>
Example prompts or scenarios that this skill can handle.
Corresponds to the JSON property examples
4677 4678 4679 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4677 def examples @examples end |
#id ⇒ String
Required. A unique identifier for the agent's skill.
Corresponds to the JSON property id
4682 4683 4684 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4682 def id @id end |
#input_modes ⇒ Array<String>
The set of supported input media types for this skill, overriding the agent's
defaults.
Corresponds to the JSON property inputModes
4688 4689 4690 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4688 def input_modes @input_modes end |
#name ⇒ String
Required. A human-readable name for the skill.
Corresponds to the JSON property name
4693 4694 4695 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4693 def name @name end |
#output_modes ⇒ Array<String>
The set of supported output media types for this skill, overriding the agent's
defaults.
Corresponds to the JSON property outputModes
4699 4700 4701 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4699 def output_modes @output_modes end |
#security_requirements ⇒ Array<Google::Apis::CesV1::LfA2aV1SecurityRequirement>
Security schemes necessary for this skill.
Corresponds to the JSON property securityRequirements
4704 4705 4706 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4704 def security_requirements @security_requirements end |
#tags ⇒ Array<String>
Required. A set of keywords describing the skill's capabilities.
Corresponds to the JSON property tags
4709 4710 4711 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4709 def @tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4716 4717 4718 4719 4720 4721 4722 4723 4724 4725 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4716 def update!(**args) @description = args[:description] if args.key?(:description) @examples = args[:examples] if args.key?(:examples) @id = args[:id] if args.key?(:id) @input_modes = args[:input_modes] if args.key?(:input_modes) @name = args[:name] if args.key?(:name) @output_modes = args[:output_modes] if args.key?(:output_modes) @security_requirements = args[:security_requirements] if args.key?(:security_requirements) @tags = args[:tags] if args.key?(:tags) end |