Class: Google::Apis::CesV1::LfA2aV1Artifact
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::LfA2aV1Artifact
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Artifacts represent task outputs.
Instance Attribute Summary collapse
-
#artifact_id ⇒ String
Required.
-
#description ⇒ String
Optional.
-
#extensions ⇒ Array<String>
The URIs of extensions that are present or contributed to this Artifact.
-
#metadata ⇒ Hash<String,Object>
Optional.
-
#name ⇒ String
A human readable name for the artifact.
-
#parts ⇒ Array<Google::Apis::CesV1::LfA2aV1Part>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LfA2aV1Artifact
constructor
A new instance of LfA2aV1Artifact.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LfA2aV1Artifact
Returns a new instance of LfA2aV1Artifact.
4782 4783 4784 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4782 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_id ⇒ String
Required. Unique identifier (e.g. UUID) for the artifact. It must be unique
within a task.
Corresponds to the JSON property artifactId
4755 4756 4757 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4755 def artifact_id @artifact_id end |
#description ⇒ String
Optional. A human readable description of the artifact.
Corresponds to the JSON property description
4760 4761 4762 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4760 def description @description end |
#extensions ⇒ Array<String>
The URIs of extensions that are present or contributed to this Artifact.
Corresponds to the JSON property extensions
4765 4766 4767 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4765 def extensions @extensions end |
#metadata ⇒ Hash<String,Object>
Optional. Metadata included with the artifact.
Corresponds to the JSON property metadata
4770 4771 4772 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4770 def @metadata end |
#name ⇒ String
A human readable name for the artifact.
Corresponds to the JSON property name
4775 4776 4777 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4775 def name @name end |
#parts ⇒ Array<Google::Apis::CesV1::LfA2aV1Part>
Required. The content of the artifact. Must contain at least one part.
Corresponds to the JSON property parts
4780 4781 4782 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4780 def parts @parts end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4787 4788 4789 4790 4791 4792 4793 4794 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4787 def update!(**args) @artifact_id = args[:artifact_id] if args.key?(:artifact_id) @description = args[:description] if args.key?(:description) @extensions = args[:extensions] if args.key?(:extensions) @metadata = args[:metadata] if args.key?(:metadata) @name = args[:name] if args.key?(:name) @parts = args[:parts] if args.key?(:parts) end |