Class: Google::Apis::CesV1::LfA2aV1Artifact
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::LfA2aV1Artifact
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Artifacts represent task outputs.
Instance Attribute Summary collapse
-
#artifact_id ⇒ String
Required.
-
#description ⇒ String
Optional.
-
#extensions ⇒ Array<String>
The URIs of extensions that are present or contributed to this Artifact.
-
#metadata ⇒ Hash<String,Object>
Optional.
-
#name ⇒ String
A human readable name for the artifact.
-
#parts ⇒ Array<Google::Apis::CesV1::LfA2aV1Part>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LfA2aV1Artifact
constructor
A new instance of LfA2aV1Artifact.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LfA2aV1Artifact
Returns a new instance of LfA2aV1Artifact.
4233 4234 4235 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4233 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact_id ⇒ String
Required. Unique identifier (e.g. UUID) for the artifact. It must be unique
within a task.
Corresponds to the JSON property artifactId
4206 4207 4208 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4206 def artifact_id @artifact_id end |
#description ⇒ String
Optional. A human readable description of the artifact.
Corresponds to the JSON property description
4211 4212 4213 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4211 def description @description end |
#extensions ⇒ Array<String>
The URIs of extensions that are present or contributed to this Artifact.
Corresponds to the JSON property extensions
4216 4217 4218 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4216 def extensions @extensions end |
#metadata ⇒ Hash<String,Object>
Optional. Metadata included with the artifact.
Corresponds to the JSON property metadata
4221 4222 4223 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4221 def @metadata end |
#name ⇒ String
A human readable name for the artifact.
Corresponds to the JSON property name
4226 4227 4228 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4226 def name @name end |
#parts ⇒ Array<Google::Apis::CesV1::LfA2aV1Part>
Required. The content of the artifact. Must contain at least one part.
Corresponds to the JSON property parts
4231 4232 4233 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4231 def parts @parts end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4238 4239 4240 4241 4242 4243 4244 4245 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4238 def update!(**args) @artifact_id = args[:artifact_id] if args.key?(:artifact_id) @description = args[:description] if args.key?(:description) @extensions = args[:extensions] if args.key?(:extensions) @metadata = args[:metadata] if args.key?(:metadata) @name = args[:name] if args.key?(:name) @parts = args[:parts] if args.key?(:parts) end |