Class: Google::Apis::CesV1::LfA2aV1HttpAuthSecurityScheme

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Defines a security scheme using HTTP authentication.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LfA2aV1HttpAuthSecurityScheme

Returns a new instance of LfA2aV1HttpAuthSecurityScheme.



5005
5006
5007
# File 'lib/google/apis/ces_v1/classes.rb', line 5005

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bearer_formatString

A hint to the client to identify how the bearer token is formatted (e.g., "JWT" ). Primarily for documentation purposes. Corresponds to the JSON property bearerFormat

Returns:

  • (String)


4991
4992
4993
# File 'lib/google/apis/ces_v1/classes.rb', line 4991

def bearer_format
  @bearer_format
end

#descriptionString

An optional description for the security scheme. Corresponds to the JSON property description

Returns:

  • (String)


4996
4997
4998
# File 'lib/google/apis/ces_v1/classes.rb', line 4996

def description
  @description
end

#schemeString

Required. The name of the HTTP Authentication scheme to be used in the Authorization header, as defined in RFC7235 (e.g., "Bearer"). This value should be registered in the IANA Authentication Scheme registry. Corresponds to the JSON property scheme

Returns:

  • (String)


5003
5004
5005
# File 'lib/google/apis/ces_v1/classes.rb', line 5003

def scheme
  @scheme
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5010
5011
5012
5013
5014
# File 'lib/google/apis/ces_v1/classes.rb', line 5010

def update!(**args)
  @bearer_format = args[:bearer_format] if args.key?(:bearer_format)
  @description = args[:description] if args.key?(:description)
  @scheme = args[:scheme] if args.key?(:scheme)
end