Class: Google::Apis::CesV1::LfA2aV1HttpAuthSecurityScheme

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Defines a security scheme using HTTP authentication.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LfA2aV1HttpAuthSecurityScheme

Returns a new instance of LfA2aV1HttpAuthSecurityScheme.



4963
4964
4965
# File 'lib/google/apis/ces_v1/classes.rb', line 4963

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bearer_formatString

A hint to the client to identify how the bearer token is formatted (e.g., "JWT" ). Primarily for documentation purposes. Corresponds to the JSON property bearerFormat

Returns:

  • (String)


4949
4950
4951
# File 'lib/google/apis/ces_v1/classes.rb', line 4949

def bearer_format
  @bearer_format
end

#descriptionString

An optional description for the security scheme. Corresponds to the JSON property description

Returns:

  • (String)


4954
4955
4956
# File 'lib/google/apis/ces_v1/classes.rb', line 4954

def description
  @description
end

#schemeString

Required. The name of the HTTP Authentication scheme to be used in the Authorization header, as defined in RFC7235 (e.g., "Bearer"). This value should be registered in the IANA Authentication Scheme registry. Corresponds to the JSON property scheme

Returns:

  • (String)


4961
4962
4963
# File 'lib/google/apis/ces_v1/classes.rb', line 4961

def scheme
  @scheme
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4968
4969
4970
4971
4972
# File 'lib/google/apis/ces_v1/classes.rb', line 4968

def update!(**args)
  @bearer_format = args[:bearer_format] if args.key?(:bearer_format)
  @description = args[:description] if args.key?(:description)
  @scheme = args[:scheme] if args.key?(:scheme)
end