Class: Google::Apis::CesV1::LfA2aV1SecurityRequirement
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::LfA2aV1SecurityRequirement
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Defines the security requirements for an agent.
Instance Attribute Summary collapse
-
#schemes ⇒ Hash<String,Google::Apis::CesV1::LfA2aV1StringList>
A map of security schemes to the required scopes.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LfA2aV1SecurityRequirement
constructor
A new instance of LfA2aV1SecurityRequirement.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LfA2aV1SecurityRequirement
Returns a new instance of LfA2aV1SecurityRequirement.
5285 5286 5287 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5285 def initialize(**args) update!(**args) end |
Instance Attribute Details
#schemes ⇒ Hash<String,Google::Apis::CesV1::LfA2aV1StringList>
A map of security schemes to the required scopes.
Corresponds to the JSON property schemes
5283 5284 5285 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5283 def schemes @schemes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5290 5291 5292 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5290 def update!(**args) @schemes = args[:schemes] if args.key?(:schemes) end |