Class: Google::Apis::CesV1::LfA2aV1SecurityScheme

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Defines a security scheme that can be used to secure an agent's endpoints. This is a discriminated union type based on the OpenAPI 3.2 Security Scheme Object. See: https://spec.openapis.org/oas/v3.2.0.html#security-scheme-object

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LfA2aV1SecurityScheme

Returns a new instance of LfA2aV1SecurityScheme.



5345
5346
5347
# File 'lib/google/apis/ces_v1/classes.rb', line 5345

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_key_security_schemeGoogle::Apis::CesV1::LfA2aV1ApiKeySecurityScheme

Defines a security scheme using an API key. Corresponds to the JSON property apiKeySecurityScheme



5323
5324
5325
# File 'lib/google/apis/ces_v1/classes.rb', line 5323

def api_key_security_scheme
  @api_key_security_scheme
end

#http_auth_security_schemeGoogle::Apis::CesV1::LfA2aV1HttpAuthSecurityScheme

Defines a security scheme using HTTP authentication. Corresponds to the JSON property httpAuthSecurityScheme



5328
5329
5330
# File 'lib/google/apis/ces_v1/classes.rb', line 5328

def http_auth_security_scheme
  @http_auth_security_scheme
end

#mtls_security_schemeGoogle::Apis::CesV1::LfA2aV1MutualTlsSecurityScheme

Defines a security scheme using mTLS authentication. Corresponds to the JSON property mtlsSecurityScheme



5333
5334
5335
# File 'lib/google/apis/ces_v1/classes.rb', line 5333

def mtls_security_scheme
  @mtls_security_scheme
end

#oauth2_security_schemeGoogle::Apis::CesV1::LfA2aV1OAuth2SecurityScheme

Defines a security scheme using OAuth 2.0. Corresponds to the JSON property oauth2SecurityScheme



5338
5339
5340
# File 'lib/google/apis/ces_v1/classes.rb', line 5338

def oauth2_security_scheme
  @oauth2_security_scheme
end

#open_id_connect_security_schemeGoogle::Apis::CesV1::LfA2aV1OpenIdConnectSecurityScheme

Defines a security scheme using OpenID Connect. Corresponds to the JSON property openIdConnectSecurityScheme



5343
5344
5345
# File 'lib/google/apis/ces_v1/classes.rb', line 5343

def open_id_connect_security_scheme
  @open_id_connect_security_scheme
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5350
5351
5352
5353
5354
5355
5356
# File 'lib/google/apis/ces_v1/classes.rb', line 5350

def update!(**args)
  @api_key_security_scheme = args[:api_key_security_scheme] if args.key?(:api_key_security_scheme)
  @http_auth_security_scheme = args[:http_auth_security_scheme] if args.key?(:http_auth_security_scheme)
  @mtls_security_scheme = args[:mtls_security_scheme] if args.key?(:mtls_security_scheme)
  @oauth2_security_scheme = args[:oauth2_security_scheme] if args.key?(:oauth2_security_scheme)
  @open_id_connect_security_scheme = args[:open_id_connect_security_scheme] if args.key?(:open_id_connect_security_scheme)
end