Class: Google::Apis::CesV1::LfA2aV1SecurityScheme

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Defines a security scheme that can be used to secure an agent's endpoints. This is a discriminated union type based on the OpenAPI 3.2 Security Scheme Object. See: https://spec.openapis.org/oas/v3.2.0.html#security-scheme-object

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LfA2aV1SecurityScheme

Returns a new instance of LfA2aV1SecurityScheme.



5326
5327
5328
# File 'lib/google/apis/ces_v1/classes.rb', line 5326

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_key_security_schemeGoogle::Apis::CesV1::LfA2aV1ApiKeySecurityScheme

Defines a security scheme using an API key. Corresponds to the JSON property apiKeySecurityScheme



5304
5305
5306
# File 'lib/google/apis/ces_v1/classes.rb', line 5304

def api_key_security_scheme
  @api_key_security_scheme
end

#http_auth_security_schemeGoogle::Apis::CesV1::LfA2aV1HttpAuthSecurityScheme

Defines a security scheme using HTTP authentication. Corresponds to the JSON property httpAuthSecurityScheme



5309
5310
5311
# File 'lib/google/apis/ces_v1/classes.rb', line 5309

def http_auth_security_scheme
  @http_auth_security_scheme
end

#mtls_security_schemeGoogle::Apis::CesV1::LfA2aV1MutualTlsSecurityScheme

Defines a security scheme using mTLS authentication. Corresponds to the JSON property mtlsSecurityScheme



5314
5315
5316
# File 'lib/google/apis/ces_v1/classes.rb', line 5314

def mtls_security_scheme
  @mtls_security_scheme
end

#oauth2_security_schemeGoogle::Apis::CesV1::LfA2aV1OAuth2SecurityScheme

Defines a security scheme using OAuth 2.0. Corresponds to the JSON property oauth2SecurityScheme



5319
5320
5321
# File 'lib/google/apis/ces_v1/classes.rb', line 5319

def oauth2_security_scheme
  @oauth2_security_scheme
end

#open_id_connect_security_schemeGoogle::Apis::CesV1::LfA2aV1OpenIdConnectSecurityScheme

Defines a security scheme using OpenID Connect. Corresponds to the JSON property openIdConnectSecurityScheme



5324
5325
5326
# File 'lib/google/apis/ces_v1/classes.rb', line 5324

def open_id_connect_security_scheme
  @open_id_connect_security_scheme
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5331
5332
5333
5334
5335
5336
5337
# File 'lib/google/apis/ces_v1/classes.rb', line 5331

def update!(**args)
  @api_key_security_scheme = args[:api_key_security_scheme] if args.key?(:api_key_security_scheme)
  @http_auth_security_scheme = args[:http_auth_security_scheme] if args.key?(:http_auth_security_scheme)
  @mtls_security_scheme = args[:mtls_security_scheme] if args.key?(:mtls_security_scheme)
  @oauth2_security_scheme = args[:oauth2_security_scheme] if args.key?(:oauth2_security_scheme)
  @open_id_connect_security_scheme = args[:open_id_connect_security_scheme] if args.key?(:open_id_connect_security_scheme)
end