Class: Google::Apis::CesV1::LfA2aV1SendMessageConfiguration

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Configuration of a send message request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LfA2aV1SendMessageConfiguration

Returns a new instance of LfA2aV1SendMessageConfiguration.



5373
5374
5375
# File 'lib/google/apis/ces_v1/classes.rb', line 5373

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accepted_output_modesArray<String>

A list of media types the client is prepared to accept for response parts. Agents SHOULD use this to tailor their output. Corresponds to the JSON property acceptedOutputModes

Returns:

  • (Array<String>)


5348
5349
5350
# File 'lib/google/apis/ces_v1/classes.rb', line 5348

def accepted_output_modes
  @accepted_output_modes
end

#history_lengthFixnum

The maximum number of most recent messages from the task's history to retrieve in the response. An unset value means the client does not impose any limit. A value of zero is a request to not include any messages. The server MUST NOT return more messages than the provided value, but MAY apply a lower limit. Corresponds to the JSON property historyLength

Returns:

  • (Fixnum)


5356
5357
5358
# File 'lib/google/apis/ces_v1/classes.rb', line 5356

def history_length
  @history_length
end

#return_immediatelyBoolean Also known as: return_immediately?

If true, the operation returns immediately after creating the task, even if processing is still in progress. If false (default), the operation MUST wait until the task reaches a terminal (COMPLETED, FAILED, CANCELED, REJECTED) or interrupted (INPUT_REQUIRED, AUTH_REQUIRED) state before returning. Corresponds to the JSON property returnImmediately

Returns:

  • (Boolean)


5365
5366
5367
# File 'lib/google/apis/ces_v1/classes.rb', line 5365

def return_immediately
  @return_immediately
end

#task_push_notification_configGoogle::Apis::CesV1::LfA2aV1TaskPushNotificationConfig

A container associating a push notification configuration with a specific task. Corresponds to the JSON property taskPushNotificationConfig



5371
5372
5373
# File 'lib/google/apis/ces_v1/classes.rb', line 5371

def task_push_notification_config
  @task_push_notification_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5378
5379
5380
5381
5382
5383
# File 'lib/google/apis/ces_v1/classes.rb', line 5378

def update!(**args)
  @accepted_output_modes = args[:accepted_output_modes] if args.key?(:accepted_output_modes)
  @history_length = args[:history_length] if args.key?(:history_length)
  @return_immediately = args[:return_immediately] if args.key?(:return_immediately)
  @task_push_notification_config = args[:task_push_notification_config] if args.key?(:task_push_notification_config)
end