Class: Google::Apis::CesV1::LfA2aV1SendMessageRequest
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::LfA2aV1SendMessageRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Represents a request for the SendMessage method.
Instance Attribute Summary collapse
-
#configuration ⇒ Google::Apis::CesV1::LfA2aV1SendMessageConfiguration
Configuration of a send message request.
-
#message ⇒ Google::Apis::CesV1::LfA2aV1Message
Messageis one unit of communication between client and server. -
#metadata ⇒ Hash<String,Object>
A flexible key-value map for passing additional context or parameters.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LfA2aV1SendMessageRequest
constructor
A new instance of LfA2aV1SendMessageRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LfA2aV1SendMessageRequest
Returns a new instance of LfA2aV1SendMessageRequest.
4477 4478 4479 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4477 def initialize(**args) update!(**args) end |
Instance Attribute Details
#configuration ⇒ Google::Apis::CesV1::LfA2aV1SendMessageConfiguration
Configuration of a send message request.
Corresponds to the JSON property configuration
4460 4461 4462 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4460 def configuration @configuration end |
#message ⇒ Google::Apis::CesV1::LfA2aV1Message
Message is one unit of communication between client and server. It can be
associated with a context and/or a task. For server messages, context_id
must be provided, and task_id only if a task was created. For client
messages, both fields are optional, with the caveat that if both are provided,
they have to match (the context_id has to be the one that is set on the task)
. If only task_id is provided, the server will infer context_id from it.
Corresponds to the JSON property message
4470 4471 4472 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4470 def @message end |
#metadata ⇒ Hash<String,Object>
A flexible key-value map for passing additional context or parameters.
Corresponds to the JSON property metadata
4475 4476 4477 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4475 def @metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4482 4483 4484 4485 4486 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4482 def update!(**args) @configuration = args[:configuration] if args.key?(:configuration) @message = args[:message] if args.key?(:message) @metadata = args[:metadata] if args.key?(:metadata) end |