Class: Google::Apis::CesV1::LfA2aV1SendMessageResponse
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::LfA2aV1SendMessageResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Represents the response for the SendMessage method.
Instance Attribute Summary collapse
-
#message ⇒ Google::Apis::CesV1::LfA2aV1Message
Messageis one unit of communication between client and server. -
#task ⇒ Google::Apis::CesV1::LfA2aV1Task
Taskis the core unit of action for A2A.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LfA2aV1SendMessageResponse
constructor
A new instance of LfA2aV1SendMessageResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LfA2aV1SendMessageResponse
Returns a new instance of LfA2aV1SendMessageResponse.
4510 4511 4512 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4510 def initialize(**args) update!(**args) end |
Instance Attribute Details
#message ⇒ Google::Apis::CesV1::LfA2aV1Message
Message is one unit of communication between client and server. It can be
associated with a context and/or a task. For server messages, context_id
must be provided, and task_id only if a task was created. For client
messages, both fields are optional, with the caveat that if both are provided,
they have to match (the context_id has to be the one that is set on the task)
. If only task_id is provided, the server will infer context_id from it.
Corresponds to the JSON property message
4501 4502 4503 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4501 def @message end |
#task ⇒ Google::Apis::CesV1::LfA2aV1Task
Task is the core unit of action for A2A. It has a current status and when
results are created for the task they are stored in the artifact. If there are
multiple turns for a task, these are stored in history.
Corresponds to the JSON property task
4508 4509 4510 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4508 def task @task end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4515 4516 4517 4518 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4515 def update!(**args) @message = args[:message] if args.key?(:message) @task = args[:task] if args.key?(:task) end |