Class: Google::Apis::CesV1::LfA2aV1Task
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::LfA2aV1Task
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Task is the core unit of action for A2A. It has a current status and when
results are created for the task they are stored in the artifact. If there are
multiple turns for a task, these are stored in history.
Instance Attribute Summary collapse
-
#artifacts ⇒ Array<Google::Apis::CesV1::LfA2aV1Artifact>
A set of output artifacts for a
Task. -
#context_id ⇒ String
Unique identifier (e.g. UUID) for the contextual collection of interactions ( tasks and messages).
-
#history ⇒ Array<Google::Apis::CesV1::LfA2aV1Message>
protolint:disable REPEATED_FIELD_NAMES_PLURALIZED The history of interactions from a
Task. -
#id ⇒ String
Required.
-
#metadata ⇒ Hash<String,Object>
protolint:enable REPEATED_FIELD_NAMES_PLURALIZED A key/value object to store custom metadata about a task.
-
#status ⇒ Google::Apis::CesV1::LfA2aV1TaskStatus
A container for the status of a task Corresponds to the JSON property
status.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LfA2aV1Task
constructor
A new instance of LfA2aV1Task.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LfA2aV1Task
Returns a new instance of LfA2aV1Task.
5574 5575 5576 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5574 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifacts ⇒ Array<Google::Apis::CesV1::LfA2aV1Artifact>
A set of output artifacts for a Task.
Corresponds to the JSON property artifacts
5543 5544 5545 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5543 def artifacts @artifacts end |
#context_id ⇒ String
Unique identifier (e.g. UUID) for the contextual collection of interactions (
tasks and messages).
Corresponds to the JSON property contextId
5549 5550 5551 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5549 def context_id @context_id end |
#history ⇒ Array<Google::Apis::CesV1::LfA2aV1Message>
protolint:disable REPEATED_FIELD_NAMES_PLURALIZED The history of interactions
from a Task.
Corresponds to the JSON property history
5555 5556 5557 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5555 def history @history end |
#id ⇒ String
Required. Unique identifier (e.g. UUID) for the task, generated by the server
for a new task.
Corresponds to the JSON property id
5561 5562 5563 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5561 def id @id end |
#metadata ⇒ Hash<String,Object>
protolint:enable REPEATED_FIELD_NAMES_PLURALIZED A key/value object to store
custom metadata about a task.
Corresponds to the JSON property metadata
5567 5568 5569 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5567 def @metadata end |
#status ⇒ Google::Apis::CesV1::LfA2aV1TaskStatus
A container for the status of a task
Corresponds to the JSON property status
5572 5573 5574 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5572 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5579 5580 5581 5582 5583 5584 5585 5586 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5579 def update!(**args) @artifacts = args[:artifacts] if args.key?(:artifacts) @context_id = args[:context_id] if args.key?(:context_id) @history = args[:history] if args.key?(:history) @id = args[:id] if args.key?(:id) @metadata = args[:metadata] if args.key?(:metadata) @status = args[:status] if args.key?(:status) end |