Class: Google::Apis::CesV1::LfA2aV1Task

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Task is the core unit of action for A2A. It has a current status and when results are created for the task they are stored in the artifact. If there are multiple turns for a task, these are stored in history.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LfA2aV1Task

Returns a new instance of LfA2aV1Task.



4561
4562
4563
# File 'lib/google/apis/ces_v1/classes.rb', line 4561

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#artifactsArray<Google::Apis::CesV1::LfA2aV1Artifact>

A set of output artifacts for a Task. Corresponds to the JSON property artifacts



4530
4531
4532
# File 'lib/google/apis/ces_v1/classes.rb', line 4530

def artifacts
  @artifacts
end

#context_idString

Unique identifier (e.g. UUID) for the contextual collection of interactions ( tasks and messages). Corresponds to the JSON property contextId

Returns:

  • (String)


4536
4537
4538
# File 'lib/google/apis/ces_v1/classes.rb', line 4536

def context_id
  @context_id
end

#historyArray<Google::Apis::CesV1::LfA2aV1Message>

protolint:disable REPEATED_FIELD_NAMES_PLURALIZED The history of interactions from a Task. Corresponds to the JSON property history



4542
4543
4544
# File 'lib/google/apis/ces_v1/classes.rb', line 4542

def history
  @history
end

#idString

Required. Unique identifier (e.g. UUID) for the task, generated by the server for a new task. Corresponds to the JSON property id

Returns:

  • (String)


4548
4549
4550
# File 'lib/google/apis/ces_v1/classes.rb', line 4548

def id
  @id
end

#metadataHash<String,Object>

protolint:enable REPEATED_FIELD_NAMES_PLURALIZED A key/value object to store custom metadata about a task. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,Object>)


4554
4555
4556
# File 'lib/google/apis/ces_v1/classes.rb', line 4554

def 
  @metadata
end

#statusGoogle::Apis::CesV1::LfA2aV1TaskStatus

A container for the status of a task Corresponds to the JSON property status



4559
4560
4561
# File 'lib/google/apis/ces_v1/classes.rb', line 4559

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4566
4567
4568
4569
4570
4571
4572
4573
# File 'lib/google/apis/ces_v1/classes.rb', line 4566

def update!(**args)
  @artifacts = args[:artifacts] if args.key?(:artifacts)
  @context_id = args[:context_id] if args.key?(:context_id)
  @history = args[:history] if args.key?(:history)
  @id = args[:id] if args.key?(:id)
  @metadata = args[:metadata] if args.key?(:metadata)
  @status = args[:status] if args.key?(:status)
end