Class: Google::Apis::CesV1::LfA2aV1TaskPushNotificationConfig
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::LfA2aV1TaskPushNotificationConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
A container associating a push notification configuration with a specific task.
Instance Attribute Summary collapse
-
#authentication ⇒ Google::Apis::CesV1::LfA2aV1AuthenticationInfo
Defines authentication details, used for push notifications.
-
#id ⇒ String
The push notification configuration details.
-
#task_id ⇒ String
The ID of the task this configuration is associated with.
-
#tenant ⇒ String
Optional.
-
#token ⇒ String
A token unique for this task or session.
-
#url ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LfA2aV1TaskPushNotificationConfig
constructor
A new instance of LfA2aV1TaskPushNotificationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LfA2aV1TaskPushNotificationConfig
Returns a new instance of LfA2aV1TaskPushNotificationConfig.
5641 5642 5643 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5641 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authentication ⇒ Google::Apis::CesV1::LfA2aV1AuthenticationInfo
Defines authentication details, used for push notifications.
Corresponds to the JSON property authentication
5612 5613 5614 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5612 def authentication @authentication end |
#id ⇒ String
The push notification configuration details. A unique identifier (e.g. UUID)
for this push notification configuration.
Corresponds to the JSON property id
5618 5619 5620 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5618 def id @id end |
#task_id ⇒ String
The ID of the task this configuration is associated with.
Corresponds to the JSON property taskId
5623 5624 5625 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5623 def task_id @task_id end |
#tenant ⇒ String
Optional. Opaque routing identifier. Must match the tenant value from the
selected AgentInterface in the Agent Card when that field is set.
Corresponds to the JSON property tenant
5629 5630 5631 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5629 def tenant @tenant end |
#token ⇒ String
A token unique for this task or session.
Corresponds to the JSON property token
5634 5635 5636 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5634 def token @token end |
#url ⇒ String
Required. The URL where the notification should be sent.
Corresponds to the JSON property url
5639 5640 5641 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5639 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5646 5647 5648 5649 5650 5651 5652 5653 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5646 def update!(**args) @authentication = args[:authentication] if args.key?(:authentication) @id = args[:id] if args.key?(:id) @task_id = args[:task_id] if args.key?(:task_id) @tenant = args[:tenant] if args.key?(:tenant) @token = args[:token] if args.key?(:token) @url = args[:url] if args.key?(:url) end |