Class: Google::Apis::CesV1::LfA2aV1TaskPushNotificationConfig
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::LfA2aV1TaskPushNotificationConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
A container associating a push notification configuration with a specific task.
Instance Attribute Summary collapse
-
#authentication ⇒ Google::Apis::CesV1::LfA2aV1AuthenticationInfo
Defines authentication details, used for push notifications.
-
#id ⇒ String
The push notification configuration details.
-
#task_id ⇒ String
The ID of the task this configuration is associated with.
-
#tenant ⇒ String
Optional.
-
#token ⇒ String
A token unique for this task or session.
-
#url ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LfA2aV1TaskPushNotificationConfig
constructor
A new instance of LfA2aV1TaskPushNotificationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LfA2aV1TaskPushNotificationConfig
Returns a new instance of LfA2aV1TaskPushNotificationConfig.
5563 5564 5565 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5563 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authentication ⇒ Google::Apis::CesV1::LfA2aV1AuthenticationInfo
Defines authentication details, used for push notifications.
Corresponds to the JSON property authentication
5535 5536 5537 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5535 def authentication @authentication end |
#id ⇒ String
The push notification configuration details. A unique identifier (e.g. UUID)
for this push notification configuration.
Corresponds to the JSON property id
5541 5542 5543 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5541 def id @id end |
#task_id ⇒ String
The ID of the task this configuration is associated with.
Corresponds to the JSON property taskId
5546 5547 5548 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5546 def task_id @task_id end |
#tenant ⇒ String
Optional. Tenant ID.
Corresponds to the JSON property tenant
5551 5552 5553 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5551 def tenant @tenant end |
#token ⇒ String
A token unique for this task or session.
Corresponds to the JSON property token
5556 5557 5558 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5556 def token @token end |
#url ⇒ String
Required. The URL where the notification should be sent.
Corresponds to the JSON property url
5561 5562 5563 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5561 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5568 5569 5570 5571 5572 5573 5574 5575 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5568 def update!(**args) @authentication = args[:authentication] if args.key?(:authentication) @id = args[:id] if args.key?(:id) @task_id = args[:task_id] if args.key?(:task_id) @tenant = args[:tenant] if args.key?(:tenant) @token = args[:token] if args.key?(:token) @url = args[:url] if args.key?(:url) end |