Class: Google::Apis::CesV1::LfA2aV1TaskPushNotificationConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

A container associating a push notification configuration with a specific task.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LfA2aV1TaskPushNotificationConfig

Returns a new instance of LfA2aV1TaskPushNotificationConfig.



4611
4612
4613
# File 'lib/google/apis/ces_v1/classes.rb', line 4611

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authenticationGoogle::Apis::CesV1::LfA2aV1AuthenticationInfo

Defines authentication details, used for push notifications. Corresponds to the JSON property authentication



4583
4584
4585
# File 'lib/google/apis/ces_v1/classes.rb', line 4583

def authentication
  @authentication
end

#idString

The push notification configuration details. A unique identifier (e.g. UUID) for this push notification configuration. Corresponds to the JSON property id

Returns:

  • (String)


4589
4590
4591
# File 'lib/google/apis/ces_v1/classes.rb', line 4589

def id
  @id
end

#task_idString

The ID of the task this configuration is associated with. Corresponds to the JSON property taskId

Returns:

  • (String)


4594
4595
4596
# File 'lib/google/apis/ces_v1/classes.rb', line 4594

def task_id
  @task_id
end

#tenantString

Optional. Tenant ID. Corresponds to the JSON property tenant

Returns:

  • (String)


4599
4600
4601
# File 'lib/google/apis/ces_v1/classes.rb', line 4599

def tenant
  @tenant
end

#tokenString

A token unique for this task or session. Corresponds to the JSON property token

Returns:

  • (String)


4604
4605
4606
# File 'lib/google/apis/ces_v1/classes.rb', line 4604

def token
  @token
end

#urlString

Required. The URL where the notification should be sent. Corresponds to the JSON property url

Returns:

  • (String)


4609
4610
4611
# File 'lib/google/apis/ces_v1/classes.rb', line 4609

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4616
4617
4618
4619
4620
4621
4622
4623
# File 'lib/google/apis/ces_v1/classes.rb', line 4616

def update!(**args)
  @authentication = args[:authentication] if args.key?(:authentication)
  @id = args[:id] if args.key?(:id)
  @task_id = args[:task_id] if args.key?(:task_id)
  @tenant = args[:tenant] if args.key?(:tenant)
  @token = args[:token] if args.key?(:token)
  @url = args[:url] if args.key?(:url)
end