Class: Google::Apis::CesV1::LfA2aV1TaskStatus
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::LfA2aV1TaskStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
A container for the status of a task
Instance Attribute Summary collapse
-
#message ⇒ Google::Apis::CesV1::LfA2aV1Message
Messageis one unit of communication between client and server. -
#state ⇒ String
Required.
-
#timestamp ⇒ String
ISO 8601 Timestamp when the status was recorded.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LfA2aV1TaskStatus
constructor
A new instance of LfA2aV1TaskStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LfA2aV1TaskStatus
Returns a new instance of LfA2aV1TaskStatus.
4651 4652 4653 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4651 def initialize(**args) update!(**args) end |
Instance Attribute Details
#message ⇒ Google::Apis::CesV1::LfA2aV1Message
Message is one unit of communication between client and server. It can be
associated with a context and/or a task. For server messages, context_id
must be provided, and task_id only if a task was created. For client
messages, both fields are optional, with the caveat that if both are provided,
they have to match (the context_id has to be the one that is set on the task)
. If only task_id is provided, the server will infer context_id from it.
Corresponds to the JSON property message
4638 4639 4640 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4638 def @message end |
#state ⇒ String
Required. The current state of this task.
Corresponds to the JSON property state
4643 4644 4645 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4643 def state @state end |
#timestamp ⇒ String
ISO 8601 Timestamp when the status was recorded. Example: "2023-10-27T10:00:
00Z"
Corresponds to the JSON property timestamp
4649 4650 4651 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4649 def @timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4656 4657 4658 4659 4660 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4656 def update!(**args) @message = args[:message] if args.key?(:message) @state = args[:state] if args.key?(:state) @timestamp = args[:timestamp] if args.key?(:timestamp) end |