Class: Google::Apis::CesV1::LoggingSettings
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::LoggingSettings
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Settings to describe the logging behaviors for the app.
Instance Attribute Summary collapse
-
#audio_recording_config ⇒ Google::Apis::CesV1::AudioRecordingConfig
Configuration for how the audio interactions should be recorded.
-
#bigquery_export_settings ⇒ Google::Apis::CesV1::BigQueryExportSettings
Settings to describe the BigQuery export behaviors for the app.
-
#cloud_logging_settings ⇒ Google::Apis::CesV1::CloudLoggingSettings
Settings to describe the Cloud Logging behaviors for the app.
-
#conversation_logging_settings ⇒ Google::Apis::CesV1::ConversationLoggingSettings
Settings to describe the conversation logging behaviors for the app.
-
#evaluation_audio_recording_config ⇒ Google::Apis::CesV1::AudioRecordingConfig
Configuration for how the audio interactions should be recorded.
-
#metric_analysis_settings ⇒ Google::Apis::CesV1::MetricAnalysisSettings
Settings to describe the conversation data collection behaviors for LLM analysis metrics pipeline.
-
#redaction_config ⇒ Google::Apis::CesV1::RedactionConfig
Configuration to instruct how sensitive data should be handled.
-
#unredacted_audio_recording_config ⇒ Google::Apis::CesV1::AudioRecordingConfig
Configuration for how the audio interactions should be recorded.
-
#unredacted_bigquery_export_settings ⇒ Google::Apis::CesV1::BigQueryExportSettings
Settings to describe the BigQuery export behaviors for the app.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LoggingSettings
constructor
A new instance of LoggingSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LoggingSettings
Returns a new instance of LoggingSettings.
6099 6100 6101 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6099 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audio_recording_config ⇒ Google::Apis::CesV1::AudioRecordingConfig
Configuration for how the audio interactions should be recorded.
Corresponds to the JSON property audioRecordingConfig
6056 6057 6058 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6056 def audio_recording_config @audio_recording_config end |
#bigquery_export_settings ⇒ Google::Apis::CesV1::BigQueryExportSettings
Settings to describe the BigQuery export behaviors for the app.
Corresponds to the JSON property bigqueryExportSettings
6061 6062 6063 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6061 def bigquery_export_settings @bigquery_export_settings end |
#cloud_logging_settings ⇒ Google::Apis::CesV1::CloudLoggingSettings
Settings to describe the Cloud Logging behaviors for the app.
Corresponds to the JSON property cloudLoggingSettings
6066 6067 6068 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6066 def cloud_logging_settings @cloud_logging_settings end |
#conversation_logging_settings ⇒ Google::Apis::CesV1::ConversationLoggingSettings
Settings to describe the conversation logging behaviors for the app.
Corresponds to the JSON property conversationLoggingSettings
6071 6072 6073 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6071 def conversation_logging_settings @conversation_logging_settings end |
#evaluation_audio_recording_config ⇒ Google::Apis::CesV1::AudioRecordingConfig
Configuration for how the audio interactions should be recorded.
Corresponds to the JSON property evaluationAudioRecordingConfig
6076 6077 6078 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6076 def evaluation_audio_recording_config @evaluation_audio_recording_config end |
#metric_analysis_settings ⇒ Google::Apis::CesV1::MetricAnalysisSettings
Settings to describe the conversation data collection behaviors for LLM
analysis metrics pipeline.
Corresponds to the JSON property metricAnalysisSettings
6082 6083 6084 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6082 def metric_analysis_settings @metric_analysis_settings end |
#redaction_config ⇒ Google::Apis::CesV1::RedactionConfig
Configuration to instruct how sensitive data should be handled.
Corresponds to the JSON property redactionConfig
6087 6088 6089 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6087 def redaction_config @redaction_config end |
#unredacted_audio_recording_config ⇒ Google::Apis::CesV1::AudioRecordingConfig
Configuration for how the audio interactions should be recorded.
Corresponds to the JSON property unredactedAudioRecordingConfig
6092 6093 6094 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6092 def unredacted_audio_recording_config @unredacted_audio_recording_config end |
#unredacted_bigquery_export_settings ⇒ Google::Apis::CesV1::BigQueryExportSettings
Settings to describe the BigQuery export behaviors for the app.
Corresponds to the JSON property unredactedBigqueryExportSettings
6097 6098 6099 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6097 def unredacted_bigquery_export_settings @unredacted_bigquery_export_settings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6104 6105 6106 6107 6108 6109 6110 6111 6112 6113 6114 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6104 def update!(**args) @audio_recording_config = args[:audio_recording_config] if args.key?(:audio_recording_config) @bigquery_export_settings = args[:bigquery_export_settings] if args.key?(:bigquery_export_settings) @cloud_logging_settings = args[:cloud_logging_settings] if args.key?(:cloud_logging_settings) @conversation_logging_settings = args[:conversation_logging_settings] if args.key?(:conversation_logging_settings) @evaluation_audio_recording_config = args[:evaluation_audio_recording_config] if args.key?(:evaluation_audio_recording_config) @metric_analysis_settings = args[:metric_analysis_settings] if args.key?(:metric_analysis_settings) @redaction_config = args[:redaction_config] if args.key?(:redaction_config) @unredacted_audio_recording_config = args[:unredacted_audio_recording_config] if args.key?(:unredacted_audio_recording_config) @unredacted_bigquery_export_settings = args[:unredacted_bigquery_export_settings] if args.key?(:unredacted_bigquery_export_settings) end |