Class: Google::Apis::CesV1::LoggingSettings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Settings to describe the logging behaviors for the app.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LoggingSettings

Returns a new instance of LoggingSettings.



6057
6058
6059
# File 'lib/google/apis/ces_v1/classes.rb', line 6057

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audio_recording_configGoogle::Apis::CesV1::AudioRecordingConfig

Configuration for how the audio interactions should be recorded. Corresponds to the JSON property audioRecordingConfig



6014
6015
6016
# File 'lib/google/apis/ces_v1/classes.rb', line 6014

def audio_recording_config
  @audio_recording_config
end

#bigquery_export_settingsGoogle::Apis::CesV1::BigQueryExportSettings

Settings to describe the BigQuery export behaviors for the app. Corresponds to the JSON property bigqueryExportSettings



6019
6020
6021
# File 'lib/google/apis/ces_v1/classes.rb', line 6019

def bigquery_export_settings
  @bigquery_export_settings
end

#cloud_logging_settingsGoogle::Apis::CesV1::CloudLoggingSettings

Settings to describe the Cloud Logging behaviors for the app. Corresponds to the JSON property cloudLoggingSettings



6024
6025
6026
# File 'lib/google/apis/ces_v1/classes.rb', line 6024

def cloud_logging_settings
  @cloud_logging_settings
end

#conversation_logging_settingsGoogle::Apis::CesV1::ConversationLoggingSettings

Settings to describe the conversation logging behaviors for the app. Corresponds to the JSON property conversationLoggingSettings



6029
6030
6031
# File 'lib/google/apis/ces_v1/classes.rb', line 6029

def conversation_logging_settings
  @conversation_logging_settings
end

#evaluation_audio_recording_configGoogle::Apis::CesV1::AudioRecordingConfig

Configuration for how the audio interactions should be recorded. Corresponds to the JSON property evaluationAudioRecordingConfig



6034
6035
6036
# File 'lib/google/apis/ces_v1/classes.rb', line 6034

def evaluation_audio_recording_config
  @evaluation_audio_recording_config
end

#metric_analysis_settingsGoogle::Apis::CesV1::MetricAnalysisSettings

Settings to describe the conversation data collection behaviors for LLM analysis metrics pipeline. Corresponds to the JSON property metricAnalysisSettings



6040
6041
6042
# File 'lib/google/apis/ces_v1/classes.rb', line 6040

def metric_analysis_settings
  @metric_analysis_settings
end

#redaction_configGoogle::Apis::CesV1::RedactionConfig

Configuration to instruct how sensitive data should be handled. Corresponds to the JSON property redactionConfig



6045
6046
6047
# File 'lib/google/apis/ces_v1/classes.rb', line 6045

def redaction_config
  @redaction_config
end

#unredacted_audio_recording_configGoogle::Apis::CesV1::AudioRecordingConfig

Configuration for how the audio interactions should be recorded. Corresponds to the JSON property unredactedAudioRecordingConfig



6050
6051
6052
# File 'lib/google/apis/ces_v1/classes.rb', line 6050

def unredacted_audio_recording_config
  @unredacted_audio_recording_config
end

#unredacted_bigquery_export_settingsGoogle::Apis::CesV1::BigQueryExportSettings

Settings to describe the BigQuery export behaviors for the app. Corresponds to the JSON property unredactedBigqueryExportSettings



6055
6056
6057
# File 'lib/google/apis/ces_v1/classes.rb', line 6055

def unredacted_bigquery_export_settings
  @unredacted_bigquery_export_settings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6062
6063
6064
6065
6066
6067
6068
6069
6070
6071
6072
# File 'lib/google/apis/ces_v1/classes.rb', line 6062

def update!(**args)
  @audio_recording_config = args[:audio_recording_config] if args.key?(:audio_recording_config)
  @bigquery_export_settings = args[:bigquery_export_settings] if args.key?(:bigquery_export_settings)
  @cloud_logging_settings = args[:cloud_logging_settings] if args.key?(:cloud_logging_settings)
  @conversation_logging_settings = args[:conversation_logging_settings] if args.key?(:conversation_logging_settings)
  @evaluation_audio_recording_config = args[:evaluation_audio_recording_config] if args.key?(:evaluation_audio_recording_config)
  @metric_analysis_settings = args[:metric_analysis_settings] if args.key?(:metric_analysis_settings)
  @redaction_config = args[:redaction_config] if args.key?(:redaction_config)
  @unredacted_audio_recording_config = args[:unredacted_audio_recording_config] if args.key?(:unredacted_audio_recording_config)
  @unredacted_bigquery_export_settings = args[:unredacted_bigquery_export_settings] if args.key?(:unredacted_bigquery_export_settings)
end