Class: Google::Apis::CesV1::LoggingSettings
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::LoggingSettings
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Settings to describe the logging behaviors for the app.
Instance Attribute Summary collapse
-
#audio_recording_config ⇒ Google::Apis::CesV1::AudioRecordingConfig
Configuration for how the audio interactions should be recorded.
-
#bigquery_export_settings ⇒ Google::Apis::CesV1::BigQueryExportSettings
Settings to describe the BigQuery export behaviors for the app.
-
#cloud_logging_settings ⇒ Google::Apis::CesV1::CloudLoggingSettings
Settings to describe the Cloud Logging behaviors for the app.
-
#conversation_logging_settings ⇒ Google::Apis::CesV1::ConversationLoggingSettings
Settings to describe the conversation logging behaviors for the app.
-
#evaluation_audio_recording_config ⇒ Google::Apis::CesV1::AudioRecordingConfig
Configuration for how the audio interactions should be recorded.
-
#metric_analysis_settings ⇒ Google::Apis::CesV1::MetricAnalysisSettings
Settings to describe the conversation data collection behaviors for LLM analysis metrics pipeline.
-
#redaction_config ⇒ Google::Apis::CesV1::RedactionConfig
Configuration to instruct how sensitive data should be handled.
-
#unredacted_audio_recording_config ⇒ Google::Apis::CesV1::AudioRecordingConfig
Configuration for how the audio interactions should be recorded.
-
#unredacted_bigquery_export_settings ⇒ Google::Apis::CesV1::BigQueryExportSettings
Settings to describe the BigQuery export behaviors for the app.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LoggingSettings
constructor
A new instance of LoggingSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LoggingSettings
Returns a new instance of LoggingSettings.
6037 6038 6039 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6037 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audio_recording_config ⇒ Google::Apis::CesV1::AudioRecordingConfig
Configuration for how the audio interactions should be recorded.
Corresponds to the JSON property audioRecordingConfig
5994 5995 5996 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5994 def audio_recording_config @audio_recording_config end |
#bigquery_export_settings ⇒ Google::Apis::CesV1::BigQueryExportSettings
Settings to describe the BigQuery export behaviors for the app.
Corresponds to the JSON property bigqueryExportSettings
5999 6000 6001 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5999 def bigquery_export_settings @bigquery_export_settings end |
#cloud_logging_settings ⇒ Google::Apis::CesV1::CloudLoggingSettings
Settings to describe the Cloud Logging behaviors for the app.
Corresponds to the JSON property cloudLoggingSettings
6004 6005 6006 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6004 def cloud_logging_settings @cloud_logging_settings end |
#conversation_logging_settings ⇒ Google::Apis::CesV1::ConversationLoggingSettings
Settings to describe the conversation logging behaviors for the app.
Corresponds to the JSON property conversationLoggingSettings
6009 6010 6011 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6009 def conversation_logging_settings @conversation_logging_settings end |
#evaluation_audio_recording_config ⇒ Google::Apis::CesV1::AudioRecordingConfig
Configuration for how the audio interactions should be recorded.
Corresponds to the JSON property evaluationAudioRecordingConfig
6014 6015 6016 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6014 def evaluation_audio_recording_config @evaluation_audio_recording_config end |
#metric_analysis_settings ⇒ Google::Apis::CesV1::MetricAnalysisSettings
Settings to describe the conversation data collection behaviors for LLM
analysis metrics pipeline.
Corresponds to the JSON property metricAnalysisSettings
6020 6021 6022 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6020 def metric_analysis_settings @metric_analysis_settings end |
#redaction_config ⇒ Google::Apis::CesV1::RedactionConfig
Configuration to instruct how sensitive data should be handled.
Corresponds to the JSON property redactionConfig
6025 6026 6027 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6025 def redaction_config @redaction_config end |
#unredacted_audio_recording_config ⇒ Google::Apis::CesV1::AudioRecordingConfig
Configuration for how the audio interactions should be recorded.
Corresponds to the JSON property unredactedAudioRecordingConfig
6030 6031 6032 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6030 def unredacted_audio_recording_config @unredacted_audio_recording_config end |
#unredacted_bigquery_export_settings ⇒ Google::Apis::CesV1::BigQueryExportSettings
Settings to describe the BigQuery export behaviors for the app.
Corresponds to the JSON property unredactedBigqueryExportSettings
6035 6036 6037 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6035 def unredacted_bigquery_export_settings @unredacted_bigquery_export_settings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6042 6043 6044 6045 6046 6047 6048 6049 6050 6051 6052 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6042 def update!(**args) @audio_recording_config = args[:audio_recording_config] if args.key?(:audio_recording_config) @bigquery_export_settings = args[:bigquery_export_settings] if args.key?(:bigquery_export_settings) @cloud_logging_settings = args[:cloud_logging_settings] if args.key?(:cloud_logging_settings) @conversation_logging_settings = args[:conversation_logging_settings] if args.key?(:conversation_logging_settings) @evaluation_audio_recording_config = args[:evaluation_audio_recording_config] if args.key?(:evaluation_audio_recording_config) @metric_analysis_settings = args[:metric_analysis_settings] if args.key?(:metric_analysis_settings) @redaction_config = args[:redaction_config] if args.key?(:redaction_config) @unredacted_audio_recording_config = args[:unredacted_audio_recording_config] if args.key?(:unredacted_audio_recording_config) @unredacted_bigquery_export_settings = args[:unredacted_bigquery_export_settings] if args.key?(:unredacted_bigquery_export_settings) end |