Class: Google::Apis::CesV1::LoggingSettings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Settings to describe the logging behaviors for the app.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LoggingSettings

Returns a new instance of LoggingSettings.



5080
5081
5082
# File 'lib/google/apis/ces_v1/classes.rb', line 5080

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audio_recording_configGoogle::Apis::CesV1::AudioRecordingConfig

Configuration for how the audio interactions should be recorded. Corresponds to the JSON property audioRecordingConfig



5042
5043
5044
# File 'lib/google/apis/ces_v1/classes.rb', line 5042

def audio_recording_config
  @audio_recording_config
end

#bigquery_export_settingsGoogle::Apis::CesV1::BigQueryExportSettings

Settings to describe the BigQuery export behaviors for the app. Corresponds to the JSON property bigqueryExportSettings



5047
5048
5049
# File 'lib/google/apis/ces_v1/classes.rb', line 5047

def bigquery_export_settings
  @bigquery_export_settings
end

#cloud_logging_settingsGoogle::Apis::CesV1::CloudLoggingSettings

Settings to describe the Cloud Logging behaviors for the app. Corresponds to the JSON property cloudLoggingSettings



5052
5053
5054
# File 'lib/google/apis/ces_v1/classes.rb', line 5052

def cloud_logging_settings
  @cloud_logging_settings
end

#conversation_logging_settingsGoogle::Apis::CesV1::ConversationLoggingSettings

Settings to describe the conversation logging behaviors for the app. Corresponds to the JSON property conversationLoggingSettings



5057
5058
5059
# File 'lib/google/apis/ces_v1/classes.rb', line 5057

def conversation_logging_settings
  @conversation_logging_settings
end

#evaluation_audio_recording_configGoogle::Apis::CesV1::AudioRecordingConfig

Configuration for how the audio interactions should be recorded. Corresponds to the JSON property evaluationAudioRecordingConfig



5062
5063
5064
# File 'lib/google/apis/ces_v1/classes.rb', line 5062

def evaluation_audio_recording_config
  @evaluation_audio_recording_config
end

#metric_analysis_settingsGoogle::Apis::CesV1::MetricAnalysisSettings

Settings to describe the conversation data collection behaviors for LLM analysis metrics pipeline. Corresponds to the JSON property metricAnalysisSettings



5068
5069
5070
# File 'lib/google/apis/ces_v1/classes.rb', line 5068

def metric_analysis_settings
  @metric_analysis_settings
end

#redaction_configGoogle::Apis::CesV1::RedactionConfig

Configuration to instruct how sensitive data should be handled. Corresponds to the JSON property redactionConfig



5073
5074
5075
# File 'lib/google/apis/ces_v1/classes.rb', line 5073

def redaction_config
  @redaction_config
end

#unredacted_audio_recording_configGoogle::Apis::CesV1::AudioRecordingConfig

Configuration for how the audio interactions should be recorded. Corresponds to the JSON property unredactedAudioRecordingConfig



5078
5079
5080
# File 'lib/google/apis/ces_v1/classes.rb', line 5078

def unredacted_audio_recording_config
  @unredacted_audio_recording_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5085
5086
5087
5088
5089
5090
5091
5092
5093
5094
# File 'lib/google/apis/ces_v1/classes.rb', line 5085

def update!(**args)
  @audio_recording_config = args[:audio_recording_config] if args.key?(:audio_recording_config)
  @bigquery_export_settings = args[:bigquery_export_settings] if args.key?(:bigquery_export_settings)
  @cloud_logging_settings = args[:cloud_logging_settings] if args.key?(:cloud_logging_settings)
  @conversation_logging_settings = args[:conversation_logging_settings] if args.key?(:conversation_logging_settings)
  @evaluation_audio_recording_config = args[:evaluation_audio_recording_config] if args.key?(:evaluation_audio_recording_config)
  @metric_analysis_settings = args[:metric_analysis_settings] if args.key?(:metric_analysis_settings)
  @redaction_config = args[:redaction_config] if args.key?(:redaction_config)
  @unredacted_audio_recording_config = args[:unredacted_audio_recording_config] if args.key?(:unredacted_audio_recording_config)
end