Class: Google::Apis::CesV1::LoggingSettings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Settings to describe the logging behaviors for the app.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LoggingSettings

Returns a new instance of LoggingSettings.



4440
4441
4442
# File 'lib/google/apis/ces_v1/classes.rb', line 4440

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audio_recording_configGoogle::Apis::CesV1::AudioRecordingConfig

Configuration for how the audio interactions should be recorded. Corresponds to the JSON property audioRecordingConfig



4402
4403
4404
# File 'lib/google/apis/ces_v1/classes.rb', line 4402

def audio_recording_config
  @audio_recording_config
end

#bigquery_export_settingsGoogle::Apis::CesV1::BigQueryExportSettings

Settings to describe the BigQuery export behaviors for the app. Corresponds to the JSON property bigqueryExportSettings



4407
4408
4409
# File 'lib/google/apis/ces_v1/classes.rb', line 4407

def bigquery_export_settings
  @bigquery_export_settings
end

#cloud_logging_settingsGoogle::Apis::CesV1::CloudLoggingSettings

Settings to describe the Cloud Logging behaviors for the app. Corresponds to the JSON property cloudLoggingSettings



4412
4413
4414
# File 'lib/google/apis/ces_v1/classes.rb', line 4412

def cloud_logging_settings
  @cloud_logging_settings
end

#conversation_logging_settingsGoogle::Apis::CesV1::ConversationLoggingSettings

Settings to describe the conversation logging behaviors for the app. Corresponds to the JSON property conversationLoggingSettings



4417
4418
4419
# File 'lib/google/apis/ces_v1/classes.rb', line 4417

def conversation_logging_settings
  @conversation_logging_settings
end

#evaluation_audio_recording_configGoogle::Apis::CesV1::AudioRecordingConfig

Configuration for how the audio interactions should be recorded. Corresponds to the JSON property evaluationAudioRecordingConfig



4422
4423
4424
# File 'lib/google/apis/ces_v1/classes.rb', line 4422

def evaluation_audio_recording_config
  @evaluation_audio_recording_config
end

#metric_analysis_settingsGoogle::Apis::CesV1::MetricAnalysisSettings

Settings to describe the conversation data collection behaviors for LLM analysis metrics pipeline. Corresponds to the JSON property metricAnalysisSettings



4428
4429
4430
# File 'lib/google/apis/ces_v1/classes.rb', line 4428

def metric_analysis_settings
  @metric_analysis_settings
end

#redaction_configGoogle::Apis::CesV1::RedactionConfig

Configuration to instruct how sensitive data should be handled. Corresponds to the JSON property redactionConfig



4433
4434
4435
# File 'lib/google/apis/ces_v1/classes.rb', line 4433

def redaction_config
  @redaction_config
end

#unredacted_audio_recording_configGoogle::Apis::CesV1::AudioRecordingConfig

Configuration for how the audio interactions should be recorded. Corresponds to the JSON property unredactedAudioRecordingConfig



4438
4439
4440
# File 'lib/google/apis/ces_v1/classes.rb', line 4438

def unredacted_audio_recording_config
  @unredacted_audio_recording_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4445
4446
4447
4448
4449
4450
4451
4452
4453
4454
# File 'lib/google/apis/ces_v1/classes.rb', line 4445

def update!(**args)
  @audio_recording_config = args[:audio_recording_config] if args.key?(:audio_recording_config)
  @bigquery_export_settings = args[:bigquery_export_settings] if args.key?(:bigquery_export_settings)
  @cloud_logging_settings = args[:cloud_logging_settings] if args.key?(:cloud_logging_settings)
  @conversation_logging_settings = args[:conversation_logging_settings] if args.key?(:conversation_logging_settings)
  @evaluation_audio_recording_config = args[:evaluation_audio_recording_config] if args.key?(:evaluation_audio_recording_config)
  @metric_analysis_settings = args[:metric_analysis_settings] if args.key?(:metric_analysis_settings)
  @redaction_config = args[:redaction_config] if args.key?(:redaction_config)
  @unredacted_audio_recording_config = args[:unredacted_audio_recording_config] if args.key?(:unredacted_audio_recording_config)
end