Class: Google::Apis::CesV1::McpTool
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::McpTool
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
An MCP tool. See https://modelcontextprotocol.io/specification/2025-06-18/ server/tools for more details.
Instance Attribute Summary collapse
-
#api_authentication ⇒ Google::Apis::CesV1::ApiAuthentication
Authentication information required for API calls.
-
#custom_headers ⇒ Hash<String,String>
Optional.
-
#description ⇒ String
Optional.
-
#input_schema ⇒ Google::Apis::CesV1::Schema
Represents a select subset of an OpenAPI 3.0 schema object.
-
#name ⇒ String
Required.
-
#name_override ⇒ String
Optional.
-
#output_schema ⇒ Google::Apis::CesV1::Schema
Represents a select subset of an OpenAPI 3.0 schema object.
-
#server_address ⇒ String
Required.
-
#service_directory_config ⇒ Google::Apis::CesV1::ServiceDirectoryConfig
Configuration for tools using Service Directory.
-
#state ⇒ String
Output only.
-
#tls_config ⇒ Google::Apis::CesV1::TlsConfig
The TLS configuration.
Instance Method Summary collapse
-
#initialize(**args) ⇒ McpTool
constructor
A new instance of McpTool.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ McpTool
Returns a new instance of McpTool.
5165 5166 5167 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5165 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_authentication ⇒ Google::Apis::CesV1::ApiAuthentication
Authentication information required for API calls.
Corresponds to the JSON property apiAuthentication
5105 5106 5107 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5105 def api_authentication @api_authentication end |
#custom_headers ⇒ Hash<String,String>
Optional. The custom headers to send in the request to the MCP server. The
values must be in the format $context.variables. and can be set in the
session variables. See https://docs.cloud.google.com/customer-engagement-ai/
conversational-agents/ps/tool/open-api#openapi-injection for more details.
Corresponds to the JSON property customHeaders
5113 5114 5115 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5113 def custom_headers @custom_headers end |
#description ⇒ String
Optional. The description of the MCP tool.
Corresponds to the JSON property description
5118 5119 5120 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5118 def description @description end |
#input_schema ⇒ Google::Apis::CesV1::Schema
Represents a select subset of an OpenAPI 3.0 schema object.
Corresponds to the JSON property inputSchema
5123 5124 5125 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5123 def input_schema @input_schema end |
#name ⇒ String
Required. The name of the MCP tool.
Corresponds to the JSON property name
5128 5129 5130 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5128 def name @name end |
#name_override ⇒ String
Optional. The name override of the MCP tool. This is populated if the name was
overridden by a Toolset override.
Corresponds to the JSON property nameOverride
5134 5135 5136 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5134 def name_override @name_override end |
#output_schema ⇒ Google::Apis::CesV1::Schema
Represents a select subset of an OpenAPI 3.0 schema object.
Corresponds to the JSON property outputSchema
5139 5140 5141 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5139 def output_schema @output_schema end |
#server_address ⇒ String
Required. The server address of the MCP server, e.g., "https://example.com/mcp/
". If the server is built with the MCP SDK, the url should be suffixed with "/
mcp/". Only Streamable HTTP transport based servers are supported. This is the
same as the server_address in the McpToolset. See https://modelcontextprotocol.
io/specification/2025-03-26/basic/transports#streamable-http for more details.
Corresponds to the JSON property serverAddress
5148 5149 5150 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5148 def server_address @server_address end |
#service_directory_config ⇒ Google::Apis::CesV1::ServiceDirectoryConfig
Configuration for tools using Service Directory.
Corresponds to the JSON property serviceDirectoryConfig
5153 5154 5155 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5153 def service_directory_config @service_directory_config end |
#state ⇒ String
Output only. The dynamic availability state of the tool on the external server.
Corresponds to the JSON property state
5158 5159 5160 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5158 def state @state end |
#tls_config ⇒ Google::Apis::CesV1::TlsConfig
The TLS configuration.
Corresponds to the JSON property tlsConfig
5163 5164 5165 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5163 def tls_config @tls_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5170 5171 5172 5173 5174 5175 5176 5177 5178 5179 5180 5181 5182 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5170 def update!(**args) @api_authentication = args[:api_authentication] if args.key?(:api_authentication) @custom_headers = args[:custom_headers] if args.key?(:custom_headers) @description = args[:description] if args.key?(:description) @input_schema = args[:input_schema] if args.key?(:input_schema) @name = args[:name] if args.key?(:name) @name_override = args[:name_override] if args.key?(:name_override) @output_schema = args[:output_schema] if args.key?(:output_schema) @server_address = args[:server_address] if args.key?(:server_address) @service_directory_config = args[:service_directory_config] if args.key?(:service_directory_config) @state = args[:state] if args.key?(:state) @tls_config = args[:tls_config] if args.key?(:tls_config) end |