Class: Google::Apis::CesV1::McpToolOverride
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::McpToolOverride
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Overrides associated with a given tool in a Toolset. This enables "pinning" or "overriding" of tool definitions from the external dynamic server.
Instance Attribute Summary collapse
-
#description_override ⇒ String
Optional.
-
#name_override ⇒ String
Optional.
-
#snapshot ⇒ Google::Apis::CesV1::McpToolDefinition
Container for a tool's core definition elements that are snapshot.
-
#tool ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ McpToolOverride
constructor
A new instance of McpToolOverride.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ McpToolOverride
Returns a new instance of McpToolOverride.
6283 6284 6285 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6283 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description_override ⇒ String
Optional. If present, this tool uses this description instead of the original
description from the server.
Corresponds to the JSON property descriptionOverride
6263 6264 6265 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6263 def description_override @description_override end |
#name_override ⇒ String
Optional. If present, this tool uses this name in the Agent instead of the
original name. This is primarily used as an alias if the MCP server offers
poorly named tools.
Corresponds to the JSON property nameOverride
6270 6271 6272 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6270 def name_override @name_override end |
#snapshot ⇒ Google::Apis::CesV1::McpToolDefinition
Container for a tool's core definition elements that are snapshot. Schemas in
the snapshot are used as-is and cannot be overridden.
Corresponds to the JSON property snapshot
6276 6277 6278 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6276 def snapshot @snapshot end |
#tool ⇒ String
Required. The original name of the tool as it is emitted by the MCP server.
Corresponds to the JSON property tool
6281 6282 6283 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6281 def tool @tool end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6288 6289 6290 6291 6292 6293 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6288 def update!(**args) @description_override = args[:description_override] if args.key?(:description_override) @name_override = args[:name_override] if args.key?(:name_override) @snapshot = args[:snapshot] if args.key?(:snapshot) @tool = args[:tool] if args.key?(:tool) end |