Class: Google::Apis::CesV1::McpToolOverride

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Overrides associated with a given tool in a Toolset. This enables "pinning" or "overriding" of tool definitions from the external dynamic server.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ McpToolOverride

Returns a new instance of McpToolOverride.



5247
5248
5249
# File 'lib/google/apis/ces_v1/classes.rb', line 5247

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#description_overrideString

Optional. If present, this tool uses this description instead of the original description from the server. Corresponds to the JSON property descriptionOverride

Returns:

  • (String)


5227
5228
5229
# File 'lib/google/apis/ces_v1/classes.rb', line 5227

def description_override
  @description_override
end

#name_overrideString

Optional. If present, this tool uses this name in the Agent instead of the original name. This is primarily used as an alias if the MCP server offers poorly named tools. Corresponds to the JSON property nameOverride

Returns:

  • (String)


5234
5235
5236
# File 'lib/google/apis/ces_v1/classes.rb', line 5234

def name_override
  @name_override
end

#snapshotGoogle::Apis::CesV1::McpToolDefinition

Container for a tool's core definition elements that are snapshot. Schemas in the snapshot are used as-is and cannot be overridden. Corresponds to the JSON property snapshot



5240
5241
5242
# File 'lib/google/apis/ces_v1/classes.rb', line 5240

def snapshot
  @snapshot
end

#toolString

Required. The original name of the tool as it is emitted by the MCP server. Corresponds to the JSON property tool

Returns:

  • (String)


5245
5246
5247
# File 'lib/google/apis/ces_v1/classes.rb', line 5245

def tool
  @tool
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5252
5253
5254
5255
5256
5257
# File 'lib/google/apis/ces_v1/classes.rb', line 5252

def update!(**args)
  @description_override = args[:description_override] if args.key?(:description_override)
  @name_override = args[:name_override] if args.key?(:name_override)
  @snapshot = args[:snapshot] if args.key?(:snapshot)
  @tool = args[:tool] if args.key?(:tool)
end