Class: Google::Apis::CesV1::McpToolset

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

A toolset that contains a list of tools that are offered by the MCP server.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ McpToolset

Returns a new instance of McpToolset.



4568
4569
4570
# File 'lib/google/apis/ces_v1/classes.rb', line 4568

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_authenticationGoogle::Apis::CesV1::ApiAuthentication

Authentication information required for API calls. Corresponds to the JSON property apiAuthentication



4539
4540
4541
# File 'lib/google/apis/ces_v1/classes.rb', line 4539

def api_authentication
  @api_authentication
end

#custom_headersHash<String,String>

Optional. The custom headers to send in the request to the MCP server. The values must be in the format $context.variables. and can be set in the session variables. See https://docs.cloud.google.com/customer-engagement-ai/ conversational-agents/ps/tool/open-api#openapi-injection for more details. Corresponds to the JSON property customHeaders

Returns:

  • (Hash<String,String>)


4547
4548
4549
# File 'lib/google/apis/ces_v1/classes.rb', line 4547

def custom_headers
  @custom_headers
end

#server_addressString

Required. The address of the MCP server, for example, "https://example.com/mcp/ ". If the server is built with the MCP SDK, the url should be suffixed with "/ mcp/". Only Streamable HTTP transport based servers are supported. See https:// modelcontextprotocol.io/specification/2025-03-26/basic/transports#streamable- http for more details. Corresponds to the JSON property serverAddress

Returns:

  • (String)


4556
4557
4558
# File 'lib/google/apis/ces_v1/classes.rb', line 4556

def server_address
  @server_address
end

#service_directory_configGoogle::Apis::CesV1::ServiceDirectoryConfig

Configuration for tools using Service Directory. Corresponds to the JSON property serviceDirectoryConfig



4561
4562
4563
# File 'lib/google/apis/ces_v1/classes.rb', line 4561

def service_directory_config
  @service_directory_config
end

#tls_configGoogle::Apis::CesV1::TlsConfig

The TLS configuration. Corresponds to the JSON property tlsConfig



4566
4567
4568
# File 'lib/google/apis/ces_v1/classes.rb', line 4566

def tls_config
  @tls_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4573
4574
4575
4576
4577
4578
4579
# File 'lib/google/apis/ces_v1/classes.rb', line 4573

def update!(**args)
  @api_authentication = args[:api_authentication] if args.key?(:api_authentication)
  @custom_headers = args[:custom_headers] if args.key?(:custom_headers)
  @server_address = args[:server_address] if args.key?(:server_address)
  @service_directory_config = args[:service_directory_config] if args.key?(:service_directory_config)
  @tls_config = args[:tls_config] if args.key?(:tls_config)
end