Class: Google::Apis::CesV1::Message

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

A message within a conversation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Message

Returns a new instance of Message.



5338
5339
5340
# File 'lib/google/apis/ces_v1/classes.rb', line 5338

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chunksArray<Google::Apis::CesV1::Chunk>

Optional. Content of the message as a series of chunks. Corresponds to the JSON property chunks

Returns:



5325
5326
5327
# File 'lib/google/apis/ces_v1/classes.rb', line 5325

def chunks
  @chunks
end

#event_timeString

Optional. Timestamp when the message was sent or received. Should not be used if the message is part of an example. Corresponds to the JSON property eventTime

Returns:

  • (String)


5331
5332
5333
# File 'lib/google/apis/ces_v1/classes.rb', line 5331

def event_time
  @event_time
end

#roleString

Optional. The role within the conversation, e.g., user, agent. Corresponds to the JSON property role

Returns:

  • (String)


5336
5337
5338
# File 'lib/google/apis/ces_v1/classes.rb', line 5336

def role
  @role
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5343
5344
5345
5346
5347
# File 'lib/google/apis/ces_v1/classes.rb', line 5343

def update!(**args)
  @chunks = args[:chunks] if args.key?(:chunks)
  @event_time = args[:event_time] if args.key?(:event_time)
  @role = args[:role] if args.key?(:role)
end