Class: Google::Apis::CesV1::MetricAnalysisSettings
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::MetricAnalysisSettings
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Settings to describe the conversation data collection behaviors for LLM analysis metrics pipeline.
Instance Attribute Summary collapse
-
#llm_metrics_opted_out ⇒ Boolean
(also: #llm_metrics_opted_out?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MetricAnalysisSettings
constructor
A new instance of MetricAnalysisSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MetricAnalysisSettings
Returns a new instance of MetricAnalysisSettings.
4627 4628 4629 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4627 def initialize(**args) update!(**args) end |
Instance Attribute Details
#llm_metrics_opted_out ⇒ Boolean Also known as: llm_metrics_opted_out?
Optional. Whether to collect conversation data for llm analysis metrics. If
true, conversation data will not be collected for llm analysis metrics;
otherwise, conversation data will be collected.
Corresponds to the JSON property llmMetricsOptedOut
4624 4625 4626 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4624 def llm_metrics_opted_out @llm_metrics_opted_out end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4632 4633 4634 |
# File 'lib/google/apis/ces_v1/classes.rb', line 4632 def update!(**args) @llm_metrics_opted_out = args[:llm_metrics_opted_out] if args.key?(:llm_metrics_opted_out) end |