Class: Google::Apis::CesV1::ModelSettings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Model settings contains various configurations for the LLM model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ModelSettings

Returns a new instance of ModelSettings.



4897
4898
4899
# File 'lib/google/apis/ces_v1/classes.rb', line 4897

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#modelString

Optional. The LLM model that the agent should use. If not set, the agent will inherit the model from its parent agent. Corresponds to the JSON property model

Returns:

  • (String)


4887
4888
4889
# File 'lib/google/apis/ces_v1/classes.rb', line 4887

def model
  @model
end

#temperatureFloat

Optional. If set, this temperature will be used for the LLM model. Temperature controls the randomness of the model's responses. Lower temperatures produce responses that are more predictable. Higher temperatures produce responses that are more creative. Corresponds to the JSON property temperature

Returns:

  • (Float)


4895
4896
4897
# File 'lib/google/apis/ces_v1/classes.rb', line 4895

def temperature
  @temperature
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4902
4903
4904
4905
# File 'lib/google/apis/ces_v1/classes.rb', line 4902

def update!(**args)
  @model = args[:model] if args.key?(:model)
  @temperature = args[:temperature] if args.key?(:temperature)
end