Class: Google::Apis::CesV1::OpenApiToolset

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

A toolset that contains a list of tools that are defined by an OpenAPI schema.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OpenApiToolset

Returns a new instance of OpenApiToolset.



5321
5322
5323
# File 'lib/google/apis/ces_v1/classes.rb', line 5321

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_authenticationGoogle::Apis::CesV1::ApiAuthentication

Authentication information required for API calls. Corresponds to the JSON property apiAuthentication



5288
5289
5290
# File 'lib/google/apis/ces_v1/classes.rb', line 5288

def api_authentication
  @api_authentication
end

#ignore_unknown_fieldsBoolean Also known as: ignore_unknown_fields?

Optional. If true, the agent will ignore unknown fields in the API response for all operations defined in the OpenAPI schema. Corresponds to the JSON property ignoreUnknownFields

Returns:

  • (Boolean)


5294
5295
5296
# File 'lib/google/apis/ces_v1/classes.rb', line 5294

def ignore_unknown_fields
  @ignore_unknown_fields
end

#open_api_schemaString

Required. The OpenAPI schema of the toolset. Corresponds to the JSON property openApiSchema

Returns:

  • (String)


5300
5301
5302
# File 'lib/google/apis/ces_v1/classes.rb', line 5300

def open_api_schema
  @open_api_schema
end

#service_directory_configGoogle::Apis::CesV1::ServiceDirectoryConfig

Configuration for tools using Service Directory. Corresponds to the JSON property serviceDirectoryConfig



5305
5306
5307
# File 'lib/google/apis/ces_v1/classes.rb', line 5305

def service_directory_config
  @service_directory_config
end

#tls_configGoogle::Apis::CesV1::TlsConfig

The TLS configuration. Corresponds to the JSON property tlsConfig



5310
5311
5312
# File 'lib/google/apis/ces_v1/classes.rb', line 5310

def tls_config
  @tls_config
end

#urlString

Optional. The server URL of the Open API schema. This field is only set in toolsets in the environment dependencies during the export process if the schema contains a server url. During the import process, if this url is present in the environment dependencies and the schema has the $env_var placeholder, it will replace the placeholder in the schema. Corresponds to the JSON property url

Returns:

  • (String)


5319
5320
5321
# File 'lib/google/apis/ces_v1/classes.rb', line 5319

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5326
5327
5328
5329
5330
5331
5332
5333
# File 'lib/google/apis/ces_v1/classes.rb', line 5326

def update!(**args)
  @api_authentication = args[:api_authentication] if args.key?(:api_authentication)
  @ignore_unknown_fields = args[:ignore_unknown_fields] if args.key?(:ignore_unknown_fields)
  @open_api_schema = args[:open_api_schema] if args.key?(:open_api_schema)
  @service_directory_config = args[:service_directory_config] if args.key?(:service_directory_config)
  @tls_config = args[:tls_config] if args.key?(:tls_config)
  @url = args[:url] if args.key?(:url)
end