Class: Google::Apis::CesV1::OpenApiToolset
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::OpenApiToolset
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
A toolset that contains a list of tools that are defined by an OpenAPI schema.
Instance Attribute Summary collapse
-
#api_authentication ⇒ Google::Apis::CesV1::ApiAuthentication
Authentication information required for API calls.
-
#ignore_unknown_fields ⇒ Boolean
(also: #ignore_unknown_fields?)
Optional.
-
#open_api_schema ⇒ String
Required.
-
#service_directory_config ⇒ Google::Apis::CesV1::ServiceDirectoryConfig
Configuration for tools using Service Directory.
-
#tls_config ⇒ Google::Apis::CesV1::TlsConfig
The TLS configuration.
-
#url ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OpenApiToolset
constructor
A new instance of OpenApiToolset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OpenApiToolset
Returns a new instance of OpenApiToolset.
5154 5155 5156 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5154 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_authentication ⇒ Google::Apis::CesV1::ApiAuthentication
Authentication information required for API calls.
Corresponds to the JSON property apiAuthentication
5121 5122 5123 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5121 def api_authentication @api_authentication end |
#ignore_unknown_fields ⇒ Boolean Also known as: ignore_unknown_fields?
Optional. If true, the agent will ignore unknown fields in the API response
for all operations defined in the OpenAPI schema.
Corresponds to the JSON property ignoreUnknownFields
5127 5128 5129 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5127 def ignore_unknown_fields @ignore_unknown_fields end |
#open_api_schema ⇒ String
Required. The OpenAPI schema of the toolset.
Corresponds to the JSON property openApiSchema
5133 5134 5135 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5133 def open_api_schema @open_api_schema end |
#service_directory_config ⇒ Google::Apis::CesV1::ServiceDirectoryConfig
Configuration for tools using Service Directory.
Corresponds to the JSON property serviceDirectoryConfig
5138 5139 5140 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5138 def service_directory_config @service_directory_config end |
#tls_config ⇒ Google::Apis::CesV1::TlsConfig
The TLS configuration.
Corresponds to the JSON property tlsConfig
5143 5144 5145 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5143 def tls_config @tls_config end |
#url ⇒ String
Optional. The server URL of the Open API schema. This field is only set in
toolsets in the environment dependencies during the export process if the
schema contains a server url. During the import process, if this url is
present in the environment dependencies and the schema has the $env_var
placeholder, it will replace the placeholder in the schema.
Corresponds to the JSON property url
5152 5153 5154 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5152 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5159 5160 5161 5162 5163 5164 5165 5166 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5159 def update!(**args) @api_authentication = args[:api_authentication] if args.key?(:api_authentication) @ignore_unknown_fields = args[:ignore_unknown_fields] if args.key?(:ignore_unknown_fields) @open_api_schema = args[:open_api_schema] if args.key?(:open_api_schema) @service_directory_config = args[:service_directory_config] if args.key?(:service_directory_config) @tls_config = args[:tls_config] if args.key?(:tls_config) @url = args[:url] if args.key?(:url) end |