Class: Google::Apis::CesV1::PythonFunction
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::PythonFunction
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
A Python function tool.
Instance Attribute Summary collapse
-
#description ⇒ String
Output only.
-
#name ⇒ String
Optional.
-
#python_code ⇒ String
Optional.
-
#service_directory_config ⇒ Google::Apis::CesV1::ServiceDirectoryConfig
Configuration for tools using Service Directory.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PythonFunction
constructor
A new instance of PythonFunction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PythonFunction
Returns a new instance of PythonFunction.
6859 6860 6861 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6859 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Output only. The description of the Python function, parsed from the python
code's docstring.
Corresponds to the JSON property description
6840 6841 6842 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6840 def description @description end |
#name ⇒ String
Optional. The name of the Python function to execute. Must match a Python
function name defined in the python code. Case sensitive. If the name is not
provided, the first function defined in the python code will be used.
Corresponds to the JSON property name
6847 6848 6849 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6847 def name @name end |
#python_code ⇒ String
Optional. The Python code to execute for the tool.
Corresponds to the JSON property pythonCode
6852 6853 6854 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6852 def python_code @python_code end |
#service_directory_config ⇒ Google::Apis::CesV1::ServiceDirectoryConfig
Configuration for tools using Service Directory.
Corresponds to the JSON property serviceDirectoryConfig
6857 6858 6859 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6857 def service_directory_config @service_directory_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6864 6865 6866 6867 6868 6869 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6864 def update!(**args) @description = args[:description] if args.key?(:description) @name = args[:name] if args.key?(:name) @python_code = args[:python_code] if args.key?(:python_code) @service_directory_config = args[:service_directory_config] if args.key?(:service_directory_config) end |