Class: Google::Apis::CesV1::PythonFunction

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

A Python function tool.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PythonFunction

Returns a new instance of PythonFunction.



6843
6844
6845
# File 'lib/google/apis/ces_v1/classes.rb', line 6843

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Output only. The description of the Python function, parsed from the python code's docstring. Corresponds to the JSON property description

Returns:

  • (String)


6824
6825
6826
# File 'lib/google/apis/ces_v1/classes.rb', line 6824

def description
  @description
end

#nameString

Optional. The name of the Python function to execute. Must match a Python function name defined in the python code. Case sensitive. If the name is not provided, the first function defined in the python code will be used. Corresponds to the JSON property name

Returns:

  • (String)


6831
6832
6833
# File 'lib/google/apis/ces_v1/classes.rb', line 6831

def name
  @name
end

#python_codeString

Optional. The Python code to execute for the tool. Corresponds to the JSON property pythonCode

Returns:

  • (String)


6836
6837
6838
# File 'lib/google/apis/ces_v1/classes.rb', line 6836

def python_code
  @python_code
end

#service_directory_configGoogle::Apis::CesV1::ServiceDirectoryConfig

Configuration for tools using Service Directory. Corresponds to the JSON property serviceDirectoryConfig



6841
6842
6843
# File 'lib/google/apis/ces_v1/classes.rb', line 6841

def service_directory_config
  @service_directory_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6848
6849
6850
6851
6852
6853
# File 'lib/google/apis/ces_v1/classes.rb', line 6848

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @name = args[:name] if args.key?(:name)
  @python_code = args[:python_code] if args.key?(:python_code)
  @service_directory_config = args[:service_directory_config] if args.key?(:service_directory_config)
end