Class: Google::Apis::CesV1::PythonFunction
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::PythonFunction
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
A Python function tool.
Instance Attribute Summary collapse
-
#description ⇒ String
Output only.
-
#name ⇒ String
Optional.
-
#python_code ⇒ String
Optional.
-
#service_directory_config ⇒ Google::Apis::CesV1::ServiceDirectoryConfig
Configuration for tools using Service Directory.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PythonFunction
constructor
A new instance of PythonFunction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PythonFunction
Returns a new instance of PythonFunction.
6781 6782 6783 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6781 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Output only. The description of the Python function, parsed from the python
code's docstring.
Corresponds to the JSON property description
6762 6763 6764 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6762 def description @description end |
#name ⇒ String
Optional. The name of the Python function to execute. Must match a Python
function name defined in the python code. Case sensitive. If the name is not
provided, the first function defined in the python code will be used.
Corresponds to the JSON property name
6769 6770 6771 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6769 def name @name end |
#python_code ⇒ String
Optional. The Python code to execute for the tool.
Corresponds to the JSON property pythonCode
6774 6775 6776 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6774 def python_code @python_code end |
#service_directory_config ⇒ Google::Apis::CesV1::ServiceDirectoryConfig
Configuration for tools using Service Directory.
Corresponds to the JSON property serviceDirectoryConfig
6779 6780 6781 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6779 def service_directory_config @service_directory_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6786 6787 6788 6789 6790 6791 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6786 def update!(**args) @description = args[:description] if args.key?(:description) @name = args[:name] if args.key?(:name) @python_code = args[:python_code] if args.key?(:python_code) @service_directory_config = args[:service_directory_config] if args.key?(:service_directory_config) end |