Class: Google::Apis::CesV1::PythonFunction
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::PythonFunction
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
A Python function tool.
Instance Attribute Summary collapse
-
#description ⇒ String
Output only.
-
#name ⇒ String
Optional.
-
#python_code ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PythonFunction
constructor
A new instance of PythonFunction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PythonFunction
Returns a new instance of PythonFunction.
5339 5340 5341 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5339 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Output only. The description of the Python function, parsed from the python
code's docstring.
Corresponds to the JSON property description
5325 5326 5327 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5325 def description @description end |
#name ⇒ String
Optional. The name of the Python function to execute. Must match a Python
function name defined in the python code. Case sensitive. If the name is not
provided, the first function defined in the python code will be used.
Corresponds to the JSON property name
5332 5333 5334 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5332 def name @name end |
#python_code ⇒ String
Optional. The Python code to execute for the tool.
Corresponds to the JSON property pythonCode
5337 5338 5339 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5337 def python_code @python_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5344 5345 5346 5347 5348 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5344 def update!(**args) @description = args[:description] if args.key?(:description) @name = args[:name] if args.key?(:name) @python_code = args[:python_code] if args.key?(:python_code) end |