Class: Google::Apis::CesV1::RedactionConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Configuration to instruct how sensitive data should be handled.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RedactionConfig

Returns a new instance of RedactionConfig.



5376
5377
5378
# File 'lib/google/apis/ces_v1/classes.rb', line 5376

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deidentify_templateString

Optional. DLP deidentify template name to instruct on how to de-identify content. Format: projects/project/locations/ location/deidentifyTemplates/deidentify_template` Corresponds to the JSON propertydeidentifyTemplate`

Returns:

  • (String)


5360
5361
5362
# File 'lib/google/apis/ces_v1/classes.rb', line 5360

def deidentify_template
  @deidentify_template
end

#enable_redactionBoolean Also known as: enable_redaction?

Optional. If true, redaction will be applied in various logging scenarios, including conversation history, Cloud Logging and audio recording. Corresponds to the JSON property enableRedaction

Returns:

  • (Boolean)


5366
5367
5368
# File 'lib/google/apis/ces_v1/classes.rb', line 5366

def enable_redaction
  @enable_redaction
end

#inspect_templateString

Optional. DLP inspect template name to configure detection of sensitive data types. Format: projects/project/ locations/location/inspectTemplates/inspect_template` Corresponds to the JSON propertyinspectTemplate`

Returns:

  • (String)


5374
5375
5376
# File 'lib/google/apis/ces_v1/classes.rb', line 5374

def inspect_template
  @inspect_template
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5381
5382
5383
5384
5385
# File 'lib/google/apis/ces_v1/classes.rb', line 5381

def update!(**args)
  @deidentify_template = args[:deidentify_template] if args.key?(:deidentify_template)
  @enable_redaction = args[:enable_redaction] if args.key?(:enable_redaction)
  @inspect_template = args[:inspect_template] if args.key?(:inspect_template)
end