Class: Google::Apis::CesV1::RetrieveToolSchemaResponse
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::RetrieveToolSchemaResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Response message for ToolService.RetrieveToolSchema.
Instance Attribute Summary collapse
-
#input_schema ⇒ Google::Apis::CesV1::Schema
Represents a select subset of an OpenAPI 3.0 schema object.
-
#output_schema ⇒ Google::Apis::CesV1::Schema
Represents a select subset of an OpenAPI 3.0 schema object.
-
#tool ⇒ String
The name of the tool that the schema is for.
-
#toolset_tool ⇒ Google::Apis::CesV1::ToolsetTool
A tool that is created from a toolset.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RetrieveToolSchemaResponse
constructor
A new instance of RetrieveToolSchemaResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RetrieveToolSchemaResponse
Returns a new instance of RetrieveToolSchemaResponse.
5652 5653 5654 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5652 def initialize(**args) update!(**args) end |
Instance Attribute Details
#input_schema ⇒ Google::Apis::CesV1::Schema
Represents a select subset of an OpenAPI 3.0 schema object.
Corresponds to the JSON property inputSchema
5634 5635 5636 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5634 def input_schema @input_schema end |
#output_schema ⇒ Google::Apis::CesV1::Schema
Represents a select subset of an OpenAPI 3.0 schema object.
Corresponds to the JSON property outputSchema
5639 5640 5641 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5639 def output_schema @output_schema end |
#tool ⇒ String
The name of the tool that the schema is for. Format: projects/project/
locations/location/apps/app/tools/tool`
Corresponds to the JSON propertytool`
5645 5646 5647 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5645 def tool @tool end |
#toolset_tool ⇒ Google::Apis::CesV1::ToolsetTool
A tool that is created from a toolset.
Corresponds to the JSON property toolsetTool
5650 5651 5652 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5650 def toolset_tool @toolset_tool end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5657 5658 5659 5660 5661 5662 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5657 def update!(**args) @input_schema = args[:input_schema] if args.key?(:input_schema) @output_schema = args[:output_schema] if args.key?(:output_schema) @tool = args[:tool] if args.key?(:tool) @toolset_tool = args[:toolset_tool] if args.key?(:toolset_tool) end |