Class: Google::Apis::CesV1::RetrieveToolsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Request message for ToolService.RetrieveTools.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RetrieveToolsRequest

Returns a new instance of RetrieveToolsRequest.



5675
5676
5677
# File 'lib/google/apis/ces_v1/classes.rb', line 5675

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#tool_idsArray<String>

Optional. The identifiers of the tools to retrieve from the toolset. If empty, all tools in the toolset will be returned. Corresponds to the JSON property toolIds

Returns:

  • (Array<String>)


5673
5674
5675
# File 'lib/google/apis/ces_v1/classes.rb', line 5673

def tool_ids
  @tool_ids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5680
5681
5682
# File 'lib/google/apis/ces_v1/classes.rb', line 5680

def update!(**args)
  @tool_ids = args[:tool_ids] if args.key?(:tool_ids)
end