Class: Google::Apis::CesV1::RetrieveToolsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Request message for ToolService.RetrieveTools.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RetrieveToolsRequest

Returns a new instance of RetrieveToolsRequest.



5475
5476
5477
# File 'lib/google/apis/ces_v1/classes.rb', line 5475

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#tool_idsArray<String>

Optional. The identifiers of the tools to retrieve from the toolset. If empty, all tools in the toolset will be returned. Corresponds to the JSON property toolIds

Returns:

  • (Array<String>)


5473
5474
5475
# File 'lib/google/apis/ces_v1/classes.rb', line 5473

def tool_ids
  @tool_ids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5480
5481
5482
# File 'lib/google/apis/ces_v1/classes.rb', line 5480

def update!(**args)
  @tool_ids = args[:tool_ids] if args.key?(:tool_ids)
end