Class: Google::Apis::CesV1::RetrieveToolsResponse
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::RetrieveToolsResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Response message for ToolService.RetrieveTools.
Instance Attribute Summary collapse
-
#tools ⇒ Array<Google::Apis::CesV1::Tool>
The list of tools that are included in the specified toolset.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RetrieveToolsResponse
constructor
A new instance of RetrieveToolsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RetrieveToolsResponse
Returns a new instance of RetrieveToolsResponse.
5494 5495 5496 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5494 def initialize(**args) update!(**args) end |
Instance Attribute Details
#tools ⇒ Array<Google::Apis::CesV1::Tool>
The list of tools that are included in the specified toolset.
Corresponds to the JSON property tools
5492 5493 5494 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5492 def tools @tools end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5499 5500 5501 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5499 def update!(**args) @tools = args[:tools] if args.key?(:tools) end |