Class: Google::Apis::CesV1::Schema

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Represents a select subset of an OpenAPI 3.0 schema object.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Schema

Returns a new instance of Schema.



6188
6189
6190
# File 'lib/google/apis/ces_v1/classes.rb', line 6188

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_propertiesGoogle::Apis::CesV1::Schema

Represents a select subset of an OpenAPI 3.0 schema object. Corresponds to the JSON property additionalProperties



6082
6083
6084
# File 'lib/google/apis/ces_v1/classes.rb', line 6082

def additional_properties
  @additional_properties
end

#any_ofArray<Google::Apis::CesV1::Schema>

Optional. The value should be validated against any (one or more) of the subschemas in the list. Corresponds to the JSON property anyOf

Returns:



6088
6089
6090
# File 'lib/google/apis/ces_v1/classes.rb', line 6088

def any_of
  @any_of
end

#defaultObject

Optional. Default value of the data. Corresponds to the JSON property default

Returns:

  • (Object)


6093
6094
6095
# File 'lib/google/apis/ces_v1/classes.rb', line 6093

def default
  @default
end

#defsHash<String,Google::Apis::CesV1::Schema>

Optional. A map of definitions for use by ref. Only allowed at the root of the schema. Corresponds to the JSON property defs

Returns:



6099
6100
6101
# File 'lib/google/apis/ces_v1/classes.rb', line 6099

def defs
  @defs
end

#descriptionString

Optional. The description of the data. Corresponds to the JSON property description

Returns:

  • (String)


6104
6105
6106
# File 'lib/google/apis/ces_v1/classes.rb', line 6104

def description
  @description
end

#enumArray<String>

Optional. Possible values of the element of primitive type with enum format. Examples: 1. We can define direction as : type:STRING, format:enum, enum:[" EAST", NORTH", "SOUTH", "WEST"] 2. We can define apartment number as : type: INTEGER, format:enum, enum:["101", "201", "301"] Corresponds to the JSON property enum

Returns:

  • (Array<String>)


6112
6113
6114
# File 'lib/google/apis/ces_v1/classes.rb', line 6112

def enum
  @enum
end

#itemsGoogle::Apis::CesV1::Schema

Represents a select subset of an OpenAPI 3.0 schema object. Corresponds to the JSON property items



6117
6118
6119
# File 'lib/google/apis/ces_v1/classes.rb', line 6117

def items
  @items
end

#max_itemsFixnum

Optional. Maximum number of the elements for Type.ARRAY. Corresponds to the JSON property maxItems

Returns:

  • (Fixnum)


6122
6123
6124
# File 'lib/google/apis/ces_v1/classes.rb', line 6122

def max_items
  @max_items
end

#maximumFloat

Optional. Maximum value for Type.INTEGER and Type.NUMBER. Corresponds to the JSON property maximum

Returns:

  • (Float)


6127
6128
6129
# File 'lib/google/apis/ces_v1/classes.rb', line 6127

def maximum
  @maximum
end

#min_itemsFixnum

Optional. Minimum number of the elements for Type.ARRAY. Corresponds to the JSON property minItems

Returns:

  • (Fixnum)


6132
6133
6134
# File 'lib/google/apis/ces_v1/classes.rb', line 6132

def min_items
  @min_items
end

#minimumFloat

Optional. Minimum value for Type.INTEGER and Type.NUMBER. Corresponds to the JSON property minimum

Returns:

  • (Float)


6137
6138
6139
# File 'lib/google/apis/ces_v1/classes.rb', line 6137

def minimum
  @minimum
end

#nullableBoolean Also known as: nullable?

Optional. Indicates if the value may be null. Corresponds to the JSON property nullable

Returns:

  • (Boolean)


6142
6143
6144
# File 'lib/google/apis/ces_v1/classes.rb', line 6142

def nullable
  @nullable
end

#prefix_itemsArray<Google::Apis::CesV1::Schema>

Optional. Schemas of initial elements of Type.ARRAY. Corresponds to the JSON property prefixItems

Returns:



6148
6149
6150
# File 'lib/google/apis/ces_v1/classes.rb', line 6148

def prefix_items
  @prefix_items
end

#propertiesHash<String,Google::Apis::CesV1::Schema>

Optional. Properties of Type.OBJECT. Corresponds to the JSON property properties

Returns:



6153
6154
6155
# File 'lib/google/apis/ces_v1/classes.rb', line 6153

def properties
  @properties
end

#refString

Optional. Allows indirect references between schema nodes. The value should be a valid reference to a child of the root defs. For example, the following schema defines a reference to a schema node named "Pet": type: object properties: pet: ref: #/defs/Pet defs: Pet: type: object properties: name: type: string The value of the "pet" property is a reference to the schema node named "Pet". See details in https://json-schema.org/understanding-json- schema/structuring. Corresponds to the JSON property ref

Returns:

  • (String)


6164
6165
6166
# File 'lib/google/apis/ces_v1/classes.rb', line 6164

def ref
  @ref
end

#requiredArray<String>

Optional. Required properties of Type.OBJECT. Corresponds to the JSON property required

Returns:

  • (Array<String>)


6169
6170
6171
# File 'lib/google/apis/ces_v1/classes.rb', line 6169

def required
  @required
end

#titleString

Optional. The title of the schema. Corresponds to the JSON property title

Returns:

  • (String)


6174
6175
6176
# File 'lib/google/apis/ces_v1/classes.rb', line 6174

def title
  @title
end

#typeString

Required. The type of the data. Corresponds to the JSON property type

Returns:

  • (String)


6179
6180
6181
# File 'lib/google/apis/ces_v1/classes.rb', line 6179

def type
  @type
end

#unique_itemsBoolean Also known as: unique_items?

Optional. Indicate the items in the array must be unique. Only applies to TYPE. ARRAY. Corresponds to the JSON property uniqueItems

Returns:

  • (Boolean)


6185
6186
6187
# File 'lib/google/apis/ces_v1/classes.rb', line 6185

def unique_items
  @unique_items
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6193
6194
6195
6196
6197
6198
6199
6200
6201
6202
6203
6204
6205
6206
6207
6208
6209
6210
6211
6212
6213
# File 'lib/google/apis/ces_v1/classes.rb', line 6193

def update!(**args)
  @additional_properties = args[:additional_properties] if args.key?(:additional_properties)
  @any_of = args[:any_of] if args.key?(:any_of)
  @default = args[:default] if args.key?(:default)
  @defs = args[:defs] if args.key?(:defs)
  @description = args[:description] if args.key?(:description)
  @enum = args[:enum] if args.key?(:enum)
  @items = args[:items] if args.key?(:items)
  @max_items = args[:max_items] if args.key?(:max_items)
  @maximum = args[:maximum] if args.key?(:maximum)
  @min_items = args[:min_items] if args.key?(:min_items)
  @minimum = args[:minimum] if args.key?(:minimum)
  @nullable = args[:nullable] if args.key?(:nullable)
  @prefix_items = args[:prefix_items] if args.key?(:prefix_items)
  @properties = args[:properties] if args.key?(:properties)
  @ref = args[:ref] if args.key?(:ref)
  @required = args[:required] if args.key?(:required)
  @title = args[:title] if args.key?(:title)
  @type = args[:type] if args.key?(:type)
  @unique_items = args[:unique_items] if args.key?(:unique_items)
end