Class: Google::Apis::CesV1::Schema

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Represents a select subset of an OpenAPI 3.0 schema object.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Schema

Returns a new instance of Schema.



5661
5662
5663
# File 'lib/google/apis/ces_v1/classes.rb', line 5661

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_propertiesGoogle::Apis::CesV1::Schema

Represents a select subset of an OpenAPI 3.0 schema object. Corresponds to the JSON property additionalProperties



5555
5556
5557
# File 'lib/google/apis/ces_v1/classes.rb', line 5555

def additional_properties
  @additional_properties
end

#any_ofArray<Google::Apis::CesV1::Schema>

Optional. The value should be validated against any (one or more) of the subschemas in the list. Corresponds to the JSON property anyOf

Returns:



5561
5562
5563
# File 'lib/google/apis/ces_v1/classes.rb', line 5561

def any_of
  @any_of
end

#defaultObject

Optional. Default value of the data. Corresponds to the JSON property default

Returns:

  • (Object)


5566
5567
5568
# File 'lib/google/apis/ces_v1/classes.rb', line 5566

def default
  @default
end

#defsHash<String,Google::Apis::CesV1::Schema>

Optional. A map of definitions for use by ref. Only allowed at the root of the schema. Corresponds to the JSON property defs

Returns:



5572
5573
5574
# File 'lib/google/apis/ces_v1/classes.rb', line 5572

def defs
  @defs
end

#descriptionString

Optional. The description of the data. Corresponds to the JSON property description

Returns:

  • (String)


5577
5578
5579
# File 'lib/google/apis/ces_v1/classes.rb', line 5577

def description
  @description
end

#enumArray<String>

Optional. Possible values of the element of primitive type with enum format. Examples: 1. We can define direction as : type:STRING, format:enum, enum:[" EAST", NORTH", "SOUTH", "WEST"] 2. We can define apartment number as : type: INTEGER, format:enum, enum:["101", "201", "301"] Corresponds to the JSON property enum

Returns:

  • (Array<String>)


5585
5586
5587
# File 'lib/google/apis/ces_v1/classes.rb', line 5585

def enum
  @enum
end

#itemsGoogle::Apis::CesV1::Schema

Represents a select subset of an OpenAPI 3.0 schema object. Corresponds to the JSON property items



5590
5591
5592
# File 'lib/google/apis/ces_v1/classes.rb', line 5590

def items
  @items
end

#max_itemsFixnum

Optional. Maximum number of the elements for Type.ARRAY. Corresponds to the JSON property maxItems

Returns:

  • (Fixnum)


5595
5596
5597
# File 'lib/google/apis/ces_v1/classes.rb', line 5595

def max_items
  @max_items
end

#maximumFloat

Optional. Maximum value for Type.INTEGER and Type.NUMBER. Corresponds to the JSON property maximum

Returns:

  • (Float)


5600
5601
5602
# File 'lib/google/apis/ces_v1/classes.rb', line 5600

def maximum
  @maximum
end

#min_itemsFixnum

Optional. Minimum number of the elements for Type.ARRAY. Corresponds to the JSON property minItems

Returns:

  • (Fixnum)


5605
5606
5607
# File 'lib/google/apis/ces_v1/classes.rb', line 5605

def min_items
  @min_items
end

#minimumFloat

Optional. Minimum value for Type.INTEGER and Type.NUMBER. Corresponds to the JSON property minimum

Returns:

  • (Float)


5610
5611
5612
# File 'lib/google/apis/ces_v1/classes.rb', line 5610

def minimum
  @minimum
end

#nullableBoolean Also known as: nullable?

Optional. Indicates if the value may be null. Corresponds to the JSON property nullable

Returns:

  • (Boolean)


5615
5616
5617
# File 'lib/google/apis/ces_v1/classes.rb', line 5615

def nullable
  @nullable
end

#prefix_itemsArray<Google::Apis::CesV1::Schema>

Optional. Schemas of initial elements of Type.ARRAY. Corresponds to the JSON property prefixItems

Returns:



5621
5622
5623
# File 'lib/google/apis/ces_v1/classes.rb', line 5621

def prefix_items
  @prefix_items
end

#propertiesHash<String,Google::Apis::CesV1::Schema>

Optional. Properties of Type.OBJECT. Corresponds to the JSON property properties

Returns:



5626
5627
5628
# File 'lib/google/apis/ces_v1/classes.rb', line 5626

def properties
  @properties
end

#refString

Optional. Allows indirect references between schema nodes. The value should be a valid reference to a child of the root defs. For example, the following schema defines a reference to a schema node named "Pet": type: object properties: pet: ref: #/defs/Pet defs: Pet: type: object properties: name: type: string The value of the "pet" property is a reference to the schema node named "Pet". See details in https://json-schema.org/understanding-json- schema/structuring. Corresponds to the JSON property ref

Returns:

  • (String)


5637
5638
5639
# File 'lib/google/apis/ces_v1/classes.rb', line 5637

def ref
  @ref
end

#requiredArray<String>

Optional. Required properties of Type.OBJECT. Corresponds to the JSON property required

Returns:

  • (Array<String>)


5642
5643
5644
# File 'lib/google/apis/ces_v1/classes.rb', line 5642

def required
  @required
end

#titleString

Optional. The title of the schema. Corresponds to the JSON property title

Returns:

  • (String)


5647
5648
5649
# File 'lib/google/apis/ces_v1/classes.rb', line 5647

def title
  @title
end

#typeString

Required. The type of the data. Corresponds to the JSON property type

Returns:

  • (String)


5652
5653
5654
# File 'lib/google/apis/ces_v1/classes.rb', line 5652

def type
  @type
end

#unique_itemsBoolean Also known as: unique_items?

Optional. Indicate the items in the array must be unique. Only applies to TYPE. ARRAY. Corresponds to the JSON property uniqueItems

Returns:

  • (Boolean)


5658
5659
5660
# File 'lib/google/apis/ces_v1/classes.rb', line 5658

def unique_items
  @unique_items
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5666
5667
5668
5669
5670
5671
5672
5673
5674
5675
5676
5677
5678
5679
5680
5681
5682
5683
5684
5685
5686
# File 'lib/google/apis/ces_v1/classes.rb', line 5666

def update!(**args)
  @additional_properties = args[:additional_properties] if args.key?(:additional_properties)
  @any_of = args[:any_of] if args.key?(:any_of)
  @default = args[:default] if args.key?(:default)
  @defs = args[:defs] if args.key?(:defs)
  @description = args[:description] if args.key?(:description)
  @enum = args[:enum] if args.key?(:enum)
  @items = args[:items] if args.key?(:items)
  @max_items = args[:max_items] if args.key?(:max_items)
  @maximum = args[:maximum] if args.key?(:maximum)
  @min_items = args[:min_items] if args.key?(:min_items)
  @minimum = args[:minimum] if args.key?(:minimum)
  @nullable = args[:nullable] if args.key?(:nullable)
  @prefix_items = args[:prefix_items] if args.key?(:prefix_items)
  @properties = args[:properties] if args.key?(:properties)
  @ref = args[:ref] if args.key?(:ref)
  @required = args[:required] if args.key?(:required)
  @title = args[:title] if args.key?(:title)
  @type = args[:type] if args.key?(:type)
  @unique_items = args[:unique_items] if args.key?(:unique_items)
end