Class: Google::Apis::CesV1::Schema
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::Schema
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Represents a select subset of an OpenAPI 3.0 schema object.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Google::Apis::CesV1::Schema
Represents a select subset of an OpenAPI 3.0 schema object.
-
#any_of ⇒ Array<Google::Apis::CesV1::Schema>
Optional.
-
#default ⇒ Object
Optional.
-
#defs ⇒ Hash<String,Google::Apis::CesV1::Schema>
Optional.
-
#description ⇒ String
Optional.
-
#enum ⇒ Array<String>
Optional.
-
#items ⇒ Google::Apis::CesV1::Schema
Represents a select subset of an OpenAPI 3.0 schema object.
-
#max_items ⇒ Fixnum
Optional.
-
#maximum ⇒ Float
Optional.
-
#min_items ⇒ Fixnum
Optional.
-
#minimum ⇒ Float
Optional.
-
#nullable ⇒ Boolean
(also: #nullable?)
Optional.
-
#prefix_items ⇒ Array<Google::Apis::CesV1::Schema>
Optional.
-
#properties ⇒ Hash<String,Google::Apis::CesV1::Schema>
Optional.
-
#ref ⇒ String
Optional.
-
#required ⇒ Array<String>
Optional.
-
#title ⇒ String
Optional.
-
#type ⇒ String
Required.
-
#unique_items ⇒ Boolean
(also: #unique_items?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Schema
constructor
A new instance of Schema.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Schema
Returns a new instance of Schema.
5661 5662 5663 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5661 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_properties ⇒ Google::Apis::CesV1::Schema
Represents a select subset of an OpenAPI 3.0 schema object.
Corresponds to the JSON property additionalProperties
5555 5556 5557 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5555 def additional_properties @additional_properties end |
#any_of ⇒ Array<Google::Apis::CesV1::Schema>
Optional. The value should be validated against any (one or more) of the
subschemas in the list.
Corresponds to the JSON property anyOf
5561 5562 5563 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5561 def any_of @any_of end |
#default ⇒ Object
Optional. Default value of the data.
Corresponds to the JSON property default
5566 5567 5568 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5566 def default @default end |
#defs ⇒ Hash<String,Google::Apis::CesV1::Schema>
Optional. A map of definitions for use by ref. Only allowed at the root of
the schema.
Corresponds to the JSON property defs
5572 5573 5574 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5572 def defs @defs end |
#description ⇒ String
Optional. The description of the data.
Corresponds to the JSON property description
5577 5578 5579 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5577 def description @description end |
#enum ⇒ Array<String>
Optional. Possible values of the element of primitive type with enum format.
Examples: 1. We can define direction as : type:STRING, format:enum, enum:["
EAST", NORTH", "SOUTH", "WEST"] 2. We can define apartment number as : type:
INTEGER, format:enum, enum:["101", "201", "301"]
Corresponds to the JSON property enum
5585 5586 5587 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5585 def enum @enum end |
#items ⇒ Google::Apis::CesV1::Schema
Represents a select subset of an OpenAPI 3.0 schema object.
Corresponds to the JSON property items
5590 5591 5592 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5590 def items @items end |
#max_items ⇒ Fixnum
Optional. Maximum number of the elements for Type.ARRAY.
Corresponds to the JSON property maxItems
5595 5596 5597 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5595 def max_items @max_items end |
#maximum ⇒ Float
Optional. Maximum value for Type.INTEGER and Type.NUMBER.
Corresponds to the JSON property maximum
5600 5601 5602 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5600 def maximum @maximum end |
#min_items ⇒ Fixnum
Optional. Minimum number of the elements for Type.ARRAY.
Corresponds to the JSON property minItems
5605 5606 5607 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5605 def min_items @min_items end |
#minimum ⇒ Float
Optional. Minimum value for Type.INTEGER and Type.NUMBER.
Corresponds to the JSON property minimum
5610 5611 5612 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5610 def minimum @minimum end |
#nullable ⇒ Boolean Also known as: nullable?
Optional. Indicates if the value may be null.
Corresponds to the JSON property nullable
5615 5616 5617 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5615 def nullable @nullable end |
#prefix_items ⇒ Array<Google::Apis::CesV1::Schema>
Optional. Schemas of initial elements of Type.ARRAY.
Corresponds to the JSON property prefixItems
5621 5622 5623 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5621 def prefix_items @prefix_items end |
#properties ⇒ Hash<String,Google::Apis::CesV1::Schema>
Optional. Properties of Type.OBJECT.
Corresponds to the JSON property properties
5626 5627 5628 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5626 def properties @properties end |
#ref ⇒ String
Optional. Allows indirect references between schema nodes. The value should be
a valid reference to a child of the root defs. For example, the following
schema defines a reference to a schema node named "Pet": type: object
properties: pet: ref: #/defs/Pet defs: Pet: type: object properties: name:
type: string The value of the "pet" property is a reference to the schema
node named "Pet". See details in https://json-schema.org/understanding-json-
schema/structuring.
Corresponds to the JSON property ref
5637 5638 5639 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5637 def ref @ref end |
#required ⇒ Array<String>
Optional. Required properties of Type.OBJECT.
Corresponds to the JSON property required
5642 5643 5644 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5642 def required @required end |
#title ⇒ String
Optional. The title of the schema.
Corresponds to the JSON property title
5647 5648 5649 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5647 def title @title end |
#type ⇒ String
Required. The type of the data.
Corresponds to the JSON property type
5652 5653 5654 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5652 def type @type end |
#unique_items ⇒ Boolean Also known as: unique_items?
Optional. Indicate the items in the array must be unique. Only applies to TYPE.
ARRAY.
Corresponds to the JSON property uniqueItems
5658 5659 5660 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5658 def unique_items @unique_items end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5666 5667 5668 5669 5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 5684 5685 5686 |
# File 'lib/google/apis/ces_v1/classes.rb', line 5666 def update!(**args) @additional_properties = args[:additional_properties] if args.key?(:additional_properties) @any_of = args[:any_of] if args.key?(:any_of) @default = args[:default] if args.key?(:default) @defs = args[:defs] if args.key?(:defs) @description = args[:description] if args.key?(:description) @enum = args[:enum] if args.key?(:enum) @items = args[:items] if args.key?(:items) @max_items = args[:max_items] if args.key?(:max_items) @maximum = args[:maximum] if args.key?(:maximum) @min_items = args[:min_items] if args.key?(:min_items) @minimum = args[:minimum] if args.key?(:minimum) @nullable = args[:nullable] if args.key?(:nullable) @prefix_items = args[:prefix_items] if args.key?(:prefix_items) @properties = args[:properties] if args.key?(:properties) @ref = args[:ref] if args.key?(:ref) @required = args[:required] if args.key?(:required) @title = args[:title] if args.key?(:title) @type = args[:type] if args.key?(:type) @unique_items = args[:unique_items] if args.key?(:unique_items) end |