Class: Google::Apis::CesV1::ServiceAccountAuthConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Configurations for authentication using a custom service account.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceAccountAuthConfig

Returns a new instance of ServiceAccountAuthConfig.



7237
7238
7239
# File 'lib/google/apis/ces_v1/classes.rb', line 7237

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#scopesArray<String>

Optional. The OAuth scopes to grant. If not specified, the default scope https://www.googleapis.com/auth/cloud-platform is used. Corresponds to the JSON property scopes

Returns:

  • (Array<String>)


7226
7227
7228
# File 'lib/google/apis/ces_v1/classes.rb', line 7226

def scopes
  @scopes
end

#service_accountString

Required. The email address of the service account used for authentication. CES uses this service account to exchange an access token and the access token is then sent in the Authorization header of the request. The service account must have the roles/iam.serviceAccountTokenCreator role granted to the CES service agent service-@gcp-sa-ces.iam.gserviceaccount.com. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


7235
7236
7237
# File 'lib/google/apis/ces_v1/classes.rb', line 7235

def 
  @service_account
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7242
7243
7244
7245
# File 'lib/google/apis/ces_v1/classes.rb', line 7242

def update!(**args)
  @scopes = args[:scopes] if args.key?(:scopes)
  @service_account = args[:service_account] if args.key?(:service_account)
end