Class: Google::Apis::CesV1::ServiceAccountAuthConfig
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::ServiceAccountAuthConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Configurations for authentication using a custom service account.
Instance Attribute Summary collapse
-
#scopes ⇒ Array<String>
Optional.
-
#service_account ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceAccountAuthConfig
constructor
A new instance of ServiceAccountAuthConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceAccountAuthConfig
Returns a new instance of ServiceAccountAuthConfig.
6279 6280 6281 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6279 def initialize(**args) update!(**args) end |
Instance Attribute Details
#scopes ⇒ Array<String>
Optional. The OAuth scopes to grant. If not specified, the default scope
https://www.googleapis.com/auth/cloud-platform is used.
Corresponds to the JSON property scopes
6268 6269 6270 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6268 def scopes @scopes end |
#service_account ⇒ String
Required. The email address of the service account used for authentication.
CES uses this service account to exchange an access token and the access token
is then sent in the Authorization header of the request. The service account
must have the roles/iam.serviceAccountTokenCreator role granted to the CES
service agent service-@gcp-sa-ces.iam.gserviceaccount.com.
Corresponds to the JSON property serviceAccount
6277 6278 6279 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6277 def service_account @service_account end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6284 6285 6286 6287 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6284 def update!(**args) @scopes = args[:scopes] if args.key?(:scopes) @service_account = args[:service_account] if args.key?(:service_account) end |