Class: Google::Apis::CesV1::ServiceAccountAuthConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Configurations for authentication using a custom service account.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceAccountAuthConfig

Returns a new instance of ServiceAccountAuthConfig.



5952
5953
5954
# File 'lib/google/apis/ces_v1/classes.rb', line 5952

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#scopesArray<String>

Optional. The OAuth scopes to grant. If not specified, the default scope https://www.googleapis.com/auth/cloud-platform is used. Corresponds to the JSON property scopes

Returns:

  • (Array<String>)


5941
5942
5943
# File 'lib/google/apis/ces_v1/classes.rb', line 5941

def scopes
  @scopes
end

#service_accountString

Required. The email address of the service account used for authentication. CES uses this service account to exchange an access token and the access token is then sent in the Authorization header of the request. The service account must have the roles/iam.serviceAccountTokenCreator role granted to the CES service agent service-@gcp-sa-ces.iam.gserviceaccount.com. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


5950
5951
5952
# File 'lib/google/apis/ces_v1/classes.rb', line 5950

def 
  @service_account
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5957
5958
5959
5960
# File 'lib/google/apis/ces_v1/classes.rb', line 5957

def update!(**args)
  @scopes = args[:scopes] if args.key?(:scopes)
  @service_account = args[:service_account] if args.key?(:service_account)
end