Class: Google::Apis::CesV1::SessionConfig
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::SessionConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
The configuration for the session.
Instance Attribute Summary collapse
-
#deployment ⇒ String
Optional.
-
#enable_text_streaming ⇒ Boolean
(also: #enable_text_streaming?)
Optional.
-
#entry_agent ⇒ String
Optional.
-
#historical_contexts ⇒ Array<Google::Apis::CesV1::Message>
Optional.
-
#input_audio_config ⇒ Google::Apis::CesV1::InputAudioConfig
InputAudioConfig configures how the CES agent should interpret the incoming audio data.
-
#output_audio_config ⇒ Google::Apis::CesV1::OutputAudioConfig
OutputAudioConfig configures how the CES agent should synthesize outgoing audio responses.
-
#remote_dialogflow_query_parameters ⇒ Google::Apis::CesV1::SessionConfigRemoteDialogflowQueryParameters
QueryParameters to send to the remote Dialogflow agent when the session control is transferred to the remote agent.
-
#time_zone ⇒ String
Optional.
-
#use_tool_fakes ⇒ Boolean
(also: #use_tool_fakes?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SessionConfig
constructor
A new instance of SessionConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SessionConfig
Returns a new instance of SessionConfig.
7355 7356 7357 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7355 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deployment ⇒ String
Optional. The deployment of the app to use for the session. Format: projects/
project/locations/location/apps/app/deployments/deployment`
Corresponds to the JSON propertydeployment`
7292 7293 7294 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7292 def deployment @deployment end |
#enable_text_streaming ⇒ Boolean Also known as: enable_text_streaming?
Optional. Whether to enable streaming text outputs from the model. By default,
text outputs from the model are collected before sending to the client. NOTE:
This is only supported for text (non-voice) sessions via StreamRunSession or
BidiRunSession.
Corresponds to the JSON property enableTextStreaming
7300 7301 7302 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7300 def enable_text_streaming @enable_text_streaming end |
#entry_agent ⇒ String
Optional. The entry agent to handle the session. If not specified, the session
will be handled by the root agent of the app. Format: projects/project/
locations/location/apps/app/agents/agent`
Corresponds to the JSON propertyentryAgent`
7308 7309 7310 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7308 def entry_agent @entry_agent end |
#historical_contexts ⇒ Array<Google::Apis::CesV1::Message>
Optional. The historical context of the session, including user inputs, agent
responses, and other messages. Typically, CES agent would manage session
automatically so client doesn't need to explicitly populate this field.
However, client can optionally override the historical contexts to force the
session start from certain state.
Corresponds to the JSON property historicalContexts
7317 7318 7319 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7317 def historical_contexts @historical_contexts end |
#input_audio_config ⇒ Google::Apis::CesV1::InputAudioConfig
InputAudioConfig configures how the CES agent should interpret the incoming
audio data.
Corresponds to the JSON property inputAudioConfig
7323 7324 7325 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7323 def input_audio_config @input_audio_config end |
#output_audio_config ⇒ Google::Apis::CesV1::OutputAudioConfig
OutputAudioConfig configures how the CES agent should synthesize outgoing
audio responses.
Corresponds to the JSON property outputAudioConfig
7329 7330 7331 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7329 def output_audio_config @output_audio_config end |
#remote_dialogflow_query_parameters ⇒ Google::Apis::CesV1::SessionConfigRemoteDialogflowQueryParameters
QueryParameters to send to the remote
Dialogflow agent when the session control is transferred to the
remote agent.
Corresponds to the JSON property remoteDialogflowQueryParameters
7338 7339 7340 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7338 def remote_dialogflow_query_parameters @remote_dialogflow_query_parameters end |
#time_zone ⇒ String
Optional. The time zone of the user. If provided, the agent will use the time
zone for date and time related variables. Otherwise, the agent will use the
time zone specified in the App.time_zone_settings. The format is the IANA Time
Zone Database time zone, e.g. "America/Los_Angeles".
Corresponds to the JSON property timeZone
7346 7347 7348 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7346 def time_zone @time_zone end |
#use_tool_fakes ⇒ Boolean Also known as: use_tool_fakes?
Optional. Whether to use tool fakes for the session. If this field is set, the
agent will attempt use tool fakes instead of calling the real tools.
Corresponds to the JSON property useToolFakes
7352 7353 7354 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7352 def use_tool_fakes @use_tool_fakes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7360 7361 7362 7363 7364 7365 7366 7367 7368 7369 7370 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7360 def update!(**args) @deployment = args[:deployment] if args.key?(:deployment) @enable_text_streaming = args[:enable_text_streaming] if args.key?(:enable_text_streaming) @entry_agent = args[:entry_agent] if args.key?(:entry_agent) @historical_contexts = args[:historical_contexts] if args.key?(:historical_contexts) @input_audio_config = args[:input_audio_config] if args.key?(:input_audio_config) @output_audio_config = args[:output_audio_config] if args.key?(:output_audio_config) @remote_dialogflow_query_parameters = args[:remote_dialogflow_query_parameters] if args.key?(:remote_dialogflow_query_parameters) @time_zone = args[:time_zone] if args.key?(:time_zone) @use_tool_fakes = args[:use_tool_fakes] if args.key?(:use_tool_fakes) end |