Class: Google::Apis::CesV1::SessionConfigRemoteDialogflowQueryParameters

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

QueryParameters to send to the remote Dialogflow agent when the session control is transferred to the remote agent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SessionConfigRemoteDialogflowQueryParameters

Returns a new instance of SessionConfigRemoteDialogflowQueryParameters.



6444
6445
6446
# File 'lib/google/apis/ces_v1/classes.rb', line 6444

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_user_metadataHash<String,Object>

Optional. The end user metadata to be sent in QueryParameters. Corresponds to the JSON property endUserMetadata

Returns:

  • (Hash<String,Object>)


6428
6429
6430
# File 'lib/google/apis/ces_v1/classes.rb', line 6428

def 
  @end_user_metadata
end

#payloadHash<String,Object>

Optional. The payload to be sent in QueryParameters . Corresponds to the JSON property payload

Returns:

  • (Hash<String,Object>)


6435
6436
6437
# File 'lib/google/apis/ces_v1/classes.rb', line 6435

def payload
  @payload
end

#webhook_headersHash<String,String>

Optional. The HTTP headers to be sent as webhook_headers in QueryParameters. Corresponds to the JSON property webhookHeaders

Returns:

  • (Hash<String,String>)


6442
6443
6444
# File 'lib/google/apis/ces_v1/classes.rb', line 6442

def webhook_headers
  @webhook_headers
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6449
6450
6451
6452
6453
# File 'lib/google/apis/ces_v1/classes.rb', line 6449

def update!(**args)
  @end_user_metadata = args[:end_user_metadata] if args.key?(:end_user_metadata)
  @payload = args[:payload] if args.key?(:payload)
  @webhook_headers = args[:webhook_headers] if args.key?(:webhook_headers)
end