Class: Google::Apis::CesV1::SessionInput

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Input for the session.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SessionInput

Returns a new instance of SessionInput.



7541
7542
7543
# File 'lib/google/apis/ces_v1/classes.rb', line 7541

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audioString

Optional. Audio data from the end user. Corresponds to the JSON property audio NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


7491
7492
7493
# File 'lib/google/apis/ces_v1/classes.rb', line 7491

def audio
  @audio
end

#blobGoogle::Apis::CesV1::Blob

Represents a blob input or output in the conversation. Corresponds to the JSON property blob



7496
7497
7498
# File 'lib/google/apis/ces_v1/classes.rb', line 7496

def blob
  @blob
end

#dtmfString

Optional. DTMF digits from the end user. Corresponds to the JSON property dtmf

Returns:

  • (String)


7501
7502
7503
# File 'lib/google/apis/ces_v1/classes.rb', line 7501

def dtmf
  @dtmf
end

#eventGoogle::Apis::CesV1::Event

Event input. Corresponds to the JSON property event



7506
7507
7508
# File 'lib/google/apis/ces_v1/classes.rb', line 7506

def event
  @event
end

#imageGoogle::Apis::CesV1::Image

Represents an image input or output in the conversation. Corresponds to the JSON property image



7511
7512
7513
# File 'lib/google/apis/ces_v1/classes.rb', line 7511

def image
  @image
end

#textString

Optional. Text data from the end user. Corresponds to the JSON property text

Returns:

  • (String)


7516
7517
7518
# File 'lib/google/apis/ces_v1/classes.rb', line 7516

def text
  @text
end

#tool_responsesGoogle::Apis::CesV1::ToolResponses

Execution results for the requested tool calls from the client. Corresponds to the JSON property toolResponses



7521
7522
7523
# File 'lib/google/apis/ces_v1/classes.rb', line 7521

def tool_responses
  @tool_responses
end

#variablesHash<String,Object>

Optional. Contextual variables for the session, keyed by name. Only variables declared in the app will be used by the CES agent. Unrecognized variables will still be sent to the Dialogflow agent as additional session parameters. Corresponds to the JSON property variables

Returns:

  • (Hash<String,Object>)


7528
7529
7530
# File 'lib/google/apis/ces_v1/classes.rb', line 7528

def variables
  @variables
end

#will_continueBoolean Also known as: will_continue?

Optional. A flag to indicate if the current message is a fragment of a larger input in the bidi streaming session. When set to true, the agent defers processing until it receives a subsequent message where will_continue is false, or until the system detects an endpoint in the audio input. NOTE: This field does not apply to audio and DTMF inputs, as they are always processed automatically based on the endpointing signal. Corresponds to the JSON property willContinue

Returns:

  • (Boolean)


7538
7539
7540
# File 'lib/google/apis/ces_v1/classes.rb', line 7538

def will_continue
  @will_continue
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7546
7547
7548
7549
7550
7551
7552
7553
7554
7555
7556
# File 'lib/google/apis/ces_v1/classes.rb', line 7546

def update!(**args)
  @audio = args[:audio] if args.key?(:audio)
  @blob = args[:blob] if args.key?(:blob)
  @dtmf = args[:dtmf] if args.key?(:dtmf)
  @event = args[:event] if args.key?(:event)
  @image = args[:image] if args.key?(:image)
  @text = args[:text] if args.key?(:text)
  @tool_responses = args[:tool_responses] if args.key?(:tool_responses)
  @variables = args[:variables] if args.key?(:variables)
  @will_continue = args[:will_continue] if args.key?(:will_continue)
end