Class: Google::Apis::CesV1::SessionOutput

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Output for the session.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SessionOutput

Returns a new instance of SessionOutput.



7626
7627
7628
# File 'lib/google/apis/ces_v1/classes.rb', line 7626

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audioString

Output audio from the CES agent. Corresponds to the JSON property audio NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


7567
7568
7569
# File 'lib/google/apis/ces_v1/classes.rb', line 7567

def audio
  @audio
end

#citationsGoogle::Apis::CesV1::Citations

Citations associated with the agent response. Corresponds to the JSON property citations



7572
7573
7574
# File 'lib/google/apis/ces_v1/classes.rb', line 7572

def citations
  @citations
end

#contextArray<Hash<String,Object>>

Context messages for external supervision guardrails. Corresponds to the JSON property context

Returns:

  • (Array<Hash<String,Object>>)


7577
7578
7579
# File 'lib/google/apis/ces_v1/classes.rb', line 7577

def context
  @context
end

#diagnostic_infoGoogle::Apis::CesV1::SessionOutputDiagnosticInfo

Contains execution details during the processing. Corresponds to the JSON property diagnosticInfo



7582
7583
7584
# File 'lib/google/apis/ces_v1/classes.rb', line 7582

def diagnostic_info
  @diagnostic_info
end

#end_sessionGoogle::Apis::CesV1::EndSession

Indicates the session has terminated, due to either successful completion (e.g. user says "Good bye!" ) or an agent escalation. The agent will not process any further inputs after session is terminated and the client should half- close and disconnect after receiving all remaining responses from the agent. Corresponds to the JSON property endSession



7590
7591
7592
# File 'lib/google/apis/ces_v1/classes.rb', line 7590

def end_session
  @end_session
end

#google_search_suggestionsGoogle::Apis::CesV1::GoogleSearchSuggestions

Search suggestions from Google Search Tool. Corresponds to the JSON property googleSearchSuggestions



7595
7596
7597
# File 'lib/google/apis/ces_v1/classes.rb', line 7595

def google_search_suggestions
  @google_search_suggestions
end

#payloadHash<String,Object>

Custom payload with structured output from the CES agent. Corresponds to the JSON property payload

Returns:

  • (Hash<String,Object>)


7600
7601
7602
# File 'lib/google/apis/ces_v1/classes.rb', line 7600

def payload
  @payload
end

#textString

Output text from the CES agent. Corresponds to the JSON property text

Returns:

  • (String)


7605
7606
7607
# File 'lib/google/apis/ces_v1/classes.rb', line 7605

def text
  @text
end

#tool_callsGoogle::Apis::CesV1::ToolCalls

Request for the client to execute the tools and return the execution results before continuing the session. Corresponds to the JSON property toolCalls



7611
7612
7613
# File 'lib/google/apis/ces_v1/classes.rb', line 7611

def tool_calls
  @tool_calls
end

#turn_completedBoolean Also known as: turn_completed?

If true, the CES agent has detected the end of the current conversation turn and will provide no further output for this turn. Corresponds to the JSON property turnCompleted

Returns:

  • (Boolean)


7617
7618
7619
# File 'lib/google/apis/ces_v1/classes.rb', line 7617

def turn_completed
  @turn_completed
end

#turn_indexFixnum

Indicates the sequential order of conversation turn to which this output belongs to, starting from 1. Corresponds to the JSON property turnIndex

Returns:

  • (Fixnum)


7624
7625
7626
# File 'lib/google/apis/ces_v1/classes.rb', line 7624

def turn_index
  @turn_index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7631
7632
7633
7634
7635
7636
7637
7638
7639
7640
7641
7642
7643
# File 'lib/google/apis/ces_v1/classes.rb', line 7631

def update!(**args)
  @audio = args[:audio] if args.key?(:audio)
  @citations = args[:citations] if args.key?(:citations)
  @context = args[:context] if args.key?(:context)
  @diagnostic_info = args[:diagnostic_info] if args.key?(:diagnostic_info)
  @end_session = args[:end_session] if args.key?(:end_session)
  @google_search_suggestions = args[:google_search_suggestions] if args.key?(:google_search_suggestions)
  @payload = args[:payload] if args.key?(:payload)
  @text = args[:text] if args.key?(:text)
  @tool_calls = args[:tool_calls] if args.key?(:tool_calls)
  @turn_completed = args[:turn_completed] if args.key?(:turn_completed)
  @turn_index = args[:turn_index] if args.key?(:turn_index)
end