Class: Google::Apis::CesV1::SessionOutput
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::SessionOutput
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Output for the session.
Instance Attribute Summary collapse
-
#audio ⇒ String
Output audio from the CES agent.
-
#citations ⇒ Google::Apis::CesV1::Citations
Citations associated with the agent response.
-
#context ⇒ Array<Hash<String,Object>>
Context messages for external supervision guardrails.
-
#diagnostic_info ⇒ Google::Apis::CesV1::SessionOutputDiagnosticInfo
Contains execution details during the processing.
-
#end_session ⇒ Google::Apis::CesV1::EndSession
Indicates the session has terminated, due to either successful completion (e.g. user says "Good bye!" ) or an agent escalation.
-
#google_search_suggestions ⇒ Google::Apis::CesV1::GoogleSearchSuggestions
Search suggestions from Google Search Tool.
-
#payload ⇒ Hash<String,Object>
Custom payload with structured output from the CES agent.
-
#text ⇒ String
Output text from the CES agent.
-
#tool_calls ⇒ Google::Apis::CesV1::ToolCalls
Request for the client to execute the tools and return the execution results before continuing the session.
-
#turn_completed ⇒ Boolean
(also: #turn_completed?)
If true, the CES agent has detected the end of the current conversation turn and will provide no further output for this turn.
-
#turn_index ⇒ Fixnum
Indicates the sequential order of conversation turn to which this output belongs to, starting from 1.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SessionOutput
constructor
A new instance of SessionOutput.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SessionOutput
Returns a new instance of SessionOutput.
7577 7578 7579 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7577 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audio ⇒ String
Output audio from the CES agent.
Corresponds to the JSON property audio
NOTE: Values are automatically base64 encoded/decoded in the client library.
7518 7519 7520 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7518 def audio @audio end |
#citations ⇒ Google::Apis::CesV1::Citations
Citations associated with the agent response.
Corresponds to the JSON property citations
7523 7524 7525 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7523 def citations @citations end |
#context ⇒ Array<Hash<String,Object>>
Context messages for external supervision guardrails.
Corresponds to the JSON property context
7528 7529 7530 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7528 def context @context end |
#diagnostic_info ⇒ Google::Apis::CesV1::SessionOutputDiagnosticInfo
Contains execution details during the processing.
Corresponds to the JSON property diagnosticInfo
7533 7534 7535 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7533 def diagnostic_info @diagnostic_info end |
#end_session ⇒ Google::Apis::CesV1::EndSession
Indicates the session has terminated, due to either successful completion (e.g.
user says "Good bye!" ) or an agent escalation. The agent will not process
any further inputs after session is terminated and the client should half-
close and disconnect after receiving all remaining responses from the agent.
Corresponds to the JSON property endSession
7541 7542 7543 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7541 def end_session @end_session end |
#google_search_suggestions ⇒ Google::Apis::CesV1::GoogleSearchSuggestions
Search suggestions from Google Search Tool.
Corresponds to the JSON property googleSearchSuggestions
7546 7547 7548 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7546 def google_search_suggestions @google_search_suggestions end |
#payload ⇒ Hash<String,Object>
Custom payload with structured output from the CES agent.
Corresponds to the JSON property payload
7551 7552 7553 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7551 def payload @payload end |
#text ⇒ String
Output text from the CES agent.
Corresponds to the JSON property text
7556 7557 7558 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7556 def text @text end |
#tool_calls ⇒ Google::Apis::CesV1::ToolCalls
Request for the client to execute the tools and return the execution results
before continuing the session.
Corresponds to the JSON property toolCalls
7562 7563 7564 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7562 def tool_calls @tool_calls end |
#turn_completed ⇒ Boolean Also known as: turn_completed?
If true, the CES agent has detected the end of the current conversation turn
and will provide no further output for this turn.
Corresponds to the JSON property turnCompleted
7568 7569 7570 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7568 def turn_completed @turn_completed end |
#turn_index ⇒ Fixnum
Indicates the sequential order of conversation turn to which this output
belongs to, starting from 1.
Corresponds to the JSON property turnIndex
7575 7576 7577 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7575 def turn_index @turn_index end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7582 7583 7584 7585 7586 7587 7588 7589 7590 7591 7592 7593 7594 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7582 def update!(**args) @audio = args[:audio] if args.key?(:audio) @citations = args[:citations] if args.key?(:citations) @context = args[:context] if args.key?(:context) @diagnostic_info = args[:diagnostic_info] if args.key?(:diagnostic_info) @end_session = args[:end_session] if args.key?(:end_session) @google_search_suggestions = args[:google_search_suggestions] if args.key?(:google_search_suggestions) @payload = args[:payload] if args.key?(:payload) @text = args[:text] if args.key?(:text) @tool_calls = args[:tool_calls] if args.key?(:tool_calls) @turn_completed = args[:turn_completed] if args.key?(:turn_completed) @turn_index = args[:turn_index] if args.key?(:turn_index) end |