Class: Google::Apis::CesV1::SessionOutput

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Output for the session.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SessionOutput

Returns a new instance of SessionOutput.



6267
6268
6269
# File 'lib/google/apis/ces_v1/classes.rb', line 6267

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audioString

Output audio from the CES agent. Corresponds to the JSON property audio NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


6213
6214
6215
# File 'lib/google/apis/ces_v1/classes.rb', line 6213

def audio
  @audio
end

#citationsGoogle::Apis::CesV1::Citations

Citations associated with the agent response. Corresponds to the JSON property citations



6218
6219
6220
# File 'lib/google/apis/ces_v1/classes.rb', line 6218

def citations
  @citations
end

#diagnostic_infoGoogle::Apis::CesV1::SessionOutputDiagnosticInfo

Contains execution details during the processing. Corresponds to the JSON property diagnosticInfo



6223
6224
6225
# File 'lib/google/apis/ces_v1/classes.rb', line 6223

def diagnostic_info
  @diagnostic_info
end

#end_sessionGoogle::Apis::CesV1::EndSession

Indicates the session has terminated, due to either successful completion (e.g. user says "Good bye!" ) or an agent escalation. The agent will not process any further inputs after session is terminated and the client should half- close and disconnect after receiving all remaining responses from the agent. Corresponds to the JSON property endSession



6231
6232
6233
# File 'lib/google/apis/ces_v1/classes.rb', line 6231

def end_session
  @end_session
end

#google_search_suggestionsGoogle::Apis::CesV1::GoogleSearchSuggestions

Search suggestions from Google Search Tool. Corresponds to the JSON property googleSearchSuggestions



6236
6237
6238
# File 'lib/google/apis/ces_v1/classes.rb', line 6236

def google_search_suggestions
  @google_search_suggestions
end

#payloadHash<String,Object>

Custom payload with structured output from the CES agent. Corresponds to the JSON property payload

Returns:

  • (Hash<String,Object>)


6241
6242
6243
# File 'lib/google/apis/ces_v1/classes.rb', line 6241

def payload
  @payload
end

#textString

Output text from the CES agent. Corresponds to the JSON property text

Returns:

  • (String)


6246
6247
6248
# File 'lib/google/apis/ces_v1/classes.rb', line 6246

def text
  @text
end

#tool_callsGoogle::Apis::CesV1::ToolCalls

Request for the client to execute the tools and return the execution results before continuing the session. Corresponds to the JSON property toolCalls



6252
6253
6254
# File 'lib/google/apis/ces_v1/classes.rb', line 6252

def tool_calls
  @tool_calls
end

#turn_completedBoolean Also known as: turn_completed?

If true, the CES agent has detected the end of the current conversation turn and will provide no further output for this turn. Corresponds to the JSON property turnCompleted

Returns:

  • (Boolean)


6258
6259
6260
# File 'lib/google/apis/ces_v1/classes.rb', line 6258

def turn_completed
  @turn_completed
end

#turn_indexFixnum

Indicates the sequential order of conversation turn to which this output belongs to, starting from 1. Corresponds to the JSON property turnIndex

Returns:

  • (Fixnum)


6265
6266
6267
# File 'lib/google/apis/ces_v1/classes.rb', line 6265

def turn_index
  @turn_index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6272
6273
6274
6275
6276
6277
6278
6279
6280
6281
6282
6283
# File 'lib/google/apis/ces_v1/classes.rb', line 6272

def update!(**args)
  @audio = args[:audio] if args.key?(:audio)
  @citations = args[:citations] if args.key?(:citations)
  @diagnostic_info = args[:diagnostic_info] if args.key?(:diagnostic_info)
  @end_session = args[:end_session] if args.key?(:end_session)
  @google_search_suggestions = args[:google_search_suggestions] if args.key?(:google_search_suggestions)
  @payload = args[:payload] if args.key?(:payload)
  @text = args[:text] if args.key?(:text)
  @tool_calls = args[:tool_calls] if args.key?(:tool_calls)
  @turn_completed = args[:turn_completed] if args.key?(:turn_completed)
  @turn_index = args[:turn_index] if args.key?(:turn_index)
end