Class: Google::Apis::CesV1::SessionOutput

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Output for the session.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SessionOutput

Returns a new instance of SessionOutput.



6067
6068
6069
# File 'lib/google/apis/ces_v1/classes.rb', line 6067

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audioString

Output audio from the CES agent. Corresponds to the JSON property audio NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


6013
6014
6015
# File 'lib/google/apis/ces_v1/classes.rb', line 6013

def audio
  @audio
end

#citationsGoogle::Apis::CesV1::Citations

Citations associated with the agent response. Corresponds to the JSON property citations



6018
6019
6020
# File 'lib/google/apis/ces_v1/classes.rb', line 6018

def citations
  @citations
end

#diagnostic_infoGoogle::Apis::CesV1::SessionOutputDiagnosticInfo

Contains execution details during the processing. Corresponds to the JSON property diagnosticInfo



6023
6024
6025
# File 'lib/google/apis/ces_v1/classes.rb', line 6023

def diagnostic_info
  @diagnostic_info
end

#end_sessionGoogle::Apis::CesV1::EndSession

Indicates the session has terminated, due to either successful completion (e.g. user says "Good bye!" ) or an agent escalation. The agent will not process any further inputs after session is terminated and the client should half- close and disconnect after receiving all remaining responses from the agent. Corresponds to the JSON property endSession



6031
6032
6033
# File 'lib/google/apis/ces_v1/classes.rb', line 6031

def end_session
  @end_session
end

#google_search_suggestionsGoogle::Apis::CesV1::GoogleSearchSuggestions

Search suggestions from Google Search Tool. Corresponds to the JSON property googleSearchSuggestions



6036
6037
6038
# File 'lib/google/apis/ces_v1/classes.rb', line 6036

def google_search_suggestions
  @google_search_suggestions
end

#payloadHash<String,Object>

Custom payload with structured output from the CES agent. Corresponds to the JSON property payload

Returns:

  • (Hash<String,Object>)


6041
6042
6043
# File 'lib/google/apis/ces_v1/classes.rb', line 6041

def payload
  @payload
end

#textString

Output text from the CES agent. Corresponds to the JSON property text

Returns:

  • (String)


6046
6047
6048
# File 'lib/google/apis/ces_v1/classes.rb', line 6046

def text
  @text
end

#tool_callsGoogle::Apis::CesV1::ToolCalls

Request for the client to execute the tools and return the execution results before continuing the session. Corresponds to the JSON property toolCalls



6052
6053
6054
# File 'lib/google/apis/ces_v1/classes.rb', line 6052

def tool_calls
  @tool_calls
end

#turn_completedBoolean Also known as: turn_completed?

If true, the CES agent has detected the end of the current conversation turn and will provide no further output for this turn. Corresponds to the JSON property turnCompleted

Returns:

  • (Boolean)


6058
6059
6060
# File 'lib/google/apis/ces_v1/classes.rb', line 6058

def turn_completed
  @turn_completed
end

#turn_indexFixnum

Indicates the sequential order of conversation turn to which this output belongs to, starting from 1. Corresponds to the JSON property turnIndex

Returns:

  • (Fixnum)


6065
6066
6067
# File 'lib/google/apis/ces_v1/classes.rb', line 6065

def turn_index
  @turn_index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6072
6073
6074
6075
6076
6077
6078
6079
6080
6081
6082
6083
# File 'lib/google/apis/ces_v1/classes.rb', line 6072

def update!(**args)
  @audio = args[:audio] if args.key?(:audio)
  @citations = args[:citations] if args.key?(:citations)
  @diagnostic_info = args[:diagnostic_info] if args.key?(:diagnostic_info)
  @end_session = args[:end_session] if args.key?(:end_session)
  @google_search_suggestions = args[:google_search_suggestions] if args.key?(:google_search_suggestions)
  @payload = args[:payload] if args.key?(:payload)
  @text = args[:text] if args.key?(:text)
  @tool_calls = args[:tool_calls] if args.key?(:tool_calls)
  @turn_completed = args[:turn_completed] if args.key?(:turn_completed)
  @turn_index = args[:turn_index] if args.key?(:turn_index)
end