Class: Google::Apis::CesV1::SessionOutputDiagnosticInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Contains execution details during the processing.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SessionOutputDiagnosticInfo

Returns a new instance of SessionOutputDiagnosticInfo.



7611
7612
7613
# File 'lib/google/apis/ces_v1/classes.rb', line 7611

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#messagesArray<Google::Apis::CesV1::Message>

List of the messages that happened during the processing. Corresponds to the JSON property messages

Returns:



7604
7605
7606
# File 'lib/google/apis/ces_v1/classes.rb', line 7604

def messages
  @messages
end

#root_spanGoogle::Apis::CesV1::Span

A span is a unit of work or a single operation during the request processing. Corresponds to the JSON property rootSpan



7609
7610
7611
# File 'lib/google/apis/ces_v1/classes.rb', line 7609

def root_span
  @root_span
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7616
7617
7618
7619
# File 'lib/google/apis/ces_v1/classes.rb', line 7616

def update!(**args)
  @messages = args[:messages] if args.key?(:messages)
  @root_span = args[:root_span] if args.key?(:root_span)
end