Class: Google::Apis::CesV1::SessionOutputDiagnosticInfo
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::SessionOutputDiagnosticInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Contains execution details during the processing.
Instance Attribute Summary collapse
-
#messages ⇒ Array<Google::Apis::CesV1::Message>
List of the messages that happened during the processing.
-
#root_span ⇒ Google::Apis::CesV1::Span
A span is a unit of work or a single operation during the request processing.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SessionOutputDiagnosticInfo
constructor
A new instance of SessionOutputDiagnosticInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SessionOutputDiagnosticInfo
Returns a new instance of SessionOutputDiagnosticInfo.
7591 7592 7593 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7591 def initialize(**args) update!(**args) end |
Instance Attribute Details
#messages ⇒ Array<Google::Apis::CesV1::Message>
List of the messages that happened during the processing.
Corresponds to the JSON property messages
7584 7585 7586 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7584 def @messages end |
#root_span ⇒ Google::Apis::CesV1::Span
A span is a unit of work or a single operation during the request processing.
Corresponds to the JSON property rootSpan
7589 7590 7591 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7589 def root_span @root_span end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7596 7597 7598 7599 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7596 def update!(**args) @messages = args[:messages] if args.key?(:messages) @root_span = args[:root_span] if args.key?(:root_span) end |