Class: Google::Apis::CesV1::SessionOutputDiagnosticInfo
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::SessionOutputDiagnosticInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Contains execution details during the processing.
Instance Attribute Summary collapse
-
#messages ⇒ Array<Google::Apis::CesV1::Message>
List of the messages that happened during the processing.
-
#root_span ⇒ Google::Apis::CesV1::Span
A span is a unit of work or a single operation during the request processing.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SessionOutputDiagnosticInfo
constructor
A new instance of SessionOutputDiagnosticInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SessionOutputDiagnosticInfo
Returns a new instance of SessionOutputDiagnosticInfo.
6627 6628 6629 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6627 def initialize(**args) update!(**args) end |
Instance Attribute Details
#messages ⇒ Array<Google::Apis::CesV1::Message>
List of the messages that happened during the processing.
Corresponds to the JSON property messages
6620 6621 6622 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6620 def @messages end |
#root_span ⇒ Google::Apis::CesV1::Span
A span is a unit of work or a single operation during the request processing.
Corresponds to the JSON property rootSpan
6625 6626 6627 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6625 def root_span @root_span end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6632 6633 6634 6635 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6632 def update!(**args) @messages = args[:messages] if args.key?(:messages) @root_span = args[:root_span] if args.key?(:root_span) end |