Class: Google::Apis::CesV1::SessionOutputDiagnosticInfo
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::SessionOutputDiagnosticInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Contains execution details during the processing.
Instance Attribute Summary collapse
-
#messages ⇒ Array<Google::Apis::CesV1::Message>
List of the messages that happened during the processing.
-
#root_span ⇒ Google::Apis::CesV1::Span
A span is a unit of work or a single operation during the request processing.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SessionOutputDiagnosticInfo
constructor
A new instance of SessionOutputDiagnosticInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SessionOutputDiagnosticInfo
Returns a new instance of SessionOutputDiagnosticInfo.
6100 6101 6102 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6100 def initialize(**args) update!(**args) end |
Instance Attribute Details
#messages ⇒ Array<Google::Apis::CesV1::Message>
List of the messages that happened during the processing.
Corresponds to the JSON property messages
6093 6094 6095 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6093 def @messages end |
#root_span ⇒ Google::Apis::CesV1::Span
A span is a unit of work or a single operation during the request processing.
Corresponds to the JSON property rootSpan
6098 6099 6100 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6098 def root_span @root_span end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6105 6106 6107 6108 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6105 def update!(**args) @messages = args[:messages] if args.key?(:messages) @root_span = args[:root_span] if args.key?(:root_span) end |