Class: Google::Apis::CesV1::Span

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

A span is a unit of work or a single operation during the request processing.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Span

Returns a new instance of Span.



6345
6346
6347
# File 'lib/google/apis/ces_v1/classes.rb', line 6345

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attributesHash<String,Object>

Output only. Key-value attributes associated with the span. Corresponds to the JSON property attributes

Returns:

  • (Hash<String,Object>)


6318
6319
6320
# File 'lib/google/apis/ces_v1/classes.rb', line 6318

def attributes
  @attributes
end

#child_spansArray<Google::Apis::CesV1::Span>

Output only. The child spans that are nested under this span. Corresponds to the JSON property childSpans

Returns:



6323
6324
6325
# File 'lib/google/apis/ces_v1/classes.rb', line 6323

def child_spans
  @child_spans
end

#durationString

Output only. The duration of the span. Corresponds to the JSON property duration

Returns:

  • (String)


6328
6329
6330
# File 'lib/google/apis/ces_v1/classes.rb', line 6328

def duration
  @duration
end

#end_timeString

Output only. The end time of the span. Corresponds to the JSON property endTime

Returns:

  • (String)


6333
6334
6335
# File 'lib/google/apis/ces_v1/classes.rb', line 6333

def end_time
  @end_time
end

#nameString

Output only. The name of the span. Corresponds to the JSON property name

Returns:

  • (String)


6338
6339
6340
# File 'lib/google/apis/ces_v1/classes.rb', line 6338

def name
  @name
end

#start_timeString

Output only. The start time of the span. Corresponds to the JSON property startTime

Returns:

  • (String)


6343
6344
6345
# File 'lib/google/apis/ces_v1/classes.rb', line 6343

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6350
6351
6352
6353
6354
6355
6356
6357
# File 'lib/google/apis/ces_v1/classes.rb', line 6350

def update!(**args)
  @attributes = args[:attributes] if args.key?(:attributes)
  @child_spans = args[:child_spans] if args.key?(:child_spans)
  @duration = args[:duration] if args.key?(:duration)
  @end_time = args[:end_time] if args.key?(:end_time)
  @name = args[:name] if args.key?(:name)
  @start_time = args[:start_time] if args.key?(:start_time)
end