Class: Google::Apis::CesV1::Span
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::Span
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
A span is a unit of work or a single operation during the request processing.
Instance Attribute Summary collapse
-
#attributes ⇒ Hash<String,Object>
Output only.
-
#child_spans ⇒ Array<Google::Apis::CesV1::Span>
Output only.
-
#duration ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#start_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Span
constructor
A new instance of Span.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Span
Returns a new instance of Span.
6345 6346 6347 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6345 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attributes ⇒ Hash<String,Object>
Output only. Key-value attributes associated with the span.
Corresponds to the JSON property attributes
6318 6319 6320 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6318 def attributes @attributes end |
#child_spans ⇒ Array<Google::Apis::CesV1::Span>
Output only. The child spans that are nested under this span.
Corresponds to the JSON property childSpans
6323 6324 6325 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6323 def child_spans @child_spans end |
#duration ⇒ String
Output only. The duration of the span.
Corresponds to the JSON property duration
6328 6329 6330 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6328 def duration @duration end |
#end_time ⇒ String
Output only. The end time of the span.
Corresponds to the JSON property endTime
6333 6334 6335 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6333 def end_time @end_time end |
#name ⇒ String
Output only. The name of the span.
Corresponds to the JSON property name
6338 6339 6340 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6338 def name @name end |
#start_time ⇒ String
Output only. The start time of the span.
Corresponds to the JSON property startTime
6343 6344 6345 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6343 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6350 6351 6352 6353 6354 6355 6356 6357 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6350 def update!(**args) @attributes = args[:attributes] if args.key?(:attributes) @child_spans = args[:child_spans] if args.key?(:child_spans) @duration = args[:duration] if args.key?(:duration) @end_time = args[:end_time] if args.key?(:end_time) @name = args[:name] if args.key?(:name) @start_time = args[:start_time] if args.key?(:start_time) end |