Class: Google::Apis::CesV1::Span

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

A span is a unit of work or a single operation during the request processing.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Span

Returns a new instance of Span.



6145
6146
6147
# File 'lib/google/apis/ces_v1/classes.rb', line 6145

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attributesHash<String,Object>

Output only. Key-value attributes associated with the span. Corresponds to the JSON property attributes

Returns:

  • (Hash<String,Object>)


6118
6119
6120
# File 'lib/google/apis/ces_v1/classes.rb', line 6118

def attributes
  @attributes
end

#child_spansArray<Google::Apis::CesV1::Span>

Output only. The child spans that are nested under this span. Corresponds to the JSON property childSpans

Returns:



6123
6124
6125
# File 'lib/google/apis/ces_v1/classes.rb', line 6123

def child_spans
  @child_spans
end

#durationString

Output only. The duration of the span. Corresponds to the JSON property duration

Returns:

  • (String)


6128
6129
6130
# File 'lib/google/apis/ces_v1/classes.rb', line 6128

def duration
  @duration
end

#end_timeString

Output only. The end time of the span. Corresponds to the JSON property endTime

Returns:

  • (String)


6133
6134
6135
# File 'lib/google/apis/ces_v1/classes.rb', line 6133

def end_time
  @end_time
end

#nameString

Output only. The name of the span. Corresponds to the JSON property name

Returns:

  • (String)


6138
6139
6140
# File 'lib/google/apis/ces_v1/classes.rb', line 6138

def name
  @name
end

#start_timeString

Output only. The start time of the span. Corresponds to the JSON property startTime

Returns:

  • (String)


6143
6144
6145
# File 'lib/google/apis/ces_v1/classes.rb', line 6143

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6150
6151
6152
6153
6154
6155
6156
6157
# File 'lib/google/apis/ces_v1/classes.rb', line 6150

def update!(**args)
  @attributes = args[:attributes] if args.key?(:attributes)
  @child_spans = args[:child_spans] if args.key?(:child_spans)
  @duration = args[:duration] if args.key?(:duration)
  @end_time = args[:end_time] if args.key?(:end_time)
  @name = args[:name] if args.key?(:name)
  @start_time = args[:start_time] if args.key?(:start_time)
end