Class: Google::Apis::CesV1::SynthesizeSpeechConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Configuration for how the agent response should be synthesized.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SynthesizeSpeechConfig

Returns a new instance of SynthesizeSpeechConfig.



6745
6746
6747
# File 'lib/google/apis/ces_v1/classes.rb', line 6745

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#speaking_rateFloat

Optional. The speaking rate/speed in the range [0.25, 2.0]. 1.0 is the normal native speed supported by the specific voice. 2.0 is twice as fast, and 0.5 is half as fast. Values outside of the range [0.25, 2.0] will return an error. Corresponds to the JSON property speakingRate

Returns:

  • (Float)


6735
6736
6737
# File 'lib/google/apis/ces_v1/classes.rb', line 6735

def speaking_rate
  @speaking_rate
end

#voiceString

Optional. The name of the voice. If not set, the service will choose a voice based on the other parameters such as language_code. For the list of available voices, please refer to Supported voices and languages from Cloud Text-to-Speech. Corresponds to the JSON property voice

Returns:

  • (String)


6743
6744
6745
# File 'lib/google/apis/ces_v1/classes.rb', line 6743

def voice
  @voice
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6750
6751
6752
6753
# File 'lib/google/apis/ces_v1/classes.rb', line 6750

def update!(**args)
  @speaking_rate = args[:speaking_rate] if args.key?(:speaking_rate)
  @voice = args[:voice] if args.key?(:voice)
end