Class: Google::Apis::CesV1::ToolCall
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::ToolCall
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Request for the client or the agent to execute the specified tool.
Instance Attribute Summary collapse
-
#args ⇒ Hash<String,Object>
Optional.
-
#display_name ⇒ String
Output only.
-
#id ⇒ String
Optional.
-
#tool ⇒ String
Optional.
-
#toolset_tool ⇒ Google::Apis::CesV1::ToolsetTool
A tool that is created from a toolset.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ToolCall
constructor
A new instance of ToolCall.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ToolCall
Returns a new instance of ToolCall.
8115 8116 8117 |
# File 'lib/google/apis/ces_v1/classes.rb', line 8115 def initialize(**args) update!(**args) end |
Instance Attribute Details
#args ⇒ Hash<String,Object>
Optional. The input parameters and values for the tool in JSON object format.
Corresponds to the JSON property args
8091 8092 8093 |
# File 'lib/google/apis/ces_v1/classes.rb', line 8091 def args @args end |
#display_name ⇒ String
Output only. Display name of the tool.
Corresponds to the JSON property displayName
8096 8097 8098 |
# File 'lib/google/apis/ces_v1/classes.rb', line 8096 def display_name @display_name end |
#id ⇒ String
Optional. The unique identifier of the tool call. If populated, the client
should return the execution result with the matching ID in ToolResponse.
Corresponds to the JSON property id
8102 8103 8104 |
# File 'lib/google/apis/ces_v1/classes.rb', line 8102 def id @id end |
#tool ⇒ String
Optional. The name of the tool to execute. Format: projects/project/
locations/location/apps/app/tools/tool`
Corresponds to the JSON propertytool`
8108 8109 8110 |
# File 'lib/google/apis/ces_v1/classes.rb', line 8108 def tool @tool end |
#toolset_tool ⇒ Google::Apis::CesV1::ToolsetTool
A tool that is created from a toolset.
Corresponds to the JSON property toolsetTool
8113 8114 8115 |
# File 'lib/google/apis/ces_v1/classes.rb', line 8113 def toolset_tool @toolset_tool end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8120 8121 8122 8123 8124 8125 8126 |
# File 'lib/google/apis/ces_v1/classes.rb', line 8120 def update!(**args) @args = args[:args] if args.key?(:args) @display_name = args[:display_name] if args.key?(:display_name) @id = args[:id] if args.key?(:id) @tool = args[:tool] if args.key?(:tool) @toolset_tool = args[:toolset_tool] if args.key?(:toolset_tool) end |