Class: Google::Apis::CesV1::ToolCall

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Request for the client or the agent to execute the specified tool.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ToolCall

Returns a new instance of ToolCall.



8064
8065
8066
# File 'lib/google/apis/ces_v1/classes.rb', line 8064

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#argsHash<String,Object>

Optional. The input parameters and values for the tool in JSON object format. Corresponds to the JSON property args

Returns:

  • (Hash<String,Object>)


8040
8041
8042
# File 'lib/google/apis/ces_v1/classes.rb', line 8040

def args
  @args
end

#display_nameString

Output only. Display name of the tool. Corresponds to the JSON property displayName

Returns:

  • (String)


8045
8046
8047
# File 'lib/google/apis/ces_v1/classes.rb', line 8045

def display_name
  @display_name
end

#idString

Optional. The unique identifier of the tool call. If populated, the client should return the execution result with the matching ID in ToolResponse. Corresponds to the JSON property id

Returns:

  • (String)


8051
8052
8053
# File 'lib/google/apis/ces_v1/classes.rb', line 8051

def id
  @id
end

#toolString

Optional. The name of the tool to execute. Format: projects/project/ locations/location/apps/app/tools/tool` Corresponds to the JSON propertytool`

Returns:

  • (String)


8057
8058
8059
# File 'lib/google/apis/ces_v1/classes.rb', line 8057

def tool
  @tool
end

#toolset_toolGoogle::Apis::CesV1::ToolsetTool

A tool that is created from a toolset. Corresponds to the JSON property toolsetTool



8062
8063
8064
# File 'lib/google/apis/ces_v1/classes.rb', line 8062

def toolset_tool
  @toolset_tool
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8069
8070
8071
8072
8073
8074
8075
# File 'lib/google/apis/ces_v1/classes.rb', line 8069

def update!(**args)
  @args = args[:args] if args.key?(:args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @id = args[:id] if args.key?(:id)
  @tool = args[:tool] if args.key?(:tool)
  @toolset_tool = args[:toolset_tool] if args.key?(:toolset_tool)
end