Class: Google::Apis::CesV1::ToolCall
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::ToolCall
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Request for the client or the agent to execute the specified tool.
Instance Attribute Summary collapse
-
#args ⇒ Hash<String,Object>
Optional.
-
#display_name ⇒ String
Output only.
-
#id ⇒ String
Optional.
-
#tool ⇒ String
Optional.
-
#toolset_tool ⇒ Google::Apis::CesV1::ToolsetTool
A tool that is created from a toolset.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ToolCall
constructor
A new instance of ToolCall.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ToolCall
Returns a new instance of ToolCall.
7051 7052 7053 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7051 def initialize(**args) update!(**args) end |
Instance Attribute Details
#args ⇒ Hash<String,Object>
Optional. The input parameters and values for the tool in JSON object format.
Corresponds to the JSON property args
7027 7028 7029 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7027 def args @args end |
#display_name ⇒ String
Output only. Display name of the tool.
Corresponds to the JSON property displayName
7032 7033 7034 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7032 def display_name @display_name end |
#id ⇒ String
Optional. The unique identifier of the tool call. If populated, the client
should return the execution result with the matching ID in ToolResponse.
Corresponds to the JSON property id
7038 7039 7040 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7038 def id @id end |
#tool ⇒ String
Optional. The name of the tool to execute. Format: projects/project/
locations/location/apps/app/tools/tool`
Corresponds to the JSON propertytool`
7044 7045 7046 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7044 def tool @tool end |
#toolset_tool ⇒ Google::Apis::CesV1::ToolsetTool
A tool that is created from a toolset.
Corresponds to the JSON property toolsetTool
7049 7050 7051 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7049 def toolset_tool @toolset_tool end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7056 7057 7058 7059 7060 7061 7062 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7056 def update!(**args) @args = args[:args] if args.key?(:args) @display_name = args[:display_name] if args.key?(:display_name) @id = args[:id] if args.key?(:id) @tool = args[:tool] if args.key?(:tool) @toolset_tool = args[:toolset_tool] if args.key?(:toolset_tool) end |