Class: Google::Apis::CesV1::ToolCall

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Request for the client or the agent to execute the specified tool.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ToolCall

Returns a new instance of ToolCall.



6724
6725
6726
# File 'lib/google/apis/ces_v1/classes.rb', line 6724

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#argsHash<String,Object>

Optional. The input parameters and values for the tool in JSON object format. Corresponds to the JSON property args

Returns:

  • (Hash<String,Object>)


6700
6701
6702
# File 'lib/google/apis/ces_v1/classes.rb', line 6700

def args
  @args
end

#display_nameString

Output only. Display name of the tool. Corresponds to the JSON property displayName

Returns:

  • (String)


6705
6706
6707
# File 'lib/google/apis/ces_v1/classes.rb', line 6705

def display_name
  @display_name
end

#idString

Optional. The unique identifier of the tool call. If populated, the client should return the execution result with the matching ID in ToolResponse. Corresponds to the JSON property id

Returns:

  • (String)


6711
6712
6713
# File 'lib/google/apis/ces_v1/classes.rb', line 6711

def id
  @id
end

#toolString

Optional. The name of the tool to execute. Format: projects/project/ locations/location/apps/app/tools/tool` Corresponds to the JSON propertytool`

Returns:

  • (String)


6717
6718
6719
# File 'lib/google/apis/ces_v1/classes.rb', line 6717

def tool
  @tool
end

#toolset_toolGoogle::Apis::CesV1::ToolsetTool

A tool that is created from a toolset. Corresponds to the JSON property toolsetTool



6722
6723
6724
# File 'lib/google/apis/ces_v1/classes.rb', line 6722

def toolset_tool
  @toolset_tool
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6729
6730
6731
6732
6733
6734
6735
# File 'lib/google/apis/ces_v1/classes.rb', line 6729

def update!(**args)
  @args = args[:args] if args.key?(:args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @id = args[:id] if args.key?(:id)
  @tool = args[:tool] if args.key?(:tool)
  @toolset_tool = args[:toolset_tool] if args.key?(:toolset_tool)
end