Class: Google::Apis::CesV1::ToolCalls
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::ToolCalls
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Request for the client to execute the tools and return the execution results before continuing the session.
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(**args) ⇒ ToolCalls
constructor
A new instance of ToolCalls.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ToolCalls
Returns a new instance of ToolCalls.
6535 6536 6537 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6535 def initialize(**args) update!(**args) end |
Instance Attribute Details
#tool_calls ⇒ Array<Google::Apis::CesV1::ToolCall>
Optional. The list of tool calls to execute.
Corresponds to the JSON property toolCalls
6533 6534 6535 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6533 def tool_calls @tool_calls end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6540 6541 6542 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6540 def update!(**args) @tool_calls = args[:tool_calls] if args.key?(:tool_calls) end |