Class: Google::Apis::CesV1::ToolResponse
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::ToolResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
The execution result of a specific tool from the client or the agent.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Output only.
-
#id ⇒ String
Optional.
-
#response ⇒ Hash<String,Object>
Required.
-
#tool ⇒ String
Optional.
-
#toolset_tool ⇒ Google::Apis::CesV1::ToolsetTool
A tool that is created from a toolset.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ToolResponse
constructor
A new instance of ToolResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ToolResponse
Returns a new instance of ToolResponse.
6604 6605 6606 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6604 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Output only. Display name of the tool.
Corresponds to the JSON property displayName
6578 6579 6580 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6578 def display_name @display_name end |
#id ⇒ String
Optional. The matching ID of the tool call the response is for.
Corresponds to the JSON property id
6583 6584 6585 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6583 def id @id end |
#response ⇒ Hash<String,Object>
Required. The tool execution result in JSON object format. Use "output" key to
specify tool response and "error" key to specify error details (if any). If "
output" and "error" keys are not specified, then whole "response" is treated
as tool execution result.
Corresponds to the JSON property response
6591 6592 6593 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6591 def response @response end |
#tool ⇒ String
Optional. The name of the tool to execute. Format: projects/project/
locations/location/apps/app/tools/tool`
Corresponds to the JSON propertytool`
6597 6598 6599 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6597 def tool @tool end |
#toolset_tool ⇒ Google::Apis::CesV1::ToolsetTool
A tool that is created from a toolset.
Corresponds to the JSON property toolsetTool
6602 6603 6604 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6602 def toolset_tool @toolset_tool end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6609 6610 6611 6612 6613 6614 6615 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6609 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @id = args[:id] if args.key?(:id) @response = args[:response] if args.key?(:response) @tool = args[:tool] if args.key?(:tool) @toolset_tool = args[:toolset_tool] if args.key?(:toolset_tool) end |