Class: Google::Apis::CesV1::Toolset
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::Toolset
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
A toolset represents a group of dynamically managed tools that can be used by the agent.
Instance Attribute Summary collapse
-
#connector_toolset ⇒ Google::Apis::CesV1::ConnectorToolset
A toolset that generates tools from an Integration Connectors Connection.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Optional.
-
#etag ⇒ String
ETag used to ensure the object hasn't changed during a read-modify-write operation.
-
#execution_type ⇒ String
Optional.
-
#mcp_toolset ⇒ Google::Apis::CesV1::McpToolset
A toolset that contains a list of tools that are offered by the MCP server.
-
#name ⇒ String
Identifier.
-
#open_api_toolset ⇒ Google::Apis::CesV1::OpenApiToolset
A toolset that contains a list of tools that are defined by an OpenAPI schema.
-
#timeout ⇒ String
Optional.
-
#tool_fake_config ⇒ Google::Apis::CesV1::ToolFakeConfig
Configuration for tool behavior in fake mode.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Toolset
constructor
A new instance of Toolset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Toolset
Returns a new instance of Toolset.
8311 8312 8313 |
# File 'lib/google/apis/ces_v1/classes.rb', line 8311 def initialize(**args) update!(**args) end |
Instance Attribute Details
#connector_toolset ⇒ Google::Apis::CesV1::ConnectorToolset
A toolset that generates tools from an Integration Connectors Connection.
Corresponds to the JSON property connectorToolset
8249 8250 8251 |
# File 'lib/google/apis/ces_v1/classes.rb', line 8249 def connector_toolset @connector_toolset end |
#create_time ⇒ String
Output only. Timestamp when the toolset was created.
Corresponds to the JSON property createTime
8254 8255 8256 |
# File 'lib/google/apis/ces_v1/classes.rb', line 8254 def create_time @create_time end |
#description ⇒ String
Optional. The description of the toolset.
Corresponds to the JSON property description
8259 8260 8261 |
# File 'lib/google/apis/ces_v1/classes.rb', line 8259 def description @description end |
#display_name ⇒ String
Optional. The display name of the toolset. Must be unique within the same app.
Corresponds to the JSON property displayName
8264 8265 8266 |
# File 'lib/google/apis/ces_v1/classes.rb', line 8264 def display_name @display_name end |
#etag ⇒ String
ETag used to ensure the object hasn't changed during a read-modify-write
operation. If the etag is empty, the update will overwrite any concurrent
changes.
Corresponds to the JSON property etag
8271 8272 8273 |
# File 'lib/google/apis/ces_v1/classes.rb', line 8271 def etag @etag end |
#execution_type ⇒ String
Optional. The execution type of the tools in the toolset.
Corresponds to the JSON property executionType
8276 8277 8278 |
# File 'lib/google/apis/ces_v1/classes.rb', line 8276 def execution_type @execution_type end |
#mcp_toolset ⇒ Google::Apis::CesV1::McpToolset
A toolset that contains a list of tools that are offered by the MCP server.
Corresponds to the JSON property mcpToolset
8281 8282 8283 |
# File 'lib/google/apis/ces_v1/classes.rb', line 8281 def mcp_toolset @mcp_toolset end |
#name ⇒ String
Identifier. The unique identifier of the toolset. Format: projects/project/
locations/location/apps/app/toolsets/toolset`
Corresponds to the JSON propertyname`
8287 8288 8289 |
# File 'lib/google/apis/ces_v1/classes.rb', line 8287 def name @name end |
#open_api_toolset ⇒ Google::Apis::CesV1::OpenApiToolset
A toolset that contains a list of tools that are defined by an OpenAPI schema.
Corresponds to the JSON property openApiToolset
8292 8293 8294 |
# File 'lib/google/apis/ces_v1/classes.rb', line 8292 def open_api_toolset @open_api_toolset end |
#timeout ⇒ String
Optional. The timeout for the toolset execution. If not set, the default
timeout is 30 seconds for SYNCHRONOUS toolsets and 60 seconds for
ASYNCHRONOUS toolsets.
Corresponds to the JSON property timeout
8299 8300 8301 |
# File 'lib/google/apis/ces_v1/classes.rb', line 8299 def timeout @timeout end |
#tool_fake_config ⇒ Google::Apis::CesV1::ToolFakeConfig
Configuration for tool behavior in fake mode.
Corresponds to the JSON property toolFakeConfig
8304 8305 8306 |
# File 'lib/google/apis/ces_v1/classes.rb', line 8304 def tool_fake_config @tool_fake_config end |
#update_time ⇒ String
Output only. Timestamp when the toolset was last updated.
Corresponds to the JSON property updateTime
8309 8310 8311 |
# File 'lib/google/apis/ces_v1/classes.rb', line 8309 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8316 8317 8318 8319 8320 8321 8322 8323 8324 8325 8326 8327 8328 8329 |
# File 'lib/google/apis/ces_v1/classes.rb', line 8316 def update!(**args) @connector_toolset = args[:connector_toolset] if args.key?(:connector_toolset) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @execution_type = args[:execution_type] if args.key?(:execution_type) @mcp_toolset = args[:mcp_toolset] if args.key?(:mcp_toolset) @name = args[:name] if args.key?(:name) @open_api_toolset = args[:open_api_toolset] if args.key?(:open_api_toolset) @timeout = args[:timeout] if args.key?(:timeout) @tool_fake_config = args[:tool_fake_config] if args.key?(:tool_fake_config) @update_time = args[:update_time] if args.key?(:update_time) end |