Class: Google::Apis::CesV1::Toolset

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

A toolset represents a group of dynamically managed tools that can be used by the agent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Toolset

Returns a new instance of Toolset.



8260
8261
8262
# File 'lib/google/apis/ces_v1/classes.rb', line 8260

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connector_toolsetGoogle::Apis::CesV1::ConnectorToolset

A toolset that generates tools from an Integration Connectors Connection. Corresponds to the JSON property connectorToolset



8198
8199
8200
# File 'lib/google/apis/ces_v1/classes.rb', line 8198

def connector_toolset
  @connector_toolset
end

#create_timeString

Output only. Timestamp when the toolset was created. Corresponds to the JSON property createTime

Returns:

  • (String)


8203
8204
8205
# File 'lib/google/apis/ces_v1/classes.rb', line 8203

def create_time
  @create_time
end

#descriptionString

Optional. The description of the toolset. Corresponds to the JSON property description

Returns:

  • (String)


8208
8209
8210
# File 'lib/google/apis/ces_v1/classes.rb', line 8208

def description
  @description
end

#display_nameString

Optional. The display name of the toolset. Must be unique within the same app. Corresponds to the JSON property displayName

Returns:

  • (String)


8213
8214
8215
# File 'lib/google/apis/ces_v1/classes.rb', line 8213

def display_name
  @display_name
end

#etagString

ETag used to ensure the object hasn't changed during a read-modify-write operation. If the etag is empty, the update will overwrite any concurrent changes. Corresponds to the JSON property etag

Returns:

  • (String)


8220
8221
8222
# File 'lib/google/apis/ces_v1/classes.rb', line 8220

def etag
  @etag
end

#execution_typeString

Optional. The execution type of the tools in the toolset. Corresponds to the JSON property executionType

Returns:

  • (String)


8225
8226
8227
# File 'lib/google/apis/ces_v1/classes.rb', line 8225

def execution_type
  @execution_type
end

#mcp_toolsetGoogle::Apis::CesV1::McpToolset

A toolset that contains a list of tools that are offered by the MCP server. Corresponds to the JSON property mcpToolset



8230
8231
8232
# File 'lib/google/apis/ces_v1/classes.rb', line 8230

def mcp_toolset
  @mcp_toolset
end

#nameString

Identifier. The unique identifier of the toolset. Format: projects/project/ locations/location/apps/app/toolsets/toolset` Corresponds to the JSON propertyname`

Returns:

  • (String)


8236
8237
8238
# File 'lib/google/apis/ces_v1/classes.rb', line 8236

def name
  @name
end

#open_api_toolsetGoogle::Apis::CesV1::OpenApiToolset

A toolset that contains a list of tools that are defined by an OpenAPI schema. Corresponds to the JSON property openApiToolset



8241
8242
8243
# File 'lib/google/apis/ces_v1/classes.rb', line 8241

def open_api_toolset
  @open_api_toolset
end

#timeoutString

Optional. The timeout for the toolset execution. If not set, the default timeout is 30 seconds for SYNCHRONOUS toolsets and 60 seconds for ASYNCHRONOUS toolsets. Corresponds to the JSON property timeout

Returns:

  • (String)


8248
8249
8250
# File 'lib/google/apis/ces_v1/classes.rb', line 8248

def timeout
  @timeout
end

#tool_fake_configGoogle::Apis::CesV1::ToolFakeConfig

Configuration for tool behavior in fake mode. Corresponds to the JSON property toolFakeConfig



8253
8254
8255
# File 'lib/google/apis/ces_v1/classes.rb', line 8253

def tool_fake_config
  @tool_fake_config
end

#update_timeString

Output only. Timestamp when the toolset was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


8258
8259
8260
# File 'lib/google/apis/ces_v1/classes.rb', line 8258

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8265
8266
8267
8268
8269
8270
8271
8272
8273
8274
8275
8276
8277
8278
# File 'lib/google/apis/ces_v1/classes.rb', line 8265

def update!(**args)
  @connector_toolset = args[:connector_toolset] if args.key?(:connector_toolset)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @execution_type = args[:execution_type] if args.key?(:execution_type)
  @mcp_toolset = args[:mcp_toolset] if args.key?(:mcp_toolset)
  @name = args[:name] if args.key?(:name)
  @open_api_toolset = args[:open_api_toolset] if args.key?(:open_api_toolset)
  @timeout = args[:timeout] if args.key?(:timeout)
  @tool_fake_config = args[:tool_fake_config] if args.key?(:tool_fake_config)
  @update_time = args[:update_time] if args.key?(:update_time)
end