Class: Google::Apis::CesV1::Toolset
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::Toolset
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
A toolset represents a group of dynamically managed tools that can be used by the agent.
Instance Attribute Summary collapse
-
#connector_toolset ⇒ Google::Apis::CesV1::ConnectorToolset
A toolset that generates tools from an Integration Connectors Connection.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Optional.
-
#etag ⇒ String
ETag used to ensure the object hasn't changed during a read-modify-write operation.
-
#execution_type ⇒ String
Optional.
-
#mcp_toolset ⇒ Google::Apis::CesV1::McpToolset
A toolset that contains a list of tools that are offered by the MCP server.
-
#name ⇒ String
Identifier.
-
#open_api_toolset ⇒ Google::Apis::CesV1::OpenApiToolset
A toolset that contains a list of tools that are defined by an OpenAPI schema.
-
#timeout ⇒ String
Optional.
-
#tool_fake_config ⇒ Google::Apis::CesV1::ToolFakeConfig
Configuration for tool behavior in fake mode.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Toolset
constructor
A new instance of Toolset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Toolset
Returns a new instance of Toolset.
8234 8235 8236 |
# File 'lib/google/apis/ces_v1/classes.rb', line 8234 def initialize(**args) update!(**args) end |
Instance Attribute Details
#connector_toolset ⇒ Google::Apis::CesV1::ConnectorToolset
A toolset that generates tools from an Integration Connectors Connection.
Corresponds to the JSON property connectorToolset
8172 8173 8174 |
# File 'lib/google/apis/ces_v1/classes.rb', line 8172 def connector_toolset @connector_toolset end |
#create_time ⇒ String
Output only. Timestamp when the toolset was created.
Corresponds to the JSON property createTime
8177 8178 8179 |
# File 'lib/google/apis/ces_v1/classes.rb', line 8177 def create_time @create_time end |
#description ⇒ String
Optional. The description of the toolset.
Corresponds to the JSON property description
8182 8183 8184 |
# File 'lib/google/apis/ces_v1/classes.rb', line 8182 def description @description end |
#display_name ⇒ String
Optional. The display name of the toolset. Must be unique within the same app.
Corresponds to the JSON property displayName
8187 8188 8189 |
# File 'lib/google/apis/ces_v1/classes.rb', line 8187 def display_name @display_name end |
#etag ⇒ String
ETag used to ensure the object hasn't changed during a read-modify-write
operation. If the etag is empty, the update will overwrite any concurrent
changes.
Corresponds to the JSON property etag
8194 8195 8196 |
# File 'lib/google/apis/ces_v1/classes.rb', line 8194 def etag @etag end |
#execution_type ⇒ String
Optional. The execution type of the tools in the toolset.
Corresponds to the JSON property executionType
8199 8200 8201 |
# File 'lib/google/apis/ces_v1/classes.rb', line 8199 def execution_type @execution_type end |
#mcp_toolset ⇒ Google::Apis::CesV1::McpToolset
A toolset that contains a list of tools that are offered by the MCP server.
Corresponds to the JSON property mcpToolset
8204 8205 8206 |
# File 'lib/google/apis/ces_v1/classes.rb', line 8204 def mcp_toolset @mcp_toolset end |
#name ⇒ String
Identifier. The unique identifier of the toolset. Format: projects/project/
locations/location/apps/app/toolsets/toolset`
Corresponds to the JSON propertyname`
8210 8211 8212 |
# File 'lib/google/apis/ces_v1/classes.rb', line 8210 def name @name end |
#open_api_toolset ⇒ Google::Apis::CesV1::OpenApiToolset
A toolset that contains a list of tools that are defined by an OpenAPI schema.
Corresponds to the JSON property openApiToolset
8215 8216 8217 |
# File 'lib/google/apis/ces_v1/classes.rb', line 8215 def open_api_toolset @open_api_toolset end |
#timeout ⇒ String
Optional. The timeout for the toolset execution. If not set, the default
timeout is 30 seconds for SYNCHRONOUS toolsets and 60 seconds for
ASYNCHRONOUS toolsets.
Corresponds to the JSON property timeout
8222 8223 8224 |
# File 'lib/google/apis/ces_v1/classes.rb', line 8222 def timeout @timeout end |
#tool_fake_config ⇒ Google::Apis::CesV1::ToolFakeConfig
Configuration for tool behavior in fake mode.
Corresponds to the JSON property toolFakeConfig
8227 8228 8229 |
# File 'lib/google/apis/ces_v1/classes.rb', line 8227 def tool_fake_config @tool_fake_config end |
#update_time ⇒ String
Output only. Timestamp when the toolset was last updated.
Corresponds to the JSON property updateTime
8232 8233 8234 |
# File 'lib/google/apis/ces_v1/classes.rb', line 8232 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8239 8240 8241 8242 8243 8244 8245 8246 8247 8248 8249 8250 8251 8252 |
# File 'lib/google/apis/ces_v1/classes.rb', line 8239 def update!(**args) @connector_toolset = args[:connector_toolset] if args.key?(:connector_toolset) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @execution_type = args[:execution_type] if args.key?(:execution_type) @mcp_toolset = args[:mcp_toolset] if args.key?(:mcp_toolset) @name = args[:name] if args.key?(:name) @open_api_toolset = args[:open_api_toolset] if args.key?(:open_api_toolset) @timeout = args[:timeout] if args.key?(:timeout) @tool_fake_config = args[:tool_fake_config] if args.key?(:tool_fake_config) @update_time = args[:update_time] if args.key?(:update_time) end |