Class: Google::Apis::CesV1::Toolset
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::Toolset
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
A toolset represents a group of dynamically managed tools that can be used by the agent.
Instance Attribute Summary collapse
-
#connector_toolset ⇒ Google::Apis::CesV1::ConnectorToolset
A toolset that generates tools from an Integration Connectors Connection.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Optional.
-
#etag ⇒ String
ETag used to ensure the object hasn't changed during a read-modify-write operation.
-
#execution_type ⇒ String
Optional.
-
#mcp_toolset ⇒ Google::Apis::CesV1::McpToolset
A toolset that contains a list of tools that are offered by the MCP server.
-
#name ⇒ String
Identifier.
-
#open_api_toolset ⇒ Google::Apis::CesV1::OpenApiToolset
A toolset that contains a list of tools that are defined by an OpenAPI schema.
-
#tool_fake_config ⇒ Google::Apis::CesV1::ToolFakeConfig
Configuration for tool behavior in fake mode.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Toolset
constructor
A new instance of Toolset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Toolset
Returns a new instance of Toolset.
7240 7241 7242 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7240 def initialize(**args) update!(**args) end |
Instance Attribute Details
#connector_toolset ⇒ Google::Apis::CesV1::ConnectorToolset
A toolset that generates tools from an Integration Connectors Connection.
Corresponds to the JSON property connectorToolset
7185 7186 7187 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7185 def connector_toolset @connector_toolset end |
#create_time ⇒ String
Output only. Timestamp when the toolset was created.
Corresponds to the JSON property createTime
7190 7191 7192 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7190 def create_time @create_time end |
#description ⇒ String
Optional. The description of the toolset.
Corresponds to the JSON property description
7195 7196 7197 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7195 def description @description end |
#display_name ⇒ String
Optional. The display name of the toolset. Must be unique within the same app.
Corresponds to the JSON property displayName
7200 7201 7202 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7200 def display_name @display_name end |
#etag ⇒ String
ETag used to ensure the object hasn't changed during a read-modify-write
operation. If the etag is empty, the update will overwrite any concurrent
changes.
Corresponds to the JSON property etag
7207 7208 7209 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7207 def etag @etag end |
#execution_type ⇒ String
Optional. The execution type of the tools in the toolset.
Corresponds to the JSON property executionType
7212 7213 7214 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7212 def execution_type @execution_type end |
#mcp_toolset ⇒ Google::Apis::CesV1::McpToolset
A toolset that contains a list of tools that are offered by the MCP server.
Corresponds to the JSON property mcpToolset
7217 7218 7219 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7217 def mcp_toolset @mcp_toolset end |
#name ⇒ String
Identifier. The unique identifier of the toolset. Format: projects/project/
locations/location/apps/app/toolsets/toolset`
Corresponds to the JSON propertyname`
7223 7224 7225 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7223 def name @name end |
#open_api_toolset ⇒ Google::Apis::CesV1::OpenApiToolset
A toolset that contains a list of tools that are defined by an OpenAPI schema.
Corresponds to the JSON property openApiToolset
7228 7229 7230 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7228 def open_api_toolset @open_api_toolset end |
#tool_fake_config ⇒ Google::Apis::CesV1::ToolFakeConfig
Configuration for tool behavior in fake mode.
Corresponds to the JSON property toolFakeConfig
7233 7234 7235 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7233 def tool_fake_config @tool_fake_config end |
#update_time ⇒ String
Output only. Timestamp when the toolset was last updated.
Corresponds to the JSON property updateTime
7238 7239 7240 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7238 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7245 7246 7247 7248 7249 7250 7251 7252 7253 7254 7255 7256 7257 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7245 def update!(**args) @connector_toolset = args[:connector_toolset] if args.key?(:connector_toolset) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @execution_type = args[:execution_type] if args.key?(:execution_type) @mcp_toolset = args[:mcp_toolset] if args.key?(:mcp_toolset) @name = args[:name] if args.key?(:name) @open_api_toolset = args[:open_api_toolset] if args.key?(:open_api_toolset) @tool_fake_config = args[:tool_fake_config] if args.key?(:tool_fake_config) @update_time = args[:update_time] if args.key?(:update_time) end |