Class: Google::Apis::CesV1::Toolset
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::Toolset
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
A toolset represents a group of dynamically managed tools that can be used by the agent.
Instance Attribute Summary collapse
-
#connector_toolset ⇒ Google::Apis::CesV1::ConnectorToolset
A toolset that generates tools from an Integration Connectors Connection.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Optional.
-
#etag ⇒ String
ETag used to ensure the object hasn't changed during a read-modify-write operation.
-
#execution_type ⇒ String
Optional.
-
#mcp_toolset ⇒ Google::Apis::CesV1::McpToolset
A toolset that contains a list of tools that are offered by the MCP server.
-
#name ⇒ String
Identifier.
-
#open_api_toolset ⇒ Google::Apis::CesV1::OpenApiToolset
A toolset that contains a list of tools that are defined by an OpenAPI schema.
-
#tool_fake_config ⇒ Google::Apis::CesV1::ToolFakeConfig
Configuration for tool behavior in fake mode.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Toolset
constructor
A new instance of Toolset.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Toolset
Returns a new instance of Toolset.
6913 6914 6915 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6913 def initialize(**args) update!(**args) end |
Instance Attribute Details
#connector_toolset ⇒ Google::Apis::CesV1::ConnectorToolset
A toolset that generates tools from an Integration Connectors Connection.
Corresponds to the JSON property connectorToolset
6858 6859 6860 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6858 def connector_toolset @connector_toolset end |
#create_time ⇒ String
Output only. Timestamp when the toolset was created.
Corresponds to the JSON property createTime
6863 6864 6865 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6863 def create_time @create_time end |
#description ⇒ String
Optional. The description of the toolset.
Corresponds to the JSON property description
6868 6869 6870 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6868 def description @description end |
#display_name ⇒ String
Optional. The display name of the toolset. Must be unique within the same app.
Corresponds to the JSON property displayName
6873 6874 6875 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6873 def display_name @display_name end |
#etag ⇒ String
ETag used to ensure the object hasn't changed during a read-modify-write
operation. If the etag is empty, the update will overwrite any concurrent
changes.
Corresponds to the JSON property etag
6880 6881 6882 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6880 def etag @etag end |
#execution_type ⇒ String
Optional. The execution type of the tools in the toolset.
Corresponds to the JSON property executionType
6885 6886 6887 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6885 def execution_type @execution_type end |
#mcp_toolset ⇒ Google::Apis::CesV1::McpToolset
A toolset that contains a list of tools that are offered by the MCP server.
Corresponds to the JSON property mcpToolset
6890 6891 6892 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6890 def mcp_toolset @mcp_toolset end |
#name ⇒ String
Identifier. The unique identifier of the toolset. Format: projects/project/
locations/location/apps/app/toolsets/toolset`
Corresponds to the JSON propertyname`
6896 6897 6898 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6896 def name @name end |
#open_api_toolset ⇒ Google::Apis::CesV1::OpenApiToolset
A toolset that contains a list of tools that are defined by an OpenAPI schema.
Corresponds to the JSON property openApiToolset
6901 6902 6903 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6901 def open_api_toolset @open_api_toolset end |
#tool_fake_config ⇒ Google::Apis::CesV1::ToolFakeConfig
Configuration for tool behavior in fake mode.
Corresponds to the JSON property toolFakeConfig
6906 6907 6908 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6906 def tool_fake_config @tool_fake_config end |
#update_time ⇒ String
Output only. Timestamp when the toolset was last updated.
Corresponds to the JSON property updateTime
6911 6912 6913 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6911 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6918 6919 6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6918 def update!(**args) @connector_toolset = args[:connector_toolset] if args.key?(:connector_toolset) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @execution_type = args[:execution_type] if args.key?(:execution_type) @mcp_toolset = args[:mcp_toolset] if args.key?(:mcp_toolset) @name = args[:name] if args.key?(:name) @open_api_toolset = args[:open_api_toolset] if args.key?(:open_api_toolset) @tool_fake_config = args[:tool_fake_config] if args.key?(:tool_fake_config) @update_time = args[:update_time] if args.key?(:update_time) end |