Class: Google::Apis::CesV1::ToolsetTool

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

A tool that is created from a toolset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ToolsetTool

Returns a new instance of ToolsetTool.



6735
6736
6737
# File 'lib/google/apis/ces_v1/classes.rb', line 6735

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#tool_idString

Optional. The tool ID to filter the tools to retrieve the schema for. Corresponds to the JSON property toolId

Returns:

  • (String)


6727
6728
6729
# File 'lib/google/apis/ces_v1/classes.rb', line 6727

def tool_id
  @tool_id
end

#toolsetString

Required. The resource name of the Toolset from which this tool is derived. Format: projects/project/locations/location/apps/app/toolsets/toolset` Corresponds to the JSON propertytoolset`

Returns:

  • (String)


6733
6734
6735
# File 'lib/google/apis/ces_v1/classes.rb', line 6733

def toolset
  @toolset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6740
6741
6742
6743
# File 'lib/google/apis/ces_v1/classes.rb', line 6740

def update!(**args)
  @tool_id = args[:tool_id] if args.key?(:tool_id)
  @toolset = args[:toolset] if args.key?(:toolset)
end