Class: Google::Apis::CesV1::TransferRule
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::TransferRule
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Rule for transferring to a specific agent.
Instance Attribute Summary collapse
-
#child_agent ⇒ String
Required.
-
#deterministic_transfer ⇒ Google::Apis::CesV1::TransferRuleDeterministicTransfer
Deterministic transfer rule.
-
#direction ⇒ String
Required.
-
#disable_planner_transfer ⇒ Google::Apis::CesV1::TransferRuleDisablePlannerTransfer
A rule that prevents the planner from transferring to the target agent.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TransferRule
constructor
A new instance of TransferRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TransferRule
Returns a new instance of TransferRule.
6772 6773 6774 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6772 def initialize(**args) update!(**args) end |
Instance Attribute Details
#child_agent ⇒ String
Required. The resource name of the child agent the rule applies to. Format:
projects/project/locations/location/apps/app/agents/agent`
Corresponds to the JSON propertychildAgent`
6754 6755 6756 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6754 def child_agent @child_agent end |
#deterministic_transfer ⇒ Google::Apis::CesV1::TransferRuleDeterministicTransfer
Deterministic transfer rule. When the condition evaluates to true, the
transfer occurs.
Corresponds to the JSON property deterministicTransfer
6760 6761 6762 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6760 def deterministic_transfer @deterministic_transfer end |
#direction ⇒ String
Required. The direction of the transfer.
Corresponds to the JSON property direction
6765 6766 6767 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6765 def direction @direction end |
#disable_planner_transfer ⇒ Google::Apis::CesV1::TransferRuleDisablePlannerTransfer
A rule that prevents the planner from transferring to the target agent.
Corresponds to the JSON property disablePlannerTransfer
6770 6771 6772 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6770 def disable_planner_transfer @disable_planner_transfer end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6777 6778 6779 6780 6781 6782 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6777 def update!(**args) @child_agent = args[:child_agent] if args.key?(:child_agent) @deterministic_transfer = args[:deterministic_transfer] if args.key?(:deterministic_transfer) @direction = args[:direction] if args.key?(:direction) @disable_planner_transfer = args[:disable_planner_transfer] if args.key?(:disable_planner_transfer) end |