Class: Google::Apis::CesV1::TriggerAction

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Action that is taken when a certain precondition is met.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TriggerAction

Returns a new instance of TriggerAction.



8461
8462
8463
# File 'lib/google/apis/ces_v1/classes.rb', line 8461

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#generative_answerGoogle::Apis::CesV1::TriggerActionGenerativeAnswer

The agent will immediately respond with a generative answer. Corresponds to the JSON property generativeAnswer



8449
8450
8451
# File 'lib/google/apis/ces_v1/classes.rb', line 8449

def generative_answer
  @generative_answer
end

#respond_immediatelyGoogle::Apis::CesV1::TriggerActionRespondImmediately

The agent will immediately respond with a preconfigured response. Corresponds to the JSON property respondImmediately



8454
8455
8456
# File 'lib/google/apis/ces_v1/classes.rb', line 8454

def respond_immediately
  @respond_immediately
end

#transfer_agentGoogle::Apis::CesV1::TriggerActionTransferAgent

The agent will transfer the conversation to a different agent. Corresponds to the JSON property transferAgent



8459
8460
8461
# File 'lib/google/apis/ces_v1/classes.rb', line 8459

def transfer_agent
  @transfer_agent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8466
8467
8468
8469
8470
# File 'lib/google/apis/ces_v1/classes.rb', line 8466

def update!(**args)
  @generative_answer = args[:generative_answer] if args.key?(:generative_answer)
  @respond_immediately = args[:respond_immediately] if args.key?(:respond_immediately)
  @transfer_agent = args[:transfer_agent] if args.key?(:transfer_agent)
end