Class: Google::Apis::CesV1::TriggerAction
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::TriggerAction
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Action that is taken when a certain precondition is met.
Instance Attribute Summary collapse
-
#generative_answer ⇒ Google::Apis::CesV1::TriggerActionGenerativeAnswer
The agent will immediately respond with a generative answer.
-
#respond_immediately ⇒ Google::Apis::CesV1::TriggerActionRespondImmediately
The agent will immediately respond with a preconfigured response.
-
#transfer_agent ⇒ Google::Apis::CesV1::TriggerActionTransferAgent
The agent will transfer the conversation to a different agent.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TriggerAction
constructor
A new instance of TriggerAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TriggerAction
Returns a new instance of TriggerAction.
7062 7063 7064 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7062 def initialize(**args) update!(**args) end |
Instance Attribute Details
#generative_answer ⇒ Google::Apis::CesV1::TriggerActionGenerativeAnswer
The agent will immediately respond with a generative answer.
Corresponds to the JSON property generativeAnswer
7050 7051 7052 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7050 def generative_answer @generative_answer end |
#respond_immediately ⇒ Google::Apis::CesV1::TriggerActionRespondImmediately
The agent will immediately respond with a preconfigured response.
Corresponds to the JSON property respondImmediately
7055 7056 7057 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7055 def respond_immediately @respond_immediately end |
#transfer_agent ⇒ Google::Apis::CesV1::TriggerActionTransferAgent
The agent will transfer the conversation to a different agent.
Corresponds to the JSON property transferAgent
7060 7061 7062 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7060 def transfer_agent @transfer_agent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7067 7068 7069 7070 7071 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7067 def update!(**args) @generative_answer = args[:generative_answer] if args.key?(:generative_answer) @respond_immediately = args[:respond_immediately] if args.key?(:respond_immediately) @transfer_agent = args[:transfer_agent] if args.key?(:transfer_agent) end |