Class: Google::Apis::CesV1::TriggerAction
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::TriggerAction
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Action that is taken when a certain precondition is met.
Instance Attribute Summary collapse
-
#generative_answer ⇒ Google::Apis::CesV1::TriggerActionGenerativeAnswer
The agent will immediately respond with a generative answer.
-
#respond_immediately ⇒ Google::Apis::CesV1::TriggerActionRespondImmediately
The agent will immediately respond with a preconfigured response.
-
#transfer_agent ⇒ Google::Apis::CesV1::TriggerActionTransferAgent
The agent will transfer the conversation to a different agent.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TriggerAction
constructor
A new instance of TriggerAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TriggerAction
Returns a new instance of TriggerAction.
6849 6850 6851 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6849 def initialize(**args) update!(**args) end |
Instance Attribute Details
#generative_answer ⇒ Google::Apis::CesV1::TriggerActionGenerativeAnswer
The agent will immediately respond with a generative answer.
Corresponds to the JSON property generativeAnswer
6837 6838 6839 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6837 def generative_answer @generative_answer end |
#respond_immediately ⇒ Google::Apis::CesV1::TriggerActionRespondImmediately
The agent will immediately respond with a preconfigured response.
Corresponds to the JSON property respondImmediately
6842 6843 6844 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6842 def respond_immediately @respond_immediately end |
#transfer_agent ⇒ Google::Apis::CesV1::TriggerActionTransferAgent
The agent will transfer the conversation to a different agent.
Corresponds to the JSON property transferAgent
6847 6848 6849 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6847 def transfer_agent @transfer_agent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6854 6855 6856 6857 6858 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6854 def update!(**args) @generative_answer = args[:generative_answer] if args.key?(:generative_answer) @respond_immediately = args[:respond_immediately] if args.key?(:respond_immediately) @transfer_agent = args[:transfer_agent] if args.key?(:transfer_agent) end |