Class: Google::Apis::CesV1::TriggerActionRespondImmediately

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

The agent will immediately respond with a preconfigured response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TriggerActionRespondImmediately

Returns a new instance of TriggerActionRespondImmediately.



7103
7104
7105
# File 'lib/google/apis/ces_v1/classes.rb', line 7103

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#responsesArray<Google::Apis::CesV1::TriggerActionResponse>

Required. The canned responses for the agent to choose from. The response is chosen randomly. Corresponds to the JSON property responses



7101
7102
7103
# File 'lib/google/apis/ces_v1/classes.rb', line 7101

def responses
  @responses
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7108
7109
7110
# File 'lib/google/apis/ces_v1/classes.rb', line 7108

def update!(**args)
  @responses = args[:responses] if args.key?(:responses)
end