Class: Google::Apis::CesV1::TriggerActionRespondImmediately
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::TriggerActionRespondImmediately
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
The agent will immediately respond with a preconfigured response.
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(**args) ⇒ TriggerActionRespondImmediately
constructor
A new instance of TriggerActionRespondImmediately.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TriggerActionRespondImmediately
Returns a new instance of TriggerActionRespondImmediately.
6890 6891 6892 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6890 def initialize(**args) update!(**args) end |
Instance Attribute Details
#responses ⇒ Array<Google::Apis::CesV1::TriggerActionResponse>
Required. The canned responses for the agent to choose from. The response is
chosen randomly.
Corresponds to the JSON property responses
6888 6889 6890 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6888 def responses @responses end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6895 6896 6897 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6895 def update!(**args) @responses = args[:responses] if args.key?(:responses) end |