Class: Google::Apis::CesV1::VpcScSettings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

VPC-SC settings for the app.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpcScSettings

Returns a new instance of VpcScSettings.



8522
8523
8524
# File 'lib/google/apis/ces_v1/classes.rb', line 8522

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowed_originsArray<String>

Optional. The allowed HTTP(s) origins that OpenAPI tools in the App are able to directly call when VPC Service Controls are enabled. These strings must match the origin exactly, including the port if specified. For example, "https: //example.com" or "https://example.com:443". This list does not yet apply to Python tools that may make direct HTTP calls. Corresponds to the JSON property allowedOrigins

Returns:

  • (Array<String>)


8520
8521
8522
# File 'lib/google/apis/ces_v1/classes.rb', line 8520

def allowed_origins
  @allowed_origins
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8527
8528
8529
# File 'lib/google/apis/ces_v1/classes.rb', line 8527

def update!(**args)
  @allowed_origins = args[:allowed_origins] if args.key?(:allowed_origins)
end