Class: Google::Apis::CesV1::WebSearchQuery

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Represents a single web search query and its associated search uri.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WebSearchQuery

Returns a new instance of WebSearchQuery.



8520
8521
8522
# File 'lib/google/apis/ces_v1/classes.rb', line 8520

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#queryString

The search query text. Corresponds to the JSON property query

Returns:

  • (String)


8513
8514
8515
# File 'lib/google/apis/ces_v1/classes.rb', line 8513

def query
  @query
end

#uriString

The URI to the Google Search results page for the query. Corresponds to the JSON property uri

Returns:

  • (String)


8518
8519
8520
# File 'lib/google/apis/ces_v1/classes.rb', line 8518

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8525
8526
8527
8528
# File 'lib/google/apis/ces_v1/classes.rb', line 8525

def update!(**args)
  @query = args[:query] if args.key?(:query)
  @uri = args[:uri] if args.key?(:uri)
end