Class: Google::Apis::CesV1::WebSearchQuery

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Represents a single web search query and its associated search uri.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WebSearchQuery

Returns a new instance of WebSearchQuery.



7525
7526
7527
# File 'lib/google/apis/ces_v1/classes.rb', line 7525

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#queryString

The search query text. Corresponds to the JSON property query

Returns:

  • (String)


7518
7519
7520
# File 'lib/google/apis/ces_v1/classes.rb', line 7518

def query
  @query
end

#uriString

The URI to the Google Search results page for the query. Corresponds to the JSON property uri

Returns:

  • (String)


7523
7524
7525
# File 'lib/google/apis/ces_v1/classes.rb', line 7523

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7530
7531
7532
7533
# File 'lib/google/apis/ces_v1/classes.rb', line 7530

def update!(**args)
  @query = args[:query] if args.key?(:query)
  @uri = args[:uri] if args.key?(:uri)
end