Class: Google::Apis::CesV1::WebSearchQuery
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::WebSearchQuery
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Represents a single web search query and its associated search uri.
Instance Attribute Summary collapse
-
#query ⇒ String
The search query text.
-
#uri ⇒ String
The URI to the Google Search results page for the query.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WebSearchQuery
constructor
A new instance of WebSearchQuery.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WebSearchQuery
Returns a new instance of WebSearchQuery.
6962 6963 6964 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6962 def initialize(**args) update!(**args) end |
Instance Attribute Details
#query ⇒ String
The search query text.
Corresponds to the JSON property query
6955 6956 6957 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6955 def query @query end |
#uri ⇒ String
The URI to the Google Search results page for the query.
Corresponds to the JSON property uri
6960 6961 6962 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6960 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6967 6968 6969 6970 |
# File 'lib/google/apis/ces_v1/classes.rb', line 6967 def update!(**args) @query = args[:query] if args.key?(:query) @uri = args[:uri] if args.key?(:uri) end |