Class: Google::Apis::CesV1::WidgetTool
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::WidgetTool
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Represents a widget tool that the agent can invoke. When the tool is chosen by the agent, agent will return the widget to the client. The client is responsible for processing the widget and generating the next user query to continue the interaction with the agent.
Instance Attribute Summary collapse
-
#data_mapping ⇒ Google::Apis::CesV1::WidgetToolDataMapping
Configuration for mapping data from a source tool to the widget's input parameters.
-
#description ⇒ String
Optional.
-
#name ⇒ String
Required.
-
#parameters ⇒ Google::Apis::CesV1::Schema
Represents a select subset of an OpenAPI 3.0 schema object.
-
#text_response_config ⇒ Google::Apis::CesV1::WidgetToolTextResponseConfig
Configuration for the text response returned with the widget.
-
#ui_config ⇒ Hash<String,Object>
Optional.
-
#widget_type ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WidgetTool
constructor
A new instance of WidgetTool.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WidgetTool
Returns a new instance of WidgetTool.
8624 8625 8626 |
# File 'lib/google/apis/ces_v1/classes.rb', line 8624 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_mapping ⇒ Google::Apis::CesV1::WidgetToolDataMapping
Configuration for mapping data from a source tool to the widget's input
parameters.
Corresponds to the JSON property dataMapping
8591 8592 8593 |
# File 'lib/google/apis/ces_v1/classes.rb', line 8591 def data_mapping @data_mapping end |
#description ⇒ String
Optional. The description of the widget tool.
Corresponds to the JSON property description
8596 8597 8598 |
# File 'lib/google/apis/ces_v1/classes.rb', line 8596 def description @description end |
#name ⇒ String
Required. The display name of the widget tool.
Corresponds to the JSON property name
8601 8602 8603 |
# File 'lib/google/apis/ces_v1/classes.rb', line 8601 def name @name end |
#parameters ⇒ Google::Apis::CesV1::Schema
Represents a select subset of an OpenAPI 3.0 schema object.
Corresponds to the JSON property parameters
8606 8607 8608 |
# File 'lib/google/apis/ces_v1/classes.rb', line 8606 def parameters @parameters end |
#text_response_config ⇒ Google::Apis::CesV1::WidgetToolTextResponseConfig
Configuration for the text response returned with the widget.
Corresponds to the JSON property textResponseConfig
8611 8612 8613 |
# File 'lib/google/apis/ces_v1/classes.rb', line 8611 def text_response_config @text_response_config end |
#ui_config ⇒ Hash<String,Object>
Optional. Configuration for rendering the widget.
Corresponds to the JSON property uiConfig
8616 8617 8618 |
# File 'lib/google/apis/ces_v1/classes.rb', line 8616 def ui_config @ui_config end |
#widget_type ⇒ String
Optional. The type of the widget tool. If not specified, the default type will
be CUSTOMIZED.
Corresponds to the JSON property widgetType
8622 8623 8624 |
# File 'lib/google/apis/ces_v1/classes.rb', line 8622 def @widget_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8629 8630 8631 8632 8633 8634 8635 8636 8637 |
# File 'lib/google/apis/ces_v1/classes.rb', line 8629 def update!(**args) @data_mapping = args[:data_mapping] if args.key?(:data_mapping) @description = args[:description] if args.key?(:description) @name = args[:name] if args.key?(:name) @parameters = args[:parameters] if args.key?(:parameters) @text_response_config = args[:text_response_config] if args.key?(:text_response_config) @ui_config = args[:ui_config] if args.key?(:ui_config) @widget_type = args[:widget_type] if args.key?(:widget_type) end |