Class: Google::Apis::CesV1::WidgetTool
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::WidgetTool
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Represents a widget tool that the agent can invoke. When the tool is chosen by the agent, agent will return the widget to the client. The client is responsible for processing the widget and generating the next user query to continue the interaction with the agent.
Instance Attribute Summary collapse
-
#data_mapping ⇒ Google::Apis::CesV1::WidgetToolDataMapping
Configuration for mapping data from a source tool to the widget's input parameters.
-
#description ⇒ String
Optional.
-
#name ⇒ String
Required.
-
#parameters ⇒ Google::Apis::CesV1::Schema
Represents a select subset of an OpenAPI 3.0 schema object.
-
#text_response_config ⇒ Google::Apis::CesV1::WidgetToolTextResponseConfig
Configuration for the text response returned with the widget.
-
#ui_config ⇒ Hash<String,Object>
Optional.
-
#widget_type ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WidgetTool
constructor
A new instance of WidgetTool.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WidgetTool
Returns a new instance of WidgetTool.
7580 7581 7582 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7580 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_mapping ⇒ Google::Apis::CesV1::WidgetToolDataMapping
Configuration for mapping data from a source tool to the widget's input
parameters.
Corresponds to the JSON property dataMapping
7547 7548 7549 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7547 def data_mapping @data_mapping end |
#description ⇒ String
Optional. The description of the widget tool.
Corresponds to the JSON property description
7552 7553 7554 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7552 def description @description end |
#name ⇒ String
Required. The display name of the widget tool.
Corresponds to the JSON property name
7557 7558 7559 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7557 def name @name end |
#parameters ⇒ Google::Apis::CesV1::Schema
Represents a select subset of an OpenAPI 3.0 schema object.
Corresponds to the JSON property parameters
7562 7563 7564 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7562 def parameters @parameters end |
#text_response_config ⇒ Google::Apis::CesV1::WidgetToolTextResponseConfig
Configuration for the text response returned with the widget.
Corresponds to the JSON property textResponseConfig
7567 7568 7569 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7567 def text_response_config @text_response_config end |
#ui_config ⇒ Hash<String,Object>
Optional. Configuration for rendering the widget.
Corresponds to the JSON property uiConfig
7572 7573 7574 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7572 def ui_config @ui_config end |
#widget_type ⇒ String
Optional. The type of the widget tool. If not specified, the default type will
be CUSTOMIZED.
Corresponds to the JSON property widgetType
7578 7579 7580 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7578 def @widget_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7585 7586 7587 7588 7589 7590 7591 7592 7593 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7585 def update!(**args) @data_mapping = args[:data_mapping] if args.key?(:data_mapping) @description = args[:description] if args.key?(:description) @name = args[:name] if args.key?(:name) @parameters = args[:parameters] if args.key?(:parameters) @text_response_config = args[:text_response_config] if args.key?(:text_response_config) @ui_config = args[:ui_config] if args.key?(:ui_config) @widget_type = args[:widget_type] if args.key?(:widget_type) end |