Class: Google::Apis::CesV1::WidgetTool

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Represents a widget tool that the agent can invoke. When the tool is chosen by the agent, agent will return the widget to the client. The client is responsible for processing the widget and generating the next user query to continue the interaction with the agent.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WidgetTool

Returns a new instance of WidgetTool.



7253
7254
7255
# File 'lib/google/apis/ces_v1/classes.rb', line 7253

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_mappingGoogle::Apis::CesV1::WidgetToolDataMapping

Configuration for mapping data from a source tool to the widget's input parameters. Corresponds to the JSON property dataMapping



7220
7221
7222
# File 'lib/google/apis/ces_v1/classes.rb', line 7220

def data_mapping
  @data_mapping
end

#descriptionString

Optional. The description of the widget tool. Corresponds to the JSON property description

Returns:

  • (String)


7225
7226
7227
# File 'lib/google/apis/ces_v1/classes.rb', line 7225

def description
  @description
end

#nameString

Required. The display name of the widget tool. Corresponds to the JSON property name

Returns:

  • (String)


7230
7231
7232
# File 'lib/google/apis/ces_v1/classes.rb', line 7230

def name
  @name
end

#parametersGoogle::Apis::CesV1::Schema

Represents a select subset of an OpenAPI 3.0 schema object. Corresponds to the JSON property parameters



7235
7236
7237
# File 'lib/google/apis/ces_v1/classes.rb', line 7235

def parameters
  @parameters
end

#text_response_configGoogle::Apis::CesV1::WidgetToolTextResponseConfig

Configuration for the text response returned with the widget. Corresponds to the JSON property textResponseConfig



7240
7241
7242
# File 'lib/google/apis/ces_v1/classes.rb', line 7240

def text_response_config
  @text_response_config
end

#ui_configHash<String,Object>

Optional. Configuration for rendering the widget. Corresponds to the JSON property uiConfig

Returns:

  • (Hash<String,Object>)


7245
7246
7247
# File 'lib/google/apis/ces_v1/classes.rb', line 7245

def ui_config
  @ui_config
end

#widget_typeString

Optional. The type of the widget tool. If not specified, the default type will be CUSTOMIZED. Corresponds to the JSON property widgetType

Returns:

  • (String)


7251
7252
7253
# File 'lib/google/apis/ces_v1/classes.rb', line 7251

def widget_type
  @widget_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7258
7259
7260
7261
7262
7263
7264
7265
7266
# File 'lib/google/apis/ces_v1/classes.rb', line 7258

def update!(**args)
  @data_mapping = args[:data_mapping] if args.key?(:data_mapping)
  @description = args[:description] if args.key?(:description)
  @name = args[:name] if args.key?(:name)
  @parameters = args[:parameters] if args.key?(:parameters)
  @text_response_config = args[:text_response_config] if args.key?(:text_response_config)
  @ui_config = args[:ui_config] if args.key?(:ui_config)
  @widget_type = args[:widget_type] if args.key?(:widget_type)
end