Class: Google::Apis::CesV1::WidgetToolDataMapping
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::WidgetToolDataMapping
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Configuration for mapping data from a source tool to the widget's input parameters.
Instance Attribute Summary collapse
-
#field_mappings ⇒ Hash<String,String>
Optional.
-
#mode ⇒ String
Optional.
-
#python_function ⇒ Google::Apis::CesV1::PythonFunction
A Python function tool.
-
#python_script ⇒ String
Deprecated: Use
python_functioninstead. -
#source_tool_name ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WidgetToolDataMapping
constructor
A new instance of WidgetToolDataMapping.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WidgetToolDataMapping
Returns a new instance of WidgetToolDataMapping.
7629 7630 7631 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7629 def initialize(**args) update!(**args) end |
Instance Attribute Details
#field_mappings ⇒ Hash<String,String>
Optional. A map of widget input parameter fields to the corresponding output
fields of the source tool.
Corresponds to the JSON property fieldMappings
7605 7606 7607 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7605 def field_mappings @field_mappings end |
#mode ⇒ String
Optional. The mode of the data mapping.
Corresponds to the JSON property mode
7610 7611 7612 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7610 def mode @mode end |
#python_function ⇒ Google::Apis::CesV1::PythonFunction
A Python function tool.
Corresponds to the JSON property pythonFunction
7615 7616 7617 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7615 def python_function @python_function end |
#python_script ⇒ String
Deprecated: Use python_function instead.
Corresponds to the JSON property pythonScript
7620 7621 7622 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7620 def python_script @python_script end |
#source_tool_name ⇒ String
Optional. The resource name of the tool that provides the data for the widget (
e.g., a search tool or a custom function). Format: projects/project/
locations/location/agents/agent/tools/tool`
Corresponds to the JSON propertysourceToolName`
7627 7628 7629 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7627 def source_tool_name @source_tool_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7634 7635 7636 7637 7638 7639 7640 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7634 def update!(**args) @field_mappings = args[:field_mappings] if args.key?(:field_mappings) @mode = args[:mode] if args.key?(:mode) @python_function = args[:python_function] if args.key?(:python_function) @python_script = args[:python_script] if args.key?(:python_script) @source_tool_name = args[:source_tool_name] if args.key?(:source_tool_name) end |