Class: Google::Apis::CesV1::WidgetToolDataMapping

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Configuration for mapping data from a source tool to the widget's input parameters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WidgetToolDataMapping

Returns a new instance of WidgetToolDataMapping.



7302
7303
7304
# File 'lib/google/apis/ces_v1/classes.rb', line 7302

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#field_mappingsHash<String,String>

Optional. A map of widget input parameter fields to the corresponding output fields of the source tool. Corresponds to the JSON property fieldMappings

Returns:

  • (Hash<String,String>)


7278
7279
7280
# File 'lib/google/apis/ces_v1/classes.rb', line 7278

def field_mappings
  @field_mappings
end

#modeString

Optional. The mode of the data mapping. Corresponds to the JSON property mode

Returns:

  • (String)


7283
7284
7285
# File 'lib/google/apis/ces_v1/classes.rb', line 7283

def mode
  @mode
end

#python_functionGoogle::Apis::CesV1::PythonFunction

A Python function tool. Corresponds to the JSON property pythonFunction



7288
7289
7290
# File 'lib/google/apis/ces_v1/classes.rb', line 7288

def python_function
  @python_function
end

#python_scriptString

Deprecated: Use python_function instead. Corresponds to the JSON property pythonScript

Returns:

  • (String)


7293
7294
7295
# File 'lib/google/apis/ces_v1/classes.rb', line 7293

def python_script
  @python_script
end

#source_tool_nameString

Optional. The resource name of the tool that provides the data for the widget ( e.g., a search tool or a custom function). Format: projects/project/ locations/location/agents/agent/tools/tool` Corresponds to the JSON propertysourceToolName`

Returns:

  • (String)


7300
7301
7302
# File 'lib/google/apis/ces_v1/classes.rb', line 7300

def source_tool_name
  @source_tool_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7307
7308
7309
7310
7311
7312
7313
# File 'lib/google/apis/ces_v1/classes.rb', line 7307

def update!(**args)
  @field_mappings = args[:field_mappings] if args.key?(:field_mappings)
  @mode = args[:mode] if args.key?(:mode)
  @python_function = args[:python_function] if args.key?(:python_function)
  @python_script = args[:python_script] if args.key?(:python_script)
  @source_tool_name = args[:source_tool_name] if args.key?(:source_tool_name)
end