Class: Google::Apis::CesV1::WidgetToolTextResponseConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Configuration for the text response returned with the widget.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WidgetToolTextResponseConfig

Returns a new instance of WidgetToolTextResponseConfig.



8733
8734
8735
# File 'lib/google/apis/ces_v1/classes.rb', line 8733

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#static_textString

Optional. The static text response to return when type is STATIC. Corresponds to the JSON property staticText

Returns:

  • (String)


8720
8721
8722
# File 'lib/google/apis/ces_v1/classes.rb', line 8720

def static_text
  @static_text
end

#text_response_instructionString

Optional. Instruction for the LLM on how to generate the text response. Used as the description for the text response parameter if type is LLM_GENERATED. Corresponds to the JSON property textResponseInstruction

Returns:

  • (String)


8726
8727
8728
# File 'lib/google/apis/ces_v1/classes.rb', line 8726

def text_response_instruction
  @text_response_instruction
end

#typeString

Optional. The strategy for providing the text response. Corresponds to the JSON property type

Returns:

  • (String)


8731
8732
8733
# File 'lib/google/apis/ces_v1/classes.rb', line 8731

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8738
8739
8740
8741
8742
# File 'lib/google/apis/ces_v1/classes.rb', line 8738

def update!(**args)
  @static_text = args[:static_text] if args.key?(:static_text)
  @text_response_instruction = args[:text_response_instruction] if args.key?(:text_response_instruction)
  @type = args[:type] if args.key?(:type)
end