Class: Google::Apis::CesV1::WidgetToolTextResponseConfig
- Inherits:
-
Object
- Object
- Google::Apis::CesV1::WidgetToolTextResponseConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb
Overview
Configuration for the text response returned with the widget.
Instance Attribute Summary collapse
-
#static_text ⇒ String
Optional.
-
#text_response_instruction ⇒ String
Optional.
-
#type ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WidgetToolTextResponseConfig
constructor
A new instance of WidgetToolTextResponseConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WidgetToolTextResponseConfig
Returns a new instance of WidgetToolTextResponseConfig.
7336 7337 7338 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7336 def initialize(**args) update!(**args) end |
Instance Attribute Details
#static_text ⇒ String
Optional. The static text response to return when type is STATIC.
Corresponds to the JSON property staticText
7323 7324 7325 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7323 def static_text @static_text end |
#text_response_instruction ⇒ String
Optional. Instruction for the LLM on how to generate the text response. Used
as the description for the text response parameter if type is LLM_GENERATED.
Corresponds to the JSON property textResponseInstruction
7329 7330 7331 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7329 def text_response_instruction @text_response_instruction end |
#type ⇒ String
Optional. The strategy for providing the text response.
Corresponds to the JSON property type
7334 7335 7336 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7334 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7341 7342 7343 7344 7345 |
# File 'lib/google/apis/ces_v1/classes.rb', line 7341 def update!(**args) @static_text = args[:static_text] if args.key?(:static_text) @text_response_instruction = args[:text_response_instruction] if args.key?(:text_response_instruction) @type = args[:type] if args.key?(:type) end |