Class: Google::Apis::CesV1::WidgetToolTextResponseConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/ces_v1/classes.rb,
lib/google/apis/ces_v1/representations.rb,
lib/google/apis/ces_v1/representations.rb

Overview

Configuration for the text response returned with the widget.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WidgetToolTextResponseConfig

Returns a new instance of WidgetToolTextResponseConfig.



7100
7101
7102
# File 'lib/google/apis/ces_v1/classes.rb', line 7100

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#static_textString

Optional. The static text response to return when type is STATIC. Corresponds to the JSON property staticText

Returns:

  • (String)


7087
7088
7089
# File 'lib/google/apis/ces_v1/classes.rb', line 7087

def static_text
  @static_text
end

#text_response_instructionString

Optional. Instruction for the LLM on how to generate the text response. Used as the description for the text response parameter if type is LLM_GENERATED. Corresponds to the JSON property textResponseInstruction

Returns:

  • (String)


7093
7094
7095
# File 'lib/google/apis/ces_v1/classes.rb', line 7093

def text_response_instruction
  @text_response_instruction
end

#typeString

Optional. The strategy for providing the text response. Corresponds to the JSON property type

Returns:

  • (String)


7098
7099
7100
# File 'lib/google/apis/ces_v1/classes.rb', line 7098

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7105
7106
7107
7108
7109
# File 'lib/google/apis/ces_v1/classes.rb', line 7105

def update!(**args)
  @static_text = args[:static_text] if args.key?(:static_text)
  @text_response_instruction = args[:text_response_instruction] if args.key?(:text_response_instruction)
  @type = args[:type] if args.key?(:type)
end